// Program:  AstroNavig-V13ios.c    based on AstroNavig-13.c
// Authors:  Heiner Mueller-Krumbhaar and Henning Umland
//
// Results agree with Astronomical_Almanac_v1.06.htm by H.Umland, 22. june 2021
// NOTE: This program-version vor Apple-IOS requires file astronavtab911.dat for the moon-data LEA406b.
// Former Versions ASTRONAV-U34stars3.c  19 March 2021,   now 10 May 2021
// COPYRIGHT: check below section E) COPYRIGHT.

/*
For C-compiler under WINDOWS see e.g.:  https://www.chip.de/downloads/Orwell-Dev-C_58134498.html
this is the former Dev-CPP-compiler and Integrated-Development-Environment (GNU-compiler).
For generating an ANDROID-APP on mobile phone, see: C4droid-APP, in Google or Samsung-stores.
For C-Compiler under Apple-IOS (Ipad,Iphone) see: Mobile C [C/C++ Compiler] by Jeong Seop Lee.
(they have been tested on Windows-64-PC, Samsung-Galaxy-s10e and Apple-ipad and Apple-iphone)

A) Purpose and usage of the Program: 
This program calculates the position of a ship at sea, given precise time and 
two observations of celestial bodies like sun,moon, planet (venus to saturn) or bright stars.
Default-values are set after the line containing the word: "initconditions".

Two observations of celestial bodies at different azimuths are needed. Furthermore an estimate for
the position of the first observation is needed.
If the second observation is made after sailing a distance, course and velocity of that displacement
should be given ("Versegelung"). It seems that it may be sufficient to estiamte the approximate
position only roughly within about +- 20 degrees north-south or east-west. 
The first run of the program then may be iterated (by just hitting the RETURN key), until the deviation
between estimated and final position is below 2 nautical miles.
Values for temperature and air-pressure, relevant for refraction of light, can be adjusted if necessary.
The value of Delta-T, time difference between TT and UTC, is given for all times until 2020
according to Fred Espenak of NASA and actually IERS. Extrapolation for > 2020 into the future is provided 
similar to USNO-MICA or IERS-estimates, adapted from Paul Hirose. Actual values can be adjusted by user!
In addition, file astronav0x0.txt contains the data "year dT-seconds" used for Delta_T for year>2020.
This file -0x0.txt is produced automatically, but while existent it may be modified by user!
(Note: The responsibility for crude C-language formulations throughout and for errors and programming 
oddities in the navigational parts of this program is solely resting with H. Mueller-Krumbhaar). 

B) Sources of information used in this program: 
The position of all celestial objects sun, moon, planets and stars are calculated within this program,
without needing access to internet. 
Basis for these so called "Ephemerides" are professional data, coming from the following sources:

The basic program follows Jean Meeus's famous book "Astronomical Algorithms" (see References below).
The ephemerides for sun, moon, planets and stars within our program are computed in 
the functions suneph(), mooneph(), planetseph(), starseph(). Input/output via their parameterlists.
Ephemeris for Sun and Planets come from series-expansions VSOP87D by famous P.Bretagnon and G.Francou, France.
The data were claimed to be good within about 1 arc-second (further information about precison below).
The position algorithm for sun, originally following Jean Meeus book p.165ff, was later replaced by
VSOP87D-Ephemeris, and for the Stars by the FK5-Fnfter-Fundamentalkatalog, (Astron.Rechen-Instit.Heidelberg).
The Moon is somewhat special. Tables came from Chapront, Chapront-Touze, Francou, and later
the precision table ELPMPP02 from J.Chapront and G.Francou 2002. But here we use program and precision-data
LEA406b by Sergey M. Kudryavtsev, Moscow, A&A 471, 1069-1075 (2007), tables 9.dat to 11.dat. The precision
was shown to be substantially higher than VSOP87, and should at least be comparable to ELPMPP02.("tau0").
Delta-T is now following the United Kingdom Hydrographic office, based (as also JPL-DE441) on 
the publication: Proceedings of the Royal Society A, 472, by F.Stephenson, L.Morrison and C.Hohenkerk,
to be found at: https://astro.ukho.gov.uk/nao/lvm/
A small correction in Delta-T (JDE moon only) for years > 2700 maintains precision with JPL-Model DE441.
Finally, previous JAVASCRIPT-programs of Henning Umland, given in: https://CELNAV.DE, specifically the
Astronomical-Almanac-105.htm (and predecessors) were used for quantitative comparison down to machine-precision.
Umlands program already contained the full VSOP87 data for sun and planets, FK5 for stars, 
and for moon the shortened List of Chapront ELP2000/82, all given in a form easily transferable to C-language. 
In reverse, LEA406b data by Kudryavtsev for the moon have been integrated into H.Umlands actual version.  
Nutation here was given based on either Model IAU 1980 or IAU-2000-B. Actually, we now use IAU 1980, 
as it is simpler and deviates only marginally from IAU2003B according to our experience. For stars and
years 2050 and beyond we compared our results to the Windows-program aa56.exe by Stephen L. Moshier. 
We thank S.M. Kudryavtsev and S.L. Moshier for constructive email-exchange.

C) PRECISION:
According to "Explanatory Supplements to the Astronomical Almanac" by IAU 2013 (UKHO & USNO), Chapter 8,
by E.Standish and J.Williams, by year 2003 the fundamental planetary and lunar ephemerides DE405/LE405 
come from Caltech's Jet Propulsion Laboratory (=JPL). Their present model (year 2021) DE441 is implemented  
in the NASA-JPL-HORIZONS program. It differs only slightly from the previous version DE431.
Our code agrees within ~1 arcsec for years 1800-2200) and ~3 arcsecs up to year 3500, given Delta-T=TT-UT1. 
This NASA-JPL-Horizons-Model DE441 is our standard reference for the solar system.
As the JPL-DE441 model does not cover the position and motion of stars, we use ICE.51 =
Interactive Computer Ephemeris 0.51 (ICE) by U.S. Naval Observatory (1980), since the web-pages of
https://www.usno.navy.mil/USNO/astronomical-applications are currently under reconstruction.
Finally, a private web-site www.moshier.net offers with "aa-56.exe" a rather precise ephemeris software.
Those algorithms are from US Astronomical Almanac and are claimed to agree from 1987 onwards (JPL-Model DE200), 
(checked by us against ICE and JPL-HORIZONS), applicable over hundreds of years. 
Our results originally agreed exactly with J.Meeus, p.136, p.153, p.169, p.227 and p.342,343 etc.  
Meanwhile we have advanced and tested our program in detail. Comparison with JPL-HORIZONS over selected dates 
in years 500AD, 1000, 1500, 1700, 2020, 2045, 2200, 3500, and with ICE over years 1900-2045 (ends before 2050), 
and with aa56.exe in years 2020, 2045, 2200, 3500 showed only small deviations for all celestial bodies.
Conclusion: Our program here is expected to agree with the above-mentioned precision programs 
within +- 1 arcsecond for RA and DEC for the period from year 1800 until the year 2200.
Beyond those limits but within years 500 to 3500, the precision is still better than +- 10 arcseconds.
NOTE: Precision is defined for GHA*cosine(DEC) etc., not for GHA alone, due to the singularity for DEC=+-90!
The FINAL output also gives SUN_Rise/Set, Azimuth(d), civil Dawn(min), but only about 2 minutes precise.

The navigational aspects "position line navigation" was checked against: 
Kumm,Lbbers,Schultz: bungen SHS, II.Astronav, "Sonne und Mond", p.25
and against Helmut Knopp,, Astronomische Navigation, Beispiel II, and further examples contained therein.

WARNING: No guarantee whatsoever for the quality of the program. Use at your own risk.

D) REFERENCES:
- Astronomical Algorithms, by Jean Meeus, published by Willmann-Bell Inc., edition 2005.
  (Mid of october 2020 I had a friendly phone-chat with Mr. Perry Remaklus, 80+-year old owner of Willmann Bell,
   about the status of an order. It is a pity, that a few days later Willmann Bell stopped their business).  
- www.CELNAV.de, "LONG-TERM ALMANAC FOR SUN, MOON, BRIGHTER PLANETS, AND POLARIS-1.20.htm" by Henning Umland.
  and: "Long-term...STARS...V-1.16.htm". Updates agree with the present program.
- VSOP87D:  https://github.com/ctdk/vsop87;  by Bretagnon et Francou, 
  and Jay Tanner: http://neoprogrammics.com/vsop87/source_code_generator_tool/
- Interactive Computer Ephemeris 0.51 (ICE) by U.S. Naval Observatory (1980).
- Stephen (Steve) L. Moshier: www.moshier.net, aa-56.zip; and: Astronomy and Astrophysics 262, 613-616 (1992).
- IAU1980 Nutation series: https://hpiers.obspm.fr/eop-pc/models/nutations/nut_IAU1980.dat, and:
  https://www.iers.org/IERS/EN/Publications/TechnicalNotes/tn21.html?nn=12932 
- IAU-2000-B Nutation series: Dennis McCarthy and Brian LUZUM, 
  from: Celestial Mechanics and Dynamical Astronomy 85, p.37-49, 2003. Precision < 0.001 arcsec.
- LEA406 - MOON-data by S. Kudryavtsev: A&A 471, 10691075 (2007): 
  Tables 6-11:  http://cdsweb.u-strasbg.fr/cgi-bin/qcat?J/A+A/471/1069 (very useful)
- Delta-T: https://astro.ukho.gov.uk/nao/lvm/ (see above).

E) COPYRIGHT:
You may use this program under the "GNU General Public License" (easy to identify in internet).
Any part of this program here may be subject to further copyright conditions by authors or from 
references mentioned above. You are responsible to fulfill those conditions also.
If you become aware of further copyright conditions, please let us know.

##############################################################################
WARNING: This program is NOT intended for tutorial purposes! 
The program was never designed as an entity, but grew out of a one-page FORTRAN-program: 
Formulas for sun-ephemeris by Albrand and Junge, Formeln fr Navigation,
and kept growing and diversifying over the years.
############################################################################## 
*/

#include<stdio.h>
#include<stdlib.h>
#include<conio.h>
#include<math.h>
#include<string.h>
  
//cccccccccccccccccccccccccc MOON LEA406 KUDRYAVTSEV  ccccccccccccccccccccccccccc  
 // MOON  LEA-406  KUDRYAVTSEV cccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccc subroutine MOON LE-406b -cccccccccccccccccccccccc

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
double norm360( double xxx )
// Normalize angles to 0..360 degrees
{
    double jg;
    double r,z, h1;
    r=360.;
    z=xxx;
    
    if(z<0)
    {
     z=fabs(z);
	 jg=floor(z/r);
	 z=z -jg*r;
	 z=-z;	
	}
    
    while (z<0.) {
      z=z+r;
	}
    jg=floor(z/r); 
    z=z - jg*r;
    return z;
};

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
double dmod(double x,double  y)
{
    // keep x within 0..+y radians or degrees
    double  ix,rx,s;

    if(y<0) y=-y;
    s=1;
    if(x<0) s=-1;
    x=s*x;  // =abs(x)

    ix=floor(x/y);
    rx=x-ix*y;
    rx=s*rx;
    if(rx<0) rx=rx+y;
    x=s*x; // =orig x

    return rx;
};
//cccccccccccccccccccccccccccccccc hmk-addition ccccccccccccccccccccccccc
// --------------------------------------------
double dmodz(double x, double y)
{
    //c keep x within 0..360 degrees
    // implicit double(a - h, o - z
    double  h,rx;
    int ix;   
    ix=x/y;
    rx=(x-ix*y);
    return rx;
};



//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

double julday( int year, int month, int day, int hour, int min, int sec )
//Calculate Julian Day
{
    double jd, y, m , d, ut;
    double a,b;
    
    ut= hour+min/60.+sec/3600.;
    d= day+ut/24.;
    
    y = year;
    m = month;   
	//printf("JULDAY: y,m,d. %f %f %f\n",y,m,d); 

    if ( m < 3) 
	 {
	  	y=year-1; 
		m=month+12;
	 }
	
	a = floor(y/100.);
	b = 2.-a+floor(a/4.) ;
	
	if(y < 1583)  b=0.; 
	
	jd = floor(365.25*(y+4716)) + floor(30.6001*(m+1)) + d + b -1524.5;
	
	//printf("JULDAY:  a,b,jd: %f %f %f\n", a,b,jd);	
    return(jd);
};

//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccc original subroutine lea406 cccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

void LEA406(double JDE,double *qLON,double *qLAT,double *qRAD) //This is the Main Subroutine !
{  
    //c     this subroutine reads the lea-406 lunar analytical series and
    //c     gives the geocentric position of the moon referenced to
    //c     the earth mean equator and equinox of j2000.
    //c
    //c     calling sequence parameters:
    //c
    //c       tdb = input 2-word d.p. julian date (tdb) at which lunar position is wanted.
    //c       tdb(1)=2451545.
    //c       tdb(2)=1.
    //c       model=1
    //c
    //c       call lea406(tdb, model, p)
    //c
    //c       version 1.1 (august 9, 2007)
    
    const int naux0=3;
	const int n8rec = 1800;  // note: original 11200
	FILE *fptr911, *fptr9, *fptr10, *fptr11;  //Pointers for files 9,10,11
	char strx[150];
	
	double aux0[naux0], tdb[4];
	double a_r[n8rec], at_r[n8rec], att_r[n8rec];
	double  tdb_0[3], p[5], p0[4], p1[4];
	double pi = 6.283185307179586;
    double radeg = 1.7453292519943296*1.e-2;
    double rasec = 4.8481368110953599*1.e-6;
    double dtc,dtm,frm0,r,arg,v,u;
    
    double pimk,vmk,umk,rmk,dpsi8,vmknut,svmk,sumk,chlon8,chdec8;
    int    idvmk,imvmk,isvmk,idumk,imumk,isumk;
    
    int modelcur = -1, loaddata;
	int ind[15];
	int i,j,k,l,m,n,model;
    int i_r,i_v,i_u;
    int ntab9,ntab10,ntab11;
    int jz,jz0,ka,ke,ires;
    
   //..................................................................................
   
   // NASA-JetPropulsionLab has issued model DE441. 
   // For datum year>2700 or year<1300 we therefore introduce a correction to MOON data only = JDEdif.
   // NOTE: difference from Almanac106c.html: here we do nat have JD but only JDE!
    double jdlow=2720304.5,  jd3500=2999498.5,  jd0500=1903773.5,  jd1300=2195773.5 ;
    double JDEdif0=40/86400.0; // = 40 seconds Delta_T correction for year 3500 and beyond, moon only
    double JDEdif;   
   // this is the JPL-model-DE441correction for years 2700.. 3500, affecting only the moon:
     JDEdif=JDEdif0 *(JDE-jdlow)/(jd3500-jdlow);   // JD between jdlow and 3500, but here JDE,as no JD available
      if(JDE < jdlow   ) JDEdif=0;
      if(JDE > jd3500) JDEdif=JDEdif0;
      
      if(JDE < jd1300) {
          JDEdif0=28/86400.0;  // = 28 seconds Delta_T correction for year 0500, linear down from 1300, moon only 
          JDEdif= - JDEdif0 *(JDE-jd1300)/(jd0500-jd1300);   // JD between jd1300 and jd0500 (JDE here instead of JD)
        }

    //dtc = (JDEdif+ JDE-2451545.)/36525. ;  // from Javascript! time difference in centuries;

	tdb[1]=JDE + JDEdif; // historic, TDB not really necessary, but we leave it better here.
    //END of NASA-JPL-DE441.correction = JDEdif. To remove corrrection, set JDEdif=0.

//..................................................................................
    
	tdb[2]=0.;
	tdb[3]=0.;
	        
	  double sumfr,sumfrm;
      double frm[5];
      double fr[5][16];
      
      double qfr[16][5] = {    	// Basis of Moon-Files table9.dat-table11.dat from Kudryavtsev
	  { 252.25090552 , 538101628.688982 , -0.0192789 , 0.00000639 , 0.},
      {181.97980085 , 210664136.433548 , 0.0059381 , -0.00000627 ,  0.},
      {100.46645683 , 129597742.283429 , -0.0204411 ,  -.00000523 , 0. },
      {355.43299958 , 68905077.493988 , 0.0094264 ,  -.00001043 , 0. },
      { 34.35151874 , 10925660.377991 , -0.3060378 ,  0.00005706 , .000004667 },
      { 50.07744430 , 4399609.855732 ,  0.7561614 ,  -.00016618 , -.000011484 },
      {314.05500511 , 1542481.193933 , -0.0175083 ,  0.00002156 , 0. },
      {304.34866548 , 786550.320744 ,  0.0021103 , -0.00000895 ,  0. },
      {125.04455501 , -6967919.3631 , 6.3602 ,   .007625 ,  -.00003586 },
      {297.85019547 , 1602961601.2090 , -6.3706 , 0.006593 ,-0.00003169 },
      {357.52910918 , 129596581.0481 , -0.5532 , 0.000136 ,-0.00001149 },
      {134.96340251 , 1717915923.2178 , 31.8792 , 0.051635 ,-0.00024470 },
      { 93.27209062 , 1739527262.8478 ,-12.7512 ,-0.001037 , 0.00000417 },
      { 0., 5028.82 , 1.112022 , 0.0000773 , -0.00002353 },
      {218.31664563 , 1732564372.30470 ,-5.2790 , 0.006665 ,-0.00005522 }
      }; //warning: last line is not qfr but corresponds to frm.

    model=1; // historic, but needed for simlified version LEA406b

	//printf("\n\n Subroutine LEA406 MOON-ephemerides Start...\n\n");
	
    //DEFINE ARRAYS FR and FRM
	//printf(" check Array-Erfassung, convert to FR[...]\n\n");
    for (i=0; i<=4; ++i) // tranfer from qfr to fr
	{
	for (j=1; j<=15; ++j)
	 { 
  		fr[i][j] = qfr[j-1][i];
  		if(j==15) frm[i]=fr[i][j];
	 } 
	}	//Now array FR[i][j] and array FRM[j]  are defined !

//..........................................................................................................
    //Lenght of tables: ntab9=1029;  ntab10= 1753; ntab11= 1089;
    ntab9=1029;  ntab10= 1753; ntab11= 1089;
    tdb_0[1] = 2451545.;
    tdb_0[2] = 0. ;    // initial epoch(j2000.0);   
    //c
    //c check if the model and input epoch are consistent
    //c
    if (model == 1)  // This is a historic leftover, no other value allowed   
	{ 
        if ((tdb[1] + tdb[2]) < 625673.5 || (tdb[1] + tdb[2]) > 2816787.5) 
        {
            printf(" ! input epoch is outside the time-interval\n"); 
			printf(" where the LEA-406b series are precise!\n");
            printf(" Range 625674..2816787, JDE=%f\n",tdb[1]);
			//getchar();
        }
    } else exit(9);
    //c
    //c calculation of time difference between the input epoch and initial epoch
    //c    
	dtc = (tdb[1]-tdb_0[1]+tdb[2])/36525. ;  // time difefrence in tdb centuries;
    dtm = dtc/10.;                                 //  time difefrence in tdb millenniums;        
    //c
    //c subsequent reading the data arrays if the model is changed.
    //c    
    if (model == 1) 
    { // simplified analytical series lea - 406b are used
        //printf(">>CHECK-3\n");         
         //c reading simplified series for coordinate r (lunar distance)
        //printf(">>CHECK-4\n");    
    
        //Lenght of tables: ntab9=1029;  ntab10= 1753; ntab11= 1089;
     ntab9=1029;  ntab10= 1753; ntab11= 1089;  
	        
	// TABLES 9-11 in File astronavtab911.dat    -  original call: //fptr9=fopen("ctable9.dat","r");	  
	 fptr911=fopen("astronavtab911.dat","r");
	 if(fptr911==NULL)
   {
      printf(" Datei astonavtab911 existiert nicht!\n"); 
	  vmk=0; umk=0; rmk=0;
	  goto g999;
   }
   
	 rewind(fptr911);		  
	    ntab9=909; ntab10=910; ntab11=911;
	 fscanf(fptr911,"%d %d %d %s\n", &ntab9,&ntab10,&ntab11, strx);  
	 //printf(">> ntab9,10,11=%d %d %d %s \n",ntab9,ntab10,ntab11,strx); 	 	 

	// r-ARRAYS		  	
      double c_r[n8rec], ct_r[n8rec], ctt_r[n8rec];  
	  double f0_r[n8rec], f1_r[n8rec], f2_r[n8rec], f3_r[n8rec], f4_r[n8rec];
      
	 i=0;    		     
	 while (i < ntab9)  // max: ntab9
      { i=i+1;
	    fscanf(fptr911,"%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d  %lf %lf %lf %lf %lf %lf \n",
		&k, &ind[12], &ind[11], &ind[13], &ind[10], &ind[9], 
		&ind[1], &ind[2], &ind[3], &ind[4], &ind[5], &ind[6], &ind[7], &ind[8], &ind[14],
		&a_r[i], &at_r[i], &att_r[i], &c_r[i], &ct_r[i], &ctt_r[i]);
			   
	   /* //CONTROl fscanf:
	    printf(">> i..ind[14]: %d  %d %d %d %d %d ",k, ind[12], ind[11], ind[13], ind[10], ind[9]);
		printf(" %d %d %d %d %d %d %d %d %d \n",
		 ind[1], ind[2], ind[3], ind[4], ind[4], ind[6], ind[7], ind[8], ind[14] );
		printf("   a_r[i]..ctt_r[i]]: %f %f %f %f %f %f\n", a_r[i], at_r[i], att_r[i], c_r[i], ct_r[i], ctt_r[i] );
	   */ 	        
        c_r[i] = c_r[i]*radeg;
        ct_r[i] = ct_r[i]*radeg;
        ctt_r[i] = ctt_r[i]*radeg;
        //c
        //c calculating the arguments [rad]
        //c
        f0_r[i] = 0.;
        f1_r[i] = 0.;
        f2_r[i] = 0.;
        f3_r[i] = 0.;
        f4_r[i] = 0.;
        
        for(k=1; k<=14; k++) // k<=14
		{
        f0_r[i] = f0_r[i] + ind[k]*fr[0][k];
        f1_r[i] = f1_r[i] + ind[k]*fr[1][k];
        f2_r[i] = f2_r[i] + ind[k]*fr[2][k];
        f3_r[i] = f3_r[i] + ind[k]*fr[3][k];
        f4_r[i] = f4_r[i] + ind[k]*fr[4][k];
        }
     
        f0_r[i] = f0_r[i]*radeg;
        f1_r[i] = f1_r[i]*rasec;
        f2_r[i] = f2_r[i]*rasec;
        f3_r[i] = f3_r[i]*rasec;
        f4_r[i] = f4_r[i]*rasec;
        
      }; //end while table9
 
g9:
    i_r = i;
//c
//c reading simplified series for coordinate v (lunar ecliptic longitude)
//c

    // v-ARRAYS  
	  double a_v[n8rec], at_v[n8rec], att_v[n8rec], c_v[n8rec], ct_v[n8rec], ctt_v[n8rec]; 
	  double f0_v[n8rec], f1_v[n8rec], f2_v[n8rec], f3_v[n8rec], f4_v[n8rec];  

    i=0;
    while (i<ntab10)   //ntab10
    {
  	  i=i+1;
      fscanf(fptr911,"%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d  %lf %lf %lf %lf %lf %lf \n",
		&k, &ind[12], &ind[11], &ind[13], &ind[10], &ind[9], 
		&ind[1], &ind[2], &ind[3], &ind[4], &ind[5], &ind[6], &ind[7], &ind[8], &ind[14],
		&a_v[i], &at_v[i], &att_v[i], &c_v[i], &ct_v[i], &ctt_v[i]); 

	/* //CONTROl fscanf:
	    printf(">> i..ind[14]: %d  %d %d %d %d %d ",k, ind[12], ind[11], ind[13], ind[10], ind[9]);
		printf(" %d %d %d %d %d %d %d %d %d \n",
		 ind[1], ind[2], ind[3], ind[4], ind[4], ind[6], ind[7], ind[8], ind[14] );
		printf("   a_v[i]..ctt_v[i]]: %f %f %f %f %f %f\n", a_v[i], at_v[i], att_v[i], c_v[i], ct_v[i], ctt_v[i] );
	*/

		c_v[i] = c_v[i]*radeg;
		ct_v[i] = ct_v[i]*radeg;
		ctt_v[i] = ctt_v[i]*radeg;
	//c
	//c calculating the arguments [rad]
	//c
		f0_v[i] = 0.;
		f1_v[i] = 0.;
		f2_v[i] = 0.;
		f3_v[i] = 0.;
		f4_v[i] = 0.;

		for(k=1; k<=14; k++)
		{
		f0_v[i] = f0_v[i] + ind[k]*fr[0][k];
		f1_v[i] = f1_v[i] + ind[k]*fr[1][k];
		f2_v[i] = f2_v[i] + ind[k]*fr[2][k];
		f3_v[i] = f3_v[i] + ind[k]*fr[3][k];
		f4_v[i] = f4_v[i] + ind[k]*fr[4][k];
		}

		f0_v[i] = f0_v[i]*radeg;
		f1_v[i] = f1_v[i]*rasec;
		f2_v[i] = f2_v[i]*rasec;
		f3_v[i] = f3_v[i]*rasec;
		f4_v[i] = f4_v[i]*rasec;
		frm0 = frm[0]*3600.;
		
	}; //end while table10
g10:
	i_v = i;
	//c
	//c reading simplified series for coordinate u (lunar ecliptic latitude)
	//c
	
	// u-ARRAYS
	  double a_u[n8rec], at_u[n8rec], att_u[n8rec], c_u[n8rec], ct_u[n8rec], ctt_u[n8rec];
	  double  f0_u[n8rec], f1_u[n8rec], f2_u[n8rec], f3_u[n8rec], f4_u[n8rec];
		
     i=0;
	 while (i<ntab11) //ntab11 max
	 {
    		i=i+1;
    	fscanf(fptr911,"%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d  %lf %lf %lf %lf %lf %lf \n",
		&k, &ind[12], &ind[11], &ind[13], &ind[10], &ind[9], 
		&ind[1], &ind[2], &ind[3], &ind[4], &ind[5], &ind[6], &ind[7], &ind[8], &ind[14],
		&a_u[i], &at_u[i], &att_u[i], &c_u[i], &ct_u[i], &ctt_u[i]); 
	 	 
	/* //CONTROl fscanf:
	    printf(">> i..ind[14]: %d  %d %d %d %d %d ",k, ind[12], ind[11], ind[13], ind[10], ind[9]);
		printf(" %d %d %d %d %d %d %d %d %d \n",
		 ind[1], ind[2], ind[3], ind[4], ind[4], ind[6], ind[7], ind[8], ind[14] );
		printf("   a_u[i]..ctt_u[i]]: %f %f %f %f %f %f\n", a_u[i], at_u[i], att_u[i], c_u[i], ct_u[i], ctt_u[i] );
	*/

		c_u[i] = c_u[i]*radeg;
		ct_u[i] = ct_u[i]*radeg;
		ctt_u[i] = ctt_u[i]*radeg;
	//c
	//c calculating the arguments [rad]
	//c
		f0_u[i] = 0.;
		f1_u[i] = 0.;
		f2_u[i] = 0.;
		f3_u[i] = 0.;
		f4_u[i] = 0.;

		for(k=1; k<=14; k++)
		{
		 f0_u[i] = f0_u[i] + ind[k]*fr[0][k];
		 f1_u[i] = f1_u[i] + ind[k]*fr[1][k];
		 f2_u[i] = f2_u[i] + ind[k]*fr[2][k];
		 f3_u[i] = f3_u[i] + ind[k]*fr[3][k];
		 f4_u[i] = f4_u[i] + ind[k]*fr[4][k];
	    }

		f0_u[i] = f0_u[i]*radeg;
		f1_u[i] = f1_u[i]*rasec;
		f2_u[i] = f2_u[i]*rasec;
		f3_u[i] = f3_u[i]*rasec;
		f4_u[i] = f4_u[i]*rasec;

	 }; //end while table11
g11:
		i_u = i;
		fclose(fptr911);
//c
//c calculation of the coordinate r (lunar distance) at the input epoch [km]
//c
		r = 0.;
		for(i=0; i<=i_r; i++)  // i<=i_r
 		{
	     arg = (((f4_r[i]*dtc + f3_r[i])*dtc + f2_r[i])*dtc + f1_r[i])*dtc + f0_r[i];	     
		 r = r + a_r[i]*cos(arg + c_r[i]);
		 if (at_r[i] > 0.) r = r + at_r[i]*dtm*cos(arg + ct_r[i]);
		 if (att_r[i] > 0.) r = r + att_r[i]*dtm*dtm*cos(arg + ctt_r[i]);
		}
//c
//c calculation of the coordinate v (lunar ecliptic longitude) at the input epoch [rad]
//c
		v = frm0 + (((frm[4]*dtc + frm[3])*dtc + frm[2])*dtc + frm[1])*dtc;
		for(i=0; i<=i_v; i++)
		{
		  arg = (((f4_v[i]*dtc + f3_v[i])*dtc + f2_v[i])*dtc + f1_v[i])*dtc + f0_v[i];
 		 v = v + a_v[i]*sin(arg + c_v[i]);
 		 if (at_v[i] > 0.) v = v + at_v[i]*dtm*sin(arg + ct_v[i]);
 		 if (att_v[i] > 0.) v = v + att_v[i]*dtm*dtm*sin(arg + ctt_v[i]);
		}
		v = dmod(v*rasec, pi);
//c
//c calculation of the coordinate u (lunar ecliptic latitude) at the input epoch [rad]
//c
		u = 0.;
		for (i=0; i<=i_u; i++)
		{
		  arg = (((f4_u[i]*dtc + f3_u[i])*dtc + f2_u[i])*dtc + f1_u[i])*dtc + f0_u[i];
 		  u = u + a_u[i]*sin(arg + c_u[i]);
		  if (at_u[i] > 0.) u = u + at_u[i]*dtm*sin(arg + ct_u[i]);
		  if (att_u[i] > 0.) u = u + att_u[i]*dtm*dtm*sin(arg + ctt_u[i]);
		}
		u = dmod(u*rasec, pi);
//c>> hmk-modification............................................

	pimk = 3.1415926535898;
	vmk = v*180./pimk;   vmk=norm360(vmk);
	umk = u*180./pimk;
	rmk = r;

// still missing: transformation from ecliptic to geocebntric system (see Chapront&Francou-fortran)!\n");
 
   }
  g999:
	*qLON=vmk;
	*qLAT=umk;
	*qRAD=rmk;
// END of SR LEA406b ccccccccccccccccccccccccccccccccccccccccccccccccccccccc
};



//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//cccccccccccccccc  FUNCTIONS ASTRONAV cccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc

/////////////////////////////////////////////////////////////
void quadipol(double xa[], double ya[], int n, double x, double *y, double *dy)
{
// Polynom Interpolation from Numerical Recipes (adapted)
	int i,m,ns=1;
	double den,dif,dift,ho,hp,w;
	double c[10];
	double d[10];

	dif=fabs(x-xa[1]);
	for (i=1;i<=n;i++) {
		if ( (dift=fabs(x-xa[i])) < dif) {
			ns=i;
			dif=dift;
		}
		c[i]=ya[i];
		d[i]=ya[i];
	}
	*y=ya[ns--];
	for (m=1;m<n;m++) {
		for (i=1;i<=n-m;i++)
		 {
			ho=xa[i]-x;
			hp=xa[i+m]-x;
			w=c[i+1]-d[i];
			if ( (den=ho-hp) == 0.0) 
			{printf(" ??ERROR quadipol,setting Delta-T=0.\n File astronav0x0.txt corrupted?\n"); getchar(); };
			den=w/den;
			d[i]=hp*den;
			c[i]=ho*den;
		}
		*y += (*dy=(2*ns < (n-m) ? c[ns+1] : d[ns--]));
	}
};
//cccccccccccccccccccccccccccccccccccccccccccccccccc
double delta1(int nyear)
{
    //cc HMK-value extrapolation ,adapted to USNO-MICA and IERS-extrap.
    // implicit double(a - h, o - z)
    int nt;
    double y;   
    nt = nyear - 2015;
    y = 67.62 + 0.341*nt + 0.003*nt*nt;
    
    return y;
};

//ccccccccccccccccccccccccccccccc
//-------------------------------
int truncit(double x)
{
  int k;
  k=x;
  if(x<0) k=x-0.5;
  return k;
}

//ccccccccccccccccccccccccccccccccccccccccccccccc
//-----------------------------------------------
int roundit(double x)
{
  int k;
  k=x+0.5;
  if(x<0) k=x-0.5;
  return k;
}

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
double lim180( double xxx )
{
    // limits xxx to +- 180, assuming that already 0 < xxx < 360!
	long int jg;
    double r,z, h1;
    z=xxx;
	if(z > 180) z=z-360;
    return(z);
};

//////////////////////////////////////////////////////////////////
void cxangle(double w0, int *ig0,int *im0,int *imr0,int *isr0,double *sm0,double *ss0)
    // ermittelt aus  'winkel.dec' = 17.2764 => 17 deg 16'35.04'' 
    // geestet mit Winkel 359.99999 = 359 deg, 59 min, 59.964 sec ODER = 359 deg, 59.9940 min. 
    // Achtung: es knnen bei Rundung Minuten=60 und Sekunden=60 auftreten.
    // Parameter:  input:  w0= GRAD.DECIMAL; 
    //   output: ig0=grad; im0=min;
	//    imr0=minuten gerundet, wenn keine sekunden abgefragt werden; isr0=sekunden, gerundet (danach gibts ja nichts), 
	//    sm0=minutes als float, wenn keine sekunden abgefragt werden; ss0 = sekunden als float , wenn deg und min als integer.
{   
    double z0, xmin, xsec;
    int ig,im,is,isr,imr,isign;


    z0=w0;
    isign=1; 
	if(z0 < 0.) isign=-1;
    z0=fabs(z0);                 // z0=voller Winkel dezimal, ohne Vorzeichen   
    ig = z0;                     // ig=ganzzahlige Grad, nicht gerundet
    xmin = (z0 - ig)*60. ;       // xmin = Minuten inkl Sekunden, dezimal
    im = xmin;                   // im = ganzzahlige Minuten, nicht gerundet  
    xsec = (xmin - im)*60. ;     // xsec= Sekunden, dezimal
     
    isr= xsec+0.5;               // is=ganzzahl Sekunden, gerundet  
    imr= xmin+0.5;               // imr=ganzzahlMinuten, gerundet
     
	*ig0 =ig*isign;
	*im0 =im*isign;
	*imr0=imr*isign;
	*isr0=isr*isign;
	
	*sm0=xmin*isign;
	*ss0=xsec*isign;
	 
	//Mglicher Output, Beispiele:
	// ig0, im0, isr0 =  alles ganzzahl, Sekunden ganzzahl gerundet
	// ig0, im0, ss0 =   deg und min ganz, restliche sekunden dezimal
	// ig0, imr0     =   deg und min ganz, min gerundet
	// ig0, sm0      =   deg ganzzahl, min (inkl sek) dezimal
};

//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
double angdec( int degree, int minute, int second )
{
// converts degrees and minutes in 'degrees.decimal' with correct sign	
 double www;
 int is0;
 
 is0=1;
 if (degree<0) is0=-1; if(minute<0) is0=-1; if(second<0) is0=-1;
 www= is0*( abs(second)/3600. + abs(minute)/60. + abs(degree) );
 return (www);
}

//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
int angcheck( double w0 )
{
// check for vertical line; w0=angle in degree.dec	
 int ivert;
 double www;
 www=norm360(w0);
 ivert=0;
 if(fabs(www-180.) < 0.1) ivert=999;
 www=www-180.;
 www=norm360(www);
 if(fabs(www-180.) < 0.1) ivert=999; 
 return (ivert);
}
////////////////////////////////////////////////
int iarr35(char ld[][35], int jz, int ka, int ke) 
// Die FUNCTION erwartet einen ARRAY  ld[64][30] mit 64 Zeilen zu je max. 30 Zeichen formatiertem Text.
// Aus der Zeile  jz  werden dann die Characters ka bis ke extrahiert 
// und dann als integer kk ausgegeben: return(kk).    
{
   int i,kk, kdif;
   char str0[100] ="Dies ist der Teststring Function \0";

 kdif=ke+1-ka;
 
 for (i = 0 ; i<kdif ; i++)
  {
  	str0[i]= ld[jz][i+ka];
  }
  str0[i]='\0';
      //printf(">>substrng i, str0: %d %s ", i,str0);
  kk=atoi(str0);
      //printf(">>ATOI: jz= %d kk= %d \n",jz,kk);
      //printf("\n");
  return (kk);
};
////////////////////////////////////////////////
double farr35(char ld[110][35], int jz, int ka, int ke) 
// Die FUNCTION erwartet einen ARRAY  ld[110][35] mit 110 Zeilen zu je max. 35 Zeichen formatiertem Text.
// Aus der Zeile  jz  werden dann die Characters ka bis ke extrahiert 
// und dann als integer kk ausgegeben: return(kk).    
{
   int i,j,kk, kdif;
   double xx;
   char str0[100] ="Dies ist der Teststring Function \0";
   char ldsimp[100];
  
		for (j = 0; j < 35; ++j) 
		{
			// mapping 2D array to 1D array
			ldsimp[j] = ld[jz][j];
		}

 ldsimp[j]='\0';

 kdif=ke+1-ka;
 for (i = 0 ; i<kdif ; i++)
  {
  	//str0[i]= ld[jz][i+ka];
  	str0[i]= ldsimp[i+ka];
  }
  str0[i]='\0';
     //printf(">> substrng str0: %s ", str0);
  xx=atof(str0);
     //printf(">> ATOf: jz= %d xx= %f \n",jz,xx);
  return (xx);
};


////////////////////////////////////////////////
double farr60(char navstar[64][60], int jz, int ka, int ke) 
// Die FUNCTION erwartet einen ARRAY  ld[64][60] mit 64 Zeilen zu je max. 60 Zeichen formatiertem Text.
// Aus der Zeile  jz  werden dann die Characters ka bis ke extrahiert 
// und dann als integer kk ausgegeben: return(kk).    
{
   int i,j,kk, kdif;
   double xx;
   char str0[100] ="Dies ist der Teststring Function 123456789 123456789 123456789 \0";
   char ldsimp[100];
  
		for (j = 0; j < 60; ++j) 
		{
			// mapping 2D array to 1D array
			ldsimp[j] = navstar[jz][j];
		}

 ldsimp[j]='\0';


 kdif=ke+1-ka;
 
 for (i = 0 ; i<kdif ; i++)
  {
  	str0[i]= ldsimp[i+ka];
  	//printf("%s",str0[i]);
  }
  str0[i]='\0';
     //printf(">> substrng str0: %s ", str0);
  xx=atof(str0);
     //printf(">> ATOf: jz= %d xx= %f \n",jz,xx); getchar();
  return (xx);
};


///////////////////////////  VSOP87D-EARTH //////////////////////

const double pi0=3.14159265358979323846264338327950;

//copied from Umland

//Radians
double norm2pi( double x0)
{
  double pi20=2.*pi0;
  double x;
  x=x0;
  while (x<0) {x+=pi20;}
  return x;
}
//Cosine of normalized angle (in radians)
double cost(double x) //input-radians
{
	double y;
    y=cos(norm2pi(x));
    return y;
}
//Sine of angles in degrees
double sind(double x) // input degrees
{   double d2r0=pi0/180.;
 	double y;
    y=sin(d2r0*x);
    return y;
}
//Cosine of angles in degrees
double cosd(double x) // input degrees
{   double d2r0=pi0/180.;
	double y;
    y=cos(d2r0*x);
    return y;
}

//Tangent of angles in degrees
double tand(double x)
{
	double z; 
	double dtr=3.14159265358979 /180.;
	z=tan(dtr*x);
    return (z);
};

double  trunc2(double x)
{
	double	pi=3.141592653589793238, dtr=pi/180;
	double pi2=2*pi;
return pi2*(x/pi2 - floor(x/pi2));
}
  


//////////////////////////////////////////////////////////////////////////////////////
//Heliocentric longitude of Earth
// x=0.1*TE, TE=(JDE-2451545.)/36525.;   i.e.: x =millenia since J2000.0
//    ==> look for TAU= = spa->jme  

double Learth(double x) // x= 0.1* (JDE-2452545.)/36525. time in milleniums since J2000.0
{ 
double L0=0;
L0+=1.75347045673;
L0+=0.03341656456*cost(4.66925680417+6283.07584999140*x);
L0+=0.00034894275*cost(4.62610241759+12566.15169998280*x);
L0+=0.00003417571*cost(2.82886579606+3.52311834900*x);
L0+=0.00003497056*cost(2.74411800971+5753.38488489680*x);
L0+=0.00003135896*cost(3.62767041758+77713.77146812050*x);
L0+=0.00002676218*cost(4.41808351397+7860.41939243920*x);
L0+=0.00002342687*cost(6.13516237631+3930.20969621960*x);
L0+=0.00001273166*cost(2.03709655772+529.69096509460*x);
L0+=0.00001324292*cost(0.74246356352+11506.76976979360*x);
L0+=0.00000901855*cost(2.04505443513+26.29831979980*x);
L0+=0.00001199167*cost(1.10962944315+1577.34354244780*x);
L0+=0.00000857223*cost(3.50849156957+398.14900340820*x);
L0+=0.00000779786*cost(1.17882652114+5223.69391980220*x);
L0+=0.00000990250*cost(5.23268129594+5884.92684658320*x);
L0+=0.00000753141*cost(2.53339053818+5507.55323866740*x);
L0+=0.00000505264*cost(4.58292563052+18849.22754997420*x);
L0+=0.00000492379*cost(4.20506639861+775.52261132400*x);
L0+=0.00000356655*cost(2.91954116867+0.06731030280*x);
L0+=0.00000284125*cost(1.89869034186+796.29800681640*x);
L0+=0.00000242810*cost(0.34481140906+5486.77784317500*x);
L0+=0.00000317087*cost(5.84901952218+11790.62908865880*x);
L0+=0.00000271039*cost(0.31488607649+10977.07880469900*x);
L0+=0.00000206160*cost(4.80646606059+2544.31441988340*x);
L0+=0.00000205385*cost(1.86947813692+5573.14280143310*x);
L0+=0.00000202261*cost(2.45767795458+6069.77675455340*x);
L0+=0.00000126184*cost(1.08302630210+20.77539549240*x);
L0+=0.00000155516*cost(0.83306073807+213.29909543800*x);
L0+=0.00000115132*cost(0.64544911683+0.98032106820*x);
L0+=0.00000102851*cost(0.63599846727+4694.00295470760*x);
L0+=0.00000101724*cost(4.26679821365+7.11354700080*x);
L0+=0.00000099206*cost(6.20992940258+2146.16541647520*x);
L0+=0.00000132212*cost(3.41118275555+2942.46342329160*x);
L0+=0.00000097607*cost(0.68101272270+155.42039943420*x);
L0+=0.00000085128*cost(1.29870743025+6275.96230299060*x);
L0+=0.00000074651*cost(1.75508916159+5088.62883976680*x);
L0+=0.00000101895*cost(0.97569221824+15720.83878487840*x);
L0+=0.00000084711*cost(3.67080093025+71430.69561812909*x);
L0+=0.00000073547*cost(4.67926565481+801.82093112380*x);
L0+=0.00000073874*cost(3.50319443167+3154.68708489560*x);
L0+=0.00000078756*cost(3.03698313141+12036.46073488820*x);
L0+=0.00000079637*cost(1.80791330700+17260.15465469040*x);
L0+=0.00000085803*cost(5.98322631256+161000.68573767410*x);
L0+=0.00000056963*cost(2.78430398043+6286.59896834040*x);
L0+=0.00000061148*cost(1.81839811024+7084.89678111520*x);
L0+=0.00000069627*cost(0.83297596966+9437.76293488700*x);
L0+=0.00000056116*cost(4.38694880779+14143.49524243060*x);
L0+=0.00000062449*cost(3.97763880587+8827.39026987480*x);
L0+=0.00000051145*cost(0.28306864501+5856.47765911540*x);
L0+=0.00000055577*cost(3.47006009062+6279.55273164240*x);
L0+=0.00000041036*cost(5.36817351402+8429.24126646660*x);
L0+=0.00000051605*cost(1.33282746983+1748.01641306700*x);
L0+=0.00000051992*cost(0.18914945834+12139.55350910680*x);
L0+=0.00000049000*cost(0.48735065033+1194.44701022460*x);
L0+=0.00000039200*cost(6.16832995016+10447.38783960440*x);
L0+=0.00000035566*cost(1.77597314691+6812.76681508600*x);
L0+=0.00000036770*cost(6.04133859347+10213.28554621100*x);
L0+=0.00000036596*cost(2.56955238628+1059.38193018920*x);
L0+=0.00000033291*cost(0.59309499459+17789.84561978500*x);
L0+=0.00000035954*cost(1.70876111898+2352.86615377180*x);
L0+=0.00000040938*cost(2.39850881707+19651.04848109800*x);
L0+=0.00000030047*cost(2.73975123935+1349.86740965880*x);
L0+=0.00000030412*cost(0.44294464135+83996.84731811189*x);
L0+=0.00000023663*cost(0.48473567763+8031.09226305840*x);
L0+=0.00000023574*cost(2.06527720049+3340.61242669980*x);
L0+=0.00000021089*cost(4.14825464101+951.71840625060*x);
L0+=0.00000024738*cost(0.21484762138+3.59042865180*x);
L0+=0.00000025352*cost(3.16470953405+4690.47983635860*x);
L0+=0.00000022820*cost(5.22197888032+4705.73230754360*x);
L0+=0.00000021419*cost(1.42563735525+16730.46368959580*x);
L0+=0.00000021891*cost(5.55594302562+553.56940284240*x);
L0+=0.00000017481*cost(4.56052900359+135.06508003540*x);
L0+=0.00000019925*cost(5.22208471269+12168.00269657460*x);
L0+=0.00000019860*cost(5.77470167653+6309.37416979120*x);
L0+=0.00000020300*cost(0.37133792946+283.85931886520*x);
L0+=0.00000014421*cost(4.19315332546+242.72860397400*x);
L0+=0.00000016225*cost(5.98837722564+11769.85369316640*x);
L0+=0.00000015077*cost(4.19567181073+6256.77753019160*x);
L0+=0.00000019124*cost(3.82219996949+23581.25817731760*x);
L0+=0.00000018888*cost(5.38626880969+149854.40013480789*x);
L0+=0.00000014346*cost(3.72355084422+38.02767263580*x);
L0+=0.00000017898*cost(2.21490735647+13367.97263110660*x);
L0+=0.00000012054*cost(2.62229588349+955.59974160860*x);
L0+=0.00000011287*cost(0.17739328092+4164.31198961300*x);
L0+=0.00000013971*cost(4.40138139996+6681.22485339960*x);
L0+=0.00000013621*cost(1.88934471407+7632.94325965020*x);
L0+=0.00000012503*cost(1.13052412208+5.52292430740*x);
L0+=0.00000010498*cost(5.35909518669+1592.59601363280*x);
L0+=0.00000009803*cost(0.99947478995+11371.70468975820*x);
L0+=0.00000009220*cost(4.57138609781+4292.33083295040*x);
L0+=0.00000010327*cost(6.19982566125+6438.49624942560*x);
L0+=0.00000012003*cost(1.00351456700+632.78373931320*x);
L0+=0.00000010827*cost(0.32734520222+103.09277421860*x);
L0+=0.00000008356*cost(4.53902685948+25132.30339996560*x);
L0+=0.00000010005*cost(6.02914963280+5746.27133789600*x);
L0+=0.00000008409*cost(3.29946744189+7234.79425624200*x);
L0+=0.00000008006*cost(5.82145271907+28.44918746780*x);
L0+=0.00000010523*cost(0.93871805506+11926.25441366880*x);
L0+=0.00000007686*cost(3.12142363172+7238.67559160000*x);
L0+=0.00000009378*cost(2.62414241032+5760.49843189760*x);
L0+=0.00000008127*cost(6.11228001785+4732.03062734340*x);
L0+=0.00000009232*cost(0.48343968736+522.57741809380*x);
L0+=0.00000009802*cost(5.24413991147+27511.46787353720*x);
L0+=0.00000007871*cost(0.99590177926+5643.17856367740*x);
L0+=0.00000008123*cost(6.27053013650+426.59819087600*x);
L0+=0.00000009048*cost(5.33686335897+6386.16862421000*x);
L0+=0.00000008620*cost(4.16538210888+7058.59846131540*x);
L0+=0.00000006297*cost(4.71724819317+6836.64525283380*x);
L0+=0.00000007575*cost(3.97382858911+11499.65622279280*x);
L0+=0.00000007756*cost(2.95729056763+23013.53953958720*x);
L0+=0.00000007314*cost(0.60652505806+11513.88331679440*x);
L0+=0.00000005955*cost(2.87641047971+6283.14316029419*x);
L0+=0.00000006534*cost(5.79072926033+18073.70493865020*x);
L0+=0.00000007188*cost(3.99831508699+74.78159856730*x);
L0+=0.00000007346*cost(4.38582365437+316.39186965660*x);
L0+=0.00000005413*cost(5.39199024641+419.48464387520*x);
L0+=0.00000005127*cost(2.36062848786+10973.55568635000*x);
L0+=0.00000007056*cost(0.32258441903+263.08392337280*x);
L0+=0.00000006625*cost(3.66475158672+17298.18232732620*x);
L0+=0.00000006762*cost(5.91132535899+90955.55169449610*x);
L0+=0.00000004938*cost(5.73672165674+9917.69687450980*x);
L0+=0.00000005547*cost(2.45152597661+12352.85260454480*x);
L0+=0.00000005958*cost(3.32051344676+6283.00853968860*x);
L0+=0.00000004471*cost(2.06385999536+7079.37385680780*x);
L0+=0.00000006153*cost(1.45823331144+233141.31440436149*x);
L0+=0.00000004348*cost(4.42342175480+5216.58037280140*x);
L0+=0.00000006123*cost(1.07494905258+19804.82729158280*x);
L0+=0.00000004488*cost(3.65285037150+206.18554843720*x);
L0+=0.00000004020*cost(0.83995823171+20.35531939880*x);
L0+=0.00000005188*cost(4.06503864016+6208.29425142410*x);
L0+=0.00000005307*cost(0.38217636096+31441.67756975680*x);
L0+=0.00000003785*cost(2.34369213733+3.88133535800*x);
L0+=0.00000004497*cost(3.27230796845+11015.10647733480*x);
L0+=0.00000004132*cost(0.92128915753+3738.76143010800*x);
L0+=0.00000003521*cost(5.97844807108+3894.18182954220*x);
L0+=0.00000004215*cost(1.90601120623+245.83164622940*x);
L0+=0.00000003701*cost(5.03069397926+536.80451209540*x);
L0+=0.00000003865*cost(1.82634360607+11856.21865142450*x);
L0+=0.00000003652*cost(1.01838584934+16200.77272450120*x);
L0+=0.00000003390*cost(0.97785123922+8635.94200376320*x);
L0+=0.00000003737*cost(2.95380107829+3128.38876509580*x);
L0+=0.00000003507*cost(3.71291946325+6290.18939699220*x);
L0+=0.00000003086*cost(3.64646921512+10.63666534980*x);
L0+=0.00000003397*cost(1.10590684017+14712.31711645800*x);
L0+=0.00000003334*cost(0.83684924911+6496.37494542940*x);
L0+=0.00000002805*cost(2.58504514144+14314.16811304980*x);
L0+=0.00000003650*cost(1.08344142571+88860.05707098669*x);
L0+=0.00000003388*cost(3.20185096055+5120.60114558360*x);
L0+=0.00000003252*cost(3.47859752062+6133.51265285680*x);
L0+=0.00000002553*cost(3.94869034189+1990.74501704100*x);
L0+=0.00000003520*cost(2.05559692878+244287.60000722769*x);
L0+=0.00000002565*cost(1.56071784900+23543.23050468179*x);
L0+=0.00000002621*cost(3.85639359951+266.60704172180*x);
L0+=0.00000002955*cost(3.39692949667+9225.53927328300*x);
L0+=0.00000002876*cost(6.02635617464+154717.60988768269*x);
L0+=0.00000002395*cost(1.16131956403+10984.19235169980*x);
L0+=0.00000003161*cost(1.32798718453+10873.98603048040*x);
L0+=0.00000003163*cost(5.08946464629+21228.39202354580*x);
L0+=0.00000002361*cost(4.27212906992+6040.34724601740*x);
L0+=0.00000003030*cost(1.80209931347+35371.88726597640*x);
L0+=0.00000002343*cost(3.57689860500+10969.96525769820*x);
L0+=0.00000002618*cost(2.57870156528+22483.84857449259*x);
L0+=0.00000002113*cost(3.71393780256+65147.61976813770*x);
L0+=0.00000002019*cost(0.81393923319+170.67287061920*x);
L0+=0.00000002003*cost(0.38091017375+6172.86952877200*x);
L0+=0.00000002506*cost(3.74379142438+10575.40668294180*x);
L0+=0.00000002381*cost(0.10581361289+7.04623669800*x);
L0+=0.00000001949*cost(4.86892513469+36.02786667740*x);
L0+=0.00000002074*cost(4.22794774570+5650.29211067820*x);
L0+=0.00000001924*cost(5.59460549860+6282.09552892320*x);
L0+=0.00000001949*cost(1.07002512703+5230.80746680300*x);
L0+=0.00000001988*cost(5.19736046771+6262.30045449900*x);
L0+=0.00000001887*cost(3.74365662683+23.87843774780*x);
L0+=0.00000001787*cost(1.25929682929+12559.03815298200*x);
L0+=0.00000001883*cost(1.90364058477+15.25247118500*x);
L0+=0.00000001816*cost(3.68083868442+15110.46611986620*x);
L0+=0.00000001701*cost(4.41105895380+110.20632121940*x);
L0+=0.00000001990*cost(3.93295788548+6206.80977871580*x);
L0+=0.00000002103*cost(0.75354917468+13521.75144159140*x);
L0+=0.00000001774*cost(0.48747535361+1551.04522264800*x);
L0+=0.00000001882*cost(0.86684493432+22003.91463486980*x);
L0+=0.00000001924*cost(1.22898324132+709.93304855830*x);
L0+=0.00000002009*cost(4.62850921980+6037.24420376200*x);
L0+=0.00000001924*cost(0.60231842508+6284.05617105960*x);
L0+=0.00000001596*cost(3.98332956992+13916.01910964160*x);
L0+=0.00000001664*cost(4.41939715469+8662.24032356300*x);
L0+=0.00000001971*cost(1.04560500503+18209.33026366019*x);
L0+=0.00000001942*cost(4.31335979989+6244.94281435360*x);
L0+=0.00000001476*cost(0.93271367331+2379.16447357160*x);
L0+=0.00000001810*cost(0.49112137707+1.48447270830*x);
L0+=0.00000001346*cost(1.51574702235+4136.91043351620*x);
L0+=0.00000001528*cost(5.61835711404+6127.65545055720*x);
L0+=0.00000001791*cost(3.22187270126+39302.09696219600*x);
L0+=0.00000001747*cost(3.05638656738+18319.53658487960*x);
L0+=0.00000001431*cost(4.51153808594+20426.57109242200*x);
L0+=0.00000001695*cost(0.22047718414+25158.60171976540*x);
L0+=0.00000001242*cost(4.46665769933+17256.63153634140*x);
L0+=0.00000001463*cost(4.69242679213+14945.31617355440*x);
L0+=0.00000001205*cost(1.86912144659+4590.91018048900*x);
L0+=0.00000001192*cost(2.74227166898+12569.67481833180*x);
L0+=0.00000001222*cost(5.18120087482+5333.90024102160*x);
L0+=0.00000001390*cost(5.42894648983+143571.32428481648*x);
L0+=0.00000001473*cost(1.70479245805+11712.95531823080*x);
L0+=0.00000001362*cost(2.61069503292+6062.66320755260*x);
L0+=0.00000001148*cost(6.03001800540+3634.62102451840*x);
L0+=0.00000001198*cost(5.15294130422+10177.25767953360*x);
L0+=0.00000001266*cost(0.11421493643+18422.62935909819*x);
L0+=0.00000001411*cost(1.09908857534+3496.03282613400*x);
L0+=0.00000001349*cost(2.99805109633+17654.78053974960*x);
L0+=0.00000001253*cost(2.79850152848+167283.76158766549*x);
L0+=0.00000001311*cost(1.60942984879+5481.25491886760*x);
L0+=0.00000001079*cost(6.20304501787+3.28635741780*x);
L0+=0.00000001181*cost(1.20653776978+131.54196168640*x);
L0+=0.00000001254*cost(5.45103277798+6076.89030155420*x);
L0+=0.00000001035*cost(2.32142722747+7342.45778018060*x);
L0+=0.00000001117*cost(0.38838354256+949.17560896980*x);
L0+=0.00000000966*cost(3.18341890851+11087.28512591840*x);
L0+=0.00000001171*cost(3.39635049962+12562.62858163380*x);
L0+=0.00000001121*cost(0.72627490378+220.41264243880*x);
L0+=0.00000001024*cost(2.19378315386+11403.67699557500*x);
L0+=0.00000000888*cost(3.91173199285+4686.88940770680*x);
L0+=0.00000000910*cost(1.98802695087+735.87651353180*x);
L0+=0.00000000830*cost(0.48984915507+24072.92146977640*x);
L0+=0.00000001096*cost(6.17377835617+5436.99301524020*x);
L0+=0.00000000908*cost(0.44959639433+7477.52286021600*x);
L0+=0.00000000974*cost(1.52996238356+9623.68827669120*x);
L0+=0.00000000840*cost(1.79543266333+5429.87946823940*x);
L0+=0.00000000778*cost(6.17699177946+38.13303563780*x);
L0+=0.00000000776*cost(4.09855402433+14.22709400160*x);
L0+=0.00000001068*cost(4.64200173735+43232.30665841560*x);
L0+=0.00000000954*cost(1.49988435748+1162.47470440780*x);
L0+=0.00000000907*cost(0.86986870809+10344.29506538580*x);
L0+=0.00000000931*cost(4.06044689031+28766.92442448400*x);
L0+=0.00000000739*cost(5.04368197372+639.89728631400*x);
L0+=0.00000000937*cost(3.46884698960+1589.07289528380*x);
L0+=0.00000000763*cost(5.86304932998+16858.48253293320*x);
L0+=0.00000000953*cost(4.20801492835+11190.37790013700*x);
L0+=0.00000000708*cost(1.72899988940+13095.84266507740*x);
L0+=0.00000000969*cost(1.64439522215+29088.81141598500*x);
L0+=0.00000000717*cost(0.16688678895+11.72935283600*x);
L0+=0.00000000962*cost(3.53092337542+12416.58850284820*x);
L0+=0.00000000747*cost(5.77866940346+12592.45001978260*x);
L0+=0.00000000672*cost(1.91095796194+3.93215326310*x);
L0+=0.00000000671*cost(5.46240843677+18052.92954315780*x);
L0+=0.00000000675*cost(6.28311558823+4535.05943692440*x);
L0+=0.00000000684*cost(0.39975012080+5849.36411211460*x);
L0+=0.00000000799*cost(0.29851185294+12132.43996210600*x);
L0+=0.00000000758*cost(0.96370823331+1052.26838318840*x);
L0+=0.00000000782*cost(5.33878339919+13517.87010623340*x);
L0+=0.00000000730*cost(1.70106160291+17267.26820169119*x);
L0+=0.00000000749*cost(2.59599901875+11609.86254401220*x);
L0+=0.00000000734*cost(2.78417782952+640.87760738220*x);
L0+=0.00000000688*cost(5.15048287468+16496.36139620240*x);
L0+=0.00000000770*cost(1.62469589333+4701.11650170840*x);
L0+=0.00000000633*cost(2.20587893893+25934.12433108940*x);
L0+=0.00000000760*cost(4.21317219403+377.37360791580*x);
L0+=0.00000000584*cost(2.13420121623+10557.59416082380*x);
L0+=0.00000000574*cost(0.24250054587+9779.10867612540*x);
L0+=0.00000000573*cost(3.16435264609+533.21408344360*x);
L0+=0.00000000685*cost(3.19344289472+12146.66705610760*x);
L0+=0.00000000675*cost(0.96179233959+10454.50138660520*x);
L0+=0.00000000648*cost(1.46327342555+6268.84875598980*x);
L0+=0.00000000589*cost(2.50543543638+3097.88382272579*x);
L0+=0.00000000551*cost(5.28099026956+9388.00590941520*x);
L0+=0.00000000696*cost(3.65342150016+4804.20927592700*x);
L0+=0.00000000669*cost(2.51030077026+2388.89402044920*x);
L0+=0.00000000550*cost(0.06883864342+20199.09495963300*x);
L0+=0.00000000629*cost(4.13350995675+45892.73043315699*x);
L0+=0.00000000678*cost(6.09190163533+135.62532501000*x);
L0+=0.00000000593*cost(1.50136257618+226858.23855437008*x);
L0+=0.00000000542*cost(3.58573645173+6148.01076995600*x);
L0+=0.00000000682*cost(5.02203067788+17253.04110768959*x);
L0+=0.00000000565*cost(4.29309238610+11933.36796066960*x);
L0+=0.00000000486*cost(0.77746204893+27.40155609680*x);
L0+=0.00000000503*cost(0.58963565969+15671.08175940660*x);
L0+=0.00000000616*cost(4.06539884128+227.47613278900*x);
L0+=0.00000000583*cost(6.12695541996+18875.52586977400*x);
L0+=0.00000000537*cost(2.15056440980+21954.15760939799*x);
L0+=0.00000000669*cost(6.06986269566+47162.51635463520*x);
L0+=0.00000000475*cost(0.40343842110+6915.85958930460*x);
L0+=0.00000000540*cost(2.83444222174+5326.78669402080*x);
L0+=0.00000000530*cost(5.26359885263+10988.80815753500*x);
L0+=0.00000000582*cost(3.24533095664+153.77881048480*x);
L0+=0.00000000641*cost(3.24711791371+2107.03450754240*x);
L0+=0.00000000621*cost(3.09698523779+33019.02111220460*x);
L0+=0.00000000466*cost(3.14982372198+10440.27429260360*x);
L0+=0.00000000466*cost(0.90708835657+5966.68398033480*x);
L0+=0.00000000528*cost(0.81926454470+813.55028395980*x);
L0+=0.00000000603*cost(3.81378921927+316428.22867391503*x);
L0+=0.00000000559*cost(1.81894804124+17996.03116822220*x);
L0+=0.00000000437*cost(2.28625594435+6303.85124548380*x);
L0+=0.00000000518*cost(4.86069178322+20597.24396304120*x);
L0+=0.00000000424*cost(6.23520018693+6489.26139842860*x);
L0+=0.00000000518*cost(6.17617826756+0.24381748350*x);
L0+=0.00000000404*cost(5.72804304258+5642.19824260920*x);
L0+=0.00000000458*cost(1.34117773915+6287.00800325450*x);
L0+=0.00000000548*cost(5.68454458320+155427.54293624099*x);
L0+=0.00000000547*cost(1.03391472061+3646.35037735440*x);
L0+=0.00000000428*cost(4.69800981138+846.08283475120*x);
L0+=0.00000000413*cost(6.02520699406+6279.48542133960*x);
L0+=0.00000000534*cost(3.03030638223+66567.48586525429*x);
L0+=0.00000000383*cost(1.49056949125+19800.94595622480*x);
L0+=0.00000000410*cost(5.28319622279+18451.07854656599*x);
L0+=0.00000000352*cost(4.68891600359+4907.30205014560*x);
L0+=0.00000000480*cost(5.36572651091+348.92442044800*x);
L0+=0.00000000344*cost(5.89157452896+6546.15977336420*x);
L0+=0.00000000340*cost(0.37557426440+13119.72110282519*x);
L0+=0.00000000434*cost(4.98417785901+6702.56049386660*x);
L0+=0.00000000332*cost(2.68902519126+29296.61538957860*x);
L0+=0.00000000448*cost(2.16478480251+5905.70224207560*x);
L0+=0.00000000344*cost(2.06546633735+49.75702547180*x);
L0+=0.00000000315*cost(1.24023811803+4061.21921539440*x);
L0+=0.00000000324*cost(2.30897526929+5017.50837136500*x);
L0+=0.00000000413*cost(0.17171692962+6286.66627864320*x);
L0+=0.00000000431*cost(3.86601101393+12489.88562870720*x);
L0+=0.00000000349*cost(4.55372342974+4933.20844033260*x);
L0+=0.00000000323*cost(0.41971136084+10770.89325626180*x);
L0+=0.00000000341*cost(2.68612860807+11.04570026390*x);
L0+=0.00000000316*cost(3.52936906658+17782.73207278420*x);
L0+=0.00000000315*cost(5.63357264999+568.82187402740*x);
L0+=0.00000000340*cost(3.83571212349+10660.68693504240*x);
L0+=0.00000000297*cost(0.62691416712+20995.39296644940*x);
L0+=0.00000000405*cost(1.00085779471+16460.33352952499*x);
L0+=0.00000000414*cost(1.21998752076+51092.72605085480*x);
L0+=0.00000000336*cost(4.71465945226+6179.98307577280*x);
L0+=0.00000000361*cost(3.71227508354+28237.23345938940*x);
L0+=0.00000000385*cost(6.21925225757+24356.78078864160*x);
L0+=0.00000000327*cost(1.05606504715+11919.14086666800*x);
L0+=0.00000000327*cost(6.14222420989+6254.62666252360*x);
L0+=0.00000000268*cost(2.47224339737+664.75604513000*x);
L0+=0.00000000269*cost(1.86207884109+23141.55838292460*x);
L0+=0.00000000345*cost(0.93461290184+6058.73105428950*x);
L0+=0.00000000296*cost(4.51687557180+6418.14093002680*x);
L0+=0.00000000353*cost(4.50033653082+36949.23080842420*x);
L0+=0.00000000260*cost(4.04963546305+6525.80445396540*x);
L0+=0.00000000298*cost(2.20046722622+156137.47598479928*x);
L0+=0.00000000253*cost(3.49900838384+29864.33402730900*x);
L0+=0.00000000254*cost(2.44901693835+5331.35744374080*x);
L0+=0.00000000296*cost(0.84347588787+5729.50644714900*x);
L0+=0.00000000298*cost(1.29194706125+22805.73556599360*x);
L0+=0.00000000241*cost(2.00721280805+16737.57723659660*x);
L0+=0.00000000311*cost(1.23668016334+6281.59137728310*x);
L0+=0.00000000240*cost(2.51650377121+6245.04817735560*x);
L0+=0.00000000332*cost(3.55576945724+7668.63742494250*x);
L0+=0.00000000264*cost(4.44052061202+12964.30070339100*x);
L0+=0.00000000257*cost(1.79654471948+11080.17157891760*x);
L0+=0.00000000260*cost(3.33077598420+5888.44996493220*x);
L0+=0.00000000285*cost(0.30886361430+11823.16163945020*x);
L0+=0.00000000290*cost(5.70141882483+77.67377042800*x);
L0+=0.00000000255*cost(4.00939664440+5881.40372823420*x);
L0+=0.00000000253*cost(4.73318493678+16723.35014259500*x);
L0+=0.00000000228*cost(0.95333661324+5540.08578945880*x);
L0+=0.00000000319*cost(1.38633229189+163096.18036118349*x);
L0+=0.00000000224*cost(1.65156322696+10027.90319572920*x);
L0+=0.00000000226*cost(0.34106460604+17796.95916678580*x);
L0+=0.00000000236*cost(4.19817431922+19.66976089979*x);
L0+=0.00000000280*cost(4.14080268970+12539.85338018300*x);
L0+=0.00000000275*cost(5.50306930248+32.53255079140*x);
L0+=0.00000000223*cost(5.23334210294+56.89837493560*x);
L0+=0.00000000217*cost(6.08587881787+6805.65326808520*x);
L0+=0.00000000280*cost(4.52472044653+6016.46880826960*x);
L0+=0.00000000227*cost(5.06509843737+6277.55292568400*x);
L0+=0.00000000226*cost(5.17755154305+11720.06886523160*x);
L0+=0.00000000245*cost(3.96486270306+22.77520145080*x);
L0+=0.00000000220*cost(4.72078081970+6.62855890001*x);
L0+=0.00000000207*cost(5.71701403951+41.55079098480*x);
L0+=0.00000000204*cost(3.91227411250+2699.73481931760*x);
L0+=0.00000000209*cost(0.86881969011+6321.10352262720*x);
L0+=0.00000000200*cost(2.11984445273+4274.51831083240*x);
L0+=0.00000000200*cost(5.39839888163+6019.99192661860*x);
L0+=0.00000000209*cost(5.67606291663+11293.47067435560*x);
L0+=0.00000000252*cost(1.64965729351+9380.95967271720*x);
L0+=0.00000000275*cost(5.04826903506+73.29712585900*x);
L0+=0.00000000208*cost(1.88207277133+11300.58422135640*x);
L0+=0.00000000272*cost(0.74640926842+1975.49254585600*x);
L0+=0.00000000199*cost(3.30836672397+22743.40937951640*x);
L0+=0.00000000269*cost(4.48560812155+64471.99124174489*x);
L0+=0.00000000192*cost(2.17464236325+5863.59120611620*x);
L0+=0.00000000228*cost(5.85373115869+128.01884333740*x);
L0+=0.00000000261*cost(2.64321183295+55022.93574707440*x);
L0+=0.00000000220*cost(5.75012110079+29.42950853600*x);
L0+=0.00000000187*cost(4.03230554718+467.96499035440*x);
L0+=0.00000000200*cost(5.60556112058+1066.49547719000*x);
L0+=0.00000000231*cost(1.09802712785+12341.80690428090*x);
L0+=0.00000000199*cost(0.29500625200+149.56319713460*x);
L0+=0.00000000249*cost(5.10473210814+7875.67186362420*x);
L0+=0.00000000208*cost(0.93013835019+14919.01785375460*x);
L0+=0.00000000179*cost(0.87104393079+12721.57209941700*x);
L0+=0.00000000203*cost(1.56920753653+28286.99048486120*x);
L0+=0.00000000179*cost(2.47036386443+16062.18452611680*x);
L0+=0.00000000198*cost(3.54061588502+30.91412563500*x);
L0+=0.00000000171*cost(3.45356518113+5327.47610838280*x);
L0+=0.00000000183*cost(0.72325421604+6272.03014972750*x);
L0+=0.00000000216*cost(2.97174580686+19402.79695281660*x);
L0+=0.00000000168*cost(2.51550550242+23937.85638974100*x);
L0+=0.00000000195*cost(0.09045393425+156.40072050240*x);
L0+=0.00000000179*cost(4.49471798090+31415.37924995700*x);
L0+=0.00000000216*cost(0.42177594328+23539.70738633280*x);
L0+=0.00000000189*cost(0.37542530191+9814.60410029120*x);
L0+=0.00000000218*cost(2.36835880025+16627.37091537720*x);
L0+=0.00000000166*cost(4.23182968446+16840.67001081519*x);
L0+=0.00000000200*cost(2.02153258098+16097.67995028260*x);
L0+=0.00000000169*cost(0.91318727000+95.97922721780*x);
L0+=0.00000000211*cost(5.73370637657+151.89728108520*x);
L0+=0.00000000204*cost(0.42643085174+515.46387109300*x);
L0+=0.00000000212*cost(3.00233538977+12043.57428188900*x);
L0+=0.00000000192*cost(5.46153589821+6379.05507720920*x);
L0+=0.00000000165*cost(1.38698167064+4171.42553661380*x);
L0+=0.00000000160*cost(6.23798383332+202.25339517410*x);
L0+=0.00000000215*cost(0.20889073407+5621.84292321040*x);
L0+=0.00000000181*cost(4.12439203622+13341.67431130680*x);
L0+=0.00000000153*cost(1.24460848836+29826.30635467320*x);
L0+=0.00000000150*cost(3.12999753018+799.82112516540*x);
L0+=0.00000000175*cost(4.55671604437+239424.39025435288*x);
L0+=0.00000000192*cost(1.33928820063+394.62588505920*x);
L0+=0.00000000149*cost(2.65697593276+21.33564046700*x);
L0+=0.00000000146*cost(5.58021191726+412.37109687440*x);
L0+=0.00000000156*cost(3.75650175503+12323.42309600880*x);
L0+=0.00000000143*cost(3.75708566606+58864.54391814630*x);
L0+=0.00000000143*cost(3.28248547724+29.82143814880*x);
L0+=0.00000000144*cost(1.07862546598+1265.56747862640*x);
L0+=0.00000000148*cost(0.23389236655+10021.83728009940*x);
L0+=0.00000000193*cost(5.92751083086+40879.44050464380*x);
L0+=0.00000000140*cost(4.97612440269+158.94351778320*x);
L0+=0.00000000148*cost(2.61640453469+17157.06188047180*x);
L0+=0.00000000141*cost(3.66871308723+26084.02180621620*x);
L0+=0.00000000147*cost(5.09968173403+661.23292678100*x);
L0+=0.00000000146*cost(4.96885605695+57375.80190084620*x);
L0+=0.00000000142*cost(0.78678347839+12779.45079542080*x);
L0+=0.00000000134*cost(4.79432636012+111.18664228760*x);
L0+=0.00000000140*cost(1.27748013377+107.66352393860*x);
L0+=0.00000000169*cost(2.74893543762+26735.94526221320*x);
L0+=0.00000000165*cost(3.95288000638+6357.85744855870*x);
L0+=0.00000000183*cost(5.43418358741+369.69981594040*x);
L0+=0.00000000134*cost(3.09132862833+17.81252211800*x);
L0+=0.00000000132*cost(3.05633896779+22490.96212149340*x);
L0+=0.00000000134*cost(4.09472795832+6599.46771964800*x);
L0+=0.00000000181*cost(4.22950689891+966.97087743560*x);
L0+=0.00000000152*cost(5.28885894415+12669.24447420140*x);
L0+=0.00000000150*cost(5.86819430908+97238.62754448749*x);
L0+=0.00000000142*cost(5.87266532526+22476.73502749179*x);
L0+=0.00000000145*cost(5.07330784304+87.30820453981*x);
L0+=0.00000000133*cost(5.65471067133+31.97230581680*x);
L0+=0.00000000124*cost(2.83326217072+12566.21901028560*x);
L0+=0.00000000135*cost(3.12861731644+32217.20018108080*x);
L0+=0.00000000137*cost(0.86487461904+9924.81042151060*x);
L0+=0.00000000172*cost(1.98369595114+174242.46596404970*x);
L0+=0.00000000170*cost(4.41115280254+327574.51427678125*x);
L0+=0.00000000151*cost(0.46542099527+39609.65458316560*x);
L0+=0.00000000148*cost(2.13439571118+491.66329245880*x);
L0+=0.00000000153*cost(3.78801830344+17363.24742890899*x);
L0+=0.00000000165*cost(5.31654110459+16943.76278503380*x);
L0+=0.00000000165*cost(4.06747587817+58953.14544329400*x);
L0+=0.00000000118*cost(0.63846333239+6.06591562980*x);
L0+=0.00000000159*cost(0.86086959274+221995.02880149524*x);
L0+=0.00000000119*cost(5.96432932413+1385.89527633620*x);
L0+=0.00000000114*cost(5.16516114595+25685.87280280800*x);
L0+=0.00000000112*cost(3.39403722178+21393.54196985760*x);
L0+=0.00000000112*cost(4.92889233335+56.80326216980*x);
L0+=0.00000000119*cost(2.40637635942+18635.92845453620*x);
L0+=0.00000000115*cost(0.23374479051+418.92439890060*x);
L0+=0.00000000122*cost(0.93575234049+24492.40611365159*x);
L0+=0.00000000115*cost(4.58880032176+26709.64694241340*x);
L0+=0.00000000130*cost(4.85539251000+22345.26037610820*x);
L0+=0.00000000140*cost(1.09413073202+44809.65020086340*x);
L0+=0.00000000112*cost(6.05401806281+433.71173787680*x);
L0+=0.00000000104*cost(1.54931540602+127.95153303460*x);
L0+=0.00000000105*cost(4.82620858888+33794.54372352860*x);
L0+=0.00000000102*cost(4.12448497391+15664.03552270859*x);
L0+=0.00000000107*cost(4.67919356465+77690.75950573849*x);
L0+=0.00000000118*cost(4.52320170120+19004.64794940840*x);
L0+=0.00000000107*cost(5.71774478555+77736.78343050249*x);
L0+=0.00000000143*cost(1.81201813018+4214.06901508480*x);
L0+=0.00000000125*cost(1.14419195615+625.67019231240*x);
L0+=0.00000000124*cost(3.27736514057+12566.08438968000*x);
L0+=0.00000000110*cost(1.08682570828+2787.04302385740*x);
L0+=0.00000000105*cost(1.78318141871+18139.29450141590*x);
L0+=0.00000000102*cost(4.75119578149+12242.64628332540*x);
L0+=0.00000000137*cost(1.43510636754+86464.61331683119*x);
L0+=0.00000000101*cost(4.91289409429+401.67212175720*x);
L0+=0.00000000129*cost(1.23567904485+12029.34718788740*x);
L0+=0.00000000138*cost(2.45654707999+7576.56007357400*x);
L0+=0.00000000103*cost(0.40004073416+90279.92316810328*x);
L0+=0.00000000108*cost(0.98989774940+5636.06501667660*x);
L0+=0.00000000117*cost(5.17362872063+34520.30930938080*x);
L0+=0.00000000100*cost(3.95534628189+5547.19933645960*x);
L0+=0.00000000098*cost(1.28118280598+21548.96236929180*x);
L0+=0.00000000097*cost(3.34717130592+16310.97904572060*x);
L0+=0.00000000098*cost(4.37041908717+34513.26307268280*x);
L0+=0.00000000125*cost(2.72164432960+24065.80792277559*x);
L0+=0.00000000102*cost(0.66938025772+10239.58386601080*x);
L0+=0.00000000119*cost(1.21689479331+1478.86657406440*x);
L0+=0.00000000094*cost(1.99595224256+13362.44970679920*x);
L0+=0.00000000094*cost(4.30965982872+26880.31981303260*x);
L0+=0.00000000095*cost(2.89807657534+34911.41207609100*x);
L0+=0.00000000106*cost(1.00156653590+16522.65971600220*x);
L0+=0.00000000097*cost(0.89642320201+71980.63357473118*x);
L0+=0.00000000116*cost(4.19967201116+206.70073729660*x);
L0+=0.00000000099*cost(1.37437847718+1039.02661079040*x);
L0+=0.00000000126*cost(3.21642544972+305281.94307104882*x);
L0+=0.00000000094*cost(0.68997876060+7834.12107263940*x);
L0+=0.00000000094*cost(5.58132218606+3104.93005942380*x);
L0+=0.00000000095*cost(3.03823741110+8982.81066930900*x);
L0+=0.00000000108*cost(0.52696637156+276.74577186440*x);
L0+=0.00000000124*cost(3.43899862683+172146.97134054029*x);
L0+=0.00000000102*cost(1.04031728553+95143.13292097810*x);
L0+=0.00000000104*cost(3.39218586218+290.97286586600*x);
L0+=0.00000000110*cost(3.68205877433+22380.75580027400*x);
L0+=0.00000000117*cost(0.78475956902+83286.91426955358*x);
L0+=0.00000000083*cost(0.18241793425+15141.39079431200*x);
L0+=0.00000000089*cost(4.45371820659+792.77488846740*x);
L0+=0.00000000082*cost(4.80703651241+6819.88036208680*x);
L0+=0.00000000087*cost(3.43122851097+27707.54249429480*x);
L0+=0.00000000101*cost(5.32081603011+2301.58581590939*x);
L0+=0.00000000082*cost(0.87060089842+10241.20229116720*x);
L0+=0.00000000086*cost(4.61919461931+36147.40987730040*x);
L0+=0.00000000095*cost(2.87032884659+23020.65308658799*x);
L0+=0.00000000088*cost(3.21133165690+33326.57873317420*x);
L0+=0.00000000080*cost(1.84900424847+21424.46664430340*x);
L0+=0.00000000101*cost(4.18796434479+30666.15495843280*x);
L0+=0.00000000107*cost(5.77864921649+34115.11406927460*x);
L0+=0.00000000104*cost(1.08739495962+6288.59877429880*x);
L0+=0.00000000110*cost(3.32898859416+72140.62866668739*x);
L0+=0.00000000087*cost(4.40657711727+142.17862703620*x);
L0+=0.00000000109*cost(1.94546030825+24279.10701821359*x);
L0+=0.00000000087*cost(4.32472045435+742.99006053260*x);
L0+=0.00000000107*cost(4.91580912547+277.03499374140*x);
L0+=0.00000000088*cost(2.10180220766+26482.17080962440*x);
L0+=0.00000000086*cost(4.01887374432+12491.37010141550*x);
L0+=0.00000000106*cost(5.49092372854+62883.35513951360*x);
L0+=0.00000000080*cost(6.19781316983+6709.67404086740*x);
L0+=0.00000000088*cost(2.09872810657+238004.52415723629*x);
L0+=0.00000000083*cost(4.90662164029+51.28033786241*x);
L0+=0.00000000095*cost(4.13387406591+18216.44381066100*x);
L0+=0.00000000078*cost(6.06949391680+148434.53403769129*x);
L0+=0.00000000079*cost(3.03048221644+838.96928775040*x);
L0+=0.00000000074*cost(5.49813051211+29026.48522950779*x);
L0+=0.00000000073*cost(3.05008665738+567.71863773040*x);
L0+=0.00000000084*cost(0.46604373274+45.14121963660*x);
L0+=0.00000000093*cost(2.52267536308+48739.85989708300*x);
L0+=0.00000000076*cost(1.76418124905+41654.96311596780*x);
L0+=0.00000000067*cost(5.77851227793+6311.52503745920*x);
L0+=0.00000000062*cost(3.32967880172+15508.61512327440*x);
L0+=0.00000000079*cost(5.59773841328+71960.38658322369*x);
L0+=0.00000000057*cost(3.90629505268+5999.21653112620*x);
L0+=0.00000000061*cost(0.05695043232+7856.89627409019*x);
L0+=0.00000000061*cost(5.63297958433+7863.94251078820*x);
L0+=0.00000000065*cost(3.72178394016+12573.26524698360*x);
L0+=0.00000000057*cost(4.18217219541+26087.90314157420*x);
L0+=0.00000000066*cost(3.92262333487+69853.35207568129*x);
L0+=0.00000000053*cost(5.51119362045+77710.24834977149*x);
L0+=0.00000000053*cost(4.88573986961+77717.29458646949*x);
L0+=0.00000000062*cost(2.88876342225+9411.46461508720*x);
L0+=0.00000000051*cost(1.12657183874+82576.98122099529*x);
L0+=0.00000000045*cost(2.95671076719+24602.61243487099*x);
L0+=0.00000000040*cost(5.55145719241+12565.17137891460*x);
L0+=0.00000000039*cost(1.20838190039+18842.11400297339*x);
L0+=0.00000000045*cost(3.18590558749+45585.17281218740*x);
L0+=0.00000000049*cost(2.44790934886+13613.80427733600*x);

double L1=0;
L1+=6283.31966747491;
L1+=0.00206058863*cost(2.67823455584+6283.07584999140*x);
L1+=0.00004303430*cost(2.63512650414+12566.15169998280*x);
L1+=0.00000425264*cost(1.59046980729+3.52311834900*x);
L1+=0.00000108977*cost(2.96618001993+1577.34354244780*x);
L1+=0.00000093478*cost(2.59212835365+18849.22754997420*x);
L1+=0.00000119261*cost(5.79557487799+26.29831979980*x);
L1+=0.00000072122*cost(1.13846158196+529.69096509460*x);
L1+=0.00000067768*cost(1.87472304791+398.14900340820*x);
L1+=0.00000067327*cost(4.40918235168+5507.55323866740*x);
L1+=0.00000059027*cost(2.88797038460+5223.69391980220*x);
L1+=0.00000055976*cost(2.17471680261+155.42039943420*x);
L1+=0.00000045407*cost(0.39803079805+796.29800681640*x);
L1+=0.00000036369*cost(0.46624739835+775.52261132400*x);
L1+=0.00000028958*cost(2.64707383882+7.11354700080*x);
L1+=0.00000019097*cost(1.84628332577+5486.77784317500*x);
L1+=0.00000020844*cost(5.34138275149+0.98032106820*x);
L1+=0.00000018508*cost(4.96855124577+213.29909543800*x);
L1+=0.00000016233*cost(0.03216483047+2544.31441988340*x);
L1+=0.00000017293*cost(2.99116864949+6275.96230299060*x);
L1+=0.00000015832*cost(1.43049285325+2146.16541647520*x);
L1+=0.00000014615*cost(1.20532366323+10977.07880469900*x);
L1+=0.00000011877*cost(3.25804815607+5088.62883976680*x);
L1+=0.00000011514*cost(2.07502418155+4694.00295470760*x);
L1+=0.00000009721*cost(4.23925472239+1349.86740965880*x);
L1+=0.00000009969*cost(1.30262991097+6286.59896834040*x);
L1+=0.00000009452*cost(2.69957062864+242.72860397400*x);
L1+=0.00000012461*cost(2.83432285512+1748.01641306700*x);
L1+=0.00000011808*cost(5.27379790480+1194.44701022460*x);
L1+=0.00000008577*cost(5.64475868067+951.71840625060*x);
L1+=0.00000010641*cost(0.76614199202+553.56940284240*x);
L1+=0.00000007576*cost(5.30062664886+2352.86615377180*x);
L1+=0.00000005834*cost(1.76649917904+1059.38193018920*x);
L1+=0.00000006385*cost(2.65033984967+9437.76293488700*x);
L1+=0.00000005223*cost(5.66135767624+71430.69561812909*x);
L1+=0.00000005305*cost(0.90857521574+3154.68708489560*x);
L1+=0.00000006101*cost(4.66632584188+4690.47983635860*x);
L1+=0.00000004330*cost(0.24102555403+6812.76681508600*x);
L1+=0.00000005041*cost(1.42490103709+6438.49624942560*x);
L1+=0.00000004259*cost(0.77355900599+10447.38783960440*x);
L1+=0.00000005198*cost(1.85353197345+801.82093112380*x);
L1+=0.00000003744*cost(2.00119516488+8031.09226305840*x);
L1+=0.00000003558*cost(2.42901552681+14143.49524243060*x);
L1+=0.00000003372*cost(3.86210700128+1592.59601363280*x);
L1+=0.00000003374*cost(0.88776219727+12036.46073488820*x);
L1+=0.00000003175*cost(3.18785710594+4705.73230754360*x);
L1+=0.00000003221*cost(0.61599835472+8429.24126646660*x);
L1+=0.00000004132*cost(5.23992859705+7084.89678111520*x);
L1+=0.00000002970*cost(6.07026318493+4292.33083295040*x);
L1+=0.00000002900*cost(2.32464208411+20.35531939880*x);
L1+=0.00000003504*cost(4.79975694359+6279.55273164240*x);
L1+=0.00000002950*cost(1.43108874817+5746.27133789600*x);
L1+=0.00000002697*cost(4.80368225199+7234.79425624200*x);
L1+=0.00000002531*cost(6.22290682655+6836.64525283380*x);
L1+=0.00000002745*cost(0.93466065396+5760.49843189760*x);
L1+=0.00000003250*cost(3.39954640038+7632.94325965020*x);
L1+=0.00000002277*cost(5.00277837672+17789.84561978500*x);
L1+=0.00000002075*cost(3.95534978634+10213.28554621100*x);
L1+=0.00000002061*cost(2.22411683077+5856.47765911540*x);
L1+=0.00000002252*cost(5.67166499885+11499.65622279280*x);
L1+=0.00000002148*cost(5.20184578235+11513.88331679440*x);
L1+=0.00000001886*cost(0.53198320577+3340.61242669980*x);
L1+=0.00000001875*cost(4.73511970207+83996.84731811189*x);
L1+=0.00000002060*cost(2.54987293999+25132.30339996560*x);
L1+=0.00000001794*cost(1.47435409831+4164.31198961300*x);
L1+=0.00000001778*cost(3.02473091781+5.52292430740*x);
L1+=0.00000002029*cost(0.90960209983+6256.77753019160*x);
L1+=0.00000002075*cost(2.26767270157+522.57741809380*x);
L1+=0.00000001772*cost(3.02622802353+5753.38488489680*x);
L1+=0.00000001569*cost(6.12410242782+5216.58037280140*x);
L1+=0.00000001590*cost(4.63713748247+3.28635741780*x);
L1+=0.00000001542*cost(4.20004448567+13367.97263110660*x);
L1+=0.00000001427*cost(1.19088061711+3894.18182954220*x);
L1+=0.00000001375*cost(3.09301252193+135.06508003540*x);
L1+=0.00000001359*cost(4.24532506641+426.59819087600*x);
L1+=0.00000001340*cost(5.76511818622+6040.34724601740*x);
L1+=0.00000001284*cost(3.08524663344+5643.17856367740*x);
L1+=0.00000001250*cost(3.07748157144+11926.25441366880*x);
L1+=0.00000001551*cost(3.07665451458+6681.22485339960*x);
L1+=0.00000001268*cost(2.09196018331+6290.18939699220*x);
L1+=0.00000001144*cost(3.24444699514+12168.00269657460*x);
L1+=0.00000001248*cost(3.44504937285+536.80451209540*x);
L1+=0.00000001118*cost(2.31829670425+16730.46368959580*x);
L1+=0.00000001105*cost(5.31966001019+23.87843774780*x);
L1+=0.00000001051*cost(3.75015946014+7860.41939243920*x);
L1+=0.00000001025*cost(2.44688534235+1990.74501704100*x);
L1+=0.00000000962*cost(0.81771017882+3.88133535800*x);
L1+=0.00000000910*cost(0.41727865299+7079.37385680780*x);
L1+=0.00000000883*cost(5.16833917651+11790.62908865880*x);
L1+=0.00000000957*cost(4.07673573735+6127.65545055720*x);
L1+=0.00000001110*cost(3.90096793825+11506.76976979360*x);
L1+=0.00000000802*cost(3.88778875582+10973.55568635000*x);
L1+=0.00000000780*cost(2.39934293755+1589.07289528380*x);
L1+=0.00000000758*cost(1.30034364248+103.09277421860*x);
L1+=0.00000000749*cost(4.96275803300+6496.37494542940*x);
L1+=0.00000000765*cost(3.36312388424+36.02786667740*x);
L1+=0.00000000915*cost(5.41543742089+206.18554843720*x);
L1+=0.00000000776*cost(2.57589093871+11371.70468975820*x);
L1+=0.00000000772*cost(3.98369209464+955.59974160860*x);
L1+=0.00000000749*cost(5.17890001805+10969.96525769820*x);
L1+=0.00000000806*cost(0.34218864254+9917.69687450980*x);
L1+=0.00000000728*cost(5.20962563787+38.02767263580*x);
L1+=0.00000000685*cost(2.77592961854+20.77539549240*x);
L1+=0.00000000636*cost(4.28242193632+28.44918746780*x);
L1+=0.00000000608*cost(5.63278508906+10984.19235169980*x);
L1+=0.00000000704*cost(5.60738823665+3738.76143010800*x);
L1+=0.00000000685*cost(0.38876148682+15.25247118500*x);
L1+=0.00000000601*cost(0.73489602442+419.48464387520*x);
L1+=0.00000000716*cost(2.65279791438+6309.37416979120*x);
L1+=0.00000000584*cost(5.54502568227+17298.18232732620*x);
L1+=0.00000000650*cost(1.13379656406+7058.59846131540*x);
L1+=0.00000000688*cost(2.59683891779+3496.03282613400*x);
L1+=0.00000000485*cost(0.44467180946+12352.85260454480*x);
L1+=0.00000000528*cost(2.74936967681+3930.20969621960*x);
L1+=0.00000000597*cost(5.27668281777+10575.40668294180*x);
L1+=0.00000000583*cost(3.18929067810+4732.03062734340*x);
L1+=0.00000000526*cost(5.01697321546+5884.92684658320*x);
L1+=0.00000000540*cost(1.29175137075+640.87760738220*x);
L1+=0.00000000473*cost(5.49953306970+5230.80746680300*x);
L1+=0.00000000406*cost(5.21248452189+220.41264243880*x);
L1+=0.00000000395*cost(1.87474483222+16200.77272450120*x);
L1+=0.00000000370*cost(3.84921354713+18073.70493865020*x);
L1+=0.00000000367*cost(0.88533542778+6283.14316029419*x);
L1+=0.00000000379*cost(0.37983009325+10177.25767953360*x);
L1+=0.00000000356*cost(3.84145204913+11712.95531823080*x);
L1+=0.00000000374*cost(5.01577520608+7.04623669800*x);
L1+=0.00000000381*cost(4.30250406634+6062.66320755260*x);
L1+=0.00000000471*cost(0.86381834647+6069.77675455340*x);
L1+=0.00000000367*cost(1.32943839763+6283.00853968860*x);
L1+=0.00000000460*cost(5.19667219575+6284.05617105960*x);
L1+=0.00000000333*cost(5.54256205741+4686.88940770680*x);
L1+=0.00000000341*cost(4.36522989934+7238.67559160000*x);
L1+=0.00000000336*cost(4.00205876835+3097.88382272579*x);
L1+=0.00000000359*cost(6.22679790284+245.83164622940*x);
L1+=0.00000000307*cost(2.35299010924+170.67287061920*x);
L1+=0.00000000343*cost(3.77164927143+6076.89030155420*x);
L1+=0.00000000296*cost(5.44152227481+17260.15465469040*x);
L1+=0.00000000328*cost(0.13837875384+11015.10647733480*x);
L1+=0.00000000268*cost(1.13904550630+12569.67481833180*x);
L1+=0.00000000263*cost(0.00538633678+4136.91043351620*x);
L1+=0.00000000282*cost(5.04399837480+7477.52286021600*x);
L1+=0.00000000288*cost(3.13401177517+12559.03815298200*x);
L1+=0.00000000259*cost(0.93882269387+5642.19824260920*x);
L1+=0.00000000292*cost(1.98420020514+12132.43996210600*x);
L1+=0.00000000247*cost(3.84244798532+5429.87946823940*x);
L1+=0.00000000245*cost(5.70467521726+65147.61976813770*x);
L1+=0.00000000241*cost(0.99480969552+3634.62102451840*x);
L1+=0.00000000246*cost(3.06168069935+110.20632121940*x);
L1+=0.00000000239*cost(6.11855909114+11856.21865142450*x);
L1+=0.00000000263*cost(0.66348415419+21228.39202354580*x);
L1+=0.00000000262*cost(1.51070507866+12146.66705610760*x);
L1+=0.00000000230*cost(1.75927314884+9779.10867612540*x);
L1+=0.00000000223*cost(2.00967043606+6172.86952877200*x);
L1+=0.00000000246*cost(1.10411690865+6282.09552892320*x);
L1+=0.00000000221*cost(3.03945240854+8635.94200376320*x);
L1+=0.00000000214*cost(4.03840869663+14314.16811304980*x);
L1+=0.00000000236*cost(5.46915070580+13916.01910964160*x);
L1+=0.00000000224*cost(4.68408089456+24072.92146977640*x);
L1+=0.00000000212*cost(2.13695625494+5849.36411211460*x);
L1+=0.00000000207*cost(3.07724246401+11.72935283600*x);
L1+=0.00000000207*cost(6.10306282747+23543.23050468179*x);
L1+=0.00000000266*cost(1.00709566823+2388.89402044920*x);
L1+=0.00000000217*cost(6.27837036335+17267.26820169119*x);
L1+=0.00000000204*cost(2.34615348695+266.60704172180*x);
L1+=0.00000000195*cost(5.55015549753+6133.51265285680*x);
L1+=0.00000000188*cost(2.52667166175+6525.80445396540*x);
L1+=0.00000000185*cost(0.90960768344+18319.53658487960*x);
L1+=0.00000000177*cost(1.73429218289+154717.60988768269*x);
L1+=0.00000000187*cost(4.76483647432+4535.05943692440*x);
L1+=0.00000000186*cost(4.63080493407+10440.27429260360*x);
L1+=0.00000000215*cost(2.81255454560+7342.45778018060*x);
L1+=0.00000000172*cost(1.45551888559+9225.53927328300*x);
L1+=0.00000000162*cost(3.30661909388+639.89728631400*x);
L1+=0.00000000168*cost(2.17671416605+27.40155609680*x);
L1+=0.00000000160*cost(1.68164180475+15110.46611986620*x);
L1+=0.00000000158*cost(0.13519771874+13095.84266507740*x);
L1+=0.00000000183*cost(0.56281322071+13517.87010623340*x);
L1+=0.00000000179*cost(3.58450811616+87.30820453981*x);
L1+=0.00000000152*cost(2.84070476818+5650.29211067820*x);
L1+=0.00000000182*cost(0.44065530624+17253.04110768959*x);
L1+=0.00000000160*cost(5.95767264171+4701.11650170840*x);
L1+=0.00000000142*cost(1.46290137520+11087.28512591840*x);
L1+=0.00000000142*cost(2.04464036087+20426.57109242200*x);
L1+=0.00000000131*cost(5.40912137746+2699.73481931760*x);
L1+=0.00000000144*cost(2.07312090485+25158.60171976540*x);
L1+=0.00000000147*cost(6.15106982168+9623.68827669120*x);
L1+=0.00000000141*cost(5.55739979498+10454.50138660520*x);
L1+=0.00000000135*cost(0.06098110407+16723.35014259500*x);
L1+=0.00000000124*cost(5.81218025669+17256.63153634140*x);
L1+=0.00000000124*cost(2.36293551623+4933.20844033260*x);
L1+=0.00000000126*cost(3.47435905118+22483.84857449259*x);
L1+=0.00000000159*cost(5.63954754618+5729.50644714900*x);
L1+=0.00000000123*cost(3.92815963256+17996.03116822220*x);
L1+=0.00000000148*cost(3.02509280598+1551.04522264800*x);
L1+=0.00000000120*cost(5.91904349732+6206.80977871580*x);
L1+=0.00000000134*cost(3.11122937825+21954.15760939799*x);
L1+=0.00000000119*cost(5.52141123450+709.93304855830*x);
L1+=0.00000000122*cost(3.00813429479+19800.94595622480*x);
L1+=0.00000000127*cost(1.37618620001+14945.31617355440*x);
L1+=0.00000000141*cost(2.56889468729+1052.26838318840*x);
L1+=0.00000000123*cost(2.83671175442+11919.14086666800*x);
L1+=0.00000000118*cost(0.81934438215+5331.35744374080*x);
L1+=0.00000000151*cost(2.68731829165+11769.85369316640*x);
L1+=0.00000000119*cost(5.08835797638+5481.25491886760*x);
L1+=0.00000000153*cost(2.46021790779+11933.36796066960*x);
L1+=0.00000000108*cost(1.04936452145+11403.67699557500*x);
L1+=0.00000000128*cost(0.99794735107+8827.39026987480*x);
L1+=0.00000000144*cost(2.54869747042+227.47613278900*x);
L1+=0.00000000150*cost(4.50631437136+2379.16447357160*x);
L1+=0.00000000107*cost(1.79272017026+13119.72110282519*x);
L1+=0.00000000107*cost(4.43556814486+18422.62935909819*x);
L1+=0.00000000109*cost(0.29269062317+16737.57723659660*x);
L1+=0.00000000141*cost(3.18979826258+6262.30045449900*x);
L1+=0.00000000122*cost(4.23040027813+29.42950853600*x);
L1+=0.00000000111*cost(5.16954029551+17782.73207278420*x);
L1+=0.00000000100*cost(3.52213872761+18052.92954315780*x);
L1+=0.00000000108*cost(1.08514212991+16858.48253293320*x);
L1+=0.00000000106*cost(1.96085248410+74.78159856730*x);
L1+=0.00000000110*cost(2.30582372873+16460.33352952499*x);
L1+=0.00000000097*cost(3.50918940210+5333.90024102160*x);
L1+=0.00000000099*cost(3.56417337974+735.87651353180*x);
L1+=0.00000000094*cost(5.01857894228+3128.38876509580*x);
L1+=0.00000000097*cost(1.65579893894+533.21408344360*x);
L1+=0.00000000092*cost(0.89217162285+29296.61538957860*x);
L1+=0.00000000123*cost(3.16062050433+9380.95967271720*x);
L1+=0.00000000102*cost(1.20493500565+23020.65308658799*x);
L1+=0.00000000088*cost(2.21296088224+12721.57209941700*x);
L1+=0.00000000089*cost(1.54264720310+20199.09495963300*x);
L1+=0.00000000113*cost(4.83320707870+16496.36139620240*x);
L1+=0.00000000121*cost(6.19860353182+9388.00590941520*x);
L1+=0.00000000089*cost(4.08082274765+22805.73556599360*x);
L1+=0.00000000098*cost(1.09181832830+12043.57428188900*x);
L1+=0.00000000086*cost(1.13655027605+143571.32428481648*x);
L1+=0.00000000088*cost(5.96980472191+107.66352393860*x);
L1+=0.00000000082*cost(5.01340404594+22003.91463486980*x);
L1+=0.00000000094*cost(1.69615700473+23006.42599258639*x);
L1+=0.00000000081*cost(3.00657814365+2118.76386037840*x);
L1+=0.00000000098*cost(1.39215287161+8662.24032356300*x);
L1+=0.00000000077*cost(3.33555190840+15720.83878487840*x);
L1+=0.00000000082*cost(5.86880116464+2787.04302385740*x);
L1+=0.00000000076*cost(5.67183650604+14.22709400160*x);
L1+=0.00000000081*cost(6.16619455699+1039.02661079040*x);
L1+=0.00000000076*cost(3.21449884756+111.18664228760*x);
L1+=0.00000000078*cost(1.37531518377+21947.11137270000*x);
L1+=0.00000000074*cost(3.58814195051+11609.86254401220*x);
L1+=0.00000000077*cost(4.84846488388+22743.40937951640*x);
L1+=0.00000000090*cost(1.48869013606+15671.08175940660*x);
L1+=0.00000000082*cost(3.48618399109+29088.81141598500*x);
L1+=0.00000000069*cost(3.55746476593+4590.91018048900*x);
L1+=0.00000000069*cost(1.93625656075+135.62532501000*x);
L1+=0.00000000070*cost(2.66548322237+18875.52586977400*x);
L1+=0.00000000069*cost(5.41478093731+26735.94526221320*x);
L1+=0.00000000079*cost(5.15154513662+12323.42309600880*x);
L1+=0.00000000094*cost(3.62899392448+77713.77146812050*x);
L1+=0.00000000078*cost(4.17011182047+1066.49547719000*x);
L1+=0.00000000071*cost(3.89435637865+22779.43724619380*x);
L1+=0.00000000063*cost(4.53968787714+8982.81066930900*x);
L1+=0.00000000069*cost(0.96028230548+14919.01785375460*x);
L1+=0.00000000076*cost(3.29092216589+2942.46342329160*x);
L1+=0.00000000063*cost(4.09167842893+16062.18452611680*x);
L1+=0.00000000065*cost(3.34580407184+51.28033786241*x);
L1+=0.00000000065*cost(5.75757544877+52670.06959330260*x);
L1+=0.00000000068*cost(5.75884067555+21424.46664430340*x);
L1+=0.00000000057*cost(5.45122399850+12592.45001978260*x);
L1+=0.00000000057*cost(5.25043362558+20995.39296644940*x);
L1+=0.00000000073*cost(0.53299090807+2301.58581590939*x);
L1+=0.00000000070*cost(4.31243357502+19402.79695281660*x);
L1+=0.00000000067*cost(2.53852336668+377.37360791580*x);
L1+=0.00000000056*cost(3.20816844695+24889.57479599160*x);
L1+=0.00000000053*cost(3.17816599142+18451.07854656599*x);
L1+=0.00000000053*cost(3.61529270216+77.67377042800*x);
L1+=0.00000000053*cost(0.45467549335+30666.15495843280*x);
L1+=0.00000000061*cost(0.14807288453+23013.53953958720*x);
L1+=0.00000000051*cost(3.32803972907+56.89837493560*x);
L1+=0.00000000052*cost(3.41177624177+23141.55838292460*x);
L1+=0.00000000058*cost(3.13638677202+309.27832265580*x);
L1+=0.00000000070*cost(2.50592323465+31415.37924995700*x);
L1+=0.00000000052*cost(5.10673376738+17796.95916678580*x);
L1+=0.00000000067*cost(6.27917920454+22345.26037610820*x);
L1+=0.00000000050*cost(0.42577644151+25685.87280280800*x);
L1+=0.00000000048*cost(0.70204553333+1162.47470440780*x);
L1+=0.00000000066*cost(3.64350022359+15265.88651930040*x);
L1+=0.00000000050*cost(5.74382917440+19.66976089979*x);
L1+=0.00000000050*cost(4.69825387775+28237.23345938940*x);
L1+=0.00000000047*cost(5.74015846442+12139.55350910680*x);
L1+=0.00000000054*cost(1.97301333704+23581.25817731760*x);
L1+=0.00000000049*cost(4.98223579027+10021.83728009940*x);
L1+=0.00000000046*cost(5.41431705539+33019.02111220460*x);
L1+=0.00000000051*cost(1.23882053879+12539.85338018300*x);
L1+=0.00000000046*cost(2.41369976086+98068.53671630539*x);
L1+=0.00000000044*cost(0.80750593746+167283.76158766549*x);
L1+=0.00000000045*cost(4.39613584445+433.71173787680*x);
L1+=0.00000000044*cost(2.57358208785+12964.30070339100*x);
L1+=0.00000000046*cost(0.26142733448+11.04570026390*x);
L1+=0.00000000045*cost(2.46230645202+51868.24866217880*x);
L1+=0.00000000048*cost(0.89551707131+56600.27928952220*x);
L1+=0.00000000057*cost(1.86416707010+25287.72379939980*x);
L1+=0.00000000042*cost(5.26377513431+26084.02180621620*x);
L1+=0.00000000049*cost(3.17757670611+6303.85124548380*x);
L1+=0.00000000052*cost(3.65266055509+7872.14874527520*x);
L1+=0.00000000040*cost(1.81891629936+34596.36465465240*x);
L1+=0.00000000043*cost(1.94164978061+1903.43681250120*x);
L1+=0.00000000041*cost(0.74461854136+23937.85638974100*x);
L1+=0.00000000048*cost(6.26034008181+28286.99048486120*x);
L1+=0.00000000045*cost(5.45575017530+60530.48898574180*x);
L1+=0.00000000040*cost(2.92105728682+21548.96236929180*x);
L1+=0.00000000040*cost(0.04502010161+38526.57435087200*x);
L1+=0.00000000053*cost(3.64791042082+11925.27409260060*x);
L1+=0.00000000041*cost(5.04048954693+27832.03821928320*x);
L1+=0.00000000042*cost(5.19292937193+19004.64794940840*x);
L1+=0.00000000040*cost(2.57120233428+24356.78078864160*x);
L1+=0.00000000038*cost(3.49190341464+226858.23855437008*x);
L1+=0.00000000039*cost(4.61184303844+95.97922721780*x);
L1+=0.00000000043*cost(2.20648228147+13521.75144159140*x);
L1+=0.00000000040*cost(5.83461945819+16193.65917750039*x);
L1+=0.00000000045*cost(3.73714372195+7875.67186362420*x);
L1+=0.00000000043*cost(1.14078465002+49.75702547180*x);
L1+=0.00000000037*cost(1.29390383811+310.84079886840*x);
L1+=0.00000000038*cost(0.95970925950+664.75604513000*x);
L1+=0.00000000037*cost(4.27532649462+6709.67404086740*x);
L1+=0.00000000038*cost(2.20108541046+28628.33622609960*x);
L1+=0.00000000039*cost(0.85957361635+16522.65971600220*x);
L1+=0.00000000040*cost(4.35214003837+48739.85989708300*x);
L1+=0.00000000036*cost(1.68167662194+10344.29506538580*x);
L1+=0.00000000040*cost(5.13217319067+15664.03552270859*x);
L1+=0.00000000036*cost(3.72187132496+30774.50164257480*x);
L1+=0.00000000036*cost(3.32158458257+16207.88627150200*x);
L1+=0.00000000045*cost(3.94202418608+10988.80815753500*x);
L1+=0.00000000039*cost(1.51948786199+12029.34718788740*x);
L1+=0.00000000026*cost(3.87685883180+6262.72053059260*x);
L1+=0.00000000024*cost(4.91804163466+19651.04848109800*x);
L1+=0.00000000023*cost(0.29300197709+13362.44970679920*x);
L1+=0.00000000021*cost(3.18605672363+6277.55292568400*x);
L1+=0.00000000021*cost(6.07546891132+18139.29450141590*x);
L1+=0.00000000022*cost(2.31199937177+6303.43116939020*x);
L1+=0.00000000021*cost(3.58418394393+18209.33026366019*x);
L1+=0.00000000026*cost(2.06801296900+12573.26524698360*x);
L1+=0.00000000021*cost(1.56857722317+13341.67431130680*x);
L1+=0.00000000024*cost(5.72605158675+29864.33402730900*x);
L1+=0.00000000024*cost(1.40237993205+14712.31711645800*x);
L1+=0.00000000025*cost(5.71466092822+25934.12433108940*x);

double L2=0;
L2+=0.00052918870;
L2+=0.00008719837*cost(1.07209665242+6283.07584999140*x);
L2+=0.00000309125*cost(0.86728818832+12566.15169998280*x);
L2+=0.00000027339*cost(0.05297871691+3.52311834900*x);
L2+=0.00000016334*cost(5.18826691036+26.29831979980*x);
L2+=0.00000015752*cost(3.68457889430+155.42039943420*x);
L2+=0.00000009541*cost(0.75742297675+18849.22754997420*x);
L2+=0.00000008937*cost(2.05705419118+77713.77146812050*x);
L2+=0.00000006952*cost(0.82673305410+775.52261132400*x);
L2+=0.00000005064*cost(4.66284525271+1577.34354244780*x);
L2+=0.00000004061*cost(1.03057162962+7.11354700080*x);
L2+=0.00000003463*cost(5.14074632811+796.29800681640*x);
L2+=0.00000003169*cost(6.05291851171+5507.55323866740*x);
L2+=0.00000003020*cost(1.19246506441+242.72860397400*x);
L2+=0.00000002886*cost(6.11652627155+529.69096509460*x);
L2+=0.00000003810*cost(3.44050803490+5573.14280143310*x);
L2+=0.00000002714*cost(0.30637881025+398.14900340820*x);
L2+=0.00000002371*cost(4.38118838167+5223.69391980220*x);
L2+=0.00000002538*cost(2.27992810679+553.56940284240*x);
L2+=0.00000002079*cost(3.75435330484+0.98032106820*x);
L2+=0.00000001675*cost(0.90216407959+951.71840625060*x);
L2+=0.00000001534*cost(5.75900462759+1349.86740965880*x);
L2+=0.00000001224*cost(2.97328088405+2146.16541647520*x);
L2+=0.00000001449*cost(4.36415913970+1748.01641306700*x);
L2+=0.00000001341*cost(3.72061130861+1194.44701022460*x);
L2+=0.00000001254*cost(2.94846826628+6438.49624942560*x);
L2+=0.00000000999*cost(5.98640014468+6286.59896834040*x);
L2+=0.00000000917*cost(4.79788687522+5088.62883976680*x);
L2+=0.00000000828*cost(3.31321076572+213.29909543800*x);
L2+=0.00000001103*cost(1.27104454479+161000.68573767410*x);
L2+=0.00000000762*cost(3.41582762988+5486.77784317500*x);
L2+=0.00000001044*cost(0.60409577691+3154.68708489560*x);
L2+=0.00000000887*cost(5.23465144638+7084.89678111520*x);
L2+=0.00000000645*cost(1.60096192515+2544.31441988340*x);
L2+=0.00000000681*cost(3.43155669169+4694.00295470760*x);
L2+=0.00000000605*cost(2.47806340546+10977.07880469900*x);
L2+=0.00000000706*cost(6.19393222575+4690.47983635860*x);
L2+=0.00000000643*cost(1.98042503148+801.82093112380*x);
L2+=0.00000000502*cost(1.44394375363+6836.64525283380*x);
L2+=0.00000000490*cost(2.34129524194+1592.59601363280*x);
L2+=0.00000000458*cost(1.30876448575+4292.33083295040*x);
L2+=0.00000000431*cost(0.03526421494+7234.79425624200*x);
L2+=0.00000000379*cost(3.17030522615+6309.37416979120*x);
L2+=0.00000000348*cost(0.99049550009+6040.34724601740*x);
L2+=0.00000000386*cost(1.57019797263+71430.69561812909*x);
L2+=0.00000000347*cost(0.67013291338+1059.38193018920*x);
L2+=0.00000000458*cost(3.81499443681+149854.40013480789*x);
L2+=0.00000000302*cost(1.91760044838+10447.38783960440*x);
L2+=0.00000000307*cost(3.55343347416+8031.09226305840*x);
L2+=0.00000000395*cost(4.93701776616+7632.94325965020*x);
L2+=0.00000000314*cost(3.18093696547+2352.86615377180*x);
L2+=0.00000000282*cost(4.41936437052+9437.76293488700*x);
L2+=0.00000000276*cost(2.71314254553+3894.18182954220*x);
L2+=0.00000000298*cost(2.52037474210+6127.65545055720*x);
L2+=0.00000000230*cost(1.37790215549+4705.73230754360*x);
L2+=0.00000000252*cost(0.55330133471+6279.55273164240*x);
L2+=0.00000000255*cost(5.26570187369+6812.76681508600*x);
L2+=0.00000000275*cost(0.67264264272+25132.30339996560*x);
L2+=0.00000000178*cost(0.92820785174+1990.74501704100*x);
L2+=0.00000000221*cost(0.63897368842+6256.77753019160*x);
L2+=0.00000000155*cost(0.77319790838+14143.49524243060*x);
L2+=0.00000000150*cost(2.40470465561+426.59819087600*x);
L2+=0.00000000196*cost(6.06877865012+640.87760738220*x);
L2+=0.00000000137*cost(2.21679460145+8429.24126646660*x);
L2+=0.00000000127*cost(3.26094223174+17789.84561978500*x);
L2+=0.00000000128*cost(5.47237279946+12036.46073488820*x);
L2+=0.00000000122*cost(2.16291082757+10213.28554621100*x);
L2+=0.00000000118*cost(0.45789822268+7058.59846131540*x);
L2+=0.00000000141*cost(2.34932647403+11506.76976979360*x);
L2+=0.00000000100*cost(0.85621569847+6290.18939699220*x);
L2+=0.00000000092*cost(5.10587476002+7079.37385680780*x);
L2+=0.00000000126*cost(2.65428307012+88860.05707098669*x);
L2+=0.00000000106*cost(5.85646710022+7860.41939243920*x);
L2+=0.00000000084*cost(3.57457554262+16730.46368959580*x);
L2+=0.00000000089*cost(4.21433259618+83996.84731811189*x);
L2+=0.00000000097*cost(5.57938280855+13367.97263110660*x);
L2+=0.00000000102*cost(2.05853060226+87.30820453981*x);
L2+=0.00000000080*cost(4.73792651816+11926.25441366880*x);
L2+=0.00000000080*cost(5.41418965044+10973.55568635000*x);
L2+=0.00000000106*cost(4.10978997399+3496.03282613400*x);
L2+=0.00000000102*cost(3.62650006043+244287.60000722769*x);
L2+=0.00000000075*cost(4.89483161769+5643.17856367740*x);
L2+=0.00000000087*cost(0.42863750683+11015.10647733480*x);
L2+=0.00000000069*cost(1.88908760720+10177.25767953360*x);
L2+=0.00000000089*cost(1.35567273119+6681.22485339960*x);
L2+=0.00000000066*cost(0.99455837265+6525.80445396540*x);
L2+=0.00000000067*cost(5.51240997070+3097.88382272579*x);
L2+=0.00000000076*cost(2.72016814799+4164.31198961300*x);
L2+=0.00000000063*cost(1.44349902540+9917.69687450980*x);
L2+=0.00000000078*cost(3.51469733747+11856.21865142450*x);
L2+=0.00000000085*cost(0.50956043858+10575.40668294180*x);
L2+=0.00000000067*cost(3.62043033405+16496.36139620240*x);
L2+=0.00000000055*cost(5.24637517308+3340.61242669980*x);
L2+=0.00000000048*cost(5.43966777314+20426.57109242200*x);
L2+=0.00000000064*cost(5.79535817813+2388.89402044920*x);
L2+=0.00000000046*cost(5.43499966519+6275.96230299060*x);
L2+=0.00000000050*cost(3.86263598617+5729.50644714900*x);
L2+=0.00000000044*cost(1.52269529228+12168.00269657460*x);
L2+=0.00000000057*cost(4.96352373486+14945.31617355440*x);
L2+=0.00000000045*cost(1.00861230160+8635.94200376320*x);
L2+=0.00000000043*cost(3.30685683359+9779.10867612540*x);
L2+=0.00000000042*cost(0.63481258930+2699.73481931760*x);
L2+=0.00000000041*cost(5.67996766641+11712.95531823080*x);
L2+=0.00000000056*cost(4.34024451468+90955.55169449610*x);
L2+=0.00000000041*cost(5.81722212845+709.93304855830*x);
L2+=0.00000000053*cost(6.17052087143+233141.31440436149*x);
L2+=0.00000000037*cost(3.12495025087+16200.77272450120*x);
L2+=0.00000000035*cost(5.76973458495+12569.67481833180*x);
L2+=0.00000000037*cost(0.31656444326+24356.78078864160*x);
L2+=0.00000000035*cost(0.96229051027+17298.18232732620*x);
L2+=0.00000000033*cost(5.23130355867+5331.35744374080*x);
L2+=0.00000000035*cost(0.62517020593+25158.60171976540*x);
L2+=0.00000000035*cost(0.80004512129+13916.01910964160*x);
L2+=0.00000000037*cost(2.89336088688+12721.57209941700*x);
L2+=0.00000000030*cost(4.50198402401+23543.23050468179*x);
L2+=0.00000000030*cost(5.31355708693+18319.53658487960*x);
L2+=0.00000000029*cost(3.47275229977+13119.72110282519*x);
L2+=0.00000000029*cost(3.11002782516+4136.91043351620*x);
L2+=0.00000000032*cost(5.52273255667+5753.38488489680*x);
L2+=0.00000000035*cost(3.79699996680+143571.32428481648*x);
L2+=0.00000000026*cost(1.50634201907+154717.60988768269*x);
L2+=0.00000000030*cost(3.53519084118+6284.05617105960*x);
L2+=0.00000000023*cost(4.41808025967+5884.92684658320*x);
L2+=0.00000000025*cost(1.38477355808+65147.61976813770*x);
L2+=0.00000000023*cost(3.49782549797+7477.52286021600*x);
L2+=0.00000000019*cost(3.14329413716+6496.37494542940*x);
L2+=0.00000000019*cost(2.20135125199+18073.70493865020*x);
L2+=0.00000000019*cost(4.95020255309+3930.20969621960*x);
L2+=0.00000000019*cost(0.57998702747+31415.37924995700*x);
L2+=0.00000000021*cost(1.75474323399+12139.55350910680*x);
L2+=0.00000000019*cost(3.92233070499+19651.04848109800*x);
L2+=0.00000000014*cost(0.98131213224+12559.03815298200*x);
L2+=0.00000000019*cost(4.93309333729+2942.46342329160*x);
L2+=0.00000000016*cost(5.55997534558+8827.39026987480*x);
L2+=0.00000000013*cost(1.68808165516+4535.05943692440*x);
L2+=0.00000000013*cost(0.33982116161+4933.20844033260*x);
L2+=0.00000000012*cost(1.85426309994+5856.47765911540*x);
L2+=0.00000000010*cost(4.82763996845+13095.84266507740*x);
L2+=0.00000000011*cost(5.38005490571+11790.62908865880*x);
L2+=0.00000000010*cost(1.40815507226+10988.80815753500*x);
L2+=0.00000000011*cost(3.05005267431+17260.15465469040*x);
L2+=0.00000000010*cost(4.93364992366+12352.85260454480*x);

double L3=0;
L3+=0.00000289226*cost(5.84384198723+6283.07584999140*x);
L3+=0.00000034955;
L3+=0.00000016819*cost(5.48766912348+12566.15169998280*x);
L3+=0.00000002962*cost(5.19577265202+155.42039943420*x);
L3+=0.00000001288*cost(4.72200252235+3.52311834900*x);
L3+=0.00000000635*cost(5.96925937141+242.72860397400*x);
L3+=0.00000000714*cost(5.30045809128+18849.22754997420*x);
L3+=0.00000000402*cost(3.78682982419+553.56940284240*x);
L3+=0.00000000072*cost(4.29768126180+6286.59896834040*x);
L3+=0.00000000067*cost(0.90721687647+6127.65545055720*x);
L3+=0.00000000036*cost(5.24029648014+6438.49624942560*x);
L3+=0.00000000024*cost(5.16003960716+25132.30339996560*x);
L3+=0.00000000023*cost(3.01921570335+6309.37416979120*x);
L3+=0.00000000017*cost(5.82863573502+6525.80445396540*x);
L3+=0.00000000017*cost(3.67772863930+71430.69561812909*x);
L3+=0.00000000009*cost(4.58467294499+1577.34354244780*x);
L3+=0.00000000008*cost(1.40626662824+11856.21865142450*x);
L3+=0.00000000008*cost(5.07561257196+6256.77753019160*x);
L3+=0.00000000007*cost(2.82473374405+83996.84731811189*x);
L3+=0.00000000005*cost(2.71488713339+10977.07880469900*x);
L3+=0.00000000005*cost(3.76879847273+12036.46073488820*x);
L3+=0.00000000005*cost(4.28412873331+6275.96230299060*x);

double L4=0;
L4-=0.00000114084;
L4+=0.00000007717*cost(4.13446589358+6283.07584999140*x);
L4+=0.00000000765*cost(3.83803776214+12566.15169998280*x);
L4+=0.00000000420*cost(0.41925861858+155.42039943420*x);
L4+=0.00000000040*cost(3.59847585840+18849.22754997420*x);
L4+=0.00000000041*cost(3.14398414077+3.52311834900*x);
L4+=0.00000000035*cost(5.00298940826+5573.14280143310*x);
L4+=0.00000000013*cost(0.48794833701+77713.77146812050*x);
L4+=0.00000000010*cost(5.64801766350+6127.65545055720*x);
L4+=0.00000000008*cost(2.84160570605+161000.68573767410*x);
L4+=0.00000000002*cost(0.54912904658+6438.49624942560*x);

double L5=0;
L5-=0.00000000878;
L5+=0.00000000172*cost(2.76579069510+6283.07584999140*x);
L5+=0.00000000050*cost(2.01353298182+155.42039943420*x);
L5+=0.00000000028*cost(2.21496423926+12566.15169998280*x);
L5+=0.00000000005*cost(1.75600058765+18849.22754997420*x);
	
double x2 = x*x;
double x3 = x2*x;
double x4 = x3*x;
double x5 = x4*x;

double r2d0=180./pi0;
return 1 * r2d0*norm2pi(L0+L1*x+L2*x2+L3*x3+L4*x4+L5*x5);	
}

//Heliocentric latitude of Earth
double Bearth(double x)
{
double Bx0=0;
Bx0+=0.00000279620*cost(3.19870156017+84334.66158130829*x);
Bx0+=0.00000101643*cost(5.42248619256+5507.55323866740*x);
Bx0+=0.00000080445*cost(3.88013204458+5223.69391980220*x);
Bx0+=0.00000043806*cost(3.70444689758+2352.86615377180*x);
Bx0+=0.00000031933*cost(4.00026369781+1577.34354244780*x);
Bx0+=0.00000022724*cost(3.98473831560+1047.74731175470*x);
Bx0+=0.00000016392*cost(3.56456119782+5856.47765911540*x);
Bx0+=0.00000018141*cost(4.98367470263+6283.07584999140*x);
Bx0+=0.00000014443*cost(3.70275614914+9437.76293488700*x);
Bx0+=0.00000014304*cost(3.41117857525+10213.28554621100*x);
Bx0+=0.00000011246*cost(4.82820690530+14143.49524243060*x);
Bx0+=0.00000010900*cost(2.08574562327+6812.76681508600*x);
Bx0+=0.00000009714*cost(3.47303947752+4694.00295470760*x);
Bx0+=0.00000010367*cost(4.05663927946+71092.88135493269*x);
Bx0+=0.00000008775*cost(4.44016515669+5753.38488489680*x);
Bx0+=0.00000008366*cost(4.99251512180+7084.89678111520*x);
Bx0+=0.00000006921*cost(4.32559054073+6275.96230299060*x);
Bx0+=0.00000009145*cost(1.14182646613+6620.89011318780*x);
Bx0+=0.00000007194*cost(3.60193205752+529.69096509460*x);
Bx0+=0.00000007698*cost(5.55425745881+167621.57585086189*x);
Bx0+=0.00000005285*cost(2.48446991566+4705.73230754360*x);
Bx0+=0.00000005208*cost(6.24992674537+18073.70493865020*x);
Bx0+=0.00000004529*cost(2.33827747356+6309.37416979120*x);
Bx0+=0.00000005579*cost(4.41023653738+7860.41939243920*x);
Bx0+=0.00000004743*cost(0.70995680136+5884.92684658320*x);
Bx0+=0.00000004301*cost(1.10255777773+6681.22485339960*x);
Bx0+=0.00000003849*cost(1.82229412531+5486.77784317500*x);
Bx0+=0.00000004093*cost(5.11700141207+13367.97263110660*x);
Bx0+=0.00000003681*cost(0.43793170356+3154.68708489560*x);
Bx0+=0.00000003420*cost(5.42034800952+6069.77675455340*x);
Bx0+=0.00000003617*cost(6.04641937526+3930.20969621960*x);
Bx0+=0.00000003670*cost(4.58210192227+12194.03291462090*x);
Bx0+=0.00000002918*cost(1.95463881126+10977.07880469900*x);
Bx0+=0.00000002797*cost(5.61259275048+11790.62908865880*x);
Bx0+=0.00000002502*cost(0.60499729367+6496.37494542940*x);
Bx0+=0.00000002319*cost(5.01648216014+1059.38193018920*x);
Bx0+=0.00000002684*cost(1.39470396488+22003.91463486980*x);
Bx0+=0.00000002428*cost(3.24183056052+78051.58573131690*x);
Bx0+=0.00000002120*cost(4.30691000285+5643.17856367740*x);
Bx0+=0.00000002257*cost(3.15557225618+90617.73743129970*x);
Bx0+=0.00000001813*cost(3.75574218285+3340.61242669980*x);
Bx0+=0.00000002226*cost(2.79699346659+12036.46073488820*x);
Bx0+=0.00000001888*cost(0.86991545823+8635.94200376320*x);
Bx0+=0.00000001517*cost(1.95852055701+398.14900340820*x);
Bx0+=0.00000001581*cost(3.19976230948+5088.62883976680*x);
Bx0+=0.00000001421*cost(6.25530883827+2544.31441988340*x);
Bx0+=0.00000001595*cost(0.25619915135+17298.18232732620*x);
Bx0+=0.00000001391*cost(4.69964175561+7058.59846131540*x);
Bx0+=0.00000001478*cost(2.81808207569+25934.12433108940*x);
Bx0+=0.00000001481*cost(3.65823554806+11506.76976979360*x);
Bx0+=0.00000001693*cost(4.95689385293+156475.29024799570*x);
Bx0+=0.00000001183*cost(1.29343061246+775.52261132400*x);
Bx0+=0.00000001114*cost(2.37889311846+3738.76143010800*x);
Bx0+=0.00000000994*cost(4.30088900425+9225.53927328300*x);
Bx0+=0.00000000924*cost(3.06451026812+4164.31198961300*x);
Bx0+=0.00000000867*cost(0.55606931068+8429.24126646660*x);
Bx0+=0.00000000988*cost(5.97286104208+7079.37385680780*x);
Bx0+=0.00000000824*cost(1.50984806173+10447.38783960440*x);
Bx0+=0.00000000915*cost(0.12635654592+11015.10647733480*x);
Bx0+=0.00000000742*cost(1.99159139281+26087.90314157420*x);
Bx0-=0.00000001039;
Bx0+=0.00000000850*cost(4.24120016095+29864.33402730900*x);
Bx0+=0.00000000755*cost(2.89631873320+4732.03062734340*x);
Bx0+=0.00000000714*cost(1.37548118603+2146.16541647520*x);
Bx0+=0.00000000708*cost(1.91406542362+8031.09226305840*x);
Bx0+=0.00000000746*cost(0.57893808616+796.29800681640*x);
Bx0+=0.00000000802*cost(5.12339137230+2942.46342329160*x);
Bx0+=0.00000000751*cost(1.67479850166+21228.39202354580*x);
Bx0+=0.00000000602*cost(4.09976538826+64809.80550494129*x);
Bx0+=0.00000000594*cost(3.49580704962+16496.36139620240*x);
Bx0+=0.00000000592*cost(4.59481504319+4690.47983635860*x);
Bx0+=0.00000000530*cost(5.73979295200+8827.39026987480*x);
Bx0+=0.00000000503*cost(5.66433137112+33794.54372352860*x);
Bx0+=0.00000000483*cost(1.57106522411+801.82093112380*x);
Bx0+=0.00000000438*cost(0.06707733767+3128.38876509580*x);
Bx0+=0.00000000423*cost(2.86944595927+12566.15169998280*x);
Bx0+=0.00000000504*cost(3.26207669160+7632.94325965020*x);
Bx0+=0.00000000552*cost(1.02926440457+239762.20451754928*x);
Bx0+=0.00000000427*cost(3.67434378210+213.29909543800*x);
Bx0+=0.00000000404*cost(1.46193297142+15720.83878487840*x);
Bx0+=0.00000000503*cost(4.85802444134+6290.18939699220*x);
Bx0+=0.00000000417*cost(0.81920713533+5216.58037280140*x);
Bx0+=0.00000000365*cost(0.01002966162+12168.00269657460*x);
Bx0+=0.00000000363*cost(1.28376436579+6206.80977871580*x);
Bx0+=0.00000000353*cost(4.70059133110+7234.79425624200*x);
Bx0+=0.00000000415*cost(0.96862624175+4136.91043351620*x);
Bx0+=0.00000000387*cost(3.09145061418+25158.60171976540*x);
Bx0+=0.00000000373*cost(2.65119262792+7342.45778018060*x);
Bx0+=0.00000000361*cost(2.97762937739+9623.68827669120*x);
Bx0+=0.00000000418*cost(3.75759994446+5230.80746680300*x);
Bx0+=0.00000000396*cost(1.22507712354+6438.49624942560*x);
Bx0+=0.00000000322*cost(1.21162178805+8662.24032356300*x);
Bx0+=0.00000000284*cost(5.64170320068+1589.07289528380*x);
Bx0+=0.00000000379*cost(1.72248432748+14945.31617355440*x);
Bx0+=0.00000000320*cost(3.94161159962+7330.82316174610*x);
Bx0+=0.00000000313*cost(5.47602376446+1194.44701022460*x);
Bx0+=0.00000000292*cost(1.38971327603+11769.85369316640*x);
Bx0+=0.00000000305*cost(0.80429352049+37724.75341974820*x);
Bx0+=0.00000000257*cost(5.81382809757+426.59819087600*x);
Bx0+=0.00000000265*cost(6.10358507671+6836.64525283380*x);
Bx0+=0.00000000250*cost(4.56452895547+7477.52286021600*x);
Bx0+=0.00000000266*cost(2.62926282354+7238.67559160000*x);
Bx0+=0.00000000263*cost(6.22089501237+6133.51265285680*x);
Bx0+=0.00000000306*cost(2.79682380531+1748.01641306700*x);
Bx0+=0.00000000236*cost(2.46093023714+11371.70468975820*x);
Bx0+=0.00000000316*cost(1.62662805006+250908.49012041549*x);
Bx0+=0.00000000216*cost(3.68721275185+5849.36411211460*x);
Bx0+=0.00000000230*cost(0.36165162947+5863.59120611620*x);
Bx0+=0.00000000233*cost(5.03509933858+20426.57109242200*x);
Bx0+=0.00000000200*cost(5.86073159059+4535.05943692440*x);
Bx0+=0.00000000277*cost(4.65400292395+82239.16695779889*x);
Bx0+=0.00000000209*cost(3.72323200804+10973.55568635000*x);
Bx0+=0.00000000199*cost(5.05186622555+5429.87946823940*x);
Bx0+=0.00000000256*cost(2.40923279770+19651.04848109800*x);
Bx0+=0.00000000210*cost(4.50691909144+29088.81141598500*x);
Bx0+=0.00000000181*cost(6.00294783127+4292.33083295040*x);
Bx0+=0.00000000249*cost(0.12900984422+154379.79562448629*x);
Bx0+=0.00000000209*cost(3.87759458598+17789.84561978500*x);
Bx0+=0.00000000225*cost(3.18339652605+18875.52586977400*x);
Bx0+=0.00000000191*cost(4.53897489299+18477.10876461230*x);
Bx0+=0.00000000172*cost(2.09694183014+13095.84266507740*x);
Bx0+=0.00000000182*cost(3.16107943500+16730.46368959580*x);
Bx0+=0.00000000188*cost(2.22746128596+41654.96311596780*x);
Bx0+=0.00000000164*cost(5.18686275017+5481.25491886760*x);
Bx0+=0.00000000160*cost(2.49298855159+12592.45001978260*x);
Bx0+=0.00000000155*cost(1.59595438230+10021.83728009940*x);
Bx0+=0.00000000135*cost(0.21349051064+10988.80815753500*x);
Bx0+=0.00000000178*cost(3.80375177970+23581.25817731760*x);
Bx0+=0.00000000123*cost(1.66800739151+15110.46611986620*x);
Bx0+=0.00000000122*cost(2.72678272244+18849.22754997420*x);
Bx0+=0.00000000126*cost(1.17675512910+14919.01785375460*x);
Bx0+=0.00000000142*cost(3.95053441332+337.81426319640*x);
Bx0+=0.00000000116*cost(6.06340906229+6709.67404086740*x);
Bx0+=0.00000000137*cost(3.52143246757+12139.55350910680*x);
Bx0+=0.00000000136*cost(2.92179113542+32217.20018108080*x);
Bx0+=0.00000000110*cost(3.51203379263+18052.92954315780*x);
Bx0+=0.00000000147*cost(4.63371971408+22805.73556599360*x);
Bx0+=0.00000000108*cost(5.45280814878+7.11354700080*x);
Bx0+=0.00000000148*cost(0.65447253687+95480.94718417450*x);
Bx0+=0.00000000119*cost(5.92110458985+33019.02111220460*x);
Bx0+=0.00000000110*cost(5.34824206306+639.89728631400*x);
Bx0+=0.00000000106*cost(3.71081682629+14314.16811304980*x);
Bx0+=0.00000000139*cost(6.17607198418+24356.78078864160*x);
Bx0+=0.00000000118*cost(5.59738712670+161338.50000087050*x);
Bx0+=0.00000000117*cost(3.65065271640+45585.17281218740*x);
Bx0+=0.00000000127*cost(4.74596574209+49515.38250840700*x);
Bx0+=0.00000000120*cost(1.04211499785+6915.85958930460*x);
Bx0+=0.00000000120*cost(5.60638811846+5650.29211067820*x);
Bx0+=0.00000000115*cost(3.10668213289+14712.31711645800*x);
Bx0+=0.00000000099*cost(0.69018940049+12779.45079542080*x);
Bx0+=0.00000000097*cost(1.07908724794+9917.69687450980*x);
Bx0+=0.00000000093*cost(2.62295197319+17260.15465469040*x);
Bx0+=0.00000000099*cost(4.45774681732+4933.20844033260*x);
Bx0+=0.00000000123*cost(1.37488922089+28286.99048486120*x);
Bx0+=0.00000000121*cost(5.19767249813+27511.46787353720*x);
Bx0+=0.00000000105*cost(0.87192267806+77375.95720492408*x);
Bx0+=0.00000000087*cost(3.93637812950+17654.78053974960*x);
Bx0+=0.00000000122*cost(2.23956068680+83997.09113559539*x);
Bx0+=0.00000000087*cost(4.18201600952+22779.43724619380*x);
Bx0+=0.00000000104*cost(4.59580877295+1349.86740965880*x);
Bx0+=0.00000000102*cost(2.83545248411+12352.85260454480*x);
Bx0+=0.00000000102*cost(3.97386522171+10818.13528691580*x);
Bx0+=0.00000000101*cost(4.32892825857+36147.40987730040*x);
Bx0+=0.00000000094*cost(5.00001709261+150192.21439800429*x);
Bx0+=0.00000000077*cost(3.97199369296+1592.59601363280*x);
Bx0+=0.00000000100*cost(6.07733097102+26735.94526221320*x);
Bx0+=0.00000000086*cost(5.26029638250+28313.28880466100*x);
Bx0+=0.00000000093*cost(4.31900620254+44809.65020086340*x);
Bx0+=0.00000000076*cost(6.22743405935+13521.75144159140*x);
Bx0+=0.00000000072*cost(1.55820597747+6256.77753019160*x);
Bx0+=0.00000000082*cost(4.95202664555+10575.40668294180*x);
Bx0+=0.00000000082*cost(1.69647647075+1990.74501704100*x);
Bx0+=0.00000000075*cost(2.29836095644+3634.62102451840*x);
Bx0+=0.00000000075*cost(2.66367876557+16200.77272450120*x);
Bx0+=0.00000000087*cost(0.26630214764+31441.67756975680*x);
Bx0+=0.00000000077*cost(2.25530954137+5235.32853823670*x);
Bx0+=0.00000000076*cost(1.09869730846+12903.96596317920*x);
Bx0+=0.00000000058*cost(4.28246138307+12559.03815298200*x);
Bx0+=0.00000000064*cost(5.51112830114+173904.65170085328*x);
Bx0+=0.00000000056*cost(2.60133794851+73188.37597844210*x);
Bx0+=0.00000000055*cost(5.81483150022+143233.51002162008*x);
Bx0+=0.00000000054*cost(3.38482031504+323049.11878710288*x);
Bx0+=0.00000000039*cost(3.28500401343+71768.50988132549*x);
Bx0+=0.00000000039*cost(3.11239910690+96900.81328129109*x);

double B1=0;
B1+=0.00000009030*cost(3.89729061890+5507.55323866740*x);
B1+=0.00000006177*cost(1.73038850355+5223.69391980220*x);
B1+=0.00000003800*cost(5.24404145734+2352.86615377180*x);
B1+=0.00000002834*cost(2.47345037450+1577.34354244780*x);
B1+=0.00000001817*cost(0.41874743765+6283.07584999140*x);
B1+=0.00000001499*cost(1.83320979291+5856.47765911540*x);
B1+=0.00000001466*cost(5.69401926017+5753.38488489680*x);
B1+=0.00000001301*cost(2.18890066314+9437.76293488700*x);
B1+=0.00000001233*cost(4.95222451476+10213.28554621100*x);
B1+=0.00000001021*cost(0.12866660208+7860.41939243920*x);
B1+=0.00000000982*cost(0.09005453285+14143.49524243060*x);
B1+=0.00000000865*cost(1.73949953555+3930.20969621960*x);
B1+=0.00000000581*cost(2.26949174067+5884.92684658320*x);
B1+=0.00000000524*cost(5.65662503159+529.69096509460*x);
B1+=0.00000000473*cost(6.22750969242+6309.37416979120*x);
B1+=0.00000000451*cost(1.53288619213+18073.70493865020*x);
B1+=0.00000000364*cost(3.61614477374+13367.97263110660*x);
B1+=0.00000000372*cost(3.22470721320+6275.96230299060*x);
B1+=0.00000000268*cost(2.34341267879+11790.62908865880*x);
B1+=0.00000000322*cost(0.94084045832+6069.77675455340*x);
B1+=0.00000000232*cost(0.26781182579+7058.59846131540*x);
B1+=0.00000000216*cost(6.05952221329+10977.07880469900*x);
B1+=0.00000000232*cost(2.93325646109+22003.91463486980*x);
B1+=0.00000000204*cost(3.86264841382+6496.37494542940*x);
B1+=0.00000000202*cost(2.81892511133+15720.83878487840*x);
B1+=0.00000000185*cost(4.93512381859+12036.46073488820*x);
B1+=0.00000000220*cost(3.99305643742+6812.76681508600*x);
B1+=0.00000000166*cost(1.74970002999+11506.76976979360*x);
B1+=0.00000000212*cost(1.57166285369+4694.00295470760*x);
B1+=0.00000000157*cost(1.08259734788+5643.17856367740*x);
B1+=0.00000000154*cost(5.99434678412+5486.77784317500*x);
B1+=0.00000000144*cost(5.23285656085+78051.58573131690*x);
B1+=0.00000000144*cost(1.16454655948+90617.73743129970*x);
B1+=0.00000000137*cost(2.67760436027+6290.18939699220*x);
B1+=0.00000000180*cost(2.06509026215+7084.89678111520*x);
B1+=0.00000000121*cost(5.90212574947+9225.53927328300*x);
B1+=0.00000000150*cost(2.00175038718+5230.80746680300*x);
B1+=0.00000000149*cost(5.06157254516+17298.18232732620*x);
B1+=0.00000000118*cost(5.39979058038+3340.61242669980*x);
B1+=0.00000000161*cost(3.32421999691+6283.31966747490*x);
B1+=0.00000000121*cost(4.36722193162+19651.04848109800*x);
B1+=0.00000000116*cost(5.83462858507+4705.73230754360*x);
B1+=0.00000000128*cost(4.35489873365+25934.12433108940*x);
B1+=0.00000000143;
B1+=0.00000000109*cost(2.52157834166+6438.49624942560*x);
B1+=0.00000000099*cost(2.70727488041+5216.58037280140*x);
B1+=0.00000000103*cost(0.93782340879+8827.39026987480*x);
B1+=0.00000000082*cost(4.29214680390+8635.94200376320*x);
B1+=0.00000000079*cost(2.24085737326+1059.38193018920*x);
B1+=0.00000000097*cost(5.50959692365+29864.33402730900*x);
B1+=0.00000000072*cost(0.21891639822+21228.39202354580*x);
B1+=0.00000000071*cost(2.86755026812+6681.22485339960*x);
B1+=0.00000000074*cost(2.20184828895+37724.75341974820*x);
B1+=0.00000000063*cost(4.45586625948+7079.37385680780*x);
B1+=0.00000000061*cost(0.63918772258+33794.54372352860*x);
B1+=0.00000000047*cost(2.09070235724+3128.38876509580*x);
B1+=0.00000000047*cost(3.32543843300+26087.90314157420*x);
B1+=0.00000000049*cost(1.60680905005+6702.56049386660*x);
B1+=0.00000000057*cost(0.11215813438+29088.81141598500*x);
B1+=0.00000000056*cost(5.47982934911+775.52261132400*x);
B1+=0.00000000050*cost(1.89396788463+12139.55350910680*x);
B1+=0.00000000047*cost(2.97214907240+20426.57109242200*x);
B1+=0.00000000041*cost(5.55329394890+11015.10647733480*x);
B1+=0.00000000041*cost(5.91861144924+23581.25817731760*x);
B1+=0.00000000045*cost(4.95273290181+5863.59120611620*x);
B1+=0.00000000050*cost(3.62740835096+41654.96311596780*x);
B1+=0.00000000037*cost(6.09033460601+64809.80550494129*x);
B1+=0.00000000037*cost(5.86153655431+12566.15169998280*x);
B1+=0.00000000046*cost(1.65798680284+25158.60171976540*x);
B1+=0.00000000038*cost(2.00673650251+426.59819087600*x);
B1+=0.00000000036*cost(6.24373396652+6283.14316029419*x);
B1+=0.00000000036*cost(0.40465162918+6283.00853968860*x);
B1+=0.00000000032*cost(6.03707103538+2942.46342329160*x);
B1+=0.00000000041*cost(4.86809570283+1592.59601363280*x);
B1+=0.00000000028*cost(4.38359423735+7632.94325965020*x);
B1+=0.00000000028*cost(6.03334294232+17789.84561978500*x);
B1+=0.00000000026*cost(3.88971333608+5331.35744374080*x);
B1+=0.00000000026*cost(5.94932724051+16496.36139620240*x);
B1+=0.00000000031*cost(1.44666331503+16730.46368959580*x);
B1+=0.00000000026*cost(6.26376705837+23543.23050468179*x);
B1+=0.00000000033*cost(0.93797239147+213.29909543800*x);
B1+=0.00000000026*cost(3.71858432944+13095.84266507740*x);
B1+=0.00000000027*cost(0.60565274405+10988.80815753500*x);
B1+=0.00000000023*cost(4.44388985550+18849.22754997420*x);
B1+=0.00000000028*cost(1.53862289477+6279.48542133960*x);
B1+=0.00000000028*cost(1.96831814872+6286.66627864320*x);
B1+=0.00000000028*cost(5.78094918529+15110.46611986620*x);
B1+=0.00000000026*cost(2.48165809843+5729.50644714900*x);
B1+=0.00000000020*cost(3.85655029499+9623.68827669120*x);
B1+=0.00000000021*cost(5.83006047147+7234.79425624200*x);
B1+=0.00000000021*cost(0.69628570421+398.14900340820*x);
B1+=0.00000000022*cost(5.02222806555+6127.65545055720*x);
B1+=0.00000000020*cost(3.47611265290+6148.01076995600*x);
B1+=0.00000000020*cost(0.90769829044+5481.25491886760*x);
B1+=0.00000000020*cost(0.03081589303+6418.14093002680*x);
B1+=0.00000000020*cost(3.74220084927+1589.07289528380*x);
B1+=0.00000000021*cost(4.00149269576+3154.68708489560*x);
B1+=0.00000000018*cost(1.58348238359+2118.76386037840*x);
B1+=0.00000000019*cost(0.85407021371+14712.31711645800*x);

double B2=0;
B2+=0.00000001662*cost(1.62703209173+84334.66158130829*x);
B2+=0.00000000492*cost(2.41382223971+1047.74731175470*x);
B2+=0.00000000344*cost(2.24353004539+5507.55323866740*x);
B2+=0.00000000258*cost(6.00906896311+5223.69391980220*x);
B2+=0.00000000131*cost(0.95447345240+6283.07584999140*x);
B2+=0.00000000086*cost(1.67530247303+7860.41939243920*x);
B2+=0.00000000090*cost(0.97606804452+1577.34354244780*x);
B2+=0.00000000090*cost(0.37899871725+2352.86615377180*x);
B2+=0.00000000089*cost(6.25807507963+10213.28554621100*x);
B2+=0.00000000075*cost(0.84213523741+167621.57585086189*x);
B2+=0.00000000052*cost(1.70501566089+14143.49524243060*x);
B2+=0.00000000057*cost(6.15295833679+12194.03291462090*x);
B2+=0.00000000051*cost(1.27616016740+5753.38488489680*x);
B2+=0.00000000051*cost(5.37229738682+6812.76681508600*x);
B2+=0.00000000034*cost(1.73672994279+7058.59846131540*x);
B2+=0.00000000038*cost(2.77761031485+10988.80815753500*x);
B2+=0.00000000046*cost(3.38617099014+156475.29024799570*x);
B2+=0.00000000021*cost(1.95248349228+8827.39026987480*x);
B2+=0.00000000018*cost(3.33419222028+8429.24126646660*x);
B2+=0.00000000019*cost(4.32945160287+17789.84561978500*x);
B2+=0.00000000017*cost(0.66191210656+6283.00853968860*x);
B2+=0.00000000018*cost(3.74885333072+11769.85369316640*x);
B2+=0.00000000017*cost(4.23058370776+10977.07880469900*x);
B2+=0.00000000017*cost(1.78116162721+5486.77784317500*x);
B2+=0.00000000021*cost(1.36972913918+12036.46073488820*x);
B2+=0.00000000017*cost(2.79601092529+796.29800681640*x);
B2+=0.00000000015*cost(0.43087848850+11790.62908865880*x);
B2+=0.00000000017*cost(1.35132152761+78051.58573131690*x);
B2+=0.00000000015*cost(1.17032155085+213.29909543800*x);
B2+=0.00000000018*cost(2.85221514199+5088.62883976680*x);
B2+=0.00000000017*cost(0.21780913672+6283.14316029419*x);
B2+=0.00000000013*cost(1.21201504386+25132.30339996560*x);
B2+=0.00000000012*cost(1.12953712197+90617.73743129970*x);
B2+=0.00000000012*cost(5.13714452592+7079.37385680780*x);
B2+=0.00000000013*cost(3.79842135217+4933.20844033260*x);
B2+=0.00000000012*cost(4.89407978213+3738.76143010800*x);
B2+=0.00000000015*cost(6.05682328852+398.14900340820*x);
B2+=0.00000000014*cost(4.81029291856+4694.00295470760*x);
B2+=0.00000000011*cost(0.61684523405+3128.38876509580*x);
B2+=0.00000000011*cost(5.32876538500+6040.34724601740*x);
B2+=0.00000000014*cost(5.27227350286+4535.05943692440*x);
B2+=0.00000000011*cost(2.39292099451+5331.35744374080*x);
B2+=0.00000000010*cost(4.45296532710+6525.80445396540*x);
B2+=0.00000000014*cost(4.66400985037+8031.09226305840*x);
B2+=0.00000000010*cost(3.22472385926+9437.76293488700*x);
B2+=0.00000000011*cost(3.80913404437+801.82093112380*x);
B2+=0.00000000010*cost(5.15032130575+11371.70468975820*x);
B2+=0.00000000013*cost(0.98720797401+5729.50644714900*x);
B2+=0.00000000009*cost(5.94191743597+7632.94325965020*x);

double B3=0;
B3+=0.00000000011*cost(0.23877262399+7860.41939243920*x);
B3+=0.00000000009*cost(1.16069982609+5507.55323866740*x);
B3+=0.00000000008*cost(1.65357552925+5884.92684658320*x);
B3+=0.00000000008*cost(2.86720038197+7058.59846131540*x);
B3+=0.00000000007*cost(3.04818741666+5486.77784317500*x);
B3+=0.00000000007*cost(2.59437103785+529.69096509460*x);
B3+=0.00000000008*cost(4.02863090524+6256.77753019160*x);
B3+=0.00000000008*cost(2.42003508927+5753.38488489680*x);
B3+=0.00000000006*cost(0.84181087594+6275.96230299060*x);
B3+=0.00000000006*cost(5.40160929468+1577.34354244780*x);
B3+=0.00000000007*cost(2.73399865247+6309.37416979120*x);

double B4=0;
B4+=0.00000000004*cost(0.79662198849+6438.49624942560*x);
B4+=0.00000000005*cost(0.84308705203+1047.74731175470*x);
B4+=0.00000000005*cost(0.05711572303+84334.66158130829*x);
B4+=0.00000000003*cost(3.46779895686+6279.55273164240*x);
B4+=0.00000000003*cost(2.89822201212+6127.65545055720*x);

double x2 = x*x;
double x3 = x2*x;
double x4 = x3*x;

double r2d0=180./pi0;

return 1 * r2d0 *(Bx0+B1*x+B2*x2+B3*x3+B4*x4);
}


//Heliocentric distance of Earth
double Rearth(double x)
{
double R0=0;
R0+=1.00013988799;
R0+=0.01670699626*cost(3.09846350771+6283.07584999140*x);
R0+=0.00013956023*cost(3.05524609620+12566.15169998280*x);
R0+=0.00003083720*cost(5.19846674381+77713.77146812050*x);
R0+=0.00001628461*cost(1.17387749012+5753.38488489680*x);
R0+=0.00001575568*cost(2.84685245825+7860.41939243920*x);
R0+=0.00000924799*cost(5.45292234084+11506.76976979360*x);
R0+=0.00000542444*cost(4.56409149777+3930.20969621960*x);
R0+=0.00000472110*cost(3.66100022149+5884.92684658320*x);
R0+=0.00000328780*cost(5.89983646482+5223.69391980220*x);
R0+=0.00000345983*cost(0.96368617687+5507.55323866740*x);
R0+=0.00000306784*cost(0.29867139512+5573.14280143310*x);
R0+=0.00000174844*cost(3.01193636534+18849.22754997420*x);
R0+=0.00000243189*cost(4.27349536153+11790.62908865880*x);
R0+=0.00000211829*cost(5.84714540314+1577.34354244780*x);
R0+=0.00000185752*cost(5.02194447178+10977.07880469900*x);
R0+=0.00000109835*cost(5.05510636285+5486.77784317500*x);
R0+=0.00000098316*cost(0.88681311277+6069.77675455340*x);
R0+=0.00000086499*cost(5.68959778254+15720.83878487840*x);
R0+=0.00000085825*cost(1.27083733351+161000.68573767410*x);
R0+=0.00000062916*cost(0.92177108832+529.69096509460*x);
R0+=0.00000057056*cost(2.01374292014+83996.84731811189*x);
R0+=0.00000064903*cost(0.27250613787+17260.15465469040*x);
R0+=0.00000049384*cost(3.24501240359+2544.31441988340*x);
R0+=0.00000055736*cost(5.24159798933+71430.69561812909*x);
R0+=0.00000042515*cost(6.01110242003+6275.96230299060*x);
R0+=0.00000046963*cost(2.57805070386+775.52261132400*x);
R0+=0.00000038968*cost(5.36071738169+4694.00295470760*x);
R0+=0.00000044661*cost(5.53715807302+9437.76293488700*x);
R0+=0.00000035660*cost(1.67468058995+12036.46073488820*x);
R0+=0.00000031921*cost(0.18368229781+5088.62883976680*x);
R0+=0.00000031846*cost(1.77775642085+398.14900340820*x);
R0+=0.00000033193*cost(0.24370300098+7084.89678111520*x);
R0+=0.00000038245*cost(2.39255343974+8827.39026987480*x);
R0+=0.00000028464*cost(1.21344868176+6286.59896834040*x);
R0+=0.00000037490*cost(0.82952922332+19651.04848109800*x);
R0+=0.00000036957*cost(4.90107591914+12139.55350910680*x);
R0+=0.00000034537*cost(1.84270693282+2942.46342329160*x);
R0+=0.00000026275*cost(4.58896850401+10447.38783960440*x);
R0+=0.00000024596*cost(3.78660875483+8429.24126646660*x);
R0+=0.00000023587*cost(0.26866117066+796.29800681640*x);
R0+=0.00000027793*cost(1.89934330904+6279.55273164240*x);
R0+=0.00000023927*cost(4.99598548138+5856.47765911540*x);
R0+=0.00000020349*cost(4.65267995431+2146.16541647520*x);
R0+=0.00000023287*cost(2.80783650928+14143.49524243060*x);
R0+=0.00000022103*cost(1.95004702988+3154.68708489560*x);
R0+=0.00000019506*cost(5.38227371393+2352.86615377180*x);
R0+=0.00000017958*cost(0.19871379385+6812.76681508600*x);
R0+=0.00000017174*cost(4.43315560735+10213.28554621100*x);
R0+=0.00000016190*cost(5.23160507859+17789.84561978500*x);
R0+=0.00000017314*cost(6.15200787916+16730.46368959580*x);
R0+=0.00000013814*cost(5.18962074032+8031.09226305840*x);
R0+=0.00000018833*cost(0.67306674027+149854.40013480789*x);
R0+=0.00000018331*cost(2.25348733734+23581.25817731760*x);
R0+=0.00000013641*cost(3.68516118804+4705.73230754360*x);
R0+=0.00000013139*cost(0.65289581324+13367.97263110660*x);
R0+=0.00000010414*cost(4.33285688538+11769.85369316640*x);
R0+=0.00000009978*cost(4.20126336355+6309.37416979120*x);
R0+=0.00000010169*cost(1.59390681369+4690.47983635860*x);
R0+=0.00000007564*cost(2.62560597390+6256.77753019160*x);
R0+=0.00000009661*cost(3.67586791220+27511.46787353720*x);
R0+=0.00000006743*cost(0.56270332741+3340.61242669980*x);
R0+=0.00000008743*cost(6.06359123461+1748.01641306700*x);
R0+=0.00000007786*cost(3.67371235637+12168.00269657460*x);
R0+=0.00000006633*cost(5.66149277792+11371.70468975820*x);
R0+=0.00000007712*cost(0.31242577789+7632.94325965020*x);
R0+=0.00000006592*cost(3.13576266188+801.82093112380*x);
R0+=0.00000007460*cost(5.64757188143+11926.25441366880*x);
R0+=0.00000006933*cost(2.92384586400+6681.22485339960*x);
R0+=0.00000006802*cost(1.42329806420+23013.53953958720*x);
R0+=0.00000006115*cost(5.13393615454+1194.44701022460*x);
R0+=0.00000006477*cost(2.64986648492+19804.82729158280*x);
R0+=0.00000005233*cost(4.62434053374+6438.49624942560*x);
R0+=0.00000006147*cost(3.02863936662+233141.31440436149*x);
R0+=0.00000004608*cost(1.72194702724+7234.79425624200*x);
R0+=0.00000004221*cost(1.55697533729+7238.67559160000*x);
R0+=0.00000005314*cost(2.40716580847+11499.65622279280*x);
R0+=0.00000005128*cost(5.32398965690+11513.88331679440*x);
R0+=0.00000004770*cost(0.25554312006+11856.21865142450*x);
R0+=0.00000005519*cost(2.09089154502+17298.18232732620*x);
R0+=0.00000005625*cost(4.34052903053+90955.55169449610*x);
R0+=0.00000004578*cost(4.46569641570+5746.27133789600*x);
R0+=0.00000003788*cost(4.90729383510+4164.31198961300*x);
R0+=0.00000005337*cost(5.09957905104+31441.67756975680*x);
R0+=0.00000003967*cost(1.20054555174+1349.86740965880*x);
R0+=0.00000004008*cost(3.03007204392+1059.38193018920*x);
R0+=0.00000003476*cost(0.76080277030+10973.55568635000*x);
R0+=0.00000004232*cost(1.05485713117+5760.49843189760*x);
R0+=0.00000004582*cost(3.76570026763+6386.16862421000*x);
R0+=0.00000003335*cost(3.13829943354+6836.64525283380*x);
R0+=0.00000003418*cost(3.00072390334+4292.33083295040*x);
R0+=0.00000003598*cost(5.70718084323+5643.17856367740*x);
R0+=0.00000003237*cost(4.16448773994+9917.69687450980*x);
R0+=0.00000004154*cost(2.59941292162+7058.59846131540*x);
R0+=0.00000003362*cost(4.54577697964+4732.03062734340*x);
R0+=0.00000002978*cost(1.30561268820+6283.14316029419*x);
R0+=0.00000002765*cost(0.51311975679+26.29831979980*x);
R0+=0.00000002802*cost(5.66263240521+8635.94200376320*x);
R0+=0.00000002927*cost(5.73787481548+16200.77272450120*x);
R0+=0.00000003164*cost(1.69140262657+11015.10647733480*x);
R0+=0.00000002598*cost(2.96244118586+25132.30339996560*x);
R0+=0.00000003519*cost(3.62639325753+244287.60000722769*x);
R0+=0.00000002676*cost(4.20725700850+18073.70493865020*x);
R0+=0.00000002978*cost(1.74971565805+6283.00853968860*x);
R0+=0.00000002287*cost(1.06975704977+14314.16811304980*x);
R0+=0.00000002863*cost(5.92838131397+14712.31711645800*x);
R0+=0.00000003071*cost(0.23793217002+35371.88726597640*x);
R0+=0.00000002656*cost(0.89959301780+12352.85260454480*x);
R0+=0.00000002415*cost(2.79975176257+709.93304855830*x);
R0+=0.00000002814*cost(3.51488206882+21228.39202354580*x);
R0+=0.00000001977*cost(2.61358297550+951.71840625060*x);
R0+=0.00000002548*cost(2.47684686575+6208.29425142410*x);
R0+=0.00000001999*cost(0.56090388160+7079.37385680780*x);
R0+=0.00000002305*cost(1.05376461628+22483.84857449259*x);
R0+=0.00000001855*cost(2.86090681163+5216.58037280140*x);
R0+=0.00000002157*cost(1.31396741861+154717.60988768269*x);
R0+=0.00000001970*cost(4.36929875289+167283.76158766549*x);
R0+=0.00000001635*cost(5.85571606764+10984.19235169980*x);
R0+=0.00000001754*cost(2.14452408833+6290.18939699220*x);
R0+=0.00000002154*cost(6.03828341543+10873.98603048040*x);
R0+=0.00000001714*cost(3.70157691113+1592.59601363280*x);
R0+=0.00000001541*cost(6.21598380732+23543.23050468179*x);
R0+=0.00000001611*cost(1.99824499377+10969.96525769820*x);
R0+=0.00000001712*cost(1.34295663542+3128.38876509580*x);
R0+=0.00000001642*cost(5.55026665339+6496.37494542940*x);
R0+=0.00000001502*cost(5.43948825854+155.42039943420*x);
R0+=0.00000001827*cost(5.91227480261+3738.76143010800*x);
R0+=0.00000001726*cost(2.16764983583+10575.40668294180*x);
R0+=0.00000001532*cost(5.35683107070+13521.75144159140*x);
R0+=0.00000001829*cost(1.66006148731+39302.09696219600*x);
R0+=0.00000001605*cost(1.90928637633+6133.51265285680*x);
R0+=0.00000001282*cost(2.46014880418+13916.01910964160*x);
R0+=0.00000001211*cost(4.41360631550+3894.18182954220*x);
R0+=0.00000001394*cost(1.77801929354+9225.53927328300*x);
R0+=0.00000001571*cost(4.95512957592+25158.60171976540*x);
R0+=0.00000001205*cost(1.19212540615+3.52311834900*x);
R0+=0.00000001132*cost(2.69830084955+6040.34724601740*x);
R0+=0.00000001504*cost(5.77002730341+18209.33026366019*x);
R0+=0.00000001393*cost(1.62621805428+5120.60114558360*x);
R0+=0.00000001077*cost(2.93931554233+17256.63153634140*x);
R0+=0.00000001232*cost(0.71655165307+143571.32428481648*x);
R0+=0.00000001087*cost(0.99769687939+955.59974160860*x);
R0+=0.00000001068*cost(5.28472576231+65147.61976813770*x);
R0+=0.00000000980*cost(5.10949204607+6172.86952877200*x);
R0+=0.00000001169*cost(3.11664290862+14945.31617355440*x);
R0+=0.00000001202*cost(4.02992510402+553.56940284240*x);
R0+=0.00000000979*cost(2.00000879212+15110.46611986620*x);
R0+=0.00000000962*cost(4.02380771400+6282.09552892320*x);
R0+=0.00000000999*cost(3.62643002790+6262.30045449900*x);
R0+=0.00000001030*cost(5.84989900289+213.29909543800*x);
R0+=0.00000001014*cost(2.84221578218+8662.24032356300*x);
R0+=0.00000001185*cost(1.51330541132+17654.78053974960*x);
R0+=0.00000000967*cost(2.67081017562+5650.29211067820*x);
R0+=0.00000001222*cost(2.65423784904+88860.05707098669*x);
R0+=0.00000000981*cost(2.36370360283+6206.80977871580*x);
R0+=0.00000001033*cost(0.13874927606+11712.95531823080*x);
R0+=0.00000001103*cost(3.08477302937+43232.30665841560*x);
R0+=0.00000000781*cost(2.53372735932+16496.36139620240*x);
R0+=0.00000001019*cost(3.04569392376+6037.24420376200*x);
R0+=0.00000000795*cost(5.80662989111+5230.80746680300*x);
R0+=0.00000000813*cost(3.57710279439+10177.25767953360*x);
R0+=0.00000000962*cost(5.31470594766+6284.05617105960*x);
R0+=0.00000000721*cost(5.96264301567+12559.03815298200*x);
R0+=0.00000000966*cost(2.74714939953+6244.94281435360*x);
R0+=0.00000000921*cost(0.10155275926+29088.81141598500*x);
R0+=0.00000000692*cost(3.89764447548+1589.07289528380*x);
R0+=0.00000000719*cost(5.91791450402+4136.91043351620*x);
R0+=0.00000000772*cost(4.05505682353+6127.65545055720*x);
R0+=0.00000000712*cost(5.49291532439+22003.91463486980*x);
R0+=0.00000000672*cost(1.60700490811+11087.28512591840*x);
R0+=0.00000000690*cost(4.50539825563+426.59819087600*x);
R0+=0.00000000854*cost(3.26104981596+20426.57109242200*x);
R0+=0.00000000656*cost(4.32410182940+16858.48253293320*x);
R0+=0.00000000840*cost(2.59572585222+28766.92442448400*x);
R0+=0.00000000692*cost(0.61650089011+11403.67699557500*x);
R0+=0.00000000700*cost(3.40901167143+7.11354700080*x);
R0+=0.00000000726*cost(0.04243053594+5481.25491886760*x);
R0+=0.00000000557*cost(4.78317696534+20199.09495963300*x);
R0+=0.00000000649*cost(1.04027912958+6062.66320755260*x);
R0+=0.00000000633*cost(5.70229959167+45892.73043315699*x);
R0+=0.00000000592*cost(6.11836729658+9623.68827669120*x);
R0+=0.00000000523*cost(3.62840021266+5333.90024102160*x);
R0+=0.00000000604*cost(5.57734696185+10344.29506538580*x);
R0+=0.00000000496*cost(2.21023499449+1990.74501704100*x);
R0+=0.00000000691*cost(1.96071732602+12416.58850284820*x);
R0+=0.00000000640*cost(1.59074172032+18319.53658487960*x);
R0+=0.00000000625*cost(3.82362791378+13517.87010623340*x);
R0+=0.00000000663*cost(5.08444996779+283.85931886520*x);
R0+=0.00000000475*cost(1.17025894287+12569.67481833180*x);
R0+=0.00000000664*cost(4.50029469969+47162.51635463520*x);
R0+=0.00000000569*cost(0.16310365162+17267.26820169119*x);
R0+=0.00000000568*cost(3.86100969474+6076.89030155420*x);
R0+=0.00000000539*cost(4.83282276086+18422.62935909819*x);
R0+=0.00000000466*cost(0.75872342878+7342.45778018060*x);
R0+=0.00000000541*cost(3.07212190507+226858.23855437008*x);
R0+=0.00000000458*cost(0.26774483096+4590.91018048900*x);
R0+=0.00000000610*cost(1.53597051291+33019.02111220460*x);
R0+=0.00000000617*cost(2.62356328726+11190.37790013700*x);
R0+=0.00000000548*cost(4.55798855791+18875.52586977400*x);
R0+=0.00000000633*cost(4.60110281228+66567.48586525429*x);
R0+=0.00000000596*cost(5.78202396722+632.78373931320*x);
R0+=0.00000000533*cost(5.01786882904+12132.43996210600*x);
R0+=0.00000000603*cost(5.38458554802+316428.22867391503*x);
R0+=0.00000000469*cost(0.59168241917+21954.15760939799*x);
R0+=0.00000000548*cost(3.50613163558+17253.04110768959*x);
R0+=0.00000000502*cost(0.98804327589+11609.86254401220*x);
R0+=0.00000000568*cost(1.98497313089+7668.63742494250*x);
R0+=0.00000000482*cost(1.62141803864+12146.66705610760*x);
R0+=0.00000000391*cost(3.68718382989+18052.92954315780*x);
R0+=0.00000000457*cost(3.77205737340+156137.47598479928*x);
R0+=0.00000000401*cost(5.28260651958+15671.08175940660*x);
R0+=0.00000000469*cost(1.80963184268+12562.62858163380*x);
R0+=0.00000000508*cost(3.36399024699+20597.24396304120*x);
R0+=0.00000000450*cost(5.66054299250+10454.50138660520*x);
R0+=0.00000000375*cost(4.98534633105+9779.10867612540*x);
R0+=0.00000000523*cost(0.97215560834+155427.54293624099*x);
R0+=0.00000000403*cost(5.13939866506+1551.04522264800*x);
R0+=0.00000000372*cost(3.69883738807+9388.00590941520*x);
R0+=0.00000000367*cost(4.43875659716+4535.05943692440*x);
R0+=0.00000000406*cost(4.20863156600+12592.45001978260*x);
R0+=0.00000000360*cost(2.53924644657+242.72860397400*x);
R0+=0.00000000471*cost(4.61907324819+5436.99301524020*x);
R0+=0.00000000441*cost(5.83872966262+3496.03282613400*x);
R0+=0.00000000385*cost(4.94496680973+24356.78078864160*x);
R0+=0.00000000349*cost(6.15018231784+19800.94595622480*x);
R0+=0.00000000355*cost(0.21895678106+5429.87946823940*x);
R0+=0.00000000344*cost(5.62993724928+2379.16447357160*x);
R0+=0.00000000380*cost(2.72105213143+11933.36796066960*x);
R0+=0.00000000432*cost(0.24221790536+17996.03116822220*x);
R0+=0.00000000378*cost(5.22517556974+7477.52286021600*x);
R0+=0.00000000337*cost(5.10888041439+5849.36411211460*x);
R0+=0.00000000315*cost(0.57827745123+10557.59416082380*x);
R0+=0.00000000318*cost(4.49953141399+3634.62102451840*x);
R0+=0.00000000323*cost(1.54274281393+10440.27429260360*x);
R0+=0.00000000309*cost(5.76839284397+20.77539549240*x);
R0+=0.00000000301*cost(2.34727604008+4686.88940770680*x);
R0+=0.00000000414*cost(5.93237602310+51092.72605085480*x);
R0+=0.00000000361*cost(2.16398609550+28237.23345938940*x);
R0+=0.00000000288*cost(0.18376252189+13095.84266507740*x);
R0+=0.00000000277*cost(5.12952205045+13119.72110282519*x);
R0+=0.00000000327*cost(6.19222146204+6268.84875598980*x);
R0+=0.00000000273*cost(0.30522428863+23141.55838292460*x);
R0+=0.00000000267*cost(5.76152585786+5966.68398033480*x);
R0+=0.00000000308*cost(5.99280509979+22805.73556599360*x);
R0+=0.00000000345*cost(2.92489919444+36949.23080842420*x);
R0+=0.00000000253*cost(5.20995219509+24072.92146977640*x);
R0+=0.00000000342*cost(5.72702586209+16460.33352952499*x);
R0+=0.00000000261*cost(2.00304796059+6148.01076995600*x);
R0+=0.00000000238*cost(5.08264392839+6915.85958930460*x);
R0+=0.00000000249*cost(2.94762789744+135.06508003540*x);
R0+=0.00000000306*cost(3.89764686987+10988.80815753500*x);
R0+=0.00000000305*cost(0.05827812117+4701.11650170840*x);
R0+=0.00000000319*cost(2.95712862064+163096.18036118349*x);
R0+=0.00000000209*cost(4.43768461442+6546.15977336420*x);
R0+=0.00000000270*cost(2.06643178717+4804.20927592700*x);
R0+=0.00000000217*cost(0.73691592312+6303.85124548380*x);
R0+=0.00000000206*cost(0.32075959415+25934.12433108940*x);
R0+=0.00000000218*cost(0.18428135264+28286.99048486120*x);
R0+=0.00000000205*cost(5.21312087405+20995.39296644940*x);
R0+=0.00000000199*cost(0.44384292491+16737.57723659660*x);
R0+=0.00000000230*cost(6.06567392849+6287.00800325450*x);
R0+=0.00000000219*cost(1.29194216300+5326.78669402080*x);
R0+=0.00000000201*cost(1.74700937253+22743.40937951640*x);
R0+=0.00000000207*cost(4.45440927276+6279.48542133960*x);
R0+=0.00000000269*cost(6.05640445030+64471.99124174489*x);
R0+=0.00000000190*cost(0.99256176518+29296.61538957860*x);
R0+=0.00000000238*cost(5.42471431221+39609.65458316560*x);
R0+=0.00000000262*cost(5.26961924198+522.57741809380*x);
R0+=0.00000000210*cost(4.68618183158+6254.62666252360*x);
R0+=0.00000000197*cost(2.80624554080+4933.20844033260*x);
R0+=0.00000000252*cost(4.36220154608+40879.44050464380*x);
R0+=0.00000000261*cost(1.07241516738+55022.93574707440*x);
R0+=0.00000000189*cost(3.82966734476+419.48464387520*x);
R0+=0.00000000185*cost(4.14324541379+5642.19824260920*x);
R0+=0.00000000247*cost(3.44855612987+6702.56049386660*x);
R0+=0.00000000205*cost(4.04424043223+536.80451209540*x);
R0+=0.00000000191*cost(3.14082686083+16723.35014259500*x);
R0+=0.00000000222*cost(5.16263907319+23539.70738633280*x);
R0+=0.00000000180*cost(4.56214752149+6489.26139842860*x);
R0+=0.00000000219*cost(0.80382553358+16627.37091537720*x);
R0+=0.00000000227*cost(0.60156339452+5905.70224207560*x);
R0+=0.00000000168*cost(0.88753528161+16062.18452611680*x);
R0+=0.00000000158*cost(0.92127725775+23937.85638974100*x);
R0+=0.00000000157*cost(4.69607868164+6805.65326808520*x);
R0+=0.00000000207*cost(4.88410451334+6286.66627864320*x);
R0+=0.00000000160*cost(4.95943826846+10021.83728009940*x);
R0+=0.00000000166*cost(0.97126433565+3097.88382272579*x);
R0+=0.00000000209*cost(5.75663411805+3646.35037735440*x);
R0+=0.00000000175*cost(6.12762824412+239424.39025435288*x);
R0+=0.00000000173*cost(3.13887234973+6179.98307577280*x);
R0+=0.00000000157*cost(3.62822058179+18451.07854656599*x);
R0+=0.00000000157*cost(4.67695912235+6709.67404086740*x);
R0+=0.00000000146*cost(3.09506069735+4907.30205014560*x);
R0+=0.00000000165*cost(2.27139128760+10660.68693504240*x);
R0+=0.00000000201*cost(1.67701267433+2107.03450754240*x);
R0+=0.00000000144*cost(3.96947747592+6019.99192661860*x);
R0+=0.00000000171*cost(5.91302216729+6058.73105428950*x);
R0+=0.00000000144*cost(2.13155655120+26084.02180621620*x);
R0+=0.00000000151*cost(0.67417383554+2388.89402044920*x);
R0+=0.00000000189*cost(5.07122281033+263.08392337280*x);
R0+=0.00000000146*cost(5.10373877968+10770.89325626180*x);
R0+=0.00000000187*cost(1.23915444627+19402.79695281660*x);
R0+=0.00000000174*cost(0.08407293391+9380.95967271720*x);
R0+=0.00000000137*cost(1.26247412309+12566.21901028560*x);
R0+=0.00000000137*cost(3.52826010842+639.89728631400*x);
R0+=0.00000000148*cost(1.76124372592+5888.44996493220*x);
R0+=0.00000000164*cost(2.39195095081+6357.85744855870*x);
R0+=0.00000000146*cost(2.43675816553+5881.40372823420*x);
R0+=0.00000000161*cost(1.15721259372+26735.94526221320*x);
R0+=0.00000000131*cost(2.51859277344+6599.46771964800*x);
R0+=0.00000000153*cost(5.85203687779+6281.59137728310*x);
R0+=0.00000000151*cost(3.72338532649+12669.24447420140*x);
R0+=0.00000000132*cost(2.38417741883+6525.80445396540*x);
R0+=0.00000000129*cost(0.75556744143+5017.50837136500*x);
R0+=0.00000000127*cost(0.00254936441+10027.90319572920*x);
R0+=0.00000000148*cost(2.85102145528+6418.14093002680*x);
R0+=0.00000000143*cost(5.74460279367+26087.90314157420*x);
R0+=0.00000000172*cost(0.41289962240+174242.46596404970*x);
R0+=0.00000000136*cost(4.15497742275+6311.52503745920*x);
R0+=0.00000000170*cost(5.98194913129+327574.51427678125*x);
R0+=0.00000000124*cost(1.65497607604+32217.20018108080*x);
R0+=0.00000000136*cost(2.48430783417+13341.67431130680*x);
R0+=0.00000000165*cost(2.49667924600+58953.14544329400*x);
R0+=0.00000000123*cost(3.45660563754+6277.55292568400*x);
R0+=0.00000000117*cost(0.86065134175+6245.04817735560*x);
R0+=0.00000000149*cost(5.61358280963+5729.50644714900*x);
R0+=0.00000000153*cost(0.26860029950+245.83164622940*x);
R0+=0.00000000128*cost(0.71204006588+103.09277421860*x);
R0+=0.00000000159*cost(2.43166592149+221995.02880149524*x);
R0+=0.00000000130*cost(2.80707316718+6016.46880826960*x);
R0+=0.00000000137*cost(1.70657709294+12566.08438968000*x);
R0+=0.00000000111*cost(1.56305648432+17782.73207278420*x);
R0+=0.00000000113*cost(3.58302904101+25685.87280280800*x);
R0+=0.00000000109*cost(3.26403795962+6819.88036208680*x);
R0+=0.00000000122*cost(0.34120688217+1162.47470440780*x);
R0+=0.00000000119*cost(5.84644718278+12721.57209941700*x);
R0+=0.00000000144*cost(2.28899679126+12489.88562870720*x);
R0+=0.00000000137*cost(5.82029768354+44809.65020086340*x);
R0+=0.00000000107*cost(2.42818544140+5547.19933645960*x);
R0+=0.00000000134*cost(1.26539982939+5331.35744374080*x);
R0+=0.00000000103*cost(5.96518130595+6321.10352262720*x);
R0+=0.00000000109*cost(0.33808549034+11300.58422135640*x);
R0+=0.00000000129*cost(5.89187277327+12029.34718788740*x);
R0+=0.00000000122*cost(5.77325634636+11919.14086666800*x);
R0+=0.00000000107*cost(6.24998989350+77690.75950573849*x);
R0+=0.00000000107*cost(1.00535580713+77736.78343050249*x);
R0+=0.00000000143*cost(0.24122178432+4214.06901508480*x);
R0+=0.00000000143*cost(0.88529649733+7576.56007357400*x);
R0+=0.00000000107*cost(2.92124030496+31415.37924995700*x);
R0+=0.00000000099*cost(5.70862227072+5540.08578945880*x);
R0+=0.00000000110*cost(0.37528037383+5863.59120611620*x);
R0+=0.00000000104*cost(4.44107178366+2118.76386037840*x);
R0+=0.00000000098*cost(5.95877916706+4061.21921539440*x);
R0+=0.00000000113*cost(1.24206857385+84672.47584450469*x);
R0+=0.00000000124*cost(2.55619029867+12539.85338018300*x);
R0+=0.00000000110*cost(3.66952094329+238004.52415723629*x);
R0+=0.00000000112*cost(4.32512422943+97238.62754448749*x);
R0+=0.00000000097*cost(3.70151541181+11720.06886523160*x);
R0+=0.00000000120*cost(1.26895630252+12043.57428188900*x);
R0+=0.00000000094*cost(2.56461130309+19004.64794940840*x);
R0+=0.00000000117*cost(3.65425622684+34520.30930938080*x);
R0+=0.00000000098*cost(0.13589994287+11080.17157891760*x);
R0+=0.00000000097*cost(5.38330115253+7834.12107263940*x);
R0+=0.00000000097*cost(2.46722096722+71980.63357473118*x);
R0+=0.00000000095*cost(5.36958330451+6288.59877429880*x);
R0+=0.00000000111*cost(5.01961920313+11823.16163945020*x);
R0+=0.00000000090*cost(2.72299804525+26880.31981303260*x);
R0+=0.00000000099*cost(0.90164266377+18635.92845453620*x);
R0+=0.00000000126*cost(4.78722177847+305281.94307104882*x);
R0+=0.00000000093*cost(0.21240380046+18139.29450141590*x);
R0+=0.00000000124*cost(5.00979495566+172146.97134054029*x);
R0+=0.00000000099*cost(5.67090026475+16522.65971600220*x);
R0+=0.00000000092*cost(2.28180963676+12491.37010141550*x);
R0+=0.00000000090*cost(4.50544881196+40077.61957352000*x);
R0+=0.00000000100*cost(2.00639461612+12323.42309600880*x);
R0+=0.00000000095*cost(5.68801979087+14919.01785375460*x);
R0+=0.00000000087*cost(1.86043406047+27707.54249429480*x);
R0+=0.00000000105*cost(3.02903468417+22345.26037610820*x);
R0+=0.00000000087*cost(5.43970168638+6272.03014972750*x);
R0+=0.00000000089*cost(1.63389387182+33326.57873317420*x);
R0+=0.00000000082*cost(5.58298993353+10241.20229116720*x);
R0+=0.00000000094*cost(5.47749711149+9924.81042151060*x);
R0+=0.00000000082*cost(4.71988314145+15141.39079431200*x);
R0+=0.00000000097*cost(5.61458778738+2787.04302385740*x);
R0+=0.00000000096*cost(3.89073946348+6379.05507720920*x);
R0+=0.00000000081*cost(3.13038482444+36147.40987730040*x);
R0+=0.00000000110*cost(4.89978492291+72140.62866668739*x);
R0+=0.00000000097*cost(5.20764563059+6303.43116939020*x);
R0+=0.00000000082*cost(5.26342716139+9814.60410029120*x);
R0+=0.00000000109*cost(2.35555589770+83286.91426955358*x);
R0+=0.00000000097*cost(2.58492958057+30666.15495843280*x);
R0+=0.00000000093*cost(1.32651591333+23020.65308658799*x);
R0+=0.00000000078*cost(3.99588630754+11293.47067435560*x);
R0+=0.00000000090*cost(0.57771932738+26482.17080962440*x);
R0+=0.00000000106*cost(3.92012705073+62883.35513951360*x);
R0+=0.00000000098*cost(2.94397773524+316.39186965660*x);
R0+=0.00000000076*cost(3.96310417608+29026.48522950779*x);
R0+=0.00000000078*cost(1.97068529306+90279.92316810328*x);
R0+=0.00000000076*cost(0.23027966596+21424.46664430340*x);
R0+=0.00000000080*cost(2.23099742212+266.60704172180*x);
R0+=0.00000000079*cost(1.46227790922+8982.81066930900*x);
R0+=0.00000000102*cost(4.92129953565+5621.84292321040*x);
R0+=0.00000000100*cost(0.39243148321+24279.10701821359*x);
R0+=0.00000000071*cost(1.52014858474+33794.54372352860*x);
R0+=0.00000000076*cost(0.22880641443+57375.80190084620*x);
R0+=0.00000000091*cost(0.96515913904+48739.85989708300*x);
R0+=0.00000000075*cost(2.77638585157+12964.30070339100*x);
R0+=0.00000000077*cost(5.18846946344+11520.99686379520*x);
R0+=0.00000000068*cost(0.50006599129+4274.51831083240*x);
R0+=0.00000000075*cost(2.07323762803+15664.03552270859*x);
R0+=0.00000000074*cost(1.01884134928+6393.28217121080*x);
R0+=0.00000000077*cost(0.46665178780+16207.88627150200*x);
R0+=0.00000000081*cost(4.10452219483+161710.61878623239*x);
R0+=0.00000000067*cost(3.83840630887+6262.72053059260*x);
R0+=0.00000000071*cost(3.91415523291+7875.67186362420*x);
R0+=0.00000000081*cost(0.91938383237+74.78159856730*x);
R0+=0.00000000083*cost(4.69916218791+23006.42599258639*x);
R0+=0.00000000063*cost(2.32556465878+6279.19451463340*x);
R0+=0.00000000065*cost(5.41938745446+28628.33622609960*x);
R0+=0.00000000065*cost(3.02336771694+5959.57043333400*x);
R0+=0.00000000064*cost(3.31033198370+2636.72547263700*x);
R0+=0.00000000064*cost(0.18375587519+1066.49547719000*x);
R0+=0.00000000080*cost(5.81239171612+12341.80690428090*x);
R0+=0.00000000066*cost(2.15105504851+38.02767263580*x);
R0+=0.00000000062*cost(2.43313614978+10138.10951694860*x);
R0+=0.00000000060*cost(3.16153906470+5490.30096152400*x);
R0+=0.00000000069*cost(0.30764736334+7018.95236352320*x);
R0+=0.00000000068*cost(2.24442548639+24383.07910844140*x);
R0+=0.00000000078*cost(1.39649386463+9411.46461508720*x);
R0+=0.00000000063*cost(0.72976362625+6286.95718534940*x);
R0+=0.00000000073*cost(4.95125917731+6453.74872061060*x);
R0+=0.00000000078*cost(0.32736023459+6528.90749622080*x);
R0+=0.00000000059*cost(4.95362151577+35707.71008290740*x);
R0+=0.00000000070*cost(2.37962727525+15508.61512327440*x);
R0+=0.00000000073*cost(1.35229143111+5327.47610838280*x);
R0+=0.00000000072*cost(5.91833527334+10881.09957748120*x);
R0+=0.00000000059*cost(5.36231868425+10239.58386601080*x);
R0+=0.00000000059*cost(1.63156134967+61306.01159706580*x);
R0+=0.00000000054*cost(4.29491690425+21947.11137270000*x);
R0+=0.00000000057*cost(5.89190132575+34513.26307268280*x);
R0+=0.00000000074*cost(1.38235845304+9967.45389998160*x);
R0+=0.00000000053*cost(3.86543309344+32370.97899156560*x);
R0+=0.00000000055*cost(4.51794544854+34911.41207609100*x);
R0+=0.00000000063*cost(5.41479412056+11502.83761653050*x);
R0+=0.00000000063*cost(2.34416220742+11510.70192305670*x);
R0+=0.00000000068*cost(0.77493931112+29864.33402730900*x);
R0+=0.00000000060*cost(5.57024703495+5756.90800324580*x);
R0+=0.00000000072*cost(2.80863088166+10866.87248347960*x);
R0+=0.00000000061*cost(2.69736991384+82576.98122099529*x);
R0+=0.00000000063*cost(5.32068807257+3116.65941225980*x);
R0+=0.00000000052*cost(1.02278758099+6272.43918464160*x);
R0+=0.00000000069*cost(5.00698550308+25287.72379939980*x);
R0+=0.00000000066*cost(6.12047940728+12074.48840752400*x);
R0+=0.00000000051*cost(2.59519527563+11396.56344857420*x);
R0+=0.00000000056*cost(2.57995973521+17892.93839400359*x);
R0+=0.00000000059*cost(0.44167237620+250570.67585721909*x);
R0+=0.00000000059*cost(3.84070143543+5483.25472482600*x);
R0+=0.00000000049*cost(0.54704693048+22594.05489571199*x);
R0+=0.00000000065*cost(2.38423614501+52670.06959330260*x);
R0+=0.00000000069*cost(5.34363738671+66813.56483573320*x);
R0+=0.00000000057*cost(5.42770501007+310145.15282392364*x);
R0+=0.00000000053*cost(1.17760296075+149.56319713460*x);
R0+=0.00000000061*cost(4.02090887211+34596.36465465240*x);
R0+=0.00000000049*cost(4.18361320516+18606.49894600020*x);
R0+=0.00000000055*cost(0.83886167974+20452.86941222180*x);
R0+=0.00000000050*cost(1.46327331958+37455.72649597440*x);
R0+=0.00000000048*cost(4.53854727167+29822.78323632420*x);
R0+=0.00000000058*cost(3.34847975377+33990.61834428620*x);
R0+=0.00000000065*cost(1.45522693982+76251.32777062019*x);
R0+=0.00000000056*cost(2.35650663692+37724.75341974820*x);
R0+=0.00000000052*cost(2.61551081496+5999.21653112620*x);
R0+=0.00000000053*cost(0.17334326094+77717.29458646949*x);
R0+=0.00000000053*cost(0.79879700631+77710.24834977149*x);
R0+=0.00000000047*cost(0.43240779709+735.87651353180*x);
R0+=0.00000000053*cost(4.58763261686+11616.97609101300*x);
R0+=0.00000000048*cost(6.20230111054+4171.42553661380*x);
R0+=0.00000000052*cost(1.09723616404+640.87760738220*x);
R0+=0.00000000057*cost(3.42008310383+50317.20343953080*x);
R0+=0.00000000053*cost(1.01528448581+149144.46708624958*x);
R0+=0.00000000047*cost(3.00924906195+52175.80628314840*x);
R0+=0.00000000052*cost(2.03254070404+6293.71251534120*x);
R0+=0.00000000048*cost(0.12356889734+13362.44970679920*x);
R0+=0.00000000045*cost(3.37963782356+10763.77970926100*x);
R0+=0.00000000047*cost(5.50981287869+12779.45079542080*x);
R0+=0.00000000062*cost(5.45209070099+949.17560896980*x);
R0+=0.00000000061*cost(2.93237974631+5791.41255753260*x);
R0+=0.00000000044*cost(2.87440620802+8584.66166590080*x);
R0+=0.00000000046*cost(4.03141796560+10667.80048204320*x);
R0+=0.00000000047*cost(3.89902931422+3903.91137641980*x);
R0+=0.00000000046*cost(2.75700467329+6993.00889854970*x);
R0+=0.00000000045*cost(1.93386293300+206.18554843720*x);
R0+=0.00000000047*cost(2.57670800912+11492.54267579200*x);
R0+=0.00000000044*cost(3.62570223167+63658.87775083760*x);
R0+=0.00000000051*cost(0.84536826273+12345.73905754400*x);
R0+=0.00000000043*cost(0.01524970172+37853.87549938260*x);
R0+=0.00000000041*cost(3.27146326065+8858.31494432060*x);
R0+=0.00000000045*cost(3.03765521215+65236.22129328540*x);
R0+=0.00000000047*cost(1.44447548944+21393.54196985760*x);
R0+=0.00000000058*cost(5.45843180927+1975.49254585600*x);
R0+=0.00000000050*cost(2.13285524146+12573.26524698360*x);
R0+=0.00000000041*cost(1.32190847146+2547.83753823240*x);
R0+=0.00000000047*cost(3.67579608544+28313.28880466100*x);
R0+=0.00000000041*cost(2.24013475126+8273.82086703240*x);
R0+=0.00000000047*cost(6.21438985953+10991.30589870060*x);
R0+=0.00000000042*cost(3.01631817350+853.19638175200*x);
R0+=0.00000000056*cost(1.09773690181+77376.20102240759*x);
R0+=0.00000000040*cost(2.35698541041+2699.73481931760*x);
R0+=0.00000000043*cost(5.28030898459+17796.95916678580*x);
R0+=0.00000000054*cost(2.59175932091+22910.44676536859*x);
R0+=0.00000000054*cost(0.88027764102+71960.38658322369*x);
R0+=0.00000000055*cost(0.07988899477+83467.15635301729*x);
R0+=0.00000000039*cost(1.12867321442+9910.58332750900*x);
R0+=0.00000000040*cost(1.35670430524+27177.85152920020*x);
R0+=0.00000000039*cost(4.39624220245+5618.31980486140*x);
R0+=0.00000000042*cost(4.78798367468+7856.89627409019*x);
R0+=0.00000000047*cost(2.75482175292+18202.21671665939*x);
R0+=0.00000000039*cost(1.97008298629+24491.42579258340*x);
R0+=0.00000000042*cost(4.04346599946+7863.94251078820*x);
R0+=0.00000000038*cost(0.49178679251+38650.17350619900*x);
R0+=0.00000000036*cost(4.86047906533+4157.19844261220*x);
R0+=0.00000000043*cost(5.64354880978+1062.90504853820*x);
R0+=0.00000000036*cost(3.98066313627+12565.17137891460*x);
R0+=0.00000000042*cost(2.30753932657+6549.68289171320*x);
R0+=0.00000000040*cost(5.39694918320+9498.21223063460*x);
R0+=0.00000000040*cost(3.30603243754+23536.11695768099*x);
R0+=0.00000000050*cost(6.15760345261+78051.34191383338*x);

double R1=0;
R1+=0.00103018608*cost(1.10748969588+6283.07584999140*x);
R1+=0.00001721238*cost(1.06442301418+12566.15169998280*x);
R1-=0.00000702215;
R1+=0.00000032346*cost(1.02169059149+18849.22754997420*x);
R1+=0.00000030799*cost(2.84353804832+5507.55323866740*x);
R1+=0.00000024971*cost(1.31906709482+5223.69391980220*x);
R1+=0.00000018485*cost(1.42429748614+1577.34354244780*x);
R1+=0.00000010078*cost(5.91378194648+10977.07880469900*x);
R1+=0.00000008634*cost(0.27146150602+5486.77784317500*x);
R1+=0.00000008654*cost(1.42046854427+6275.96230299060*x);
R1+=0.00000005069*cost(1.68613426734+5088.62883976680*x);
R1+=0.00000004985*cost(6.01401770704+6286.59896834040*x);
R1+=0.00000004669*cost(5.98724494073+529.69096509460*x);
R1+=0.00000004395*cost(0.51800238019+4694.00295470760*x);
R1+=0.00000003872*cost(4.74969833437+2544.31441988340*x);
R1+=0.00000003750*cost(5.07097685568+796.29800681640*x);
R1+=0.00000004100*cost(1.08424786092+9437.76293488700*x);
R1+=0.00000003518*cost(0.02290216272+83996.84731811189*x);
R1+=0.00000003436*cost(0.94937019624+71430.69561812909*x);
R1+=0.00000003221*cost(6.15628775313+2146.16541647520*x);
R1+=0.00000003414*cost(5.41218322538+775.52261132400*x);
R1+=0.00000002863*cost(5.48432847146+10447.38783960440*x);
R1+=0.00000002520*cost(0.24276941146+398.14900340820*x);
R1+=0.00000002201*cost(4.95216196651+6812.76681508600*x);
R1+=0.00000002186*cost(0.41991743105+8031.09226305840*x);
R1+=0.00000002838*cost(3.42034351366+2352.86615377180*x);
R1+=0.00000002554*cost(6.13241878525+6438.49624942560*x);
R1+=0.00000001932*cost(5.31374608366+8429.24126646660*x);
R1+=0.00000002429*cost(3.09164528262+4690.47983635860*x);
R1+=0.00000001730*cost(1.53686208550+4705.73230754360*x);
R1+=0.00000002250*cost(3.68863633842+7084.89678111520*x);
R1+=0.00000002093*cost(1.28191783032+1748.01641306700*x);
R1+=0.00000001441*cost(0.81656250862+14143.49524243060*x);
R1+=0.00000001483*cost(3.22225357771+7234.79425624200*x);
R1+=0.00000001754*cost(3.22883705112+6279.55273164240*x);
R1+=0.00000001583*cost(4.09702349428+11499.65622279280*x);
R1+=0.00000001575*cost(5.53890170575+3154.68708489560*x);
R1+=0.00000001847*cost(1.82040335363+7632.94325965020*x);
R1+=0.00000001504*cost(3.63293385726+11513.88331679440*x);
R1+=0.00000001337*cost(4.64440864339+6836.64525283380*x);
R1+=0.00000001275*cost(2.69341415363+1349.86740965880*x);
R1+=0.00000001352*cost(6.15101580257+5746.27133789600*x);
R1+=0.00000001125*cost(3.35673439497+17789.84561978500*x);
R1+=0.00000001470*cost(3.65282991755+1194.44701022460*x);
R1+=0.00000001177*cost(2.57676109092+13367.97263110660*x);
R1+=0.00000001101*cost(4.49748696552+4292.33083295040*x);
R1+=0.00000001234*cost(5.65036509521+5760.49843189760*x);
R1+=0.00000000984*cost(0.65517395136+5856.47765911540*x);
R1+=0.00000000928*cost(2.32420318751+10213.28554621100*x);
R1+=0.00000001077*cost(5.82812169132+12036.46073488820*x);
R1+=0.00000000916*cost(0.76613009583+16730.46368959580*x);
R1+=0.00000000877*cost(1.50137505051+11926.25441366880*x);
R1+=0.00000001023*cost(5.62076589825+6256.77753019160*x);
R1+=0.00000000851*cost(0.65709335533+155.42039943420*x);
R1+=0.00000000802*cost(4.10519132088+951.71840625060*x);
R1+=0.00000000857*cost(1.41661697538+5753.38488489680*x);
R1+=0.00000000994*cost(1.14418521187+1059.38193018920*x);
R1+=0.00000000813*cost(1.63948433322+6681.22485339960*x);
R1+=0.00000000662*cost(4.55200452260+5216.58037280140*x);
R1+=0.00000000644*cost(4.19478168733+6040.34724601740*x);
R1+=0.00000000626*cost(1.50767713598+5643.17856367740*x);
R1+=0.00000000590*cost(6.18277145205+4164.31198961300*x);
R1+=0.00000000635*cost(0.52413263542+6290.18939699220*x);
R1+=0.00000000650*cost(0.97935690350+25132.30339996560*x);
R1+=0.00000000568*cost(2.30125315873+10973.55568635000*x);
R1+=0.00000000547*cost(5.27256412213+3340.61242669980*x);
R1+=0.00000000547*cost(2.20144422886+1592.59601363280*x);
R1+=0.00000000526*cost(0.92464258226+11371.70468975820*x);
R1+=0.00000000490*cost(5.90951388655+3894.18182954220*x);
R1+=0.00000000478*cost(1.66857963179+12168.00269657460*x);
R1+=0.00000000516*cost(3.59803483887+10969.96525769820*x);
R1+=0.00000000518*cost(3.97914412373+17298.18232732620*x);
R1+=0.00000000534*cost(5.03740926442+9917.69687450980*x);
R1+=0.00000000487*cost(2.50545369269+6127.65545055720*x);
R1+=0.00000000416*cost(4.04828175503+10984.19235169980*x);
R1+=0.00000000538*cost(5.54081539805+553.56940284240*x);
R1+=0.00000000402*cost(2.16544019233+7860.41939243920*x);
R1+=0.00000000553*cost(2.32177369366+11506.76976979360*x);
R1+=0.00000000367*cost(3.39152532250+6496.37494542940*x);
R1+=0.00000000360*cost(5.34379853282+7079.37385680780*x);
R1+=0.00000000337*cost(3.61563704045+11790.62908865880*x);
R1+=0.00000000456*cost(0.30754294809+801.82093112380*x);
R1+=0.00000000417*cost(3.70009308674+10575.40668294180*x);
R1+=0.00000000381*cost(5.82033971802+7058.59846131540*x);
R1+=0.00000000321*cost(0.31988767355+16200.77272450120*x);
R1+=0.00000000364*cost(1.08414306177+6309.37416979120*x);
R1+=0.00000000294*cost(4.54798604957+11856.21865142450*x);
R1+=0.00000000290*cost(1.26473978562+8635.94200376320*x);
R1+=0.00000000399*cost(4.16998866302+26.29831979980*x);
R1+=0.00000000262*cost(5.08316906342+10177.25767953360*x);
R1+=0.00000000243*cost(2.25746091190+11712.95531823080*x);
R1+=0.00000000237*cost(1.05070575346+242.72860397400*x);
R1+=0.00000000275*cost(3.45319481756+5884.92684658320*x);
R1+=0.00000000255*cost(5.38496831087+21228.39202354580*x);
R1+=0.00000000307*cost(4.24313526604+3738.76143010800*x);
R1+=0.00000000216*cost(3.46037894728+213.29909543800*x);
R1+=0.00000000196*cost(0.69029243914+1990.74501704100*x);
R1+=0.00000000198*cost(5.16301829964+12352.85260454480*x);
R1+=0.00000000214*cost(3.91876200279+13916.01910964160*x);
R1+=0.00000000212*cost(4.00861198517+5230.80746680300*x);
R1+=0.00000000184*cost(5.59805976614+6283.14316029419*x);
R1+=0.00000000184*cost(2.85275392124+7238.67559160000*x);
R1+=0.00000000179*cost(2.54259058334+14314.16811304980*x);
R1+=0.00000000225*cost(1.64458698399+4732.03062734340*x);
R1+=0.00000000236*cost(5.58826125715+6069.77675455340*x);
R1+=0.00000000187*cost(2.72805985443+6062.66320755260*x);
R1+=0.00000000184*cost(6.04216273598+6283.00853968860*x);
R1+=0.00000000230*cost(3.62591335086+6284.05617105960*x);
R1+=0.00000000163*cost(2.19117396803+18073.70493865020*x);
R1+=0.00000000172*cost(0.97612950740+3930.20969621960*x);
R1+=0.00000000215*cost(1.04672844028+3496.03282613400*x);
R1+=0.00000000169*cost(4.75084479006+17267.26820169119*x);
R1+=0.00000000152*cost(0.19390712179+9779.10867612540*x);
R1+=0.00000000182*cost(5.16288118255+17253.04110768959*x);
R1+=0.00000000149*cost(0.80944184260+709.93304855830*x);
R1+=0.00000000163*cost(2.19209570390+6076.89030155420*x);
R1+=0.00000000186*cost(5.01159497089+11015.10647733480*x);
R1+=0.00000000134*cost(0.97765485759+65147.61976813770*x);
R1+=0.00000000141*cost(4.38421981312+4136.91043351620*x);
R1+=0.00000000158*cost(4.60974280627+9623.68827669120*x);
R1+=0.00000000133*cost(3.30508592837+154717.60988768269*x);
R1+=0.00000000163*cost(6.11782626245+3.52311834900*x);
R1+=0.00000000174*cost(1.58078542187+7.11354700080*x);
R1+=0.00000000141*cost(0.49976927274+25158.60171976540*x);
R1+=0.00000000124*cost(6.03440460031+9225.53927328300*x);
R1+=0.00000000150*cost(5.30166336812+13517.87010623340*x);
R1+=0.00000000127*cost(1.92389511438+22483.84857449259*x);
R1+=0.00000000121*cost(2.37813129011+167283.76158766549*x);
R1+=0.00000000120*cost(3.98423684853+4686.88940770680*x);
R1+=0.00000000117*cost(5.81072642211+12569.67481833180*x);
R1+=0.00000000122*cost(5.60973054224+5642.19824260920*x);
R1+=0.00000000157*cost(3.40236426002+16496.36139620240*x);
R1+=0.00000000129*cost(2.10705116371+1589.07289528380*x);
R1+=0.00000000116*cost(0.55839966736+5849.36411211460*x);
R1+=0.00000000123*cost(1.52961392771+12559.03815298200*x);
R1+=0.00000000111*cost(0.44848279675+6172.86952877200*x);
R1+=0.00000000123*cost(5.81645568991+6282.09552892320*x);
R1+=0.00000000150*cost(4.26278409223+3128.38876509580*x);
R1+=0.00000000106*cost(2.27437761356+5429.87946823940*x);
R1+=0.00000000104*cost(4.42743707728+23543.23050468179*x);
R1+=0.00000000121*cost(0.39459045915+12132.43996210600*x);
R1+=0.00000000104*cost(2.41842602527+426.59819087600*x);
R1+=0.00000000110*cost(5.80381480447+16858.48253293320*x);
R1+=0.00000000100*cost(2.93805577485+4535.05943692440*x);
R1+=0.00000000097*cost(3.97935904984+6133.51265285680*x);
R1+=0.00000000110*cost(6.22339014386+12146.66705610760*x);
R1+=0.00000000098*cost(0.87576563709+6525.80445396540*x);
R1+=0.00000000098*cost(3.15248421301+10440.27429260360*x);
R1+=0.00000000095*cost(2.46168411100+3097.88382272579*x);
R1+=0.00000000088*cost(0.23371480284+13119.72110282519*x);
R1+=0.00000000098*cost(5.77016493489+7342.45778018060*x);
R1+=0.00000000092*cost(6.03915555063+20426.57109242200*x);
R1+=0.00000000096*cost(5.56909292561+2388.89402044920*x);
R1+=0.00000000081*cost(1.32131147691+5650.29211067820*x);
R1+=0.00000000086*cost(3.94529200528+10454.50138660520*x);
R1+=0.00000000076*cost(2.70729716925+143571.32428481648*x);
R1+=0.00000000091*cost(5.64100034152+8827.39026987480*x);
R1+=0.00000000076*cost(1.80783856698+28286.99048486120*x);
R1+=0.00000000081*cost(1.90858992196+29088.81141598500*x);
R1+=0.00000000075*cost(3.40955892978+5481.25491886760*x);
R1+=0.00000000069*cost(4.49936170873+17256.63153634140*x);
R1+=0.00000000088*cost(1.10098454357+11769.85369316640*x);
R1+=0.00000000066*cost(2.78285801977+536.80451209540*x);
R1+=0.00000000068*cost(3.88179770758+17260.15465469040*x);
R1+=0.00000000084*cost(1.59303306354+9380.95967271720*x);
R1+=0.00000000088*cost(3.88076636762+7477.52286021600*x);
R1+=0.00000000061*cost(6.17558202197+11087.28512591840*x);
R1+=0.00000000060*cost(4.34824715818+6206.80977871580*x);
R1+=0.00000000082*cost(4.59843208943+9388.00590941520*x);
R1+=0.00000000079*cost(1.63131230601+4933.20844033260*x);
R1+=0.00000000078*cost(4.20905757484+5729.50644714900*x);
R1+=0.00000000057*cost(5.48157926651+18319.53658487960*x);
R1+=0.00000000060*cost(1.01261781084+12721.57209941700*x);
R1+=0.00000000056*cost(1.63031935692+15720.83878487840*x);
R1+=0.00000000055*cost(0.24926735018+15110.46611986620*x);
R1+=0.00000000061*cost(5.93059279661+12539.85338018300*x);
R1+=0.00000000055*cost(4.84298966314+13095.84266507740*x);
R1+=0.00000000067*cost(6.11690589247+8662.24032356300*x);
R1+=0.00000000054*cost(5.73750638571+3634.62102451840*x);
R1+=0.00000000074*cost(1.05466745829+16460.33352952499*x);
R1+=0.00000000053*cost(2.29084335688+16062.18452611680*x);
R1+=0.00000000064*cost(2.13513767927+7875.67186362420*x);
R1+=0.00000000067*cost(0.07096807518+14945.31617355440*x);
R1+=0.00000000051*cost(2.31511194429+6262.72053059260*x);
R1+=0.00000000057*cost(5.77055471237+12043.57428188900*x);
R1+=0.00000000056*cost(4.41980790431+4701.11650170840*x);
R1+=0.00000000059*cost(5.87963500073+5331.35744374080*x);
R1+=0.00000000058*cost(2.30546168628+955.59974160860*x);
R1+=0.00000000049*cost(1.93839278478+5333.90024102160*x);
R1+=0.00000000048*cost(2.69973662261+6709.67404086740*x);
R1+=0.00000000064*cost(1.64379897981+6262.30045449900*x);
R1+=0.00000000046*cost(3.98449608961+98068.53671630539*x);
R1+=0.00000000050*cost(3.68875893005+12323.42309600880*x);
R1+=0.00000000045*cost(3.30068569697+22003.91463486980*x);
R1+=0.00000000047*cost(1.26317154881+11919.14086666800*x);
R1+=0.00000000045*cost(0.89150445122+51868.24866217880*x);
R1+=0.00000000043*cost(1.61526242998+6277.55292568400*x);
R1+=0.00000000043*cost(5.74295325645+11403.67699557500*x);
R1+=0.00000000044*cost(3.43070646822+10021.83728009940*x);
R1+=0.00000000056*cost(0.02481833774+15671.08175940660*x);
R1+=0.00000000055*cost(3.14274403422+33019.02111220460*x);
R1+=0.00000000045*cost(3.00877289177+8982.81066930900*x);
R1+=0.00000000046*cost(0.73303568429+6303.43116939020*x);
R1+=0.00000000049*cost(1.60455690285+6303.85124548380*x);
R1+=0.00000000045*cost(0.40210030323+6805.65326808520*x);
R1+=0.00000000053*cost(0.94869680175+10988.80815753500*x);
R1+=0.00000000041*cost(1.61122384329+6819.88036208680*x);
R1+=0.00000000055*cost(0.89439119424+11933.36796066960*x);
R1+=0.00000000045*cost(3.88495384656+60530.48898574180*x);
R1+=0.00000000040*cost(4.75740908001+38526.57435087200*x);
R1+=0.00000000040*cost(1.49921251887+18451.07854656599*x);
R1+=0.00000000040*cost(3.77498297228+26087.90314157420*x);
R1+=0.00000000051*cost(1.70258603562+1551.04522264800*x);
R1+=0.00000000039*cost(2.97100699926+2118.76386037840*x);
R1+=0.00000000053*cost(5.19854123078+77713.77146812050*x);
R1+=0.00000000047*cost(4.26356628717+21424.46664430340*x);
R1+=0.00000000037*cost(0.62902722802+24356.78078864160*x);
R1+=0.00000000036*cost(0.11087914947+10344.29506538580*x);
R1+=0.00000000036*cost(0.77037556319+12029.34718788740*x);
R1+=0.00000000035*cost(3.30933994515+24072.92146977640*x);
R1+=0.00000000035*cost(5.93650887012+31570.79964939120*x);
R1+=0.00000000036*cost(2.15108874765+30774.50164257480*x);
R1+=0.00000000036*cost(1.75078825382+16207.88627150200*x);
R1+=0.00000000033*cost(5.06264177921+226858.23855437008*x);
R1+=0.00000000034*cost(6.16891378800+24491.42579258340*x);
R1+=0.00000000035*cost(3.19120695549+32217.20018108080*x);
R1+=0.00000000034*cost(2.31528650443+55798.45835839840*x);
R1+=0.00000000032*cost(4.21446357042+15664.03552270859*x);
R1+=0.00000000039*cost(1.24979117796+6418.14093002680*x);
R1+=0.00000000037*cost(4.11943655770+2787.04302385740*x);
R1+=0.00000000032*cost(1.62887710890+639.89728631400*x);
R1+=0.00000000038*cost(5.89832942685+640.87760738220*x);
R1+=0.00000000032*cost(1.72442327688+27433.88921587499*x);
R1+=0.00000000031*cost(2.78828943753+12139.55350910680*x);
R1+=0.00000000035*cost(4.44608896525+18202.21671665939*x);
R1+=0.00000000034*cost(3.96287980676+18216.44381066100*x);
R1+=0.00000000033*cost(4.73611335874+16723.35014259500*x);
R1+=0.00000000034*cost(1.43910280005+49515.38250840700*x);
R1+=0.00000000031*cost(0.23302920161+23581.25817731760*x);
R1+=0.00000000029*cost(2.02633840220+11609.86254401220*x);
R1+=0.00000000030*cost(2.54923230240+9924.81042151060*x);
R1+=0.00000000032*cost(4.91793198558+11300.58422135640*x);
R1+=0.00000000028*cost(0.26187189577+13521.75144159140*x);
R1+=0.00000000028*cost(3.84568936822+2699.73481931760*x);
R1+=0.00000000029*cost(1.83149729794+29822.78323632420*x);
R1+=0.00000000033*cost(4.60320094415+19004.64794940840*x);
R1+=0.00000000027*cost(4.46183450287+6702.56049386660*x);
R1+=0.00000000030*cost(4.46494072240+36147.40987730040*x);
R1+=0.00000000027*cost(0.03211931363+6279.78949257360*x);
R1+=0.00000000026*cost(5.46497324333+6245.04817735560*x);
R1+=0.00000000035*cost(4.52695674113+36949.23080842420*x);
R1+=0.00000000027*cost(3.52528177609+10770.89325626180*x);
R1+=0.00000000026*cost(1.48499438453+11080.17157891760*x);
R1+=0.00000000035*cost(2.82154380962+19402.79695281660*x);
R1+=0.00000000025*cost(2.46339998836+6279.48542133960*x);
R1+=0.00000000026*cost(4.97688894643+16737.57723659660*x);
R1+=0.00000000026*cost(2.36136541526+17996.03116822220*x);
R1+=0.00000000029*cost(4.15148654061+45892.73043315699*x);
R1+=0.00000000026*cost(4.50714272714+17796.95916678580*x);
R1+=0.00000000027*cost(4.72625223674+1066.49547719000*x);
R1+=0.00000000025*cost(2.89309528854+6286.66627864320*x);
R1+=0.00000000027*cost(0.37462444357+12964.30070339100*x);
R1+=0.00000000029*cost(4.94860010533+5863.59120611620*x);
R1+=0.00000000031*cost(3.93096113577+29864.33402730900*x);
R1+=0.00000000024*cost(6.14987193584+18606.49894600020*x);
R1+=0.00000000024*cost(3.74225964547+29026.48522950779*x);
R1+=0.00000000025*cost(5.70460621565+27707.54249429480*x);
R1+=0.00000000025*cost(5.33928840652+15141.39079431200*x);
R1+=0.00000000027*cost(3.02320897140+6286.36220740920*x);
R1+=0.00000000023*cost(0.28364955406+5327.47610838280*x);
R1+=0.00000000026*cost(1.34240461687+18875.52586977400*x);
R1+=0.00000000024*cost(1.33998410121+19800.94595622480*x);
R1+=0.00000000025*cost(6.00172494004+6489.26139842860*x);
R1+=0.00000000022*cost(1.81777974484+6288.59877429880*x);
R1+=0.00000000022*cost(3.58603606640+6915.85958930460*x);
R1+=0.00000000029*cost(2.09564449439+15265.88651930040*x);
R1+=0.00000000022*cost(1.02173599251+11925.27409260060*x);
R1+=0.00000000022*cost(4.74660932338+28230.18722269139*x);
R1+=0.00000000021*cost(2.30688751432+5999.21653112620*x);
R1+=0.00000000021*cost(3.22654944430+25934.12433108940*x);
R1+=0.00000000021*cost(3.04956726238+6566.93516885660*x);
R1+=0.00000000027*cost(5.35653084499+33794.54372352860*x);
R1+=0.00000000028*cost(3.91168324815+18208.34994259200*x);
R1+=0.00000000020*cost(1.52296293311+135.06508003540*x);
R1+=0.00000000022*cost(4.66462839521+13362.44970679920*x);
R1+=0.00000000019*cost(1.78121167862+156137.47598479928*x);
R1+=0.00000000019*cost(2.99969102221+19651.04848109800*x);
R1+=0.00000000019*cost(2.86664273362+18422.62935909819*x);
R1+=0.00000000025*cost(0.94995632141+31415.37924995700*x);
R1+=0.00000000019*cost(4.71432851499+77690.75950573849*x);
R1+=0.00000000019*cost(2.54227398241+77736.78343050249*x);
R1+=0.00000000020*cost(5.91915117116+48739.85989708300*x);

double R2=0;
R2+=0.00004359385*cost(5.78455133738+6283.07584999140*x);
R2+=0.00000123633*cost(5.57934722157+12566.15169998280*x);
R2-=0.00000012341;
R2+=0.00000008792*cost(3.62777733395+77713.77146812050*x);
R2+=0.00000005689*cost(1.86958905084+5573.14280143310*x);
R2+=0.00000003301*cost(5.47027913302+18849.22754997420*x);
R2+=0.00000001471*cost(4.48028885617+5507.55323866740*x);
R2+=0.00000001013*cost(2.81456417694+5223.69391980220*x);
R2+=0.00000000854*cost(3.10878241236+1577.34354244780*x);
R2+=0.00000001102*cost(2.84173992403+161000.68573767410*x);
R2+=0.00000000648*cost(5.47349498544+775.52261132400*x);
R2+=0.00000000609*cost(1.37969434104+6438.49624942560*x);
R2+=0.00000000499*cost(4.41649242250+6286.59896834040*x);
R2+=0.00000000417*cost(0.90242451175+10977.07880469900*x);
R2+=0.00000000402*cost(3.20376585290+5088.62883976680*x);
R2+=0.00000000351*cost(1.81079227770+5486.77784317500*x);
R2+=0.00000000467*cost(3.65753702738+7084.89678111520*x);
R2+=0.00000000458*cost(5.38585314743+149854.40013480789*x);
R2+=0.00000000304*cost(3.51701098693+796.29800681640*x);
R2+=0.00000000266*cost(6.17413982699+6836.64525283380*x);
R2+=0.00000000279*cost(1.84120501086+4694.00295470760*x);
R2+=0.00000000260*cost(1.41629543251+2146.16541647520*x);
R2+=0.00000000266*cost(3.13832905677+71430.69561812909*x);
R2+=0.00000000321*cost(5.35313367048+3154.68708489560*x);
R2+=0.00000000238*cost(2.17720020018+155.42039943420*x);
R2+=0.00000000293*cost(4.61501268144+4690.47983635860*x);
R2+=0.00000000229*cost(4.75969588070+7234.79425624200*x);
R2+=0.00000000211*cost(0.21868065485+4705.73230754360*x);
R2+=0.00000000201*cost(4.21905743357+1349.86740965880*x);
R2+=0.00000000195*cost(4.57808285364+529.69096509460*x);
R2+=0.00000000253*cost(2.81496293039+1748.01641306700*x);
R2+=0.00000000182*cost(5.70454011389+6040.34724601740*x);
R2+=0.00000000179*cost(6.02897097053+4292.33083295040*x);
R2+=0.00000000186*cost(1.58690991244+6309.37416979120*x);
R2+=0.00000000170*cost(2.90220009715+9437.76293488700*x);
R2+=0.00000000166*cost(1.99984925026+8031.09226305840*x);
R2+=0.00000000158*cost(0.04783713552+2544.31441988340*x);
R2+=0.00000000197*cost(2.01083639502+1194.44701022460*x);
R2+=0.00000000165*cost(5.78372596778+83996.84731811189*x);
R2+=0.00000000214*cost(3.38285934319+7632.94325965020*x);
R2+=0.00000000140*cost(0.36401486094+10447.38783960440*x);
R2+=0.00000000151*cost(0.95153163031+6127.65545055720*x);
R2+=0.00000000136*cost(1.48426306582+2352.86615377180*x);
R2+=0.00000000127*cost(5.48475435134+951.71840625060*x);
R2+=0.00000000126*cost(5.26866506592+6279.55273164240*x);
R2+=0.00000000125*cost(3.75754889288+6812.76681508600*x);
R2+=0.00000000101*cost(4.95015746147+398.14900340820*x);
R2+=0.00000000102*cost(0.68468295277+1592.59601363280*x);
R2+=0.00000000100*cost(1.14568935785+3894.18182954220*x);
R2+=0.00000000129*cost(0.76540016965+553.56940284240*x);
R2+=0.00000000109*cost(5.41063597567+6256.77753019160*x);
R2+=0.00000000075*cost(5.84804322893+242.72860397400*x);
R2+=0.00000000095*cost(1.94452244083+11856.21865142450*x);
R2+=0.00000000077*cost(0.69373708195+8429.24126646660*x);
R2+=0.00000000100*cost(5.19725292131+244287.60000722769*x);
R2+=0.00000000080*cost(6.18440483705+1059.38193018920*x);
R2+=0.00000000069*cost(5.25699888595+14143.49524243060*x);
R2+=0.00000000085*cost(5.39484725499+25132.30339996560*x);
R2+=0.00000000066*cost(0.51779993906+801.82093112380*x);
R2+=0.00000000055*cost(5.16878202461+7058.59846131540*x);
R2+=0.00000000051*cost(3.88759155247+12036.46073488820*x);
R2+=0.00000000050*cost(5.57636570536+6290.18939699220*x);
R2+=0.00000000061*cost(2.24359003264+8635.94200376320*x);
R2+=0.00000000050*cost(5.54441900966+1990.74501704100*x);
R2+=0.00000000056*cost(4.00301078040+13367.97263110660*x);
R2+=0.00000000052*cost(4.13138898038+7860.41939243920*x);
R2+=0.00000000052*cost(3.90943054011+26.29831979980*x);
R2+=0.00000000041*cost(3.57128482780+7079.37385680780*x);
R2+=0.00000000056*cost(2.76959005761+90955.55169449610*x);
R2+=0.00000000042*cost(1.91461189199+7477.52286021600*x);
R2+=0.00000000042*cost(0.42728171713+10213.28554621100*x);
R2+=0.00000000042*cost(1.09413724455+709.93304855830*x);
R2+=0.00000000039*cost(3.93298068961+10973.55568635000*x);
R2+=0.00000000038*cost(6.17935925345+9917.69687450980*x);
R2+=0.00000000049*cost(0.83021145241+11506.76976979360*x);
R2+=0.00000000053*cost(1.45828359397+233141.31440436149*x);
R2+=0.00000000047*cost(6.21568666789+6681.22485339960*x);
R2+=0.00000000037*cost(0.36359309980+10177.25767953360*x);
R2+=0.00000000035*cost(3.33024911524+5643.17856367740*x);
R2+=0.00000000034*cost(5.63446915337+6525.80445396540*x);
R2+=0.00000000035*cost(5.36033855038+25158.60171976540*x);
R2+=0.00000000034*cost(5.36319798321+4933.20844033260*x);
R2+=0.00000000033*cost(4.24722336872+12569.67481833180*x);
R2+=0.00000000043*cost(5.26370903404+10575.40668294180*x);
R2+=0.00000000042*cost(5.08837645072+11015.10647733480*x);
R2+=0.00000000040*cost(1.98334703186+6284.05617105960*x);
R2+=0.00000000042*cost(4.22496037505+88860.05707098669*x);
R2+=0.00000000029*cost(3.19088628170+11926.25441366880*x);
R2+=0.00000000029*cost(0.15217616684+12168.00269657460*x);
R2+=0.00000000030*cost(1.61904744136+9779.10867612540*x);
R2+=0.00000000027*cost(0.76388991416+1589.07289528380*x);
R2+=0.00000000036*cost(2.74712003443+3738.76143010800*x);
R2+=0.00000000033*cost(3.08807829566+3930.20969621960*x);
R2+=0.00000000031*cost(5.34906619513+143571.32428481648*x);
R2+=0.00000000025*cost(0.10240267494+22483.84857449259*x);
R2+=0.00000000030*cost(3.47110495524+14945.31617355440*x);
R2+=0.00000000024*cost(1.10425016019+4535.05943692440*x);
R2+=0.00000000024*cost(1.58037259780+6496.37494542940*x);
R2+=0.00000000023*cost(3.87710321433+6275.96230299060*x);
R2+=0.00000000025*cost(3.94529778970+3128.38876509580*x);
R2+=0.00000000023*cost(3.44685609601+4136.91043351620*x);
R2+=0.00000000023*cost(3.83156029849+5753.38488489680*x);
R2+=0.00000000022*cost(1.86956128067+16730.46368959580*x);
R2+=0.00000000025*cost(2.42188933855+5729.50644714900*x);
R2+=0.00000000020*cost(1.78208352927+17789.84561978500*x);
R2+=0.00000000021*cost(4.30363087400+16858.48253293320*x);
R2+=0.00000000021*cost(0.49258939822+29088.81141598500*x);
R2+=0.00000000025*cost(1.33030250444+6282.09552892320*x);
R2+=0.00000000027*cost(2.54785812264+3496.03282613400*x);
R2+=0.00000000022*cost(1.11232521950+12721.57209941700*x);
R2+=0.00000000021*cost(5.97759081637+7.11354700080*x);
R2+=0.00000000019*cost(0.80292033311+16062.18452611680*x);
R2+=0.00000000023*cost(4.12454848769+2388.89402044920*x);
R2+=0.00000000022*cost(4.92663152168+18875.52586977400*x);
R2+=0.00000000023*cost(5.68902059771+16460.33352952499*x);
R2+=0.00000000023*cost(4.97346265647+17260.15465469040*x);
R2+=0.00000000023*cost(3.03021283729+66567.48586525429*x);
R2+=0.00000000016*cost(3.89740925257+5331.35744374080*x);
R2+=0.00000000017*cost(3.08268671348+154717.60988768269*x);
R2+=0.00000000016*cost(3.95085099736+3097.88382272579*x);
R2+=0.00000000016*cost(3.99041783945+6283.14316029419*x);
R2+=0.00000000020*cost(6.10644140189+167283.76158766549*x);
R2+=0.00000000015*cost(4.09775914607+11712.95531823080*x);
R2+=0.00000000016*cost(5.71769940700+17298.18232732620*x);
R2+=0.00000000016*cost(3.28894009404+5884.92684658320*x);
R2+=0.00000000015*cost(5.64785377164+12559.03815298200*x);
R2+=0.00000000016*cost(4.43452080930+6283.00853968860*x);
R2+=0.00000000014*cost(2.31721603062+5481.25491886760*x);
R2+=0.00000000014*cost(4.43479032305+13517.87010623340*x);
R2+=0.00000000014*cost(4.73209312936+7342.45778018060*x);
R2+=0.00000000012*cost(0.64705975463+18073.70493865020*x);
R2+=0.00000000011*cost(1.51443332200+16200.77272450120*x);
R2+=0.00000000011*cost(0.88708889185+21228.39202354580*x);
R2+=0.00000000014*cost(4.50116508534+640.87760738220*x);
R2+=0.00000000011*cost(4.64339996198+11790.62908865880*x);
R2+=0.00000000011*cost(1.31064298246+4164.31198961300*x);
R2+=0.00000000009*cost(3.02238989305+23543.23050468179*x);
R2+=0.00000000009*cost(2.04999402381+22003.91463486980*x);
R2+=0.00000000009*cost(4.91488110218+213.29909543800*x);

double R3=0;
R3+=0.00000144595*cost(4.27319435148+6283.07584999140*x);
R3+=0.00000006729*cost(3.91697608662+12566.15169998280*x);
R3+=0.00000000774;
R3+=0.00000000247*cost(3.73019298781+18849.22754997420*x);
R3+=0.00000000036*cost(2.80081409050+6286.59896834040*x);
R3+=0.00000000033*cost(5.62216602775+6127.65545055720*x);
R3+=0.00000000019*cost(3.71292621802+6438.49624942560*x);
R3+=0.00000000016*cost(4.26011484232+6525.80445396540*x);
R3+=0.00000000016*cost(3.50416887054+6256.77753019160*x);
R3+=0.00000000014*cost(3.62127621114+25132.30339996560*x);
R3+=0.00000000011*cost(4.39200958819+4705.73230754360*x);
R3+=0.00000000011*cost(5.22327127059+6040.34724601740*x);
R3+=0.00000000010*cost(4.28045254647+83996.84731811189*x);
R3+=0.00000000009*cost(1.56864096494+5507.55323866740*x);
R3+=0.00000000011*cost(1.37795688024+6309.37416979120*x);
R3+=0.00000000010*cost(5.19937959068+71430.69561812909*x);
R3+=0.00000000009*cost(0.47275199930+6279.55273164240*x);
R3+=0.00000000009*cost(0.74642756529+5729.50644714900*x);
R3+=0.00000000007*cost(2.97374891560+775.52261132400*x);
R3+=0.00000000007*cost(3.28615691021+7058.59846131540*x);
R3+=0.00000000007*cost(2.19184402142+6812.76681508600*x);
R3+=0.00000000005*cost(3.15419034438+529.69096509460*x);
R3+=0.00000000006*cost(4.54725567047+1059.38193018920*x);
R3+=0.00000000005*cost(1.51104406936+7079.37385680780*x);
R3+=0.00000000007*cost(2.98052059053+6681.22485339960*x);
R3+=0.00000000005*cost(2.30961231391+12036.46073488820*x);
R3+=0.00000000005*cost(3.71102966917+6290.18939699220*x);

double R4=0;
R4+=0.00000003858*cost(2.56384387339+6283.07584999140*x);
R4+=0.00000000306*cost(2.26769501230+12566.15169998280*x);
R4+=0.00000000053*cost(3.44031471924+5573.14280143310*x);
R4+=0.00000000015*cost(2.04794573436+18849.22754997420*x);
R4+=0.00000000013*cost(2.05688873673+77713.77146812050*x);
R4+=0.00000000007*cost(4.41218854480+161000.68573767410*x);
R4+=0.00000000005*cost(5.26154653107+6438.49624942560*x);
R4+=0.00000000005*cost(4.07695126049+6127.65545055720*x);
R4+=0.00000000006*cost(3.81514213664+149854.40013480789*x);
R4+=0.00000000003*cost(1.28175749811+6286.59896834040*x);

double R5=0;
R5+=0.00000000086*cost(1.21579741687+6283.07584999140*x);
R5+=0.00000000012*cost(0.65617264033+12566.15169998280*x);
R5+=0.00000000001*cost(0.38068797142+18849.22754997420*x);

double x2 = x*x;
double x3 = x2*x;
double x4 = x3*x;
double x5 = x4*x;

double r2d0=180./pi0;
	
return 1 * (R0+R1*x+R2*x2+R3*x3+R4*x4+R5*x5);
}

///////////////////// END   VSOP87   EARTH ///////////////////////////



////////////////////////////////////////////////////////////////////////////////////////
//Nutation, obliquity of the ecliptic, IERS2003 B
void Nutation(double TE, double *dpsi, double *deps, double *epsilon0, double *epsilon1)
{
//NUTATION from IERS2003 B  by DennisMcCarthy and Brian LUZUM, 
//   from: Celestial Mechanics and Dynamical astronomy 85, p.37-49, 2003. Precision < 0.001 arcsec.
//   data copied partly from Jay Tanner: http://neoprogrammics.com/ (but sign dpsi negative!)
//   Note: the last two lines of data were missing in Jay Tanners file, also the correction terms dp, de.  
//   THIS is now REMOVED!
  
double TE2=TE*TE, TE3=TE*TE*TE, u,h;  // TE= Julian Centuries from Epoch J2000
double delta_psi,delta_eps,eps0,eps;
double rld7[110],rld9[110];
double fMm,fM,fF,fD,f_omega,dp,de,x,xx;
double DegToRad,s,T,T2,T3,T4;
double L,Lp,F,D,Om, Mm,M,omega;

//NUTATION from IAU1980: http://hpiers.obspm.fr/eop-pc/models/nutations/nut_IAU1980.dat  
// and H.Umland
//    ld = Array(110,35);

  //Periodic terms for Nutation
  //HMK: manches wie bei MOON in Astronav-JMv10.c: character-string definieren, von dort
  // in einzelne vektoren einlesen (SUBSTRINGS).
  

// double rld7[110],rld9[110];
// double fMm,fM,fF,fD,f_omega,dp,de,x,xx;
// double delta_psi,delta_eps,eps0,eps;

int nld1[110],nld2[110],nld3[110],nld4[110],nld5[110], nld6[110],nld8[110];
int jmax,jz,ka,ke,kk;

char ld[110][35] = 
  {  
   " 0 0 0 0 1-171996-174.2 92025 8.9 ",     // 0 0 0 0 1 !
   " 0 0 2-2 2 -13187  -1.6  5736-3.1 ",     
   " 0 0 2 0 2  -2274  -0.2   977-0.5 ",     
   " 0 0 0 0 2   2062   0.2  -895 0.5 ",     
   " 0-1 0 0 0  -1426   3.4    54-0.1 ",     
   " 1 0 0 0 0    712   0.1    -7 0.0 ",     
   " 0 1 2-2 2   -517   1.2   224-0.6 ",     
   " 0 0 2 0 1   -386  -0.4   200 0.0 ",     
   " 1 0 2 0 2   -301   0.0   129-0.1 ",     
   " 0-1 2-2 2    217  -0.5   -95 0.3 ",     
   "-1 0 0 2 0    158   0.0    -1 0.0 ",     
   " 0 0 2-2 1    129   0.1   -70 0.0 ",     
   "-1 0 2 0 2    123   0.0   -53 0.0 ",     
   " 1 0 0 0 1     63   0.1   -33 0.0 ",     
   " 0 0 0 2 0     63   0.0    -2 0.0 ",     
   "-1 0 2 2 2    -59   0.0    26 0.0 ",     
   "-1 0 0 0 1    -58  -0.1    32 0.0 ",     
   " 1 0 2 0 1    -51   0.0    27 0.0 ",     
   "-2 0 0 2 0    -48   0.0     1 0.0 ",     
   "-2 0 2 0 1     46   0.0   -24 0.0 ",    
   " 0 0 2 2 2    -38   0.0    16 0.0 ",     
   " 2 0 2 0 2    -31   0.0    13 0.0 ",     
   " 2 0 0 0 0     29   0.0    -1 0.0 ",     
   " 1 0 2-2 2     29   0.0   -12 0.0 ",     
   " 0 0 2 0 0     26   0.0    -1 0.0 ",     
   " 0 0 2-2 0    -22   0.0     0 0.0 ",     
   "-1 0 2 0 1     21   0.0   -10 0.0 ",     
   " 0 2 0 0 0     17  -0.1     0 0.0 ",     
   " 0 2 2-2 2    -16   0.1     7 0.0 ",     
   "-1 0 0 2 1     16   0.0    -8 0.0 ",     
   " 0 1 0 0 1    -15   0.0     9 0.0 ",     
   " 1 0 0-2 1    -13   0.0     7 0.0 ",     
   " 0-1 0 0 1    -12   0.0     6 0.0 ",     
   " 2 0-2 0 0     11   0.0     0 0.0 ",     
   "-1 0 2 2 1    -10   0.0     5 0.0 ",     
   " 1 0 2 2 2     -8   0.0     3 0.0 ",     
   " 0-1 2 0 2     -7   0.0     3 0.0 ",     
   " 0 0 2 2 1     -7   0.0     3 0.0 ",     
   " 1 1 0-2 0     -7   0.0     0 0.0 ",     
   " 0 1 2 0 2      7   0.0    -3 0.0 ",     
   "-2 0 0 2 1     -6   0.0     3 0.0 ",     
   " 0 0 0 2 1     -6   0.0     3 0.0 ",     
   " 2 0 2-2 2      6   0.0    -3 0.0 ",     
   " 1 0 0 2 0      6   0.0     0 0.0 ",     
   " 1 0 2-2 1      6   0.0    -3 0.0 ",     
   " 0 0 0-2 1     -5   0.0     3 0.0 ",     
   " 0-1 2-2 1     -5   0.0     3 0.0 ",     
   " 2 0 2 0 1     -5   0.0     3 0.0 ",     
   " 1-1 0 0 0      5   0.0     0 0.0 ",     
   " 1 0 0-1 0     -4   0.0     0 0.0 ",     
   " 0 0 0 1 0     -4   0.0     0 0.0 ",     
   " 0 1 0-2 0     -4   0.0     0 0.0 ",     
   " 1 0-2 0 0      4   0.0     0 0.0 ",     
   " 2 0 0-2 1      4   0.0    -2 0.0 ",     
   " 0 1 2-2 1      4   0.0    -2 0.0 ",     
   " 1 1 0 0 0     -3   0.0     0 0.0 ",     
   " 1-1 0-1 0     -3   0.0     0 0.0 ",     
   "-1-1 2 2 2     -3   0.0     1 0.0 ",     
   " 0-1 2 2 2     -3   0.0     1 0.0 ",     
   " 1-1 2 0 2     -3   0.0     1 0.0 ",     
   " 3 0 2 0 2     -3   0.0     1 0.0 ",     
   "-2 0 2 0 2     -3   0.0     1 0.0 ",     
   " 1 0 2 0 0      3   0.0     0 0.0 ",     
   "-1 0 2 4 2     -2   0.0     1 0.0 ",     
   " 1 0 0 0 2     -2   0.0     1 0.0 ",     
   "-1 0 2-2 1     -2   0.0     1 0.0 ",     
   " 0-2 2-2 1     -2   0.0     1 0.0 ",     
   "-2 0 0 0 1     -2   0.0     1 0.0 ",     
   " 2 0 0 0 1      2   0.0    -1 0.0 ",     
   " 3 0 0 0 0      2   0.0     0 0.0 ",     
   " 1 1 2 0 2      2   0.0    -1 0.0 ",     
   " 0 0 2 1 2      2   0.0    -1 0.0 ",     
   " 1 0 0 2 1     -1   0.0     0 0.0 ",     
   " 1 0 2 2 1     -1   0.0     1 0.0 ",     
   " 1 1 0-2 1     -1   0.0     0 0.0 ",     
   " 0 1 0 2 0     -1   0.0     0 0.0 ",    
   " 0 1 2-2 0     -1   0.0     0 0.0 ",     
   " 0 1-2 2 0     -1   0.0     0 0.0 ",     
   " 1 0-2 2 0     -1   0.0     0 0.0 ",     
   " 1 0-2-2 0     -1   0.0     0 0.0 ",     
   " 1 0 2-2 0     -1   0.0     0 0.0 ",     
   " 1 0 0-4 0     -1   0.0     0 0.0 ",     
   " 2 0 0-4 0     -1   0.0     0 0.0 ",     
   " 0 0 2 4 2     -1   0.0     0 0.0 ",     
   " 0 0 2-1 2     -1   0.0     0 0.0 ",     
   "-2 0 2 4 2     -1   0.0     1 0.0 ",     
   " 2 0 2 2 2     -1   0.0     0 0.0 ",     
   " 0-1 2 0 1     -1   0.0     0 0.0 ",    
   " 0 0-2 0 1     -1   0.0     0 0.0 ",     
   " 0 0 4-2 2      1   0.0     0 0.0 ",     
   " 0 1 0 0 2      1   0.0     0 0.0 ",     
   " 1 1 2-2 2      1   0.0    -1 0.0 ",     
   " 3 0 2-2 2      1   0.0     0 0.0 ",     
   "-2 0 2 2 2      1   0.0    -1 0.0 ",     
   "-1 0 0 0 2      1   0.0    -1 0.0 ",     
   " 0 0-2 2 1      1   0.0     0 0.0 ",     
   " 0 1 2 0 1      1   0.0     0 0.0 ",     
   "-1 0 4 0 2      1   0.0     0 0.0 ",     
   " 2 1 0-2 0      1   0.0     0 0.0 ",     
   " 2 0 0 2 0      1   0.0     0 0.0 ",     
   " 2 0 2-2 1      1   0.0    -1 0.0 ",     
   " 2 0-2 0 1      1   0.0     0 0.0 ",     
   " 1-1 0-2 0      1   0.0     0 0.0 ",     
   "-1 0 0 1 1      1   0.0     0 0.0 ",     
   "-1-1 0 2 1      1   0.0     0 0.0 ",     
   " 0 1 0 1 0      1   0.0     0 0.0 ",  
  }; // ld=106 Eintraege
  
  //IAU 1980 Nutation theory:
  TE2=TE*TE, TE3=TE*TE*TE; // TE= Julian Centuries from Epoch J2000
  
  //Mean anomaly of the Moon
  Mm = norm360(134.962981389+198.867398056*TE+norm360(477000*TE)+0.008697222222*TE2+TE3/56250);
  
  //Mean anomaly of the Sun
  M = norm360(357.527723333+359.05034*TE+norm360(35640*TE)-0.0001602777778*TE2-TE3/300000);
  
  //Mean distance of the Moon from ascending node
  F = norm360(93.271910277+82.017538055*TE+norm360(483120*TE)-0.0036825*TE2+TE3/327272.7273);
  
  //Mean elongation of the Moon
  D = norm360(297.850363055+307.11148*TE+norm360(444960*TE)-0.001914166667*TE2+TE3/189473.6842);
   
  //Longitude of the ascending node of the Moon
  omega = norm360(125.044522222-134.136260833*TE-norm360(1800*TE)+0.002070833333*TE2+TE3/450000);

double checksum=Mm+M+F+D+omega; checksum=norm360(checksum);

/*
printf(">>checksum  nutation2 =%.12f\n",checksum); 

printf("Nutation2-Iau1980 \n");
printf(">> T    = %.12f Julian centuries from epoch J2000.0\n",TE);
printf(">> D    = %f degrees\n",D);
printf(">> M    = %f\n",M);
printf(">> M'   = %f\n",Mm);
printf(">> F    = %f\n",F);
printf(">> omega= %f\n",omega);  getchar();
*/ 
    
//Reading periodic terms  ////////////////////////////////////////////////////

//------------
jmax=106; //106 Eintraege, aber Zaehlung ab jz=0!
// Spalten von ld[][] auf einzelne Vektoren nld0[]schreiben.
for (jz=0; jz<jmax; jz++)
{
  //0,2 2,4 4,6 6,8 8,10 10,17 17,23 23,29 29,34
  ka=0;
  ke=2;
  kk=iarr35(ld, jz, ka,ke);
  nld1[jz]=kk;
  
  ka=2;
  ke=4;
  kk=iarr35(ld, jz, ka,ke);
  nld2[jz]=kk;
  
  ka=4;
  ke=6;
  kk=iarr35(ld, jz, ka,ke);
  nld3[jz]=kk;
  
  ka=6;
  ke=8;
  kk=iarr35(ld, jz, ka,ke);
  nld4[jz]=kk;
 
  ka=8;
  ke=10;
  kk=iarr35(ld, jz, ka,ke);
  nld5[jz]=kk;

  ka=10;
  ke=17;
  kk=iarr35(ld, jz, ka,ke);
  nld6[jz]=kk;

  ka=17;
  ke=23;
   xx=farr35(ld, jz, ka,ke);
   rld7[jz]=xx;

  ka=23;
  ke=29;
  kk=iarr35(ld, jz, ka,ke);
  nld8[jz]=kk;

  ka=29;
  ke=35;
   xx=farr35(ld, jz, ka,ke);
   rld9[jz]=xx;
      
//if(jz<11 || jz>99)
//printf(">>jz: %3d nld= %3d %3d %3d %3d %9d %9d %7.1f %8d %7.1f\n",jz,nld1[jz],nld2[jz],nld3[jz],nld4[jz],nld5[jz],nld6[jz],rld7[jz],nld8[jz],rld9[jz]);


 }

  //0,2    2,4    4,6    6,8    8,10    10,17    17,23    23,29    29,34
  //nld1   nld2   nld3   nld4   nld5    nld6     rld7     nld8     rld9 
  
dp=0;
de=0;

   jz=0;
   while (jz<106)
   {
      fMm = nld1[jz];     //nld1
      fM = nld2[jz];      //nld2
      fF = nld3[jz];      //nld3
      fD = nld4[jz];      //nld4
      f_omega = nld5[jz]; //nld5
      dp += (nld6[jz]+TE*rld7[jz])*sind(fD*D+fM*M+fMm*Mm+fF*F+f_omega*omega);
      de += (nld8[jz]+TE*rld9[jz])*cosd(fD*D+fM*M+fMm*Mm+fF*F+f_omega*omega);
      
//printf("#>>jz=%3d fMm...= %3.0f %3.0f %3.0f %3.0f %3.0f %12.8f %12.8f\n",jz, fMm,fM,fF,fD,f_omega,dp,de);
      
	  jz++;
   }
   
   //printf("nutation1oHerring: dp,de= %.12f %.12f\n",dp,de);
//.....................................................................................................
// Corrections Herring 1987, from H.Umland
   char corr[5][35] = 
  {  
   " 0 0 0 0 1   -725   417   213 224 ",     // 0 0 0 0 1 !
   " 0 1 0 0 0    523    61   208 -24 ",     
   " 0 0 2-2 2    102  -118   -41 -47 ",     
   " 0 0 2 0 2    -81     0    32   0 ", 
   " 0 0 0 0 0      0     0     0   0 ",  
  };

//------------

jmax=5; //4 Eintraege, aber Zaehlung ab jz=0!
// Spalten von corr[][] auf einzelne Vektoren nld0[]schreiben.
for (jz=0; jz<jmax; jz++)
{
  //0,2 2,4 4,6 6,8 8,10 10,17 17,23 23,29 29,34
  ka=0;
  ke=2;
  kk=iarr35(corr, jz, ka,ke);
  nld1[jz]=kk;
  
  ka=2;
  ke=4;
  kk=iarr35(corr, jz, ka,ke);
  nld2[jz]=kk;
  
  ka=4;
  ke=6;
  kk=iarr35(corr, jz, ka,ke);
  nld3[jz]=kk;
  
  ka=6;
  ke=8;
  kk=iarr35(corr, jz, ka,ke);
  nld4[jz]=kk;
 
  ka=8;
  ke=10;
  kk=iarr35(corr, jz, ka,ke);
  nld5[jz]=kk;

  ka=10;
  ke=17;
  kk=iarr35(corr, jz, ka,ke);
  nld6[jz]=kk;

  ka=17;
  ke=23;
   xx=farr35(corr, jz, ka,ke);
   rld7[jz]=xx;

  ka=23;
  ke=29;
  kk=iarr35(corr, jz, ka,ke);
  nld8[jz]=kk;

  ka=29;
  ke=35;
   xx=farr35(corr, jz, ka,ke);
   rld9[jz]=xx;

  //if(jz<11 || jz>99)
  //printf(">>jz: %3d nld= %3d %3d %3d %3d %9d %9d %7.1f %8d %7.1f\n",jz,nld1[jz],nld2[jz],nld3[jz],nld4[jz],nld5[jz],nld6[jz],rld7[jz],nld8[jz],rld9[jz]);
};
    
   double dp1=0;
   double de1=0;
   
   jz=0;
   while (jz<5)
   {
      fMm = nld1[jz];     //nld1
      fM = nld2[jz];      //nld2
      fF = nld3[jz];      //nld3
      fD = nld4[jz];      //nld4
      f_omega = nld5[jz]; //nld5
      dp1 += 0.1*(nld6[jz]*sind(fD*D+fM*M+fMm*Mm+fF*F+f_omega*omega) + rld7[jz]*cosd(fD*D+fM*M+fMm*Mm+fF*F+f_omega*omega) );
      de1 += 0.1*(nld8[jz]*cosd(fD*D+fM*M+fMm*Mm+fF*F+f_omega*omega) + rld9[jz]*sind(fD*D+fM*M+fMm*Mm+fF*F+f_omega*omega) );
	  //printf("#>>jz=%3d fMm...= %3.0f %3.0f %3.0f %3.0f %3.0f %12.1f %12.1f\n",jz, fMm,fM,fF,fD,f_omega,dp1,de1); 	  
	  jz++;
   }
/*
// Tom Herring corrections= dp1,de1, possibly suppressed:
   dp=dp+dp1;
   de=de+de1;
*/

//.....................................................................................................           
   //Nutation in longitude degrees
   delta_psi = dp/36000000;
   
   //Nutation in obliquity degrees
   delta_eps = de/36000000;
   
   //Mean obliquity of the ecliptic MEEUS, but IERS2003: 84381.4059
   //   furthermore SPA: Lasker formula (22.3) with U=TE/100
   //eps0 = (84381.448-46.815*TE-0.00059*TE2+0.001813*TE3)/3600;
   
   u = TE/100.;    // MEEUS p147: 84381.448; IERS2003 TN32,Tab1.1: 84381.4059
   h = 84381.448 + u*(-4680.93 + u*(-1.55 + u*(1999.25 + u*(-51.38 + u*(-249.67 +   
       u*( -39.05 + u*( 7.12 + u*( 27.87 + u*( 5.79 + u*2.45))))))))); 
   eps0=h/3600;	    

   //True obliquity of the ecliptic
   eps = eps0+delta_eps;

//printf(">> TE,delta_psi,delta_eps= %.12f %.12f %.12f\n", TE,delta_psi,delta_eps); getchar();


/////////////////////////////////////
g9999:  u=0;  // exit
//printf(">> TE,delta_psi,delta_eps= %.12f %.12f %.12f\n", TE,delta_psi,delta_eps); getchar();

*dpsi = delta_psi;
*deps = delta_eps;
*epsilon0 = eps0;
*epsilon1 = eps;
}; //end Nutation IERS2000-B + IAU1980


    
//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// --------------------------------------------
void shiftpos(int isw,double dist,int h1,int m1,int h2,int m2,
              double latitude1,double longitude1,double velav,double kursav,double *xlat2,double *xlong2)
// Ermittelt eine neue dead-reckoning Position latitude2(lad2,lam2),longitude2(lod2,lom2) 
// aus alter Position Latitude1,Longitude1 mit Versegelung via velav und kursav.   
// (Berechnung ueber VERGRERTE BREITE).
//              DETAILS:
// ISW=0:Distanz wird direkt genommen=>   Jetzt sind die Zeiten h1,m1,h2,m2 irrelevant.
//       Der Punkt latitude1(lad1,lam1),longitude1(lod1,lom1) wird in Richtung kursav
//       um den betrag dist verschoben. 
// ISW=1:Distanz aus Vel und Zeit-Diff=> Jetzt wird aus der Zeitdifferenz (h2,m2)-(h1,m1) mit der
//       Geschwindigkeit velav die Distanz dist berechnet. dann Punktverschiebung wie unter ISW=0.
// On INPUT: dist=nautical miles, velav=knots, kursav=degrees (later dist=latitude degrees).
// on output: xlat2, xlon2 neue Position
// Falls Kurs um 90 Grad oder 270 Grad, dann Rechnung nach Mittelbreite
{   
double lonsem,semlon,aux1,aux2;
double degrad,raddeg,pi,pi2,pi4;
double tdif,cdif,sdif;
//double latitude1,longitude1;
double latitude2,longitude2;
double latr1,lonr1,latr2,lonr2;
double kurs,vel,latav,sem1,sem2;

static int lad1,lam1,lod1,lom1,lad2,lam2,lod2,lom2;
static int ig,im,is,kchk;

//Initialize    
pi=3.1415926535898;
pi2=pi/2.;  pi4=pi/4.;
degrad=2.0*pi/360.; raddeg=180./pi;
kchk=0;


//latitude1=lad1+lam1/60.;
if(latitude1 >  89.) latitude1= 89.;
if(latitude1 < -89.) latitude1=-89.;
vel=fabs(velav);  
kursav=fabs(kursav); if(kursav > 360) kursav=kursav-360;
if(fabs(kursav- 90) < 0.01) kchk= 1;
if(fabs(kursav-270) < 0.01) kchk=-1;
kurs=kursav*degrad;

//calculate and normalize distance, also if not given initially
tdif=(h2-h1)+(m2-m1)/60.;
//if(tdif<0.) { printf("??? ERROR TDIF<0: %f \n",tdif); getchar(); }
if(isw == 1) dist=tdif*vel;
dist=dist/60.;  //normalize distance from nautical miles to degrees latitude

//calculate latitude2, this can be done directly
latitude2=latitude1+dist*cos(kurs);
latr1=latitude1*degrad; //von Grad auf Pi
latr2=latitude2*degrad;
//printf("latitude1,latitude2 %f %f\n",latitude1,latitude2);
//calculate longitude2 using LOXODROME

//////////////////////////////////// jetzt Berechnung der neuen Lnge //////////
//longitude1=lod1+lom1/60.;
lonr1=longitude1*degrad;
latav=(latitude1+latitude2)/2.;  
longitude2=longitude1 + kchk*dist/cos(latav*degrad); //falls kchk=1 !

if(kchk ==0 ) //////// Rechnung mit vergrerter Breite ////////////////////////
{
  aux2=tan(0.5*latr2+pi4);
  aux1=tan(0.5*latr1+pi4);
  lonr2=lonr1+tan(kurs)*log(aux2/aux1);
  longitude2=lonr2*raddeg; //von Pi auf Grad
}
//printf("> longitude1,longitude2 %f %f\n",longitude1,longitude2);

*xlat2 =latitude2;
*xlong2=longitude2;
};


//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// --------------------------------------------
int parsenth(int nth, int kkk)
//expects INPUT as a string, parses string  fgets(str1).
//nth=1 initially reads the string and returns integer value.
//nth=2,3,.. afterwards returns the next integer values.
//The default value  kkk  is returned, if string empty.
{
  int i, k, kres, lenstr, iaux, icount,maxs;
  static char str0[61]=" ";
  static char str1[61]="abcdefghijk";
  static char str2[61]=" ";
  static char stringin[123] = "kurt  kanns;555678;DE";
  static char delimiter[] = " ,;";
  static char *ptr;
    lenstr=999;
    kres = kkk;
    maxs=61+1;

  if(nth > 1) goto g002;

g001:   //Start and initialization for nth=1
     
  // INPUT for STR1 
  fgets(str1,maxs,stdin); 
  strcpy(str2,str1);
  lenstr=strlen(str1)  -1;
  if(lenstr < 1) return(kkk);
  nth = 1;

g002:  //Start-mark for next values of nth=2,3,4,...

icount=0;
  
//Stringteilung: initialisieren und ersten Abschnitt erstellen 
strcpy(stringin," ");
strcat(stringin,str2);
ptr = strtok(stringin, delimiter); 
while(ptr != NULL) 
{
 iaux=atoi(ptr); 
 icount = icount + 1;
 if(icount == nth) kkk=iaux; 
 // naechsten Abschnitt erstellen
 ptr = strtok(NULL, delimiter); 
} 
  strcpy(str1,str2);

 g999:
  return(kkk);
};


//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// --------------------------------------------
int parse4nth(int iterq, int nth, int kkk)
//expects INPUT as a string, parses string  fgets(str1).
//nth=1 initially reads the string and returns integer value.
//nth=2,3,.. afterwards returns the next integer values.
//The default value  kkk  is returned, if string empty.
{
  int i, k, kres, lenstr, iaux, icount,maxs;
  static char str0[61]=" ";
  static char str1[61]="abcdefghijk";
  static char str2[61]=" ";
  static char stringin[123] = "kurt  kanns;555678;DE";
  static char delimiter[] = " ,;";
  static char *ptr;
    lenstr=999;
    kres = kkk;
    maxs=61+1;

  if(iterq==1) goto g999; // This is the condition for iteration, no change
  
  if(nth > 1) goto g002;

g001:   //Start and initialization for nth=1
     
  // INPUT for STR1 
  fgets(str1,maxs,stdin); 
  strcpy(str2,str1);
  lenstr=strlen(str1)  -1;
  if(lenstr < 1) return(kkk);
  nth = 1;

g002:  //Start-mark for next values of nth=2,3,4,...

icount=0;
  
//Stringteilung: initialisieren und ersten Abschnitt erstellen 
strcpy(stringin," ");
strcat(stringin,str2);
ptr = strtok(stringin, delimiter); 
while(ptr != NULL) 
{
 iaux=atoi(ptr); 
 icount = icount + 1;
 if(icount == nth) kkk=iaux; 
 // naechsten Abschnitt erstellen
 ptr = strtok(NULL, delimiter); 
} 
  strcpy(str1,str2);

 g999:
  return(kkk);
};

//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// --------------------------------------------
double parsefd(int nth, double xxx)
//expects INPUT as a string, parses string  fgets(str1).
//nth=1 initially reads the string and returns float value.
//nth=2,3,.. afterwards returns the next integer values.
//The default value  kkk  is returned, if string empty.
{
  int i, k, kres, lenstr, iaux, icount,maxs;
  double faux,yyy;
  static char str0[61]=" ";
  static char str1[61]="abcdefghijk";
  static char str2[61]=" ";
  static char stringin[123] = "kurt  kanns;555678;DE";
  static char delimiter[] = " ,;";
  static char *ptr;
  lenstr=999;
  maxs=61 +1;
  if(nth > 1) goto g002;

g001:   //Start and initialization for nth=1
  // INPUT for STR1 
  fgets(str1,maxs,stdin); 
  strcpy(str2,str1);
  lenstr=strlen(str1) -1;
  if(lenstr < 1) return(xxx);
  nth = 1;

g002:  //Start-mark for next values of nth=2,3,4,...
icount=0;
//Stringteilung: initialisieren und ersten Abschnitt erstellen 
strcpy(stringin," ");
strcat(stringin,str2);
ptr = strtok(stringin, delimiter); 
while(ptr != NULL) {
 faux=atof(ptr); 
 icount = icount + 1;
 if(icount == nth) xxx=faux; 
 // naechsten Abschnitt erstellen
 ptr = strtok(NULL, delimiter); 
} 
  strcpy(str1,str2);
 g999:
return(xxx);
};


//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// --------------------------------------------
int istop(int kkk)
//input of value kkk =0 helps to stop.
//initially, istop returns '1'. 
//if the required input is '0' then stop returns '0'. 
{
  int i, k, kres, lenstr,maxs;
  char str0[21]="                    ";
  char str1[21]="abcdefg";

  lenstr=999;
  kres = kkk;
  maxs=21 +1;

  printf("  \n");
  strcpy(str1,str0);
  printf(" <<<<<< Enter 0 to STOP, or press [ENTER] >>>>>> \n");
  printf("              Input: ", kkk);

  fgets(str1,maxs,stdin);
  lenstr=strlen(str1) -1;

  printf(" \n");
  k=  atoi(str1); // This is the formal LIBRARY-PROGRAM
  if (lenstr >0) kkk=k;
  if(kkk != 0) kkk=1;

  return(kkk);
};

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
void spaces()
{
    int i;
    for(i=1; i<=30; i++)
    {
        printf(" \n");
    }
    return;
};

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
void pausx()
{
    printf(" \n");
    printf(" \n");
    printf("                 press ENTER to continue...\n");
    getchar();
    return;
};

//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// --------------------------------------------
int skip(int klines) // Skip k lines after input
{ 
int i;
if(klines <= 0) return(0);
printf("  >>>>>>>>   please WAIT !  >>>>>>>>>> \n");
if(klines >  0) 
{
  for(i=0; i<klines; i++)
    printf(" \n");
}

return(klines);
}

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
double green0mean(double jd)
{
  double T,d,gmst;
  //jd=2446896.30625;  // chck Meeus p 89    
  d = jd - 2451545.0;
  T = d / 36525.;        
  gmst= 280.46061837 + 360.98564736629*d + 0.000387933 *T*T - T*T*T/38710000; 
  gmst=norm360(gmst);
return gmst;
}


//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// ----------------------
double bestver(int ibestv, double x0, double y0, double xpos, double ypos, double ynorm)
{
// Besteckversetzung, von x0,y0 nach xpos,ypos (in Seemeilen) 
int ier=0,icase,is0,iangle;
double w0,slope,gradeg;
double dx,dy,dist,angle;

gradeg=2.*3.1415926535898/360.;
//printf("Besteckversetzung\n");

dx=xpos-x0; 
dy=ypos-y0; dy=dy/ynorm; dy=ynorm*lim180(norm360(dy));

dist= sqrt(dx*dx+dy*dy); //Breitengrade, (y0,ypos schon auf Breitengrade normiert)
dist=dist*60.;           //Seemeilen
//printf(">> Bestver Dist= %f\n",dist);
//printf(" x0,y0: %f %f\n",x0,y0);
//printf(" x1,y1: %f %f\n",xpos,ypos);
//getchar();

icase=0; is0=1; if(dx<0.) is0=-1;
if(  fabs(dx)<0.001 ) dx=is0*0.001;
if( (dx>0.) && (dy>0.)  ) icase=1;
if( (dx<0.) && (dy>0.)  ) icase=2;
if( (dx<0.) && (dy<0.)  ) icase=3;
if( (dx>0.) && (dy<0.)  ) icase=4;

slope=fabs(dy/dx);
if (icase==1) {
w0=atan(slope); angle=w0/gradeg;
//printf("icase: %d\n",icase);
//printf("dy,dx,slope,angle: %f %f %f %f\n",dy,dx,slope,angle);
}

if (icase==2) {
w0=atan(slope); angle=w0/gradeg; angle=180-angle;
//printf("icase: %d\n",icase);
//printf("dy,dx,slope,angle: %f %f %f %f\n",dy,dx,slope,angle);
}

if (icase==3) {
w0=atan(slope); angle=w0/gradeg; angle=180+angle;
//printf("icase: %d\n",icase);
//printf("dy,dx,slope,angle: %f %f %f %f\n",dy,dx,slope,angle);
}

if (icase==4) {
w0=atan(slope); angle=w0/gradeg; angle=360-angle;
//printf("icase: %d\n",icase);
//printf("dy,dx,slope,angle: %f %f %f %f\n",dy,dx,slope,angle);
}

if(ibestv == 1) return(dist);
if(ibestv == 2) return(angle);
}

/////////////////////////////////////////////////////////////////////////////////////////////
double BESCHICKUNG(int ibes, int iur, double Lati,double Azi, double ha0,double indb,double temperatur,double druck,  
       double aug, double SDiam,double HorPar, double *HP1,double *dip1,double *r1,double *SD1,double *gb1)
{ //SOURCE: TheMarineStudy.com, also compared to other sources.
   double Hs,Ha,H1,H2,H3,H4,H5,HP,Ho,r2d,d2r;
   double R0,R1,R2,fR,P,fP,delP,SDgc,SDaug,h2q,tah2,shp2,chp2,k;
   
   double gb,gb0,ur,ur0,hb0,dip,dip0,arg0,argpi, he0;
   double degrad,r0,r,OB,sind2;
   //SEXTANT GesamtBESCHICKUNG, Hoehe: hb = ha + gb
   // sonnen(mond)unterrand  (iur=0 bzw. 2), sonnenoberrand (iur=1 bzw 3)
      d2r=3.14159265358979/180.;
      r2d=1/d2r;
      /*
      temperatur=16.1; //Grad Celsius
      druck =1015.75 ;  //Hektopascal bzw. Millibar 
      aug=1.83;          //Augeshhe in m  
      printf(">>> temp,druck,indb,aug= %f %f %f %f\n",temperatur,druck,indb,aug); getchar(); skip(25);	  
      */
      
      ur=0; // Notation for Unterrand (+SDiam) or Oberrand (-SDiam)
      if(iur == 0 ) ur=  1;   // Sun lower rim
      if(iur == 1 ) ur= -1;   // Sun upper rim
      if(iur == 2 ) ur=  1;   // Moon lower rim
      if(iur == 3 ) ur= -1;   // Moon upper rim
      //Planets and stars: only the center is used.
      	   
//NOTE:
// Resulting left of "="-sign: in degrees, if not otherwise indicated! 
       
      HP=HorPar/60.; //horizontal Parallax, degrees
      
//Height S: Sextant reading:	  
	  Hs=ha0;
//Height 1: Index correction	  
	  H1=Hs+indb/60.;   // indb= arcmin
//Height 2: DIP=Kimmtiefe	  
	     dip= 1.76*sqrt(aug); // aug=height of eye; dip=arcmin, contains refraction-correction
	  H2=H1-dip/60;      // Dip from Height of Eye =arcmin, H2=degrees
//Height 3: Refraction  (with Umlands correction for Saastamoinen against Smarts formula)
	       tah2=tand(H2);
	     R1=0.96474/tah2-0.00113/(tah2*tah2*tah2); //H1=degrees,  R1=arcmin
	       h2q=H2*H2;
		 R2=(34.133+4.197*H2+0.00428*H2*H2)/(1+0.505*H2+0.0845*H2*H2);
	     R0=R1/60; if(Hs<15) R0=R2/60; // Refraction , depending on angle Hs, degrees
         fR=(druck*283.15)/(1010*(273.15+temperatur)); // dimensionless atmospheric scale-factor
      H3=H2-fR*R0;  //degrees
//Height 4: augmented Semi-Diameter 
         k=0.2725;  //  moon-rad/earth-rd: 1738./6378.
         HP=HorPar/60.; // horizontal Parallax HP=degrees, HorPar=arcmin         
         SDgc=r2d*asin(k*sind(HP));           //geocentric semidiameter, degrees
		 //SDaug=k*HP*(1+sind(HP)*sind(H3));  //augmented SemiDiameter, degrees, simplified MEEUS chap.55
		    shp2=sind(HP); shp2=shp2*shp2;  
		    chp2=cosd(H3)+ur*k;  chp2=chp2*chp2; 
         SDaug=r2d* atan( k/( sqrt(1/shp2 -chp2)-sind(H3) ) ); //augmented Semi-Diameter, degrees
         if(iur==0 || iur==1) SDaug=SDiam/60;   // SUN , parallax irrelevant
         if(iur>3) SDaug=0;
      H4=H3 + ur*SDaug;
//Height 5: Parallax
         P=r2d*asin(sind(HP)*cosd(H4));  //Parallax derived from original Parallax HorPar, degrees
         fP=1/298.257;  // = flattening of earth, but: Naut. Almanac 2020, p.280: fP = 0.0032;
         delP=sind(2*Lati)*cosd(Azi)*sind(H4)-sind(Lati)*sind(Lati)*cosd(H4);
         P=P + fP*HP* delP; // effective parallax, degrees, with oblateness correction
         //P=r2d*asin(sind(HP)*cosd(H4)); Meeus
	  H5=H4 + P;
	  
//Height Ho: observed and corrected = observed geocentric height
      Ho=H5;
     /*      
      printf(">>HP,H4,Lati,Azi= %f %f %f %f\n",HP,H4,Lati,Azi);
      printf(">>indb,dip,fR*R0,P,SDaug,Ho-Hs= %f %f %f %f %f %f\n",indb/60.,-dip/60,-fR*R0,P,SDaug,Ho-Hs); 	  
      printf(">> Hs,H1,H2,H3,H4,H5,Ho= %f %f %f %f %f %f %f\n",Hs,H1,H2,H3,H4,H5,Ho); getchar();	  
     */	  
      *HP1= P*60;          // parallax, arcmin
      *dip1=dip;           // dip, arcmin
      *r1=R0*60;           // refraction, arcmin  
      *SD1=SDaug*60;       // augmented semidiameter, arcmin
      *gb1= (Ho - Hs)*60 ; // GesamtBESCHICKUNG=total correction,  arcmin  
		  
	  return Ho;	   
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////  EPHEMERIDEN der SONNE  ////////////////////////////////////////////////////////////////////
void suneph(double DeltaT0,int ky,int km,int kd,int kth,int ktm,int kts, 
double *delta1, double *grts1, double *grtg1, double *alfa1,double *eqot1,double *HPsun1,double *SDsun1,double *jdesun) 
{   
int result;
double delta0,grts0,grtg0,alfa0,eqot0,sdsun,jd,jde,JD,JDE,dayfraction;
double T,T2,T3,T4;
double TE,TE2,TE3,TE4,TE5;
double Tau,Tau2,Tau3,Tau4,Tau5;
double delta_psi, delta_eps,eps0,eps;

//JULIAN DATE JD ********************************************************************

double rtd=180./3.14159265358979;
double dtr=1./rtd;
   
jd=julday( ky,km,kd,kth,ktm,kts );
JD=jd;

// TIME:  Julian centuries
T  = (JD - 2451545.)/36525.;
T2=T*T;
T3=T2*T;

// Julian Ephemeris day
jde = jd + DeltaT0/86400.;
JDE=jde;

// TIME:  Julian ephemeris centuries
TE  = (jde - 2451545.)/36525.;
TE2=TE*TE;
TE3=TE2*TE;
TE4=TE2*TE2;
TE5=TE2*TE3;

// Julian Millenia
Tau =0.1*TE;
Tau2=Tau*Tau;
Tau3*Tau*Tau2;
Tau4*Tau*Tau3;
Tau5=Tau*Tau4;

// Nutation 
Nutation(TE,&delta_psi,&delta_eps,&eps0,&eps); //Full VSOP87-Nutation correction

//Mean GHA Aries
double GHAAmean = norm360(280.46061837+ 360.98564736629*(JD-2451545)+0.000387933*T2-T3/38710000);
double GHAAtrue = norm360(GHAAmean+delta_psi*cosd(eps));

//printf(">> GHAAtrue= %.12f\n",GHAAtrue); getchar();
//SUNSUN

   //Mean longitude of the Sun
   double Lsunmean = norm360(280.4664567+360007.6982779*Tau+0.03032028*Tau2+Tau3/49931-Tau4/15299-Tau5/1988000);

   //Ecliptic longitude of the Earth
   double Le = Learth(Tau);

   //Correction Longitude FK5
   double Lsun1= norm360(Le+180-1.397*TE-0.00031*TE2);

   //Geocentric longitude of the Sun
   double Lsun0 = norm360(Le+180-0.09033/3600);  // FK5

   //Ecliptic latitude of Earth
   double Be = Bearth(Tau);

   //Geocentric latitude of the Sun
   double beta = norm360(-Be);

   //Correction Latitude FK5
   beta = beta+0.03916*(cosd(Lsun1)-sind(Lsun1))/3600;

//printf(">> beta= %.12f\n",beta); getchar();

   //Distance Earth-Sun
   double Re = Rearth(Tau);
   double dES = 149597870.691*Re;

   //Apparent longitude of the Sun
   double lambda_sun = norm360(Lsun0+delta_psi-0.005691611/Re);
   
//printf(">> lambda_sun,eps= %.12f %.12f\n",lambda_sun, eps); getchar();   

   //Right ascension of the Sun, apparent
   double RAsun = rtd*(atan2((sind(lambda_sun)*cosd(eps)-tand(beta)*sind(eps)),cosd(lambda_sun)));
   RAsun=norm360( RAsun );
    
   //Declination of the Sun, apparent
   double DECsun = rtd*asin(sind(beta)*cosd(eps)+cosd(beta)*sind(eps)*sind(lambda_sun));

   //GHA of the Sun
   double GHAsun = norm360(GHAAtrue-RAsun);

   //Semidiameter of the Sun
   double SDsun = 959.63/Re;

   //Horizontal parallax of the Sun
   double HPsun = 8.794/Re;

   //Equation of time
   //EOT = 4*(Lsun_mean-0.0057183-0.0008-RAsun+delta_psi*cosd(eps));
   double EOT = 4*GHAsun+720-1440*dayfraction;
   
   if (EOT>20) EOT-=1440;
   if (EOT<-20) EOT+=1440; 

//printf(">> RA= %.12f  DEC= %.12f  \n",RAsun,DECsun); getchar();

//Konvertiere zurck auf die alten Variablen Allbrand-Junge, version Henning-Umland (Celnav):

*delta1 = DECsun;   // Declination Sun
*grts1  = GHAsun;       // GHA Sun
*grtg1  = GHAAtrue;      // GHA Aries
*alfa1  = RAsun;   // Rectascension Sun
*eqot1  = EOT / 4.;   //degrees, from formerly minutes
*HPsun1 = HPsun/60.;  // Horizontal parallax in minutes, Meeus eq.(40.1) 
*SDsun1 = SDsun/60.;       // semi diameter of sun in minutes
*jdesun = JDE;

//SUNEPX-routine END

}

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
double quadipola(double x1,double y1, double x2,double y2, double x3,double y3, double x)
{
// Quadratic Lagrange-Interpolation usig 3 pairs of data x1,y1   x2,y2  x3,y3
// Given x, then y is returned by interpolation
	int i,n;
	double y,h1,h2,h3;
		
	h1=(x-x3)*(x-x2)/((x1-x3)*(x1-x2));
	h2=(x-x3)*(x-x1)/((x2-x3)*(x2-x1));
	h3=(x-x1)*(x-x2)/((x3-x1)*(x3-x2));
	
	y=h1*y1 + h2*y2 +h3*y3;
	
	return y;
};

////////////////////////////////////////////////
double yarr35(char yydt[100][35], int jz, int ka, int ke) 
// The function yarr35() gives as a result floating-numbers, which are extracted from the text-array yydt(). 
// That arry should contain data in columns, within column numbers ka_to_ke. The output is a floating-number.
//   Die FUNCTION erwartet einen ARRAY  yydt[100][35] mit 100 Zeilen zu je max. 35 Zeichen formatiertem Text.
//   Aus der Zeile  jz  werden dann die Characters ka bis ke extrahiert 
//   und dann als integer kk ausgegeben: return(kk).    

{
   int i,j,kk, kdif;
   double xx;
   char str0[100] ="Dies ist der Teststring Function \0";
   char ldsimp[100];
  
		for (j = 0; j < 35; ++j) 
		{
			// mapping 2D array to 1D array
			ldsimp[j] = yydt[jz][j];
		}

 ldsimp[j]='\0';

 kdif=ke+1-ka;
 for (i = 0 ; i<kdif ; i++)
  {
  	//str0[i]= ld[jz][i+ka];
  	str0[i]= ldsimp[i+ka];
  }
  str0[i]='\0';
     //printf(">> substrng str0: %s ", str0);
  xx=atof(str0);
     //printf(">> ATOf: jz= %d xx= %f \n",jz,xx);
  return (xx);
};

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
// DELTA-T = TT - UT1  is the time-difference between the Terrestrial Time and Universal Time
double deltatime( int year, int month )
{
	// New version 2021, agrrement with JPL DE441 within two sigma-uncertainty
	// Reference: See   https://astro.ukho.gov.uk/nao/lvm/
	// -> needs functions quadipola() and yarr35()

    // Extrapolations for years > 2020 along idea of Paul Hirose: Frank Reed archive, 2018 Feb. 3. 
    
    //Tables: Proceedings of the Royal Society A, 472, by Stephenson, Morrison and Hohenkerk.
	//The values of Delta-T in the tables should be used in conjunction with 
	// lunar ephemeris designated JPL DE430/LE430 in which the tidal acceleration of the Moon is -25.85"/cy2. 
	
	//NOTE: the MONTH here is ignored, but in the parameterlist kept for historical reasons

int i,j,jz,ka,ke, maxi=74;
double t,u, dlt,u2,u3,u4,u5,u6, t2,t3,t4,t5,t6,t7, s;  
double x1,y1,x2,y2,x3,y3,x,y;
double aryear[100],ardlt[100];
dlt=0;
// text-array yydt[100][35] contains  "year  Delta-T", in seconds. aryear[] and ardlt[] later the numbers.
// NOTE: between numbers there should be blanks, not tabulator!.
char yydt[100][35]=
   {
	"-700     20500  ",
    "-500     16940  ",
    "-300     14080  ",
	"-100     11560  ",
    "0.00     10440  ",
	"100      9410   ",
    "200      8420   ",
	"300      7480   ",
    "400      6540   ",
	"500      5590   ",
    "600      4650   ",
	"700      3760   ",
    "800      2940   ",
	"900      2230   ",
    "1000     1650   ",
	"1100     1220   ",
    "1200     910    ",
	"1300     680    ",
    "1400     480    ",
	"1500     290    ",
    "1600     109    ",
	"1620     80     ",
    "1640     54     ",
	"1660     35     ",
    "1680     22     ",
	"1700     14     ",
    "1720     12     ",
	"1740     15     ",
    "1760     19     ",
	"1780     21     ",
    "1800     18.4   ",
    "1810     15.7   ",
	"1820     16.5   ",
    "1830     10.8   ",
	"1840     7.6    ",
	"1850     9.3	 ",
	"1860     9.04   ",
    "1870     2.37   ",
    "1880     -3.21  ",
    "1890     -3.88  ",
    "1895     -5.02  ",
    "1900     -1.98  ",
    "1905     4.92   ",
    "1910     11.14  ",
    "1915     17.48  ",
    "1920     21.62  ",
    "1925     23.79  ",
    "1930     24.42  ",
    "1935     24.16  ",
    "1940     24.43  ",
    "1945     27.05  ",
    "1950     28.93  ",
    "1955     30.41  ",
    "1960     33.07  ",
    "1965     35.09  ",
    "1970     39.93  ",
    "1975     45.28  ",
    "1980     50.36  ",
    "1985     54.39  ",
    "1990     56.99  ",
    "1995     60.68  ",
    "2000     63.81  ",
	"2005     64.73  ",
    "2010     66.06  ",
    "2015     67.69  ",
    "2018     68.92  ",
    "2020     69.36  ",	     	    
    "2030     67     ",	    
    "2040     68     ",
    "2050     70     ",
    "2100     80     ",
    "2200     160    ",
    "2300     330    ",
    "2400     610    ",
    "2500     999   ",
   }; 

//Extract  Year and Delta-t from yydt-text-array into aryear[] and ardlt[], up to 2200
for(i=0; i<=maxi; i++)
{
  jz=i;
  ka=0; ke=4;
  x=yarr35(yydt,jz,ka,ke); aryear[i]=x;
  ka=6; ke=15;
  y=yarr35(yydt,jz,ka,ke); ardlt[i]=y;
//printf("q1: i,x,y= %d %f %f\n",i,x,y);
}

// Given a specific year = "year", now obtain dlt=Delta-T in seconds
if(year < -700 || year> 3500) goto gyear8; //error-exit

if(year < 2500)
//historic data until year 2021, and prediction until 2500: 
{ //Read through aryear[] until we find a value > year. This the is x1 (and y1) for quadipola.
  for(i=0; i<=maxi; i++)
  { 
   x2=aryear[i]; y2=ardlt[i];
   if(year < aryear[i]) goto gyear1;    
  };
 
gyear1:
	x1=aryear[i-1]; y1=ardlt[i-1];
	x2=aryear[i  ]; y2=ardlt[i  ];
	x3=aryear[i+1]; y3=ardlt[i+1]; 
  x=year; 
  y=quadipola(x1,y1,x2,y2,x3,y3, x);

  dlt=y;
  goto gyear9;
}

if(year >= 2500)
//future extrapolation beyond year 2200
{
 //Between years 2021 and 3500, calcul  dlte:  -CHECK
  t=year-1900;
  t2=t*t; 
   dlt = -119.4 + 0.004*t + 0.0031*t2; //HMK-extrapolation, with asymptotic parabola, factor 0.0031; t=year-2021  
   // that HMK-formula matches quite well with the UKHO-data 2200..2500; t=year-1900.
   //asymptotic historic from UKHO, see reference above!  original: dlt=-320+32.5*t2; t=(year-1825)/100
   //dlt = 69.185 + 0.05*t + 0.0031*t2; //HMK-extrapolation, with asymptotic parabola, factor 0.0031; t=year-2021  
   // the linear term ~t should be adjusted, as soon as there is new data
   // dlt = 67.62 + 0.3645*t + 0.0039755*t2; //=original Espenak,but	t=year-2015!
   //printf("quadratic extrapolation: dlt= %f \n",dlt);
	goto gyear9;
}
//final address and exit
gyear8:
printf(" ??? year out of range:  -700 < year < 3500 ??? \n");
dlt=0;
printf(" ??? setting Delta-T == 0 !\n");

gyear9:
return dlt;
}  //End of Deltatime *****************************************************



//cccccccccccccccccccccccccccccccccccccccccccccccccc
double delta0x(int year0)
{
    // This subroutine produces extrapolation for DELTA-T = TT - UT1.
    // First, it calculates a quadratic extrapolation, as suggested e.g.
    // by Fred Espenak,NASA (past) and Paul Hirose(future).
    // This is stored externally in file astronav0x0.txt, 
    // 15 pairs of " year  seconds" data.
    // For the desired year "year0" itmakes a quadratic interpolation
    // from the stored data, years next to year0, and returns the result.
    // NOTE: You may change the file astronav0x0.txt, because as long
	// as this file is readable by the program, those values will be
	// taken for future values of Delta-T.
	// In case the file gets corrupted, just erase it, the program
	// will restore it to the original setting. 
	
	//cc HMK-value extrapolation ,adapted to USNO-MICA and IERS-extrap.
    // implicit double(a - h, o - z)
    int nt, qyear=2010;
    double y, qsec=66.1;    
    int nyear,myear, minyear, maxyear, nz, i, kk,kkmax, kyear, ndyear,myearold,kyearold;
    double s,s1,syear,xtest,ytest,dytest,xyear;
    int yearvec[100];
    double secvec[100];
    double weight1,weight2;  
    double xa[100],ya[100];
		FILE *fptr4;	
	//yearvec[0]=2000; secvec[0] =63.8;
	yearvec[0]=qyear; secvec[0] = qsec;
	yearvec[1]=2020; secvec[1] =69.4;
	minyear=2020; maxyear=3000; myearold=0; kyearold=minyear;
	nyear=minyear;
	if(myear < minyear) myear=minyear; // INPUT for Interpolation
	kkmax=40;
	if(year0>3000) {syear=0; goto g001; }
    ndyear=5;  // Intervall for Output ..............................!
   	fptr4=fopen("astronav0x0.txt","r");
	if(fptr4 != NULL) {fclose(fptr4);}
    	else
   	fptr4=fopen("astronav0x0.txt","w");	
    for(i=1; i<=21; i++)
    {
      nyear = nyear + (i - 1)* ndyear;
      if (nyear > 3000) nyear = 3000;
      s1 = deltatime(nyear,0); //THIS IS THE ORIGINAL ESPENAK RESULT > 2020
	  fprintf(fptr4, "    %d   %.1f \n",nyear,s1);    
	  //printf("delta0x: %d %f\n",nyear,s1); getchar();
    }
      fprintf(fptr4, "  'YEAR'  'DELTA_T(seconds)' \n\n");
      fprintf(fptr4, " DELTA_T = TT-UTC is obtained (after year 2020)\n");
	  fprintf(fptr4, " from THIS FILE via local quadratic interpolation,\n");
	  fprintf(fptr4, " and then entered into program N-ALMAC-v.nn.exe - \n\n");
	  fprintf(fptr4, " Formula by Paul Hirose, see: fer3.com/arc/m2.aspx/\n");
      fprintf(fptr4, "   ... Delta-T-long-term-formula-Hirose-feb-2018-g41398\n");
	  fprintf(fptr4, " You may change the entries of the file as you like,\n");
      fprintf(fptr4, " but YEARS must be between 2020 and 3000. -\n");
	  fprintf(fptr4, " If the file gets corrupted, just erase it completely,\n");
	  fprintf(fptr4, " the program next time will rebuild it in original form.\n");
      fprintf(fptr4, " For YEAR > 3000, DELTA-T =0 !\n");
	fclose(fptr4);
// READ that stuff: And make an interpolation!
    myear=0;
   	fptr4=fopen("astronav0x0.txt","r");
   	rewind(fptr4);   	
   	kk=0;
   	while (myear < 3000  &&  kk < kkmax)
   	{  kk++;
       fscanf(fptr4,"%d %lf \n",&myear,&s);  
	   yearvec[kk]=myear;  secvec[kk]=s; 	   yearvec[0]=qyear; secvec[0] = qsec; // these elements unchangeable
	   yearvec[1]=2020; secvec[1] =69.40; // these elements unchangeable
    }
    kkmax=kk;
    fclose(fptr4);   	
    kyear=year0;  
    for(kk=1; kk<=kkmax-1; kk++)
    {
    	if(yearvec[kk] < kyearold) 
		{ syear=0; printf("??? astronav0x0.txt:\n? wrong sequence:%d\n",kyearold); getchar(); goto g001; }
    	kyearold=yearvec[kk];   	
    	if( (kyear >= yearvec[kk]) && (kyear <= yearvec[kk+1]))
    	{
			syear=secvec[kk] + (kyear-yearvec[kk])*(secvec[kk+1]-secvec[kk])/(yearvec[kk+1]-yearvec[kk]);
    		xa[1]=yearvec[kk-1]; xa[2]=yearvec[kk]; xa[3]=yearvec[kk+1]; 
            ya[1]=secvec[kk-1];  ya[2]=secvec[kk];  ya[3]=secvec[kk+1]; 
			xyear=kyear;
			quadipol(xa,ya,3,xyear,&syear,&dytest);
			goto g001;
		}
		else 
		    syear=0.;
	}
   g001:
    return syear;
};
/// END of package Delta-T ////////////////////////////////////////////////////



////////////////////////////////////////////////
int subiarr(char ld[][30], int jz, int ka, int ke) 
// Die FUNCTION erwartet einen ARRAY  ld[64][30] mit 64 Zeilen zu je max. 30 Zeichen formatiertem Text.
// Aus der Zeile  jz  werden dann die Characters ka bis ke extrahiert 
// und dann als integer kk ausgegeben: return(kk).    
{
   int i,kk, kdif;
   char str0[100] ="Dies ist der Teststring Function \0";

 kdif=ke+1-ka;
 
 for (i = 0 ; i<kdif ; i++)
  {
  	str0[i]= ld[jz][i+ka];
  }
  str0[i]='\0';
  //printf("substrng str0: %s ", str0);
  kk=atoi(str0);
  //printf("ATOI: jz= %d kk= %d \n",jz,kk);
  //printf("\n");
  return (kk);
};

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

void mooneph(int moonpar,double DeltaT0, int ky,int km,int kd,int kth,int ktm,int kts, 
double *delta1, double *grts1, double *grtg1, double *alfa1,double *HPmoon1,double *SDmoon1) 
// Ephemeriden des Mondes, berechnet nach Jean Meeus, sowie H. Umland
//  genauere Daten nach Chapront u. Francou (FORTRAN) wegen Groesse 35.000 Daten nicht hier eingebaut.
//  JETZT 2020: Genaue Daten von S. Kudryavtsev "LEA406b" (3871 Zeilen, 50.000 Daten) hier eingebaut.
//DeltaT0t= Zeitdifferenz  TT-UTC = Delta-T (separate Function)
//AUSGABE-DATEN delta0: 
//  am Schluss intern auf *delta1 setzen, extern Aufruf als &delta, danach ohne * und & weiter. 
{
double *h1,*h2;
double utm,utc,ut,tm,ta,t100;
double grtg,grtg0,grts0,dtr,rtd,g,g0;
double als,als0,alsu0,alsun,eps0,eps;
double sdelta,delta,delta0,tana2,alfa,alfa0,alfah;
double hh1,hh2,omega,omega0, hcheck1,hcheck2;
double jd,jde,JD,JDE;
double TE,TE2,TE3,TE4,TE5,TE6,T,T2,T3;
double Lmm,D,Msm,Mmm,F,A1,A2,A3,fE,fE2;
double f,fD,f2,fM,fMm,fF,coeffs,coeffc,sumL,sumR,fD2,fM2,fMm2,fF2,coeffs2,sumB;
double hL,hR,hB,lamda,beta,dellam,parlax;
double lambdaMm,betaM,dEM,lambdaMapp,RAmoon,DECmoon,GHAmoon,HPmoon,SDmoon;
double Lsm,Omega,delta_psi,delta_eps,GMST,GHAAmean,GHAAtrue,eqot0;
//---------------Moon-definitions---------------------------
//static int year=1957, month=10, day=4, hour=19, min=26, sec=24;

int i,j,jmax,k,ki,l,n,ka,ke,kdif,jz,kk,kmax, is0;
int nld1[64],nld2[64],nld3[64],nld4[64],nld5[64],nld6[64];
int nlb1[64],nlb2[64],nlb3[64],nlb4[64],nlb5[64];
int y,m,d,e,meeus342;
char str0[100] ="Dies ist der Teststring \0";
//new Variable Dclarations 

//Longitude and distance
//    ld = Array(60,30);
char ld[60][30] = 
   {  
        "0 0 1 0 6288774 -20905355 ",
        "2 0-1 0 1274027  -3699111 ",
        "2 0 0 0  658314  -2955968 ",
        "0 0 2 0  213618   -569925 ",
        "0 1 0 0 -185116     48888 ",
        "0 0 0 2 -114332     -3149 ",
        "2 0-2 0   58793    246158 ",
        "2-1-1 0   57066   -152138 ",
        "2 0 1 0   53322   -170733 ",
        "2-1 0 0   45758   -204586 ",
        "0 1-1 0  -40923   -129620 ",
        "1 0 0 0  -34720    108743 ",
        "0 1 1 0  -30383    104755 ",
        "2 0 0-2   15327     10321 ",
        "0 0 1 2  -12528         0 ",
        "0 0 1-2   10980     79661 ",
        "4 0-1 0   10675    -34782 ",
        "0 0 3 0   10034    -23210 ",
        "4 0-2 0    8548    -21636 ",
        "2 1-1 0   -7888     24208 ",
        "2 1 0 0   -6766     30824 ",
        "1 0-1 0   -5163     -8379 ",
        "1 1 0 0    4987    -16675 ",
        "2-1 1 0    4036    -12831 ",
        "2 0 2 0    3994    -10445 ",
        "4 0 0 0    3861    -11650 ",
        "2 0-3 0    3665     14403 ",
        "0 1-2 0   -2689     -7003 ",
        "2 0-1 2   -2602         0 ",
        "2-1-2 0    2390     10056 ",
        "1 0 1 0   -2348      6322 ",
        "2-2 0 0    2236     -9884 ",
        "0 1 2 0   -2120      5751 ",
        "0 2 0 0   -2069         0 ",
        "2-2-1 0    2048     -4950 ",
        "2 0 1-2   -1773      4130 ",
        "2 0 0 2   -1595         0 ",
        "4-1-1 0    1215     -3958 ",
        "0 0 2 2   -1110         0 ",
        "3 0-1 0    -892      3258 ",
        "2 1 1 0    -810      2616 ",
        "4-1-2 0     759     -1897 ",
        "0 2-1 0    -713     -2117 ",
        "2 2-1 0    -700      2354 ",
        "2 1-2 0     691         0 ",
        "2-1 0-2     596         0 ",
        "4 0 1 0     549     -1423 ",
        "0 0 4 0     537     -1117 ",
        "4-1 0 0     520     -1571 ",
        "1 0-2 0    -487     -1739 ",
        "2 1 0-2    -399         0 ",
        "0 0 2-2    -381     -4421 ",
        "1 1 1 0     351         0 ",
        "3 0-2 0    -340         0 ",
        "4 0-3 0     330         0 ",
        "2-1 2 0     327         0 ",
        "0 2 1 0    -323      1165 ",
        "1 1-1 0     299         0 ",
        "2 0 3 0     294         0 ",
        "2 0-1-2       0      8752 "
  };

//Latitude
//    lb = Array(60,30);
char lb[60][30] =
{
       "0 0 0 1 5128122 ",
       "0 0 1 1  280602 ",
       "0 0 1-1  277693 ",
       "2 0 0-1  173237 ",
       "2 0-1 1   55413 ",
       "2 0-1-1   46271 ",
       "2 0 0 1   32573 ",
       "0 0 2 1   17198 ",
       "2 0 1-1    9266 ",
       "0 0 2-1    8822 ",
       "2-1 0-1    8216 ",
       "2 0-2-1    4324 ",
       "2 0 1 1    4200 ",
       "2 1 0-1   -3359 ",
       "2-1-1 1    2463 ",
       "2-1 0 1    2211 ",
       "2-1-1-1    2065 ",
       "0 1-1-1   -1870 ",
       "4 0-1-1    1828 ",
       "0 1 0 1   -1794 ",
       "0 0 0 3   -1749 ",
       "0 1-1 1   -1565 ",
       "1 0 0 1   -1491 ",
       "0 1 1 1   -1475 ",
       "0 1 1-1   -1410 ",
       "0 1 0-1   -1344 ",
       "1 0 0-1   -1335 ",
       "0 0 3 1    1107 ",
       "4 0 0-1    1021 ",
       "4 0-1 1     833 ",
       "0 0 1-3     777 ",
       "4 0-2 1     671 ",
       "2 0 0-3     607 ",
       "2 0 2-1     596 ",
       "2-1 1-1     491 ",
       "2 0-2 1    -451 ",
       "0 0 3-1     439 ",
       "2 0 2 1     422 ",
       "2 0-3-1     421 ",
       "2 1-1 1    -366 ",
       "2 1 0 1    -351 ",
       "4 0 0 1     331 ",
       "2-1 1 1     315 ",
       "2-2 0-1     302 ",
       "0 0 1 3    -283 ",
       "2 1 1-1    -229 ",
       "1 1 0-1     223 ",
       "1 1 0 1     223 ",
       "0 1-2-1    -220 ",
       "2 1-1-1    -220 ",
       "1 0 1 1    -185 ",
       "2-1-2-1     181 ",
       "0 1 2 1    -177 ",
       "4 0-2-1     176 ",
       "4-1-1-1     166 ",
       "1 0 1-1    -164 ",
       "4 0 1-1     132 ",
       "1 0-1-1    -119 ",
       "4-1 0-1     115 ",
       "2-2 0 1     107 "      
};

/////////////   Surboutine moonepx, program-section //////////////

jmax=60;
// Spalten von ld[][] auf einzelne Vektoren nld0[]schreiben.
for (jz=0; jz<jmax; jz++)
{
  // 0,1  1,3  3,5  5,7  8,15  15,25
  ka=0;
  ke=1;
  kk=subiarr(ld, jz, ka,ke);
  nld1[jz]=kk;
  
  ka=1;
  ke=3;
  kk=subiarr(ld, jz, ka,ke);
  nld2[jz]=kk;
  
  ka=3;
  ke=5;
  kk=subiarr(ld, jz, ka,ke);
  nld3[jz]=kk;
  
  ka=5;
  ke=7;
  kk=subiarr(ld, jz, ka,ke);
  nld4[jz]=kk;
 
  ka=8;
  ke=15;
  kk=subiarr(ld, jz, ka,ke);
  nld5[jz]=kk;
  
  ka=15;
  ke=25;
  kk=subiarr(ld, jz, ka,ke);
  nld6[jz]=kk;

  //printf("nld1,2,3,4,5,6= %2d %2d %2d %2d %8d %8d\n", nld1[jz],nld2[jz],nld3[jz],nld4[jz],nld5[jz],nld6[jz] );
};

// Spalten von lb[][] auf einzelne Vektoren nlb0[]schreiben.
for (jz=0; jz<jmax; jz++)
{
  // 0,1  1,3  3,5  5,7  8,15  15,25
  ka=0;
  ke=1;
  kk=subiarr(lb, jz, ka,ke);
  nlb1[jz]=kk;
  
  ka=1;
  ke=3;
  kk=subiarr(lb, jz, ka,ke);
  nlb2[jz]=kk;
  
  ka=3;
  ke=5;
  kk=subiarr(lb, jz, ka,ke);
  nlb3[jz]=kk;
  
  ka=5;
  ke=7;
  kk=subiarr(lb, jz, ka,ke);
  nlb4[jz]=kk;
 
  ka=8;
  ke=15;
  kk=subiarr(lb, jz, ka,ke);
  nlb5[jz]=kk;
  
//  printf("nlb1,2,3,4,5= %2d %2d %2d %2d %8d \n", nlb1[jz],nlb2[jz],nlb3[jz],nlb4[jz],nlb5[jz] );
};

//Check for MEEUS page 342, and see below  for. "MEEUS342"

meeus342=0; //if this is not zero, then some values will be printed for control

//JULIAN DATE JD ********************************************************************

rtd=180./3.14159265358979;
dtr=1./rtd;
   
jd=julday( ky,km,kd,kth,ktm,kts );
JD=jd;

// TIME:  Julian centuries
T  = (JD - 2451545.)/36525.;
T2=T*T;
T3=T2*T;

skip(25);
//printf(" >>>>>>>>>>>> CHECK! <<<<<<<<\n");
//printf(" MOON: Jean Meeus p.342,343:\n");
//printf(" Date: %d-%d-%d (0h)\n",ky,km,kd);
//printf(" Julian Day: %.3f\n", jd);


// Julian Ephemeris day
jde = jd + DeltaT0/86400.;
JDE=jde;

// TIME:  Julian ephemeris centuries
TE  = (jde - 2451545.)/36525.;
TE2=TE*TE;
TE3=TE2*TE;
TE4=TE2*TE2;
TE5=TE2*TE3;

//printf(">>mooneph> DeltaT0=%f\n",DeltaT0);
//printf(" T: %.12f \n", TE);
//getchar();

//Chapront-Touze, Francou 2002: A&A 387,700-709 (2002); DOI: 10.1051/0004-6361:20020420
// table 4
//IERS 2003 technische kommunikation 32

//moonpar=0; // MONDPARAMETER: 0: Werte nach Jan Meeus,  1= Werte nach IERS 2003



//Mean GHA Aries
GMST = norm360(280.46061837+ 360.98564736629*(JD-2451545)+0.000387933*T2-T3/38710000);

if(moonpar == 0)
{ // printf(">> Moonpar =0 : J.MEEUS \n");
// Mean longitude of the moon
Lmm = norm360(218.3164477+481267.88123421*TE-0.0015786*TE2+TE3/538841-TE4/65194000);  //MEEUS
	//Mean elongation of the Moon
D = norm360(297.850192 +445267.1114034*TE-0.0018819*TE2+TE3/545868-TE4/113065000);   //MEEUS
	// Mean anomaly of the sun
Msm = norm360(357.5291092+35999.0502909*TE-0.0001536*TE2+TE3/24490000);  //= Umland ident. mit MEEUS
	//Mean anomaly of the moon
Mmm = norm360(134.9633964+477198.8675055*TE+0.0087414*TE2+TE3/69699-TE4/14712000); //MEEUS
	//Mean distance of the moon from ascending node
F = norm360(93.2720950+483202.0175233*TE-0.0036539*TE2-TE3/3526000+TE4/863310000);  //MEEUS
}

if(moonpar != 0)
{   // printf(">> Moonpar !=0 : IERS2003 \n");
// Mean longitude of the moon
//Lmm = norm360(218.3164477+481267.88123421*TE-0.0015786*TE2+TE3/538841-TE4/65194000);  //MEEUS
Lmm = norm360(218.31664563+481267.88119575*TE-0.0014663889*TE2+TE3/540135-TE4/65193770);  // IERS 2003
	//Mean elongation of the Moon
//D = norm360(297.850192 +445267.1114034*TE-0.0018819*TE2+TE3/545868-TE4/113065000);   //MEEUS
D = norm360(297.85019547+445267.1114469*TE-0.00176961*TE2+TE3/546033.7-TE4/113600504.9);   //IERS 2003	
	// Mean anomaly of the sun
Msm = norm360(357.52910918+35999.0502911*TE-0.00015367*TE2+TE3/26470588-TE4/313315926.9);  // IERS 2003
	//Mean anomaly of the moon
//Mmm = norm360(134.9633964+477198.8675055*TE+0.0087414*TE2+TE3/69699-TE4/14712000); //MEEUS
Mmm = norm360(134.96340251+477198.8675605*TE+0.00885533*TE2+TE3/69720.1-TE4/14711892.1); // IERS 2003
	//Mean distance of the moon from ascending node
//F = norm360(93.2720950+483202.0175233*TE-0.0036539*TE2-TE3/3526000+TE4/863310000);  //MEEUS
F = norm360(93.27209062+483202.0175*TE-0.0035420*TE2-TE3/3471552.5+TE4/863309352.5);  //IERS 2003
}

	//Corrections
A1 = norm360(119.75+131.849*TE);
A2 = norm360(53.09+479264.29*TE);
A3 = norm360(313.45+481266.484*TE);
fE = 1-0.002516*TE-0.0000074*TE2;
fE2 = fE*fE;

sumL=0;
sumB=0;
sumR=0;
k=0;

while ( k<60 )
{
         fD  = nld1[k];        // eval(ld[x].substring(0,1));
         fM  = nld2[k];        //eval(ld[x].substring(1,3));
         fMm = nld3[k];        //eval(ld[x].substring(3,5));
         fF  = nld4[k];        //eval(ld[x].substring(5,7));
         coeffs =  nld5[k] ;  //eval(ld[x].substring(8,15));
         coeffc =  nld6[k] ;  //eval(ld[x].substring(16,25));
         if(fM==1 || fM==-1) f=fE;
         else if(fM==2 || fM==-2) f=fE2;
         else f=1;
         hL    = f*coeffs*sind(fD*D+fM*Msm+fMm*Mmm+fF*F);
         sumL += hL;          
         hR    = f*coeffc*cosd(fD*D+fM*Msm+fMm*Mmm+fF*F);
		 sumR += hR;
         
		 fD2  =  nlb1[k] ;    // eval(lat[x].substring(0,1));
         fM2  =  nlb2[k] ;   // eval(lat[x].substring(1,3));
         fMm2 =  nlb3[k] ;   // eval(lat[x].substring(3,5));
         fF2  =  nlb4[k] ;   // eval(lat[x].substring(5,7));
         coeffs2 =  nlb5[k] ;  //eval(lat[x].substring(8,15));
         if(fM2==1 || fM2==-1) f2=fE;
         else if(fM2==2 || fM2==-2) f2=fE2;
         else f2=1;
         hB    = f2*coeffs2*sind(fD2*D+fM2*Msm+fMm2*Mmm+fF2*F);	
         sumB += hB;
    k++;
}

if(meeus342==1000)
{
printf(" --- J.Meeus page 342: ---\n");
printf(" JDE= %.3f\n",JDE);
printf(" TE = %.12f\n",TE);
printf(" L' = %4.6f\n", Lmm   );
printf(" D  = %4.6f\n", D   );
printf(" M  = %4.6f\n", Msm   );
printf(" M' = %4.6f\n", Mmm   );
printf(" F  = %4.6f\n", F   );
printf(" A1 = %4.6f\n", A1   );
printf(" A2 = %4.6f\n", A2  );
printf(" A3 = %4.6f\n", A3   );
printf(" E  = %4.6f\n", fE   );

//Correction sumL, sumB, sumR
sumL=sumL+3958*sind(A1) +1962*sind(Lmm-F) +318*sind(A2);
sumB=sumB-2235*sind(Lmm) +382*sind(A3) +175*sind(A1-F) +175*sind(A1+F) +127*sind(Lmm-Mmm) -115*sind(Lmm+Mmm);

printf(" sumL  = %4.3f\n", sumL );
printf(" sumB  = %4.3f\n", sumB );
printf(" sumR  = %4.3f\n", sumR );
printf("\n press ENTER for next page:\n");

//getchar();  // monitor !
}


lamda = Lmm + sumL/1000000;
beta  = sumB/1000000;
dellam= 385000.56 + sumR/1000;
parlax= asin(6378.14/dellam) * rtd;


//CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
    
    Nutation(TE,&delta_psi,&delta_eps,&eps0,&eps); //Full VSOP87-Nutation correction
  
//CCCCCCCCCCCCCCCCCCCCCCC coordinates lambda and beta of the moon CCCCCCCCCCCCCCCCCCCC
//  ok with Jean Meeus, p.342
	
	//Longitude of the moon
	lambdaMm = norm360(Lmm+sumL/1000000);
	//Latitude of the moon
	betaM = sumB/1000000;
	//Distance earth-moon
	dEM = 385000.56+sumR/1000; //km

	
//cccccccccccccccccccccccccccc LEA406 KUDRYAVTSEV ccccccccccccccccccccc
// printf(">> old: lonlat= %f %f\n",lambdaMm,betaM);

//printf(" High-Precision for MOON by LEA406b:\n");

double qLON,qLAT,qRAD;

LEA406(JDE, &qLON, &qLAT, &qRAD); // This is for High Precision Moon data from LEA406-Ephemerides

int ilea406=1;
if(qRAD > 1) 
{ 
  lambdaMm = qLON;
  betaM    = qLAT;
  dEM      = qRAD;
  ilea406  = 1;
}	
else
{
	printf("\n WARNING: File  astronavtab911.dat  not found.\n");
	printf(" Precision for MOON reduced to +-10 arcsecs.\n");
	getchar();
}
//printf(">> new: lonlat= %f %f\n",lambdaMm,betaM); printf(" ... press ENTER to continue ...\n");	
// printf(">>MOON JDE = %f\n",JDE); getchar();

//getchar(); 

//ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
	
	//Apparent longitude of the moon
	lambdaMapp = lambdaMm+delta_psi;
	//Right ascension of the moon, apparent
	//RAmoon = rtd*norm_2pi_rad(atan2((sind(lambdaMapp)*cosd(eps)-tand(betaM)*sind(eps)),cosd(lambdaMapp)));
    RAmoon = atan2((sind(lambdaMapp)*cosd(eps)-tand(betaM)*sind(eps)),cosd(lambdaMapp));
    RAmoon = norm360(rtd*RAmoon);
	//Declination of the moon 
	DECmoon = rtd*asin(sind(betaM)*cosd(eps)+cosd(betaM)*sind(eps)*sind(lambdaMapp));
	//True GHA Aries
    GHAAmean = GMST;
    GHAAtrue = norm360(GHAAmean+delta_psi*cosd(eps));
	//GHA of the moon
	GHAmoon = norm360(GHAAtrue-RAmoon);
	//Horizontal parallax of the moon
	HPmoon = rtd*60*asin(6378.14/dEM);
	//Semidiameter of the moon
	//SDmoon = rtd*60*asin(1738./dEM);
	SDmoon= (358473400./dEM)/60.; //Meeus p.391

if(meeus342==10000)  // monitor !
{
printf(" --- J.Meeus page 343: ---\n");
printf(" lambda_Mm  = %f \n",lambdaMm);
printf(" beta_M   = %f \n",betaM);
printf(" Distance = %8.1f km \n",dEM);
printf(" Parallax = %f deg\n",parlax);
printf(" eps = %f deg\n",eps);
printf(" delta_psi= %.3f arcsec\n",delta_psi*3600);
printf(" delta_eps= %.3f arcsec\n",delta_eps*3600);
printf("   Note:  Delta-T=0 !\n",DeltaT0);
printf(" Lambda = %f deg\n",lambdaMapp);
printf(" RAmoon = %f deg\n",RAmoon);
printf(" DECmoon = %f deg\n",DECmoon);
printf(" GHAmoon = %f deg\n",GHAmoon);
printf(" HPmoon = %.2f arcmin \n",HPmoon);
printf(" SDmoon = %.2f arcmin \n",SDmoon);
printf("\n   press ENTER to continue:\n");
getchar();
}


//**********************************************************************************
//End-OUTPUT moonepx:

*delta1= DECmoon;
*grts1 = GHAmoon;
*grtg1 = GHAAtrue; // GHA Aries
*alfa1 = RAmoon;
*HPmoon1 = HPmoon;
*SDmoon1 = SDmoon;
};
   
////////////////////////////////////////////////////////////////
void lies2(double x1, double x2, double *z1, double *z2)
//Einlesen von zwei integer oder double-Zahlen von keyboard (str1, dann: &y1,&y2), 
// und Ausgabe wieder als zwei double-Zahlen  &z1,  &z2 ,   aber
// Ausgabe von DEFAULT-Werten x1,x2, wenn nur ENTER gedrckt wurde.
{
	int maxs,s1,s2;
	double y1,y2;
	static char str1[61]="abcdefghijk";

    maxs=60;
	s1=1; s2=1;	
	y1=x1;
	y2=x2;
printf("[Default: %.0f %.2f ] ",y1,y2);  printf("Input: ");
 
fgets(str1,maxs,stdin); 
sscanf(str1,"%lf %lf",&y1,&y2);
if(y1 < 0 ) s1=-1; if(y2 < 0 ) s2=-1;
y2=s1*fabs(y2);
if(y1==0.) y2=s2*fabs(y2);	

 *z1=y1;
 *z2=y2;
  //printf("End LIES2\n");	 
}

////////////////////////////////////////////////////////////////
void lies1(int liesdf, double x1, double *z1)
//Einlesen von einer integer oder double-Zahl von keyboard (str1, dann: &y1,&y2), 
// und Ausgabe wieder als zwei double-Zahlen  &z1,  &z2 ,   aber
// Ausgabe von DEFAULT-Werten x1 wenn nur ENTER gedrckt wurde.
// liesdf=0: integer Ein-usgabe, liesdf=1: double ein-ausgabe
// Achtung: liesdf steuert nur das DISPLAY, Ein-Ausgabe funktioniert immer ber DOUBLE x1, z1.
{
	int maxs,iy1;
	double y1;
	static char str1[61]="abcdefghijk";
	  maxs=60;
	
	y1=x1;
	iy1=y1+0.5;
	
if(liesdf == 0) printf(" [Default: %d ] Input: ", iy1);
if(liesdf == 1) printf(" [Default: %.1f ] Input: ",y1);
if(liesdf == 2) printf(" [Default: %.2f ] Input: ",y1);
if(liesdf >= 3) printf(" [Default: %.3f ] Input: ",y1);
if(liesdf== -2) printf("   Input: ",y1);
 
fgets(str1,maxs,stdin); 
sscanf(str1,"%lf ",&y1);
	
 *z1=y1;	 
}


////////////////////////////////////////////////////////////////
void earthcon(int year,double deltime,double tempin,double pressin,int moonpar,double *DeltaTT,
              double *temperature,double *pressure,int *moonorb)
//Einlesen von zwei integer oder double-Zahlen von keyboard (str1, dann: &y1,&y2), 
// und Ausgabe wieder als zwei double-Zahlen  &z1,  &z2 ,   aber
// Ausgabe von DEFAULT-Werten x1,x2, wenn nur ENTER gedrckt wurde.
{
	static int ilies, i,j,k,l,m,n;
	static int memtime=0;
	static double xx,xxout, DeltaT0,temp0,press0, dummy;
	static double DeltaTmem=0.;

//Default-values: DeltaT0 = DELTA_T in this subroutine 
   dummy=delta0x(year); //CHECK for astronav0x0.txt; if NON-EXISTENT, create that file!

   DeltaT0=deltatime(year, 1); 
   //if(year>2020) DeltaT0= delta0x(year); //  obtain extrapolated value
   if(memtime!=0) DeltaT0=DeltaTmem;

temp0= tempin;
press0=pressin;
	
printf(" \n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");

printf("  The following STANDARD CONDITIONS should only\n");
printf("  be modified, if alternative parameters\n");
printf("  are known with sufficient precision!\n\n");
printf("  **********> EARTH-CONDITIONS <****************\n");              
if(year < 2020)
printf("    Delta_T=TT-UT1= %2.2f sec\n",DeltaT0);
else
printf("    Delta_T=TT-UT1= %2.2f sec (extrapolated!)\n",DeltaT0);	
printf("    Temperature = %.1f deg Celsius \n",tempin); 
printf("    Pressure    = %.1f hPa. \n",pressin);
//printf("    Moon Orbit: = %d (0: J.Meeus, 1: IERS2003)\n",moonpar);
printf("  **********************************************\n\n");
printf("       To modify, enter 1, else press RETURN:\n");

xx=DeltaT0;
ilies=0; 
printf("###> ");
lies1( -2, xx, &xxout);  // Print Default and Enter new value)
xx=xxout;
j=xx+0.5;

if(j == 1) // allow all changes
 {
	printf("Change following values or press ENTER:\n");
	
	memtime=1;
	
	xx=DeltaT0;
	printf("###> Delta_T = ");
	lies1( 2, xx, &xxout);
    if(xxout > 6000.) xxout=5999;
	if(xxout< -1000) xxout=-999;
	DeltaT0=xxout;
	DeltaTmem=DeltaT0;
	
	
	xx=temp0;  
	printf("###> Temperature = ");
	lies1( 1, xx, &xxout);
	if(xxout > 2000.) xxout=1999;
	if(xxout< -100) xxout=-99; 
	temp0=xxout;
	printf(">> temp %.1f\n",temp0);
	
	xx=press0; if(xx < 0) xx=0;
	printf("###> Pressure = ");
	lies1( 1, xx, &xxout);
	if(xxout > 2000.) xxout=1999;
	if(xxout< 0) xxout=0;
	press0=xxout;
	printf(">> press %.1f\n",press0);
		
	getchar();

 }

if(j == 0) {DeltaT0=0; DeltaTmem=DeltaT0; memtime=1;}
  
 *DeltaTT= DeltaT0; if(memtime!=0) *DeltaTT=DeltaTmem;
 *temperature=temp0;
 *pressure=press0;
 *moonorb=moonpar;
}

///////////// Versegelung einer Position lat1,long1 nach lat2,long2 /////////////////////////////
int verspos(double jd1,double jd2,double velav,double kursav,double latitude1, double longitude1,
            double *latitude2,double *longitude2)
// VERSEGELUNG von lat1,long1  nach lat2,long2  in Richtung kursav  mit Betrag dist.
// Statt Grokreis-Versegelung wird die Distanz in max. 100 LOXODROM-Stcke geteilt.
{ 
  int i,j,k,l,m,n, nsteps,errvers;
  double timedif, dist, deldist, ck,sk, dlat, dlong,newlati,newlong,clat, avlat;
  
    errvers=0;  
	timedif=(jd2-jd1)*24.; // hours
	dist=velav*timedif; //naut. miles
	if(velav<0) dist=-velav; 
	if(dist>2000) errvers=1;
	
	//printf(">>> hours, nautmiles= %f %f\n",timedif,dist);
	nsteps= floor(dist)*5.;
	if(nsteps > 1000) nsteps=1000;
	deldist=dist/nsteps;
	ck=cosd(kursav);
	sk=sind(kursav);
	dlat=ck*deldist/60.;   //degrees, not minutes!
	dlong=sk*deldist/60.;  //degrees
	
	newlati=latitude1;
	newlong=longitude1;
    for (i=1; i <= nsteps; i++)
    {
    	avlat=newlati;
		newlati=newlati+dlat;
		if(abs(newlati)>89) errvers=2;
		avlat=(avlat+newlati)*0.5;
    	clat=cosd(avlat);
    	newlong=newlong+dlong/clat;
	}
    *latitude2 =newlati;
    *longitude2=newlong;
    return(errvers);
    //printf(">>> verspos ended\n");
}

///////////////////////////////// from STARS and PLANETS: ///////////


//CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC   
//CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
//Heliocentric longitude of Venus
double Lvenus(double x)
{	
double L0=0;
L0+=3.17614666774;
L0+=0.01353968419*cost(5.59313319619+10213.28554621100*x);
L0+=0.00089891645*cost(5.30650048468+20426.57109242200*x);
L0+=0.00005477201*cost(4.41630652531+7860.41939243920*x);
L0+=0.00003455732*cost(2.69964470778+11790.62908865880*x);
L0+=0.00002372061*cost(2.99377539568+3930.20969621960*x);
L0+=0.00001317108*cost(5.18668219093+26.29831979980*x);
L0+=0.00001664069*cost(4.25018935030+1577.34354244780*x);
L0+=0.00001438322*cost(4.15745043958+9683.59458111640*x);
L0+=0.00001200521*cost(6.15357115319+30639.85663863300*x);
L0+=0.00000761380*cost(1.95014702120+529.69096509460*x);
L0+=0.00000707676*cost(1.06466707214+775.52261132400*x);
L0+=0.00000584836*cost(3.99839884762+191.44826611160*x);
L0+=0.00000769314*cost(0.81629615911+9437.76293488700*x);
L0+=0.00000499915*cost(4.12340210074+15720.83878487840*x);
L0+=0.00000326221*cost(4.59056473097+10404.73381232260*x);
L0+=0.00000429498*cost(3.58642859752+19367.18916223280*x);
L0+=0.00000326967*cost(5.67736583705+5507.55323866740*x);
L0+=0.00000231937*cost(3.16251057072+9153.90361602180*x);
L0+=0.00000179695*cost(4.65337915578+1109.37855209340*x);
L0+=0.00000128263*cost(4.22604493736+20.77539549240*x);
L0+=0.00000155464*cost(5.57043888948+19651.04848109800*x);
L0+=0.00000127907*cost(0.96209822685+5661.33204915220*x);
L0+=0.00000105547*cost(1.53721191253+801.82093112380*x);
L0+=0.00000085722*cost(0.35589249966+3154.68708489560*x);
L0+=0.00000099121*cost(0.83288185132+213.29909543800*x);
L0+=0.00000098804*cost(5.39389655503+13367.97263110660*x);
L0+=0.00000082094*cost(3.21596990826+18837.49819713819*x);
L0+=0.00000088031*cost(3.88868860307+9999.98645077300*x);
L0+=0.00000071577*cost(0.11145739345+11015.10647733480*x);
L0+=0.00000056122*cost(4.24039855475+7.11354700080*x);
L0+=0.00000070239*cost(0.67458813282+23581.25817731760*x);
L0+=0.00000050796*cost(0.24531603049+11322.66409830440*x);
L0+=0.00000046111*cost(5.31576465717+18073.70493865020*x);
L0+=0.00000044574*cost(6.06282201966+40853.14218484400*x);
L0+=0.00000042594*cost(5.32873337210+2352.86615377180*x);
L0+=0.00000042635*cost(1.79955421680+7084.89678111520*x);
L0+=0.00000041177*cost(0.36240972161+382.89653222320*x);
L0+=0.00000035749*cost(2.70448479296+10206.17199921020*x);
L0+=0.00000033893*cost(2.02347322198+6283.07584999140*x);
L0+=0.00000029138*cost(3.59230925768+22003.91463486980*x);
L0+=0.00000028479*cost(2.22375414002+1059.38193018920*x);
L0+=0.00000029850*cost(4.02176977477+10239.58386601080*x);
L0+=0.00000033252*cost(2.10025596509+27511.46787353720*x);
L0+=0.00000030172*cost(4.94191919890+13745.34623902240*x);
L0+=0.00000029252*cost(3.51392387787+283.85931886520*x);
L0+=0.00000024424*cost(2.70177493852+8624.21265092720*x);
L0+=0.00000020274*cost(3.79493637509+14143.49524243060*x);
L0+=0.00000024322*cost(4.27814493315+5.52292430740*x);
L0+=0.00000026260*cost(0.54067587552+17298.18232732620*x);
L0+=0.00000020492*cost(0.58547075036+38.02767263580*x);
L0+=0.00000018988*cost(4.13811500642+4551.95349705880*x);
L0+=0.00000023739*cost(4.82870797552+6872.67311951120*x);
L0+=0.00000015885*cost(1.50067222283+8635.94200376320*x);
L0+=0.00000019069*cost(6.12025580313+29050.78374334920*x);
L0+=0.00000018269*cost(3.04740408477+19999.97290154599*x);
L0+=0.00000013656*cost(4.41336292334+3532.06069281140*x);
L0+=0.00000017094*cost(3.52161526430+31441.67756975680*x);
L0+=0.00000010955*cost(2.84562790076+18307.80723204360*x);
L0+=0.00000011048*cost(2.58361219075+9786.68735533500*x);
L0+=0.00000009904*cost(1.08737710389+7064.12138562280*x);
L0+=0.00000010576*cost(0.85419784436+10596.18207843420*x);
L0+=0.00000009231*cost(5.52471655579+12566.15169998280*x);
L0+=0.00000011599*cost(5.81007422699+19896.88012732740*x);
L0+=0.00000011807*cost(1.91250672543+21228.39202354580*x);
L0+=0.00000010105*cost(2.34270786693+10742.97651130560*x);
L0+=0.00000008154*cost(1.92331359797+15.25247118500*x);
L0+=0.00000008893*cost(1.97291388515+10186.98722641120*x);
L0+=0.00000009352*cost(4.94508904764+35371.88726597640*x);
L0+=0.00000006821*cost(4.39733188968+8662.24032356300*x);
L0+=0.00000006688*cost(1.55310437864+14945.31617355440*x);
L0+=0.00000006413*cost(2.17677652923+10988.80815753500*x);
L0+=0.00000005802*cost(1.93462125906+3340.61242669980*x);
L0+=0.00000005950*cost(2.96578175391+4732.03062734340*x);
L0+=0.00000005275*cost(5.01877102496+28286.99048486120*x);
L0+=0.00000007047*cost(1.00111452053+632.78373931320*x);
L0+=0.00000005048*cost(4.27886209626+29580.47470844380*x);
L0+=0.00000006305*cost(0.35506331180+103.09277421860*x);
L0+=0.00000005959*cost(5.04792949464+245.83164622940*x);
L0+=0.00000004651*cost(0.85218058876+6770.71060124560*x);
L0+=0.00000005580*cost(0.48723384809+522.57741809380*x);
L0+=0.00000005327*cost(3.03115417024+10021.83728009940*x);
L0+=0.00000005010*cost(5.77375166500+28521.09277825460*x);
L0+=0.00000004608*cost(1.93302108394+4705.73230754360*x);
L0+=0.00000005526*cost(3.36797048901+25158.60171976540*x);
L0+=0.00000003863*cost(4.89351531412+25934.12433108940*x);
L0+=0.00000005303*cost(0.08161426841+39302.09696219600*x);
L0+=0.00000004254*cost(5.36046113295+21535.94964451540*x);
L0+=0.00000003763*cost(1.05304597315+19.66976089979*x);
L0+=0.00000004407*cost(4.02575374517+74.78159856730*x);
L0+=0.00000004145*cost(1.14356412295+9676.48103411560*x);
L0+=0.00000004318*cost(4.38289970585+316.39186965660*x);
L0+=0.00000003642*cost(6.11733529325+3128.38876509580*x);
L0+=0.00000003238*cost(5.39551036769+419.48464387520*x);
L0+=0.00000003909*cost(4.05263635330+9690.70812811720*x);
L0+=0.00000003152*cost(0.72553551731+16496.36139620240*x);
L0+=0.00000003496*cost(0.72414615705+3723.50895892300*x);
L0+=0.00000003755*cost(3.80208713127+19786.67380610799*x);
L0+=0.00000002891*cost(3.33782737770+32217.20018108080*x);
L0+=0.00000003016*cost(1.57249112496+17277.40693183380*x);
L0+=0.00000003825*cost(0.19612312903+426.59819087600*x);
L0+=0.00000003798*cost(0.45524571743+10316.37832042960*x);
L0+=0.00000002570*cost(1.20813474107+13936.79450513400*x);
L0+=0.00000002796*cost(3.65128969074+206.18554843720*x);
L0+=0.00000002466*cost(3.61988676373+1551.04522264800*x);
L0+=0.00000003108*cost(1.50325806664+43232.30665841560*x);
L0+=0.00000002976*cost(4.79415001304+29088.81141598500*x);
L0+=0.00000002217*cost(3.59623681714+24356.78078864160*x);
L0+=0.00000002227*cost(4.96059221940+536.80451209540*x);
L0+=0.00000002397*cost(3.45249688427+19374.30270923360*x);
L0+=0.00000002462*cost(0.53295178258+19360.07561523199*x);
L0+=0.00000002205*cost(2.70399309963+12592.45001978260*x);
L0+=0.00000002230*cost(3.01413465913+18875.52586977400*x);
L0+=0.00000001858*cost(4.06129152783+2379.16447357160*x);
L0+=0.00000001807*cost(3.15086214479+9573.38825989700*x);
L0+=0.00000002238*cost(5.52216925076+10138.50394764370*x);
L0+=0.00000002195*cost(2.32046770554+8094.52168583260*x);
L0+=0.00000002101*cost(2.90421302975+9967.45389998160*x);
L0+=0.00000001916*cost(4.56513949099+2218.75710418680*x);
L0+=0.00000001467*cost(2.42640162465+10234.06094170340*x);
L0+=0.00000001726*cost(5.59790693845+20452.86941222180*x);
L0+=0.00000001455*cost(2.44757248737+1589.07289528380*x);
L0+=0.00000001991*cost(4.04623390359+31749.23519072640*x);
L0+=0.00000001406*cost(2.71736996917+16983.99614745660*x);
L0+=0.00000001658*cost(0.11252373292+153.77881048480*x);
L0+=0.00000001851*cost(2.92898027939+47162.51635463520*x);
L0+=0.00000001492*cost(1.07513892753+9103.90699411760*x);
L0+=0.00000001247*cost(2.48433565896+17778.11626694899*x);
L0+=0.00000001549*cost(4.20553654300+3442.57494496540*x);
L0+=0.00000001243*cost(3.95452438599+170.67287061920*x);
L0+=0.00000001694*cost(6.20694480406+33019.02111220460*x);
L0+=0.00000001221*cost(4.77931820602+30110.16567353840*x);
L0+=0.00000001206*cost(0.30531303095+29864.33402730900*x);
L0+=0.00000001238*cost(5.05581820608+20213.27199698400*x);
L0+=0.00000001152*cost(3.26229919481+11.72935283600*x);
L0+=0.00000001179*cost(1.69491074791+20400.27277262220*x);
L0+=0.00000001165*cost(2.88995128147+574.34479833480*x);
L0+=0.00000001306*cost(0.14519588607+9146.79006902100*x);
L0+=0.00000001113*cost(1.52598846804+10426.58464164900*x);
L0+=0.00000001104*cost(2.58791423813+18849.22754997420*x);
L0+=0.00000001045*cost(0.57539216420+15874.61759536320*x);
L0+=0.00000001360*cost(2.41976595457+38734.37832446560*x);
L0+=0.00000000981*cost(4.37930727798+110.20632121940*x);
L0+=0.00000001095*cost(0.49492867814+51066.42773105500*x);
L0+=0.00000001146*cost(4.54241454215+10220.39909321180*x);
L0+=0.00000000981*cost(1.65915064733+10103.07922499160*x);
L0+=0.00000001270*cost(4.69374306132+9050.81084180320*x);
L0+=0.00000001065*cost(4.41645258887+22805.73556599360*x);
L0+=0.00000000854*cost(2.34437926957+6681.22485339960*x);
L0+=0.00000001104*cost(0.49781459714+1.48447270830*x);
L0+=0.00000001075*cost(1.09857593161+377.37360791580*x);
L0+=0.00000001114*cost(4.35024775806+51092.72605085480*x);
L0+=0.00000000829*cost(5.41196274578+27991.40181316000*x);
L0+=0.00000000900*cost(2.74195379617+41962.52073693740*x);
L0+=0.00000001010*cost(2.96092073452+135.62532501000*x);
L0+=0.00000000768*cost(3.98260860494+18844.61174413899*x);
L0+=0.00000001018*cost(1.36891050752+36949.23080842420*x);
L0+=0.00000000726*cost(1.67728773965+21202.09370374600*x);
L0+=0.00000000727*cost(0.89048212541+467.96499035440*x);
L0+=0.00000000869*cost(2.93767679827+10192.51015071860*x);
L0+=0.00000000696*cost(5.35698039414+10063.72234907640*x);
L0+=0.00000000920*cost(4.17128923588+18734.40542291960*x);
L0+=0.00000000691*cost(1.50594097883+27197.28169366760*x);
L0+=0.00000000835*cost(0.48050621092+20618.01935853360*x);
L0+=0.00000000711*cost(0.19750098222+18830.38465013739*x);
L0+=0.00000000811*cost(0.16685071959+12432.04265039780*x);
L0+=0.00000000756*cost(3.79022623226+9161.01716302260*x);
L0+=0.00000000622*cost(5.33659507738+9411.46461508720*x);
L0+=0.00000000862*cost(5.72705356405+10175.15251057320*x);
L0+=0.00000000853*cost(0.10404188453+2107.03450754240*x);
L0+=0.00000000742*cost(3.96365892051+813.55028395980*x);
L0+=0.00000000705*cost(0.71229660616+220.41264243880*x);
L0+=0.00000000584*cost(1.71900692700+36.02786667740*x);
L0+=0.00000000612*cost(0.36418385449+949.17560896980*x);
L0+=0.00000000587*cost(1.58648949290+6.62855890001*x);
L0+=0.00000000581*cost(5.49288908804+6309.37416979120*x);
L0+=0.00000000581*cost(4.80353237853+24150.08005134500*x);
L0+=0.00000000516*cost(6.07328802561+38.13303563780*x);
L0+=0.00000000627*cost(5.47281424954+9580.50180689780*x);
L0+=0.00000000601*cost(1.40500080774+1162.47470440780*x);
L0+=0.00000000620*cost(4.00681042667+9992.87290377220*x);
L0+=0.00000000611*cost(3.62010998629+7255.56965173440*x);
L0+=0.00000000697*cost(2.22359630727+348.92442044800*x);
L0+=0.00000000693*cost(5.77432072851+55022.93574707440*x);
L0+=0.00000000494*cost(0.29761886866+7058.59846131540*x);
L0+=0.00000000563*cost(0.24172140474+37410.56723987860*x);
L0+=0.00000000487*cost(5.86917216517+10137.01947493540*x);
L0+=0.00000000493*cost(2.04534833854+735.87651353180*x);
L0+=0.00000000636*cost(2.79707392326+40879.44050464380*x);
L0+=0.00000000519*cost(4.13945657630+16522.65971600220*x);
L0+=0.00000000535*cost(4.60569597820+19573.37471066999*x);
L0+=0.00000000555*cost(5.88120421263+26735.94526221320*x);
L0+=0.00000000440*cost(5.61490649795+23958.63178523340*x);
L0+=0.00000000541*cost(0.62494922735+10007.09999777380*x);
L0+=0.00000000427*cost(4.02335620501+14.22709400160*x);
L0+=0.00000000434*cost(0.29028429049+9264.10993724120*x);
L0+=0.00000000451*cost(1.66320363626+26087.90314157420*x);
L0+=0.00000000422*cost(3.38413582674+10787.63034454580*x);
L0+=0.00000000569*cost(5.14001758731+27490.69247804480*x);
L0+=0.00000000421*cost(4.23407313457+39793.76025465480*x);
L0+=0.00000000458*cost(5.28786368820+49.75702547180*x);
L0+=0.00000000418*cost(5.69097790790+14765.23904326980*x);
L0+=0.00000000475*cost(0.97544690438+1052.26838318840*x);
L0+=0.00000000387*cost(4.41665162999+21.85082932640*x);
L0+=0.00000000523*cost(2.90512426870+20235.12282631040*x);
L0+=0.00000000506*cost(5.26999314618+29999.95935231900*x);
L0+=0.00000000438*cost(2.49457071132+20956.26205751660*x);
L0+=0.00000000530*cost(0.71368442157+33794.54372352860*x);
L0+=0.00000000382*cost(1.92119365480+3.93215326310*x);
L0+=0.00000000365*cost(3.81715328784+20419.45754542119*x);
L0+=0.00000000426*cost(2.06384083608+38204.68735937100*x);
L0+=0.00000000496*cost(0.44077356179+9835.91193829520*x);
L0+=0.00000000410*cost(4.93346326003+19264.09638801420*x);
L0+=0.00000000380*cost(3.79573358631+8521.11987670860*x);
L0+=0.00000000334*cost(5.51158557799+10251.31321884680*x);
L0+=0.00000000412*cost(2.56129670728+77.67377042800*x);
L0+=0.00000000418*cost(2.37865963521+32.53255079140*x);
L0+=0.00000000325*cost(6.03020523465+18947.70451835760*x);
L0+=0.00000000400*cost(0.91999360201+227.47613278900*x);
L0+=0.00000000437*cost(0.91420135162+58953.14544329400*x);
L0+=0.00000000360*cost(0.82477639126+22.77520145080*x);
L0+=0.00000000413*cost(4.22381905655+44809.65020086340*x);
L0+=0.00000000375*cost(3.15657291896+19992.85935454519*x);
L0+=0.00000000371*cost(6.05370874275+20007.08644854680*x);
L0+=0.00000000361*cost(5.44371227904+19470.28193645139*x);
L0+=0.00000000386*cost(5.28120540405+47623.85278608960*x);
L0+=0.00000000389*cost(0.73216672240+19050.79729257620*x);
L0+=0.00000000320*cost(2.84811591194+10199.05845220940*x);
L0+=0.00000000386*cost(3.88754165531+1975.49254585600*x);
L0+=0.00000000276*cost(4.33979180814+20809.46762464520*x);
L0+=0.00000000276*cost(0.50647429773+9830.38901398780*x);
L0+=0.00000000309*cost(3.79299100668+18204.71445782499*x);
L0+=0.00000000377*cost(0.73768791281+11506.76976979360*x);
L0+=0.00000000322*cost(0.96138442100+30666.15495843280*x);
L0+=0.00000000363*cost(1.30472406690+9367.20271145980*x);
L0+=0.00000000366*cost(2.79972786028+11272.66747640020*x);
L0+=0.00000000271*cost(4.66141338193+846.08283475120*x);
L0+=0.00000000259*cost(0.42031175750+39264.06928956020*x);
L0+=0.00000000285*cost(0.40546033634+30.91412563500*x);
L0+=0.00000000247*cost(4.80676426942+36147.40987730040*x);
L0+=0.00000000264*cost(2.71608177583+11.04570026390*x);
L0+=0.00000000233*cost(2.76423842887+187.92514776260*x);
L0+=0.00000000248*cost(1.60765612338+10497.14486507620*x);
L0+=0.00000000271*cost(0.82348919630+19793.78735310880*x);
L0+=0.00000000225*cost(3.80080957016+8631.32619792800*x);
L0+=0.00000000263*cost(1.92311689852+37724.75341974820*x);
L0+=0.00000000214*cost(5.01663795092+639.89728631400*x);
L0+=0.00000000289*cost(0.12342601246+20277.00789528740*x);
L0+=0.00000000210*cost(0.12771800254+29.82143814880*x);
L0+=0.00000000227*cost(4.18036609801+17468.85519794540*x);
L0+=0.00000000274*cost(2.34929343000+62883.35513951360*x);
L0+=0.00000000260*cost(5.65254501655+48739.85989708300*x);
L0+=0.00000000271*cost(4.95325404028+4214.06901508480*x);
L0+=0.00000000219*cost(2.08775228014+194.97138446060*x);
L0+=0.00000000191*cost(2.49267248333+568.82187402740*x);
L0+=0.00000000250*cost(1.52909737354+6037.24420376200*x);
L0+=0.00000000231*cost(5.23674429498+491.66329245880*x);
L0+=0.00000000182*cost(4.98046042571+18418.01355326299*x);
L0+=0.00000000188*cost(2.82273639603+1385.89527633620*x);
L0+=0.00000000204*cost(4.09939796199+14919.01785375460*x);
L0+=0.00000000176*cost(3.82400982460+9360.08916445900*x);
L0+=0.00000000198*cost(2.76491873243+10217.21769947410*x);
L0+=0.00000000168*cost(5.19268384202+1066.49547719000*x);
L0+=0.00000000199*cost(1.95301487982+7564.83072073800*x);
L0+=0.00000000171*cost(2.59623459612+20405.79569692960*x);
L0+=0.00000000172*cost(5.29332132623+11764.33076885900*x);
L0+=0.00000000165*cost(2.88557908025+10207.76262190360*x);
L0+=0.00000000164*cost(3.25435371801+3914.95722503460*x);
L0+=0.00000000200*cost(3.82443218090+18314.92077904440*x);
L0+=0.00000000169*cost(1.78341902878+31022.75317085620*x);
L0+=0.00000000179*cost(0.90840065587+7880.08915333899*x);
L0+=0.00000000163*cost(2.79665037814+41.55079098480*x);
L0+=0.00000000154*cost(3.90796293476+30213.25844775700*x);
L0+=0.00000000153*cost(0.07463240782+28528.20632525540*x);
L0+=0.00000000194*cost(5.95838706838+8617.09910392640*x);
L0+=0.00000000171*cost(4.58206324409+20447.34648791440*x);
L0+=0.00000000150*cost(2.11647586229+17248.42530185440*x);
L0+=0.00000000149*cost(2.17259986320+9929.42622734580*x);
L0+=0.00000000191*cost(0.82310353823+52670.06959330260*x);
L0+=0.00000000148*cost(2.94315921485+41654.96311596780*x);
L0+=0.00000000149*cost(4.49798039726+30831.30490474460*x);
L0+=0.00000000184*cost(2.46923348701+34596.36465465240*x);
L0+=0.00000000146*cost(2.69452930300+43071.89928903080*x);
L0+=0.00000000159*cost(2.11137713570+19317.19254032860*x);
L0+=0.00000000154*cost(2.76536164654+28513.97923125379*x);
L0+=0.00000000140*cost(4.94595038686+9256.99639024040*x);
L0+=0.00000000141*cost(2.57248458154+13553.89797291080*x);
L0+=0.00000000137*cost(1.66482327575+2636.72547263700*x);
L0+=0.00000000140*cost(5.23039605990+22645.32819660879*x);
L0+=0.00000000132*cost(5.35690599728+19624.75016129820*x);
L0+=0.00000000140*cost(2.90637712614+48947.66387067660*x);
L0+=0.00000000129*cost(3.95303623681+32858.61374281979*x);
L0+=0.00000000156*cost(6.01143316387+29057.89729034999*x);
L0+=0.00000000134*cost(5.75241675118+68050.42387851159*x);
L0+=0.00000000154*cost(3.66827363753+276.74577186440*x);
L0+=0.00000000176*cost(3.77298381177+66813.56483573320*x);
L0+=0.00000000126*cost(5.00217740223+27461.71084806540*x);
L0+=0.00000000135*cost(1.34807013920+53285.18483524180*x);
L0+=0.00000000150*cost(0.25029475344+290.97286586600*x);
L0+=0.00000000152*cost(3.13035670092+29043.67019634839*x);
L0+=0.00000000169*cost(5.04348109430+73.29712585900*x);
L0+=0.00000000166*cost(5.39219948035+41236.03871706720*x);
L0+=0.00000000163*cost(5.59796070987+7576.56007357400*x);
L0+=0.00000000126*cost(0.77391784606+49.99662190420*x);
L0+=0.00000000163*cost(0.44241846674+20350.30502114640*x);
L0+=0.00000000136*cost(3.09066368912+418.92439890060*x);
L0+=0.00000000154*cost(0.47086190960+28418.00000403600*x);
L0+=0.00000000120*cost(0.88536981986+29573.36116144300*x);
L0+=0.00000000132*cost(1.48009769040+17085.95866572220*x);
L0+=0.00000000126*cost(1.39497760964+966.97087743560*x);
L0+=0.00000000143*cost(3.84026797958+14128.24277124560*x);
L0+=0.00000000147*cost(2.11627427804+34363.36559755600*x);
L0+=0.00000000106*cost(2.04696932293+37674.99639427640*x);
L0+=0.00000000106*cost(1.43873202489+27682.14074415640*x);
L0+=0.00000000149*cost(0.09286508794+8144.27871130440*x);
L0+=0.00000000103*cost(0.01992041470+18300.69368504279*x);
L0+=0.00000000121*cost(3.57602835443+45.14121963660*x);
L0+=0.00000000125*cost(0.11630302078+149.56319713460*x);
L0+=0.00000000102*cost(4.17947097730+2333.19639287200*x);
L0+=0.00000000099*cost(1.51324741657+10419.47109464820*x);
L0+=0.00000000133*cost(3.02183293676+76251.32777062019*x);
L0+=0.00000000136*cost(4.17517197268+3646.35037735440*x);
L0+=0.00000000123*cost(0.44045588682+515.46387109300*x);
L0+=0.00000000113*cost(5.69261397718+10110.19277199240*x);
L0+=0.00000000098*cost(6.23797900467+202.25339517410*x);
L0+=0.00000000099*cost(3.75627530197+59728.66805461800*x);
L0+=0.00000000101*cost(4.62832557536+65236.22129328540*x);
L0+=0.00000000111*cost(1.25947267588+10846.06928552420*x);
L0+=0.00000000110*cost(5.87455577536+38500.27603107220*x);
L0+=0.00000000128*cost(6.01024562160+90394.82301305079*x);
L0+=0.00000000091*cost(1.77665981007+1539.31586981200*x);
L0+=0.00000000092*cost(0.99804571578+95.97922721780*x);
L0+=0.00000000120*cost(3.93060866244+38526.57435087200*x);
L0+=0.00000000117*cost(2.24143299549+56600.27928952220*x);
L0+=0.00000000118*cost(6.09121325940+29786.66025688100*x);
L0+=0.00000000098*cost(4.60938156207+11787.10597030980*x);
L0+=0.00000000097*cost(3.92727733144+11794.15220700780*x);
L0+=0.00000000093*cost(5.23395435043+14169.79356223040*x);
L0+=0.00000000096*cost(5.27525709038+8734.41897214660*x);
L0+=0.00000000094*cost(0.18166654805+67589.08744705719*x);
L0+=0.00000000110*cost(4.96279287076+48417.97290558199*x);
L0+=0.00000000086*cost(0.39533409505+3956.50801601940*x);
L0+=0.00000000085*cost(5.69642646462+37703.97802425580*x);
L0+=0.00000000114*cost(5.19676285428+70743.77453195279*x);
L0+=0.00000000081*cost(5.51324815184+412.37109687440*x);
L0+=0.00000000089*cost(2.13409771828+44768.09940987860*x);
L0+=0.00000000084*cost(6.02475904578+10632.77019008620*x);
L0+=0.00000000085*cost(4.60912614442+45585.17281218740*x);
L0+=0.00000000078*cost(4.47358603432+114.43928868521*x);
L0+=0.00000000097*cost(4.02223363535+10218.80847051840*x);
L0+=0.00000000081*cost(1.03870237004+9793.80090233580*x);
L0+=0.00000000092*cost(0.80301220092+24383.07910844140*x);
L0+=0.00000000087*cost(2.15124790938+28313.28880466100*x);
L0+=0.00000000075*cost(5.17868679355+63658.87775083760*x);
L0+=0.00000000078*cost(5.81927313665+567.71863773040*x);
L0+=0.00000000075*cost(1.72618192481+19580.48825767080*x);
L0+=0.00000000071*cost(0.10259261764+90695.75207512038*x);
L0+=0.00000000077*cost(6.16012067704+1573.82042409880*x);
L0+=0.00000000076*cost(5.12884307551+49515.38250840700*x);
L0+=0.00000000069*cost(0.29569499484+10175.25787357520*x);
L0+=0.00000000061*cost(4.80385549281+19889.76658032659*x);
L0+=0.00000000060*cost(4.56685040226+30426.55754319500*x);
L0+=0.00000000062*cost(4.16222812699+42430.48572729180*x);
L0+=0.00000000050*cost(6.17899839001+22779.43724619380*x);
L0+=0.00000000048*cost(1.52546758016+20639.87018786000*x);
L0+=0.00000000046*cost(4.41738494249+34570.06633485260*x);
L0+=0.00000000037*cost(4.69675087759+44007.82926973960*x);

double L1=0;
L1+=10213.52943052898;
L1+=0.00095707712*cost(2.46424448979+10213.28554621100*x);
L1+=0.00014444977*cost(0.51624564679+20426.57109242200*x);
L1+=0.00000213374*cost(1.79547929368+30639.85663863300*x);
L1+=0.00000151669*cost(6.10635282369+1577.34354244780*x);
L1+=0.00000173904*cost(2.65535879443+26.29831979980*x);
L1+=0.00000082233*cost(5.70234133730+191.44826611160*x);
L1+=0.00000069734*cost(2.68136034979+9437.76293488700*x);
L1+=0.00000052408*cost(3.60013087656+775.52261132400*x);
L1+=0.00000038318*cost(1.03379038025+529.69096509460*x);
L1+=0.00000029633*cost(1.25056322354+5507.55323866740*x);
L1+=0.00000025056*cost(6.10664792855+10404.73381232260*x);
L1+=0.00000017772*cost(6.19369798901+1109.37855209340*x);
L1+=0.00000016510*cost(2.64330452640+7.11354700080*x);
L1+=0.00000014230*cost(5.45138233941+9153.90361602180*x);
L1+=0.00000012607*cost(1.24464400689+40853.14218484400*x);
L1+=0.00000011627*cost(4.97604495371+213.29909543800*x);
L1+=0.00000012563*cost(1.88122199199+382.89653222320*x);
L1+=0.00000008869*cost(0.95282732248+13367.97263110660*x);
L1+=0.00000007374*cost(4.39476760580+10206.17199921020*x);
L1+=0.00000006552*cost(2.28168808058+2352.86615377180*x);
L1+=0.00000006255*cost(4.08056644034+3154.68708489560*x);
L1+=0.00000006697*cost(5.05673427795+801.82093112380*x);
L1+=0.00000004084*cost(4.12103826030+18837.49819713819*x);
L1+=0.00000004882*cost(3.44515199115+11015.10647733480*x);
L1+=0.00000003549*cost(6.19934345402+5.52292430740*x);
L1+=0.00000003448*cost(1.77405651704+11322.66409830440*x);
L1+=0.00000004290*cost(0.08154809210+6283.07584999140*x);
L1+=0.00000003694*cost(2.48453945256+5661.33204915220*x);
L1+=0.00000003555*cost(1.48036949420+1059.38193018920*x);
L1+=0.00000003023*cost(2.24092938317+18073.70493865020*x);
L1+=0.00000003000*cost(0.39169917698+15.25247118500*x);
L1+=0.00000002563*cost(0.35147506973+22003.91463486980*x);
L1+=0.00000002774*cost(1.45683830639+10239.58386601080*x);
L1+=0.00000002951*cost(5.34618097429+7084.89678111520*x);
L1+=0.00000002344*cost(2.36652432105+17298.18232732620*x);
L1+=0.00000002405*cost(2.36085282088+10596.18207843420*x);
L1+=0.00000001720*cost(4.72129626061+10186.98722641120*x);
L1+=0.00000002209*cost(2.07730338665+8635.94200376320*x);
L1+=0.00000002122*cost(4.47091605309+8624.21265092720*x);
L1+=0.00000001527*cost(0.67146857292+14143.49524243060*x);
L1+=0.00000001473*cost(2.59350470099+7064.12138562280*x);
L1+=0.00000001311*cost(0.90408820221+12566.15169998280*x);
L1+=0.00000001474*cost(5.92236241437+9786.68735533500*x);
L1+=0.00000001237*cost(2.59740787132+4551.95349705880*x);
L1+=0.00000001219*cost(2.83617320088+9676.48103411560*x);
L1+=0.00000001116*cost(3.83715584719+21228.39202354580*x);
L1+=0.00000001006*cost(4.26200749078+426.59819087600*x);
L1+=0.00000001150*cost(2.35531987378+9690.70812811720*x);
L1+=0.00000001219*cost(2.27324315182+522.57741809380*x);
L1+=0.00000001150*cost(0.81088598778+10742.97651130560*x);
L1+=0.00000001101*cost(3.74248783564+18307.80723204360*x);
L1+=0.00000001031*cost(2.03889374176+38.02767263580*x);
L1+=0.00000000971*cost(6.10590045414+3532.06069281140*x);
L1+=0.00000000844*cost(4.75124127613+10988.80815753500*x);
L1+=0.00000000908*cost(1.06613723738+10021.83728009940*x);
L1+=0.00000000824*cost(0.23090829723+28286.99048486120*x);
L1+=0.00000000821*cost(2.60456032773+19.66976089979*x);
L1+=0.00000000728*cost(0.10716917942+4705.73230754360*x);
L1+=0.00000000744*cost(3.33129778857+536.80451209540*x);
L1+=0.00000000816*cost(1.27303930175+19896.88012732740*x);
L1+=0.00000000929*cost(1.08024621325+11790.62908865880*x);
L1+=0.00000000797*cost(2.23891816523+3723.50895892300*x);
L1+=0.00000000704*cost(5.95307260017+20.77539549240*x);
L1+=0.00000000665*cost(0.21346689192+7860.41939243920*x);
L1+=0.00000000733*cost(2.22147883292+19360.07561523199*x);
L1+=0.00000000702*cost(1.76206343944+19374.30270923360*x);
L1+=0.00000000575*cost(2.38792087791+6770.71060124560*x);
L1+=0.00000000538*cost(1.52023264138+25934.12433108940*x);
L1+=0.00000000690*cost(4.01873754171+19651.04848109800*x);
L1+=0.00000000532*cost(4.41576130890+574.34479833480*x);
L1+=0.00000000540*cost(2.15936134728+16496.36139620240*x);
L1+=0.00000000576*cost(5.41170044566+206.18554843720*x);
L1+=0.00000000482*cost(0.40815793538+3340.61242669980*x);
L1+=0.00000000501*cost(3.08578363577+245.83164622940*x);
L1+=0.00000000488*cost(5.22311611589+25158.60171976540*x);
L1+=0.00000000450*cost(0.21279844600+11.72935283600*x);
L1+=0.00000000432*cost(1.32004964493+103.09277421860*x);
L1+=0.00000000434*cost(5.91094755233+19786.67380610799*x);
L1+=0.00000000564*cost(0.38776462529+19367.18916223280*x);
L1+=0.00000000421*cost(2.71057839701+13936.79450513400*x);
L1+=0.00000000549*cost(6.08792865644+3930.20969621960*x);
L1+=0.00000000478*cost(4.70234715828+14945.31617355440*x);
L1+=0.00000000408*cost(4.80890663927+32217.20018108080*x);
L1+=0.00000000404*cost(2.85003595942+29864.33402730900*x);
L1+=0.00000000407*cost(2.94002049006+10220.39909321180*x);
L1+=0.00000000359*cost(0.72354778897+419.48464387520*x);
L1+=0.00000000449*cost(1.44520508753+8662.24032356300*x);
L1+=0.00000000353*cost(2.22195492336+51066.42773105500*x);
L1+=0.00000000324*cost(1.40308439067+29580.47470844380*x);
L1+=0.00000000443*cost(1.93864353398+9146.79006902100*x);
L1+=0.00000000314*cost(0.96837035284+20618.01935853360*x);
L1+=0.00000000324*cost(5.10759068171+24356.78078864160*x);
L1+=0.00000000324*cost(1.80146948625+18830.38465013739*x);
L1+=0.00000000370*cost(6.16895004656+2218.75710418680*x);
L1+=0.00000000278*cost(2.20429108375+18844.61174413899*x);
L1+=0.00000000286*cost(3.08459438435+17277.40693183380*x);
L1+=0.00000000383*cost(0.13890934755+4732.03062734340*x);
L1+=0.00000000292*cost(0.43528982259+29088.81141598500*x);
L1+=0.00000000273*cost(5.84415407168+9573.38825989700*x);
L1+=0.00000000324*cost(2.14144542781+9999.98645077300*x);
L1+=0.00000000264*cost(5.20407029554+220.41264243880*x);
L1+=0.00000000254*cost(0.34411959301+28521.09277825460*x);
L1+=0.00000000300*cost(3.76014360906+8094.52168583260*x);
L1+=0.00000000301*cost(3.64457981649+20400.27277262220*x);
L1+=0.00000000287*cost(1.84003536598+1589.07289528380*x);
L1+=0.00000000206*cost(0.97167234723+10234.06094170340*x);
L1+=0.00000000212*cost(0.24173677600+36.02786667740*x);
L1+=0.00000000216*cost(5.88618923030+18875.52586977400*x);
L1+=0.00000000198*cost(1.89506914939+20452.86941222180*x);
L1+=0.00000000258*cost(6.27611355094+1551.04522264800*x);
L1+=0.00000000197*cost(2.09222675324+9683.59458111640*x);
L1+=0.00000000217*cost(5.79472589364+9103.90699411760*x);
L1+=0.00000000188*cost(0.39123199129+19573.37471066999*x);
L1+=0.00000000195*cost(6.23142464829+30110.16567353840*x);
L1+=0.00000000187*cost(5.49670351645+170.67287061920*x);
L1+=0.00000000178*cost(4.90042854659+10787.63034454580*x);
L1+=0.00000000188*cost(1.62614804098+9161.01716302260*x);
L1+=0.00000000211*cost(2.71884568392+15720.83878487840*x);
L1+=0.00000000177*cost(1.88170417337+33019.02111220460*x);
L1+=0.00000000209*cost(2.66033422116+3442.57494496540*x);
L1+=0.00000000164*cost(4.92240093026+10426.58464164900*x);
L1+=0.00000000186*cost(5.13678812068+7255.56965173440*x);
L1+=0.00000000177*cost(5.70206821967+9992.87290377220*x);
L1+=0.00000000214*cost(2.70027196648+3128.38876509580*x);
L1+=0.00000000208*cost(3.38876526854+17778.11626694899*x);
L1+=0.00000000147*cost(4.25008782855+16983.99614745660*x);
L1+=0.00000000148*cost(3.46404418130+21202.09370374600*x);
L1+=0.00000000189*cost(1.43553862242+2379.16447357160*x);
L1+=0.00000000139*cost(2.99154379541+110.20632121940*x);
L1+=0.00000000159*cost(5.23851679605+10007.09999777380*x);
L1+=0.00000000136*cost(0.88942869764+22805.73556599360*x);
L1+=0.00000000155*cost(5.90500835975+12592.45001978260*x);
L1+=0.00000000151*cost(0.03422618975+27991.40181316000*x);
L1+=0.00000000153*cost(4.01743770323+33794.54372352860*x);
L1+=0.00000000121*cost(0.51392111799+21535.94964451540*x);
L1+=0.00000000109*cost(2.25388616761+26735.94526221320*x);
L1+=0.00000000109*cost(0.78612823474+6681.22485339960*x);
L1+=0.00000000122*cost(4.84805105466+19992.85935454519*x);
L1+=0.00000000112*cost(3.31796669604+36949.23080842420*x);
L1+=0.00000000106*cost(3.34507236765+10103.07922499160*x);
L1+=0.00000000114*cost(4.36384000196+20007.08644854680*x);
L1+=0.00000000098*cost(5.07711736751+135.62532501000*x);
L1+=0.00000000120*cost(5.41870615047+37724.75341974820*x);
L1+=0.00000000103*cost(2.62610244425+20213.27199698400*x);
L1+=0.00000000085*cost(5.04808202087+9830.38901398780*x);
L1+=0.00000000103*cost(2.01549383816+45585.17281218740*x);
L1+=0.00000000088*cost(2.62613816931+21.85082932640*x);
L1+=0.00000000084*cost(3.50355880173+639.89728631400*x);
L1+=0.00000000099*cost(0.61079620895+41654.96311596780*x);
L1+=0.00000000088*cost(3.63836700262+49515.38250840700*x);
L1+=0.00000000098*cost(2.42401801881+23581.25817731760*x);
L1+=0.00000000081*cost(0.46468679835+77.67377042800*x);
L1+=0.00000000092*cost(4.82530051729+29043.67019634839*x);
L1+=0.00000000102*cost(4.27051236894+15874.61759536320*x);
L1+=0.00000000090*cost(4.34075776744+29057.89729034999*x);
L1+=0.00000000081*cost(0.01896422336+24150.08005134500*x);
L1+=0.00000000093*cost(1.79250830018+12432.04265039780*x);
L1+=0.00000000087*cost(5.25157021446+14128.24277124560*x);
L1+=0.00000000089*cost(5.65756996753+377.37360791580*x);
L1+=0.00000000097*cost(5.67942873241+227.47613278900*x);
L1+=0.00000000076*cost(2.93363913259+38204.68735937100*x);
L1+=0.00000000091*cost(2.60544242067+1052.26838318840*x);
L1+=0.00000000087*cost(3.82284200928+27511.46787353720*x);
L1+=0.00000000073*cost(4.75280755154+40879.44050464380*x);
L1+=0.00000000067*cost(3.54815262526+30666.15495843280*x);
L1+=0.00000000067*cost(5.81350818057+20809.46762464520*x);
L1+=0.00000000064*cost(4.24772678145+153.77881048480*x);
L1+=0.00000000064*cost(2.99454749109+27197.28169366760*x);
L1+=0.00000000070*cost(4.03868009742+56600.27928952220*x);
L1+=0.00000000071*cost(4.33628806850+39264.06928956020*x);
L1+=0.00000000069*cost(1.73648747605+37410.56723987860*x);
L1+=0.00000000065*cost(1.08206062736+68050.42387851159*x);
L1+=0.00000000062*cost(4.77698454650+3914.95722503460*x);
L1+=0.00000000061*cost(4.96121014691+34596.36465465240*x);
L1+=0.00000000063*cost(5.04865067599+53445.59220462660*x);
L1+=0.00000000058*cost(3.74010494151+1066.49547719000*x);
L1+=0.00000000057*cost(5.39355890141+20419.45754542119*x);
L1+=0.00000000057*cost(3.59399518494+735.87651353180*x);
L1+=0.00000000065*cost(2.10322000074+74.78159856730*x);
L1+=0.00000000073*cost(1.31083648835+11272.66747640020*x);
L1+=0.00000000055*cost(1.33161298098+18300.69368504279*x);
L1+=0.00000000065*cost(4.21150522641+49.75702547180*x);
L1+=0.00000000061*cost(5.66161679402+17468.85519794540*x);
L1+=0.00000000053*cost(4.30231233835+18849.22754997420*x);
L1+=0.00000000055*cost(2.63906959481+52670.06959330260*x);
L1+=0.00000000050*cost(5.69803054279+39793.76025465480*x);
L1+=0.00000000049*cost(0.77345264124+35371.88726597640*x);
L1+=0.00000000048*cost(6.00565977593+283.85931886520*x);
L1+=0.00000000047*cost(2.63299859494+51868.24866217880*x);
L1+=0.00000000046*cost(0.05105081843+38526.57435087200*x);
L1+=0.00000000050*cost(4.37549274002+28513.97923125379*x);
L1+=0.00000000046*cost(2.93422086586+27682.14074415640*x);
L1+=0.00000000051*cost(5.45979584751+60530.48898574180*x);
L1+=0.00000000045*cost(5.59492908223+467.96499035440*x);
L1+=0.00000000045*cost(2.34680401001+9411.46461508720*x);
L1+=0.00000000045*cost(0.02999265111+44809.65020086340*x);
L1+=0.00000000043*cost(5.62725673544+14.22709400160*x);
L1+=0.00000000047*cost(3.73567275749+64460.69868196140*x);
L1+=0.00000000046*cost(0.12586526756+57375.80190084620*x);
L1+=0.00000000044*cost(2.03114426076+18314.92077904440*x);
L1+=0.00000000039*cost(0.99375127466+94138.32702008578*x);
L1+=0.00000000053*cost(0.41974404621+30831.30490474460*x);
L1+=0.00000000055*cost(1.38351566741+38500.27603107220*x);
L1+=0.00000000041*cost(4.47012768909+40077.61957352000*x);
L1+=0.00000000041*cost(0.36665992484+19999.97290154599*x);
L1+=0.00000000040*cost(3.06358586355+813.55028395980*x);
L1+=0.00000000040*cost(2.16802870803+59728.66805461800*x);
L1+=0.00000000037*cost(1.08739100421+17085.95866572220*x);
L1+=0.00000000039*cost(1.31040309875+48739.85989708300*x);
L1+=0.00000000036*cost(1.43280677914+42456.78404709160*x);
L1+=0.00000000037*cost(0.14190533464+29050.78374334920*x);
L1+=0.00000000037*cost(3.66792179278+20956.26205751660*x);
L1+=0.00000000025*cost(3.38876180652+7058.59846131540*x);
L1+=0.00000000031*cost(6.16829805337+10192.51015071860*x);

double L2=0;
L2+=0.00054127076;
L2+=0.00003891460*cost(0.34514360047+10213.28554621100*x);
L2+=0.00001337880*cost(2.02011286082+20426.57109242200*x);
L2+=0.00000023836*cost(2.04592119012+26.29831979980*x);
L2+=0.00000019331*cost(3.53527371458+30639.85663863300*x);
L2+=0.00000009984*cost(3.97130221102+775.52261132400*x);
L2+=0.00000007046*cost(1.51962593409+1577.34354244780*x);
L2+=0.00000006014*cost(0.99926757893+191.44826611160*x);
L2+=0.00000003163*cost(4.36095475762+9437.76293488700*x);
L2+=0.00000002125*cost(2.65810625752+40853.14218484400*x);
L2+=0.00000001934*cost(3.39287946981+382.89653222320*x);
L2+=0.00000001460*cost(6.04899046273+529.69096509460*x);
L2+=0.00000001346*cost(2.94633106219+5507.55323866740*x);
L2+=0.00000001025*cost(1.40598904981+10404.73381232260*x);
L2+=0.00000001221*cost(3.73339139385+3154.68708489560*x);
L2+=0.00000001033*cost(3.52858472904+11015.10647733480*x);
L2+=0.00000000955*cost(5.11133878923+801.82093112380*x);
L2+=0.00000000742*cost(1.49198584483+1109.37855209340*x);
L2+=0.00000000525*cost(3.32087042103+213.29909543800*x);
L2+=0.00000000578*cost(0.92614279843+10239.58386601080*x);
L2+=0.00000000602*cost(5.19220099775+7084.89678111520*x);
L2+=0.00000000431*cost(2.67159914364+13367.97263110660*x);
L2+=0.00000000389*cost(4.14116341739+8635.94200376320*x);
L2+=0.00000000355*cost(1.12061570874+9153.90361602180*x);
L2+=0.00000000301*cost(3.90047984197+10596.18207843420*x);
L2+=0.00000000212*cost(5.32697688872+18837.49819713819*x);
L2+=0.00000000260*cost(0.22761369281+2352.86615377180*x);
L2+=0.00000000243*cost(4.70747902991+6283.07584999140*x);
L2+=0.00000000196*cost(4.10467294392+11790.62908865880*x);
L2+=0.00000000194*cost(6.01197759470+7860.41939243920*x);
L2+=0.00000000140*cost(4.97015671653+14143.49524243060*x);
L2+=0.00000000134*cost(4.10529011674+17298.18232732620*x);
L2+=0.00000000119*cost(3.39375528828+11322.66409830440*x);
L2+=0.00000000126*cost(0.09854516140+18073.70493865020*x);
L2+=0.00000000122*cost(5.92478855457+574.34479833480*x);
L2+=0.00000000107*cost(0.35660030184+1059.38193018920*x);
L2+=0.00000000108*cost(2.25352052666+12566.15169998280*x);
L2+=0.00000000093*cost(5.48716819776+10021.83728009940*x);
L2+=0.00000000084*cost(4.89744332968+18307.80723204360*x);
L2+=0.00000000074*cost(2.35354025573+426.59819087600*x);
L2+=0.00000000093*cost(4.99316908815+14945.31617355440*x);
L2+=0.00000000069*cost(3.86409065860+51066.42773105500*x);
L2+=0.00000000082*cost(5.36280178643+10186.98722641120*x);
L2+=0.00000000077*cost(3.75728548372+3723.50895892300*x);
L2+=0.00000000063*cost(5.39882267787+21228.39202354580*x);
L2+=0.00000000056*cost(4.11564786973+7064.12138562280*x);
L2+=0.00000000056*cost(6.26920407723+32217.20018108080*x);
L2+=0.00000000060*cost(5.02186497542+19367.18916223280*x);
L2+=0.00000000058*cost(5.13263709670+20400.27277262220*x);
L2+=0.00000000051*cost(4.52870390511+22003.91463486980*x);
L2+=0.00000000041*cost(3.83822107919+16496.36139620240*x);
L2+=0.00000000041*cost(3.36020411807+4705.73230754360*x);
L2+=0.00000000043*cost(5.98371820588+15720.83878487840*x);
L2+=0.00000000047*cost(0.18498155367+18875.52586977400*x);
L2+=0.00000000038*cost(0.52232581277+1551.04522264800*x);
L2+=0.00000000039*cost(5.05391675878+10742.97651130560*x);
L2+=0.00000000036*cost(3.16242472203+20452.86941222180*x);
L2+=0.00000000035*cost(5.17462577483+29088.81141598500*x);
L2+=0.00000000035*cost(3.47325394141+24356.78078864160*x);
L2+=0.00000000031*cost(4.74511706231+28521.09277825460*x);
L2+=0.00000000029*cost(0.19383091192+19896.88012732740*x);
L2+=0.00000000033*cost(1.80059867635+20618.01935853360*x);
L2+=0.00000000024*cost(0.14022912457+21202.09370374600*x);
L2+=0.00000000022*cost(4.73565067573+10988.80815753500*x);
L2+=0.00000000018*cost(0.74039763161+25158.60171976540*x);
L2+=0.00000000019*cost(1.53770232218+28286.99048486120*x);
L2+=0.00000000014*cost(1.49084059765+30110.16567353840*x);
L2+=0.00000000013*cost(4.72171283479+29864.33402730900*x);
L2+=0.00000000013*cost(5.79700427846+29580.47470844380*x);
L2+=0.00000000014*cost(3.69205225010+27511.46787353720*x);

double L3=0;
L3+=0.00000135742*cost(4.80389020993+10213.28554621100*x);
L3+=0.00000077846*cost(3.66876371591+20426.57109242200*x);
L3+=0.00000026023;
L3+=0.00000001214*cost(5.31970006917+30639.85663863300*x);
L3+=0.00000000254*cost(4.15021671822+40853.14218484400*x);
L3+=0.00000000008*cost(5.55523563261+51066.42773105500*x);
L3+=0.00000000008*cost(1.40501229148+1577.34354244780*x);
L3+=0.00000000006*cost(1.27791479726+10404.73381232260*x);
L3+=0.00000000006*cost(5.76447068962+10239.58386601080*x);

double L4=0;
L4-=0.00000114016;
L4+=0.00000003209*cost(5.20514170164+20426.57109242200*x);
L4+=0.00000001714*cost(2.51099591706+10213.28554621100*x);
L4+=0.00000000050*cost(0.71356059861+30639.85663863300*x);
L4+=0.00000000023*cost(5.68127607034+40853.14218484400*x);

double L5=0;
L5-=0.00000000874;
L5+=0.00000000117*cost(0.54643013000+20426.57109242200*x);
L5+=0.00000000118*cost(1.90548541922+10213.28554621100*x);
L5+=0.00000000002*cost(1.07734277826+40853.14218484400*x);
L5+=0.00000000002*cost(1.89460223529+30639.85663863300*x);

/*
printf(">> L0: %.8f\n",L0);
printf(">> L1: %.8f\n",L1);
printf(">> L2: %.8f\n",L2);
printf(">> L3: %.8f\n",L3);
printf(">> L4: %.8f\n",L4);
printf(">> L5: %.8f\n",L5);
*/

double rtd=180/3.141592653589793;
double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;

return rtd*trunc2(L0+L1*x+L2*x2+L3*x3+L4*x4+L5*x5);
};	

//Heliocentric latitude of Venus
double Bvenus(double x)
{
double Bx0=0;
Bx0+=0.05923638472*cost(0.26702775813+10213.28554621100*x);
Bx0+=0.00040107978*cost(1.14737178106+20426.57109242200*x);
Bx0-=0.00032814918;
Bx0+=0.00001011392*cost(1.08946123021+30639.85663863300*x);
Bx0+=0.00000149458*cost(6.25390296069+18073.70493865020*x);
Bx0+=0.00000137788*cost(0.86020146523+1577.34354244780*x);
Bx0+=0.00000129973*cost(3.67152483651+9437.76293488700*x);
Bx0+=0.00000119507*cost(3.70468812804+2352.86615377180*x);
Bx0+=0.00000107971*cost(4.53903677647+22003.91463486980*x);
Bx0+=0.00000092029*cost(1.53954562706+9153.90361602180*x);
Bx0+=0.00000052982*cost(2.28138172277+5507.55323866740*x);
Bx0+=0.00000045617*cost(0.72319641722+10239.58386601080*x);
Bx0+=0.00000038855*cost(2.93437865147+10186.98722641120*x);
Bx0+=0.00000043491*cost(6.14015776699+11790.62908865880*x);
Bx0+=0.00000041700*cost(5.99126845246+19896.88012732740*x);
Bx0+=0.00000039644*cost(3.86842095901+8635.94200376320*x);
Bx0+=0.00000039175*cost(3.94960351174+529.69096509460*x);
Bx0+=0.00000033320*cost(4.83194909595+14143.49524243060*x);
Bx0+=0.00000023711*cost(2.90646621218+10988.80815753500*x);
Bx0+=0.00000023500*cost(2.00770618322+13367.97263110660*x);
Bx0+=0.00000021809*cost(2.69701424951+19651.04848109800*x);
Bx0+=0.00000020653*cost(0.98666685459+775.52261132400*x);
Bx0+=0.00000016976*cost(4.13711782135+10021.83728009940*x);
Bx0+=0.00000017835*cost(5.96268643102+25934.12433108940*x);
Bx0+=0.00000014949*cost(5.61075168206+10404.73381232260*x);
Bx0+=0.00000018579*cost(1.80529277514+40853.14218484400*x);
Bx0+=0.00000015407*cost(3.29563855296+11015.10647733480*x);
Bx0+=0.00000012936*cost(5.42651448496+29580.47470844380*x);
Bx0+=0.00000011962*cost(3.57604253827+10742.97651130560*x);
Bx0+=0.00000011827*cost(1.19070919600+8624.21265092720*x);
Bx0+=0.00000011466*cost(5.12780364967+6283.07584999140*x);
Bx0+=0.00000009484*cost(2.75167834335+191.44826611160*x);
Bx0+=0.00000013129*cost(5.70735942511+9683.59458111640*x);
Bx0+=0.00000008583*cost(0.43182249199+9786.68735533500*x);
Bx0+=0.00000009763*cost(0.14614896296+20618.01935853360*x);
Bx0+=0.00000008148*cost(1.30548515603+15720.83878487840*x);
Bx0+=0.00000006050*cost(6.26541665966+11322.66409830440*x);
Bx0+=0.00000005955*cost(4.92235372433+1059.38193018920*x);
Bx0+=0.00000006983*cost(3.44920932146+17298.18232732620*x);
Bx0+=0.00000006228*cost(1.13312070908+29864.33402730900*x);
Bx0+=0.00000006186*cost(4.92498052443+19367.18916223280*x);
Bx0+=0.00000006155*cost(2.42413946900+4705.73230754360*x);
Bx0+=0.00000005204*cost(3.42528906628+9103.90699411760*x);
Bx0+=0.00000006000*cost(3.57639095526+3154.68708489560*x);
Bx0+=0.00000004796*cost(3.86676184909+7860.41939243920*x);
Bx0+=0.00000005289*cost(4.99182712443+7084.89678111520*x);
Bx0+=0.00000004070*cost(5.58798144740+12566.15169998280*x);
Bx0+=0.00000003942*cost(5.68758787835+10206.17199921020*x);
Bx0+=0.00000003797*cost(3.89520601076+10192.51015071860*x);
Bx0+=0.00000003798*cost(6.06410995916+10234.06094170340*x);
Bx0+=0.00000003579*cost(0.73789669235+4551.95349705880*x);
Bx0+=0.00000003641*cost(2.61501257205+15874.61759536320*x);
Bx0+=0.00000003266*cost(0.97517223854+23581.25817731760*x);
Bx0+=0.00000002813*cost(0.29951755546+9411.46461508720*x);
Bx0+=0.00000003048*cost(2.51085146990+33794.54372352860*x);
Bx0+=0.00000002559*cost(4.58043833032+801.82093112380*x);
Bx0+=0.00000002462*cost(5.05790874754+29050.78374334920*x);
Bx0+=0.00000002593*cost(5.73113176751+20213.27199698400*x);
Bx0+=0.00000002625*cost(4.24272906574+213.29909543800*x);
Bx0+=0.00000002246*cost(0.82112963936+28286.99048486120*x);
Bx0+=0.00000002229*cost(2.22457598233+10426.58464164900*x);
Bx0+=0.00000001742*cost(1.48394229233+7058.59846131540*x);
Bx0+=0.00000001660*cost(5.42775825275+32217.20018108080*x);
Bx0+=0.00000001491*cost(4.64883377941+1109.37855209340*x);
Bx0+=0.00000002010*cost(0.75702888128+9999.98645077300*x);
Bx0+=0.00000001562*cost(3.93962080463+37724.75341974820*x);
Bx0+=0.00000001538*cost(2.17309577080+21535.94964451540*x);
Bx0+=0.00000001546*cost(4.70759186462+14945.31617355440*x);
Bx0+=0.00000001200*cost(1.48282382657+9830.38901398780*x);
Bx0+=0.00000001224*cost(5.55090394449+5661.33204915220*x);
Bx0+=0.00000001111*cost(1.20276209213+9573.38825989700*x);
Bx0+=0.00000001064*cost(1.98891375536+26.29831979980*x);
Bx0+=0.00000001041*cost(5.38535116069+7.11354700080*x);
Bx0+=0.00000001036*cost(1.16719443387+8662.24032356300*x);
Bx0+=0.00000001143*cost(3.20596958337+3532.06069281140*x);
Bx0+=0.00000001201*cost(0.81913312536+8094.52168583260*x);
Bx0+=0.00000001005*cost(2.38429892132+27511.46787353720*x);
Bx0+=0.00000001047*cost(4.56525030769+20419.45754542119*x);
Bx0+=0.00000000968*cost(6.18496721871+25158.60171976540*x);
Bx0+=0.00000001044*cost(1.98055689074+10596.18207843420*x);
Bx0+=0.00000000962*cost(0.48573513747+23958.63178523340*x);
Bx0+=0.00000000846*cost(0.01566400887+3128.38876509580*x);
Bx0+=0.00000000792*cost(5.39686899735+24356.78078864160*x);
Bx0+=0.00000000858*cost(5.34692750735+41654.96311596780*x);
Bx0+=0.00000000757*cost(6.25904553773+20452.86941222180*x);
Bx0+=0.00000000801*cost(4.62406152514+9929.42622734580*x);
Bx0+=0.00000000802*cost(5.37234892520+10497.14486507620*x);
Bx0+=0.00000000750*cost(3.85219782842+21228.39202354580*x);
Bx0+=0.00000000700*cost(1.98097957188+3930.20969621960*x);
Bx0+=0.00000000719*cost(6.11596800207+10218.80847051840*x);
Bx0+=0.00000000672*cost(6.23429601219+14765.23904326980*x);
Bx0+=0.00000000639*cost(5.37566437358+1589.07289528380*x);
Bx0+=0.00000000605*cost(2.42330391120+10251.31321884680*x);
Bx0+=0.00000000726*cost(6.16683781802+18875.52586977400*x);
Bx0+=0.00000000613*cost(5.99731180690+4732.03062734340*x);
Bx0+=0.00000000720*cost(3.84286345199+10207.76262190360*x);
Bx0+=0.00000000637*cost(6.17053891156+10220.39909321180*x);
Bx0+=0.00000000515*cost(1.03001478293+22779.43724619380*x);
Bx0+=0.00000000574*cost(0.43813688572+17085.95866572220*x);
Bx0+=0.00000000510*cost(1.41065159851+9161.01716302260*x);
Bx0+=0.00000000569*cost(3.34601425125+3340.61242669980*x);
Bx0+=0.00000000608*cost(1.25236241968+10175.25787357520*x);
Bx0+=0.00000000524*cost(2.39794248670+26087.90314157420*x);
Bx0+=0.00000000542*cost(1.34665646732+29088.81141598500*x);
Bx0+=0.00000000527*cost(4.01994270827+18849.22754997420*x);
Bx0+=0.00000000569*cost(1.65498800378+39264.06928956020*x);
Bx0+=0.00000000518*cost(4.96996115446+30213.25844775700*x);
Bx0+=0.00000000514*cost(5.78413007838+12592.45001978260*x);
Bx0+=0.00000000538*cost(4.56198493922+10063.72234907640*x);
Bx0+=0.00000000484*cost(4.18538027381+14919.01785375460*x);
Bx0+=0.00000000493*cost(4.79939382739+9146.79006902100*x);
Bx0+=0.00000000427*cost(3.76876868949+11272.66747640020*x);
Bx0+=0.00000000495*cost(0.49175293655+45585.17281218740*x);
Bx0+=0.00000000494*cost(3.74345863918+31441.67756975680*x);
Bx0+=0.00000000524*cost(0.97991794166+30110.16567353840*x);
Bx0+=0.00000000483*cost(1.87898057316+51066.42773105500*x);
Bx0+=0.00000000505*cost(3.70047474212+20400.27277262220*x);
Bx0+=0.00000000351*cost(4.34026574490+10137.01947493540*x);
Bx0+=0.00000000355*cost(5.56672554631+18837.49819713819*x);
Bx0+=0.00000000328*cost(3.78427378910+6681.22485339960*x);
Bx0+=0.00000000349*cost(4.20550749672+20956.26205751660*x);
Bx0+=0.00000000333*cost(4.44969281739+28521.09277825460*x);
Bx0+=0.00000000296*cost(2.83205515646+17277.40693183380*x);
Bx0+=0.00000000311*cost(2.57334132897+20809.46762464520*x);
Bx0+=0.00000000294*cost(0.75089224483+3149.16416058820*x);
Bx0+=0.00000000377*cost(3.98143308775+21202.09370374600*x);
Bx0+=0.00000000272*cost(5.56183082489+16496.36139620240*x);
Bx0+=0.00000000314*cost(0.02584607093+13745.34623902240*x);
Bx0+=0.00000000263*cost(0.55328410985+36147.40987730040*x);
Bx0+=0.00000000286*cost(5.16408902215+426.59819087600*x);
Bx0+=0.00000000279*cost(4.29871615943+19999.97290154599*x);
Bx0+=0.00000000280*cost(1.92925047377+49515.38250840700*x);
Bx0+=0.00000000265*cost(4.81168402147+20235.12282631040*x);
Bx0+=0.00000000273*cost(5.12740051559+35371.88726597640*x);
Bx0+=0.00000000306*cost(5.28903794869+382.89653222320*x);
Bx0+=0.00000000223*cost(2.50591724074+26709.64694241340*x);
Bx0+=0.00000000235*cost(5.96522395118+10198.03307502600*x);
Bx0+=0.00000000234*cost(3.52866583267+10228.53801739600*x);
Bx0+=0.00000000224*cost(6.24561979789+7064.12138562280*x);
Bx0+=0.00000000251*cost(2.84739274245+33019.02111220460*x);
Bx0+=0.00000000196*cost(1.50610393790+31749.23519072640*x);
Bx0+=0.00000000192*cost(1.69321442572+13341.67431130680*x);
Bx0+=0.00000000180*cost(6.19353087076+39793.76025465480*x);
Bx0+=0.00000000199*cost(1.16433321880+22805.73556599360*x);
Bx0+=0.00000000180*cost(3.72646417141+1551.04522264800*x);
Bx0+=0.00000000173*cost(3.35235705827+53445.59220462660*x);
Bx0+=0.00000000195*cost(1.51901264131+43232.30665841560*x);
Bx0+=0.00000000174*cost(2.84049662693+9967.45389998160*x);
Bx0+=0.00000000163*cost(4.29160537719+36949.23080842420*x);
Bx0+=0.00000000169*cost(0.37000676558+10459.11719244040*x);
Bx0+=0.00000000137*cost(5.61149803116+10529.67741586760*x);
Bx0+=0.00000000139*cost(0.87847805052+16522.65971600220*x);
Bx0+=0.00000000139*cost(4.12576475427+36301.18868778519*x);
Bx0+=0.00000000127*cost(5.14447758616+5481.25491886760*x);
Bx0+=0.00000000131*cost(3.11317801589+9896.89367655440*x);
Bx0+=0.00000000131*cost(0.89697384735+3442.57494496540*x);
Bx0+=0.00000000121*cost(1.32802112907+38734.37832446560*x);
Bx0+=0.00000000122*cost(1.59017183044+10110.19277199240*x);
Bx0+=0.00000000123*cost(2.33714216061+10316.37832042960*x);
Bx0+=0.00000000133*cost(2.90682399304+9793.80090233580*x);
Bx0+=0.00000000111*cost(2.52077634760+13936.79450513400*x);
Bx0+=0.00000000120*cost(0.36076947165+536.80451209540*x);
Bx0+=0.00000000115*cost(2.53355582059+26735.94526221320*x);
Bx0+=0.00000000108*cost(2.65839634325+10232.95530711079*x);
Bx0+=0.00000000108*cost(0.55230439694+10193.61578531121*x);
Bx0+=0.00000000138*cost(1.06919239240+65236.22129328540*x);
Bx0+=0.00000000101*cost(3.17012502017+19317.19254032860*x);
Bx0+=0.00000000127*cost(5.63110477712+10288.06714477830*x);
Bx0+=0.00000000127*cost(3.86278127025+10138.50394764370*x);
Bx0+=0.00000000137*cost(2.93350659460+47162.51635463520*x);
Bx0+=0.00000000095*cost(5.03917884334+52175.80628314840*x);
Bx0+=0.00000000094*cost(0.71308489207+38500.27603107220*x);
Bx0+=0.00000000092*cost(5.46204624886+11764.33076885900*x);
Bx0+=0.00000000096*cost(1.52914774412+9690.70812811720*x);
Bx0+=0.00000000101*cost(0.83318284426+6489.77658728800*x);
Bx0+=0.00000000115*cost(3.76443612245+522.57741809380*x);
Bx0+=0.00000000089*cost(2.53312656681+10735.86296430480*x);
Bx0+=0.00000000082*cost(0.85628515615+2379.16447357160*x);
Bx0+=0.00000000103*cost(5.22683237620+103.09277421860*x);
Bx0+=0.00000000090*cost(2.12423586627+28313.28880466100*x);
Bx0+=0.00000000090*cost(0.39668501735+9580.50180689780*x);
Bx0+=0.00000000074*cost(6.02680095550+3723.50895892300*x);
Bx0+=0.00000000081*cost(5.25045057985+10419.47109464820*x);
Bx0+=0.00000000080*cost(4.23724598221+10007.09999777380*x);
Bx0+=0.00000000091*cost(2.48874147947+10846.06928552420*x);
Bx0+=0.00000000085*cost(3.82784790321+51868.24866217880*x);
Bx0+=0.00000000081*cost(2.26235214191+3903.91137641980*x);
Bx0+=0.00000000097*cost(0.77295091600+18307.80723204360*x);
Bx0+=0.00000000094*cost(0.17063414792+6872.67311951120*x);
Bx0+=0.00000000080*cost(5.62254102739+29999.95935231900*x);
Bx0+=0.00000000068*cost(2.71762936670+16983.99614745660*x);
Bx0+=0.00000000066*cost(0.76731351736+20.77539549240*x);
Bx0+=0.00000000075*cost(0.36155638007+39302.09696219600*x);
Bx0+=0.00000000075*cost(2.27327165974+8521.11987670860*x);
Bx0+=0.00000000058*cost(2.14482855875+8631.32619792800*x);
Bx0+=0.00000000064*cost(5.83569051301+2118.76386037840*x);
Bx0+=0.00000000058*cost(2.98524209824+19889.76658032659*x);
Bx0+=0.00000000054*cost(1.78260668333+40077.61957352000*x);
Bx0+=0.00000000055*cost(4.70485939861+639.89728631400*x);
Bx0+=0.00000000060*cost(5.89661892920+41962.52073693740*x);
Bx0+=0.00000000066*cost(2.24746237999+74.78159856730*x);
Bx0+=0.00000000061*cost(3.40726181591+27490.69247804480*x);
Bx0+=0.00000000051*cost(3.07811180039+24150.08005134500*x);
Bx0+=0.00000000057*cost(2.30081371235+20529.66386664059*x);
Bx0+=0.00000000052*cost(2.37192464233+29573.36116144300*x);
Bx0+=0.00000000052*cost(4.76610409132+57375.80190084620*x);
Bx0+=0.00000000047*cost(1.61630288856+30831.30490474460*x);
Bx0+=0.00000000054*cost(5.89684197257+19903.99367432819*x);
Bx0+=0.00000000040*cost(5.32101847424+42430.48572729180*x);
Bx0+=0.00000000051*cost(5.29186795569+29587.58825544460*x);

double B1=0;
B1+=0.00513347602*cost(1.80364310797+10213.28554621100*x);
B1+=0.00004380100*cost(3.38615711591+20426.57109242200*x);
B1+=0.00000196586*cost(2.53001197486+30639.85663863300*x);
B1+=0.00000199162;
B1+=0.00000014031*cost(2.27087044687+9437.76293488700*x);
B1+=0.00000012958*cost(1.50735622957+18073.70493865020*x);
B1+=0.00000011941*cost(5.60462450426+1577.34354244780*x);
B1+=0.00000010324*cost(5.24224313355+2352.86615377180*x);
B1+=0.00000009294*cost(6.07545631303+22003.91463486980*x);
B1+=0.00000007441*cost(1.50257909439+11790.62908865880*x);
B1+=0.00000008031*cost(0.29371105198+9153.90361602180*x);
B1+=0.00000007514*cost(5.08081885990+10186.98722641120*x);
B1+=0.00000004669*cost(3.87801635015+10239.58386601080*x);
B1+=0.00000004399*cost(3.58872736593+40853.14218484400*x);
B1+=0.00000003975*cost(1.28397121206+10404.73381232260*x);
B1+=0.00000004657*cost(0.75073886819+5507.55323866740*x);
B1+=0.00000003783*cost(4.33004753984+19651.04848109800*x);
B1+=0.00000003390*cost(4.88976070903+10988.80815753500*x);
B1+=0.00000003555*cost(1.25927550356+19896.88012732740*x);
B1+=0.00000003479*cost(5.50797002160+529.69096509460*x);
B1+=0.00000002884*cost(0.08549582037+14143.49524243060*x);
B1+=0.00000001786*cost(0.37134513186+13367.97263110660*x);
B1+=0.00000001600*cost(1.68378002982+20618.01935853360*x);
B1+=0.00000001539*cost(1.21683853657+25934.12433108940*x);
B1+=0.00000001341*cost(2.90077139758+15720.83878487840*x);
B1+=0.00000000993*cost(1.74681248965+11322.66409830440*x);
B1+=0.00000001165*cost(6.13437155401+7860.41939243920*x);
B1+=0.00000001115*cost(0.66743690380+29580.47470844380*x);
B1+=0.00000000923*cost(2.25384969096+10021.83728009940*x);
B1+=0.00000000965*cost(1.36425494833+9683.59458111640*x);
B1+=0.00000000973*cost(0.39071758442+6283.07584999140*x);
B1+=0.00000000805*cost(0.53331923557+8624.21265092720*x);
B1+=0.00000000913*cost(0.76046003719+8635.94200376320*x);
B1+=0.00000000991*cost(0.55319879330+19367.18916223280*x);
B1+=0.00000000609*cost(2.62364470139+23581.25817731760*x);
B1+=0.00000000532*cost(5.10925676528+9786.68735533500*x);
B1+=0.00000000476*cost(6.17672999981+11015.10647733480*x);
B1+=0.00000000472*cost(1.69672629200+17298.18232732620*x);
B1+=0.00000000503*cost(2.65840772485+29864.33402730900*x);
B1+=0.00000000456*cost(5.01205315518+10742.97651130560*x);
B1+=0.00000000478*cost(3.94100005156+775.52261132400*x);
B1+=0.00000000477*cost(3.71554345922+10596.18207843420*x);
B1+=0.00000000347*cost(2.34551062680+9411.46461508720*x);
B1+=0.00000000458*cost(2.31894399069+9999.98645077300*x);
B1+=0.00000000374*cost(3.76878356974+21228.39202354580*x);
B1+=0.00000000440*cost(4.33400244581+15874.61759536320*x);
B1+=0.00000000349*cost(1.31468836511+10234.06094170340*x);
B1+=0.00000000310*cost(5.45422332781+10192.51015071860*x);
B1+=0.00000000346*cost(0.94242286364+1059.38193018920*x);
B1+=0.00000000308*cost(4.90145899142+3930.20969621960*x);
B1+=0.00000000331*cost(4.89498986674+10206.17199921020*x);
B1+=0.00000000269*cost(2.39650266204+801.82093112380*x);
B1+=0.00000000269*cost(0.00589873499+9830.38901398780*x);
B1+=0.00000000261*cost(3.48196147279+7058.59846131540*x);
B1+=0.00000000290*cost(0.10953964861+29050.78374334920*x);
B1+=0.00000000283*cost(6.12133736787+20419.45754542119*x);
B1+=0.00000000232*cost(3.07845850030+12566.15169998280*x);
B1+=0.00000000265*cost(4.02431894973+33794.54372352860*x);
B1+=0.00000000220*cost(2.37315851889+4551.95349705880*x);
B1+=0.00000000247*cost(3.07626728158+28286.99048486120*x);
B1+=0.00000000202*cost(3.56872121409+21535.94964451540*x);
B1+=0.00000000225*cost(5.76888896320+213.29909543800*x);
B1+=0.00000000217*cost(0.88382111135+20213.27199698400*x);
B1+=0.00000000172*cost(6.12653050186+9161.01716302260*x);
B1+=0.00000000195*cost(5.47240855400+37724.75341974820*x);
B1+=0.00000000153*cost(4.07656151671+27511.46787353720*x);
B1+=0.00000000174*cost(1.33676849359+32217.20018108080*x);
B1+=0.00000000157*cost(5.98474214437+26.29831979980*x);
B1+=0.00000000163*cost(5.45519134760+10426.58464164900*x);
B1+=0.00000000129*cost(2.08748660996+3128.38876509580*x);
B1+=0.00000000131*cost(1.51959002513+10218.80847051840*x);
B1+=0.00000000139*cost(4.42330401713+10220.39909321180*x);
B1+=0.00000000126*cost(2.62296638037+22779.43724619380*x);
B1+=0.00000000146*cost(4.69869606856+25158.60171976540*x);
B1+=0.00000000172*cost(6.13435208788+18837.49819713819*x);
B1+=0.00000000157*cost(5.44507403858+4705.73230754360*x);
B1+=0.00000000117*cost(6.18296175153+20400.27277262220*x);
B1+=0.00000000164*cost(3.30849473132+51066.42773105500*x);
B1+=0.00000000113*cost(3.64412860654+7.11354700080*x);
B1+=0.00000000109*cost(5.21220660788+8662.24032356300*x);
B1+=0.00000000133*cost(1.78047296245+191.44826611160*x);
B1+=0.00000000117*cost(0.14681677884+9146.79006902100*x);
B1+=0.00000000116*cost(0.61940521198+41654.96311596780*x);
B1+=0.00000000096*cost(1.49631428731+7084.89678111520*x);
B1+=0.00000000096*cost(1.21744230443+10198.03307502600*x);
B1+=0.00000000082*cost(1.45863866349+10207.76262190360*x);
B1+=0.00000000085*cost(6.04057728058+21202.09370374600*x);
B1+=0.00000000083*cost(0.19985600927+14919.01785375460*x);
B1+=0.00000000077*cost(5.50132310610+5661.33204915220*x);
B1+=0.00000000077*cost(2.00173927326+10228.53801739600*x);
B1+=0.00000000093*cost(1.85466268819+45585.17281218740*x);
B1+=0.00000000066*cost(3.25826124156+1109.37855209340*x);
B1+=0.00000000089*cost(0.64100435648+3154.68708489560*x);
B1+=0.00000000061*cost(3.80043027736+11272.66747640020*x);
B1+=0.00000000077*cost(1.85516358950+3532.06069281140*x);
B1+=0.00000000062*cost(0.81341290651+382.89653222320*x);
B1+=0.00000000072*cost(2.35312965005+9103.90699411760*x);
B1+=0.00000000053*cost(3.21969389511+20452.86941222180*x);
B1+=0.00000000067*cost(1.42090542131+24356.78078864160*x);
B1+=0.00000000056*cost(2.97733070198+30110.16567353840*x);
B1+=0.00000000051*cost(4.22406663447+20809.46762464520*x);
B1+=0.00000000058*cost(6.20761936031+29088.81141598500*x);
B1+=0.00000000061*cost(3.27309494322+49515.38250840700*x);
B1+=0.00000000046*cost(5.49443476235+31441.67756975680*x);
B1+=0.00000000050*cost(4.16651052942+13341.67431130680*x);
B1+=0.00000000047*cost(1.25473247769+33019.02111220460*x);
B1+=0.00000000047*cost(2.03402044389+23958.63178523340*x);
B1+=0.00000000036*cost(5.24409311105+3149.16416058820*x);
B1+=0.00000000038*cost(4.15337829669+18849.22754997420*x);
B1+=0.00000000042*cost(0.43005959574+1589.07289528380*x);
B1+=0.00000000041*cost(1.21289342964+12592.45001978260*x);
B1+=0.00000000038*cost(5.91928287144+28521.09277825460*x);
B1+=0.00000000033*cost(3.98241699279+4732.03062734340*x);
B1+=0.00000000035*cost(2.24417218267+16496.36139620240*x);
B1+=0.00000000040*cost(6.13293942728+26087.90314157420*x);
B1+=0.00000000044*cost(1.78123294860+426.59819087600*x);
B1+=0.00000000041*cost(3.16744909855+39264.06928956020*x);
B1+=0.00000000033*cost(4.96183427323+536.80451209540*x);
B1+=0.00000000034*cost(0.12963030501+30213.25844775700*x);
B1+=0.00000000036*cost(5.41167321573+522.57741809380*x);
B1+=0.00000000027*cost(4.44250239485+17277.40693183380*x);
B1+=0.00000000034*cost(5.94541303751+9929.42622734580*x);
B1+=0.00000000033*cost(0.40689057274+10497.14486507620*x);
B1+=0.00000000023*cost(2.59067946967+10175.25787357520*x);
B1+=0.00000000022*cost(0.69625017371+19999.97290154599*x);
B1+=0.00000000023*cost(3.76162101633+10251.31321884680*x);
B1+=0.00000000023*cost(0.62711494266+35371.88726597640*x);
B1+=0.00000000022*cost(4.64142978776+19889.76658032659*x);
B1+=0.00000000020*cost(4.01315480107+26709.64694241340*x);
B1+=0.00000000020*cost(4.03344400680+29573.36116144300*x);
B1+=0.00000000023*cost(0.90416640595+8094.52168583260*x);
B1+=0.00000000022*cost(1.92092469688+17085.95866572220*x);
B1+=0.00000000019*cost(5.04938942644+6681.22485339960*x);

double B2=0;
B2+=0.00022377665*cost(3.38509143877+10213.28554621100*x);
B2+=0.00000281739;
B2+=0.00000173164*cost(5.25563766915+20426.57109242200*x);
B2+=0.00000026945*cost(3.87040891568+30639.85663863300*x);
B2+=0.00000001174*cost(0.09768632072+10186.98722641120*x);
B2+=0.00000000685*cost(3.19139067811+11790.62908865880*x);
B2+=0.00000000788*cost(4.36515965295+10239.58386601080*x);
B2+=0.00000000592*cost(5.22270440328+40853.14218484400*x);
B2+=0.00000000515*cost(6.12821215207+10988.80815753500*x);
B2+=0.00000000538*cost(0.57550272342+2352.86615377180*x);
B2+=0.00000000540*cost(3.11657836329+18073.70493865020*x);
B2+=0.00000000454*cost(2.79306867629+10404.73381232260*x);
B2+=0.00000000374*cost(6.10468482446+9437.76293488700*x);
B2+=0.00000000431*cost(4.00778431184+1577.34354244780*x);
B2+=0.00000000360*cost(6.01747842320+19651.04848109800*x);
B2+=0.00000000375*cost(1.31319959789+22003.91463486980*x);
B2+=0.00000000354*cost(5.12509281266+9153.90361602180*x);
B2+=0.00000000150*cost(4.58623687118+15720.83878487840*x);
B2+=0.00000000164*cost(5.41790158607+5507.55323866740*x);
B2+=0.00000000159*cost(2.78191550878+19896.88012732740*x);
B2+=0.00000000157*cost(0.65774905071+529.69096509460*x);
B2+=0.00000000155*cost(2.54824315372+9683.59458111640*x);
B2+=0.00000000109*cost(2.01866665583+14143.49524243060*x);
B2+=0.00000000106*cost(2.28289033017+6283.07584999140*x);
B2+=0.00000000115*cost(3.23636374193+20618.01935853360*x);
B2+=0.00000000128*cost(5.32400510939+13367.97263110660*x);
B2+=0.00000000087*cost(3.28265082435+11322.66409830440*x);
B2+=0.00000000090*cost(5.23585072275+10596.18207843420*x);
B2+=0.00000000055*cost(4.82369879741+7058.59846131540*x);
B2+=0.00000000044*cost(0.58444963462+10206.17199921020*x);
B2+=0.00000000044*cost(2.34401612969+19367.18916223280*x);
B2+=0.00000000038*cost(4.55053233088+9999.98645077300*x);
B2+=0.00000000039*cost(5.84340580032+10220.39909321180*x);
B2+=0.00000000036*cost(4.41006216127+51066.42773105500*x);
B2+=0.00000000039*cost(3.14348236386+9411.46461508720*x);
B2+=0.00000000033*cost(4.55748660340+10742.97651130560*x);
B2+=0.00000000037*cost(2.79630938717+25934.12433108940*x);
B2+=0.00000000034*cost(0.55287110072+11015.10647733480*x);
B2+=0.00000000034*cost(2.25809144959+29580.47470844380*x);
B2+=0.00000000038*cost(1.88638747393+801.82093112380*x);
B2+=0.00000000034*cost(1.22706917271+10021.83728009940*x);
B2+=0.00000000027*cost(4.83867137637+9830.38901398780*x);
B2+=0.00000000027*cost(4.31140179350+23581.25817731760*x);
B2+=0.00000000027*cost(2.17187621336+8635.94200376320*x);
B2+=0.00000000020*cost(5.66581696952+21228.39202354580*x);
B2+=0.00000000024*cost(2.17208107850+18849.22754997420*x);
B2+=0.00000000020*cost(5.29318634138+775.52261132400*x);
B2+=0.00000000019*cost(2.73486845601+3128.38876509580*x);
B2+=0.00000000013*cost(3.40362915274+1059.38193018920*x);
B2+=0.00000000014*cost(0.05074160195+7860.41939243920*x);
B2+=0.00000000014*cost(5.43035907265+26.29831979980*x);
B2+=0.00000000012*cost(3.24834347355+9103.90699411760*x);
B2+=0.00000000013*cost(5.04826725887+7.11354700080*x);
B2+=0.00000000015*cost(1.42027402522+29050.78374334920*x);
B2+=0.00000000010*cost(4.98138067490+10426.58464164900*x);
B2+=0.00000000011*cost(0.85773045784+17298.18232732620*x);
B2+=0.00000000011*cost(4.23048200054+29864.33402730900*x);
B2+=0.00000000010*cost(0.26447399758+3930.20969621960*x);
B2+=0.00000000011*cost(1.46728576671+20419.45754542119*x);

double B3=0;
B3+=0.00000646671*cost(4.99166565277+10213.28554621100*x);
B3-=0.00000019952;
B3+=0.00000005540*cost(0.77376923951+20426.57109242200*x);
B3+=0.00000002526*cost(5.44493763020+30639.85663863300*x);
B3+=0.00000000079*cost(1.51447613604+10186.98722641120*x);
B3+=0.00000000056*cost(0.63647808442+40853.14218484400*x);
B3+=0.00000000058*cost(5.70731176550+10239.58386601080*x);
B3+=0.00000000031*cost(4.72523061067+11790.62908865880*x);
B3+=0.00000000026*cost(1.02068113372+10988.80815753500*x);
B3+=0.00000000025*cost(5.60599130442+9437.76293488700*x);
B3+=0.00000000017*cost(2.05293621864+2352.86615377180*x);
B3+=0.00000000011*cost(4.33056892256+10404.73381232260*x);
B3+=0.00000000009*cost(1.36283915068+19651.04848109800*x);
B3+=0.00000000007*cost(4.69592781899+18073.70493865020*x);
B3+=0.00000000006*cost(2.97926526705+22003.91463486980*x);

double B4=0;
B4+=0.00000014102*cost(0.31537190181+10213.28554621100*x);
B4+=0.00000000190*cost(2.35466404492+20426.57109242200*x);
B4+=0.00000000164*cost(0.74476215141+30639.85663863300*x);
B4-=0.00000000214;
B4+=0.00000000004*cost(2.34190883009+40853.14218484400*x);

double B5=0;
B5+=0.00000000239*cost(2.05201727566+10213.28554621100*x);
B5+=0.00000000039;
B5+=0.00000000011*cost(3.82500275251+20426.57109242200*x);
B5+=0.00000000009*cost(2.32953116868+30639.85663863300*x);

double rtd=180/3.141592653589793;
double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
	
return rtd*(Bx0+B1*x+B2*x2+B3*x3+B4*x4+B5*x5);
}

	
//Distance Venus-Sun [AU]
double Rvenus(double x)
{	
double R0=0;
R0+=0.72334820905;
R0+=0.00489824185*cost(4.02151832268+10213.28554621100*x);
R0+=0.00001658058*cost(4.90206728012+20426.57109242200*x);
R0+=0.00001632093*cost(2.84548851892+7860.41939243920*x);
R0+=0.00001378048*cost(1.12846590600+11790.62908865880*x);
R0+=0.00000498399*cost(2.58682187717+9683.59458111640*x);
R0+=0.00000373958*cost(1.42314837063+3930.20969621960*x);
R0+=0.00000263616*cost(5.52938185920+9437.76293488700*x);
R0+=0.00000237455*cost(2.55135903978+15720.83878487840*x);
R0+=0.00000221983*cost(2.01346776772+19367.18916223280*x);
R0+=0.00000119467*cost(3.01975365264+10404.73381232260*x);
R0+=0.00000125896*cost(2.72769833559+1577.34354244780*x);
R0+=0.00000076178*cost(1.59577224486+9153.90361602180*x);
R0+=0.00000085336*cost(3.98607953754+19651.04848109800*x);
R0+=0.00000074347*cost(4.11957854039+5507.55323866740*x);
R0+=0.00000041904*cost(1.64273363458+18837.49819713819*x);
R0+=0.00000042493*cost(3.81864530735+13367.97263110660*x);
R0+=0.00000039430*cost(5.39019422358+23581.25817731760*x);
R0+=0.00000029042*cost(5.67739528728+5661.33204915220*x);
R0+=0.00000027555*cost(5.72392407794+775.52261132400*x);
R0+=0.00000027283*cost(4.82151812709+11015.10647733480*x);
R0+=0.00000031274*cost(2.31806719544+9999.98645077300*x);
R0+=0.00000019700*cost(4.96157560245+11322.66409830440*x);
R0+=0.00000019809*cost(0.53189326492+27511.46787353720*x);
R0+=0.00000013567*cost(3.75530870628+18073.70493865020*x);
R0+=0.00000012921*cost(1.13381083556+10206.17199921020*x);
R0+=0.00000016215*cost(0.56453834290+529.69096509460*x);
R0+=0.00000011821*cost(5.09025877427+3154.68708489560*x);
R0+=0.00000011728*cost(0.23432298744+7084.89678111520*x);
R0+=0.00000013079*cost(5.24353197586+17298.18232732620*x);
R0+=0.00000013180*cost(3.37207825651+13745.34623902240*x);
R0+=0.00000009097*cost(3.07004895769+1109.37855209340*x);
R0+=0.00000010818*cost(2.45024712908+10239.58386601080*x);
R0+=0.00000011438*cost(4.56838894696+29050.78374334920*x);
R0+=0.00000008377*cost(5.78327612352+30639.85663863300*x);
R0+=0.00000008193*cost(1.95023111860+22003.91463486980*x);
R0+=0.00000009308*cost(1.61615909286+2352.86615377180*x);
R0+=0.00000010652*cost(1.95528396140+31441.67756975680*x);
R0+=0.00000010357*cost(1.20234990061+15874.61759536320*x);
R0+=0.00000009585*cost(1.46639856228+19999.97290154599*x);
R0+=0.00000006506*cost(2.17390732263+14143.49524243060*x);
R0+=0.00000007562*cost(1.13789564977+8624.21265092720*x);
R0+=0.00000006434*cost(0.84419623033+6283.07584999140*x);
R0+=0.00000005898*cost(0.01093731110+8635.94200376320*x);
R0+=0.00000005632*cost(3.94956548631+12566.15169998280*x);
R0+=0.00000005523*cost(1.27394296557+18307.80723204360*x);
R0+=0.00000004488*cost(2.47835729057+191.44826611160*x);
R0+=0.00000004529*cost(4.73027770400+19896.88012732740*x);
R0+=0.00000006193*cost(3.25881250939+6872.67311951120*x);
R0+=0.00000006070*cost(0.35337419942+21228.39202354580*x);
R0+=0.00000004315*cost(2.59737099519+4551.95349705880*x);
R0+=0.00000006005*cost(3.37874723475+35371.88726597640*x);
R0+=0.00000003852*cost(1.01162850357+9786.68735533500*x);
R0+=0.00000004033*cost(0.00050855580+801.82093112380*x);
R0+=0.00000003920*cost(5.56542869407+10596.18207843420*x);
R0+=0.00000002709*cost(5.80195530112+7064.12138562280*x);
R0+=0.00000003216*cost(0.39767254848+10186.98722641120*x);
R0+=0.00000003089*cost(6.26174762876+14945.31617355440*x);
R0+=0.00000002982*cost(4.21196716354+28521.09277825460*x);
R0+=0.00000003284*cost(0.70709821006+10742.97651130560*x);
R0+=0.00000003484*cost(4.79878191875+39302.09696219600*x);
R0+=0.00000003172*cost(1.80518954174+25158.60171976540*x);
R0+=0.00000002463*cost(0.68708153678+10988.80815753500*x);
R0+=0.00000002374*cost(3.77948685343+21535.94964451540*x);
R0+=0.00000002198*cost(2.82996372521+8662.24032356300*x);
R0+=0.00000001958*cost(5.41763804167+16496.36139620240*x);
R0+=0.00000001876*cost(2.63426768393+29580.47470844380*x);
R0+=0.00000001902*cost(2.85782199133+3532.06069281140*x);
R0+=0.00000001706*cost(3.67573010379+26.29831979980*x);
R0+=0.00000001817*cost(0.41611036449+4705.73230754360*x);
R0+=0.00000001858*cost(1.50368318296+10021.83728009940*x);
R0+=0.00000002087*cost(6.22112874639+43232.30665841560*x);
R0+=0.00000001950*cost(2.21447019683+19786.67380610799*x);
R0+=0.00000001497*cost(0.00134773824+17277.40693183380*x);
R0+=0.00000001819*cost(3.23144993268+29088.81141598500*x);
R0+=0.00000001423*cost(5.85979618707+9676.48103411560*x);
R0+=0.00000001223*cost(5.55818994329+6770.71060124560*x);
R0+=0.00000001140*cost(5.92088900094+13936.79450513400*x);
R0+=0.00000001484*cost(2.47665429253+31749.23519072640*x);
R0+=0.00000001185*cost(1.42087628351+4732.03062734340*x);
R0+=0.00000001323*cost(2.48821075422+9690.70812811720*x);
R0+=0.00000001249*cost(1.88323673734+19374.30270923360*x);
R0+=0.00000001270*cost(5.24647873116+19360.07561523199*x);
R0+=0.00000001402*cost(5.17536780118+10316.37832042960*x);
R0+=0.00000001042*cost(3.05454698508+25934.12433108940*x);
R0+=0.00000001174*cost(1.42913732999+18875.52586977400*x);
R0+=0.00000001278*cost(1.35747287297+47162.51635463520*x);
R0+=0.00000000917*cost(6.26337648765+20618.01935853360*x);
R0+=0.00000000905*cost(1.12740203561+12592.45001978260*x);
R0+=0.00000001093*cost(4.64451720605+33019.02111220460*x);
R0+=0.00000001014*cost(1.09259406433+1059.38193018920*x);
R0+=0.00000000783*cost(2.02118183873+24356.78078864160*x);
R0+=0.00000000779*cost(0.41585274010+3340.61242669980*x);
R0+=0.00000000700*cost(1.14936815714+16983.99614745660*x);
R0+=0.00000000878*cost(0.87852464964+38734.37832446560*x);
R0+=0.00000000623*cost(0.89976912165+17778.11626694899*x);
R0+=0.00000000608*cost(1.58476225197+9573.38825989700*x);
R0+=0.00000000800*cost(3.94213003073+10138.50394764370*x);
R0+=0.00000000760*cost(1.31851313748+9967.45389998160*x);
R0+=0.00000000802*cost(2.78173370208+51092.72605085480*x);
R0+=0.00000000664*cost(4.45864682400+3128.38876509580*x);
R0+=0.00000000674*cost(5.11214939998+382.89653222320*x);
R0+=0.00000000530*cost(0.85392938403+10234.06094170340*x);
R0+=0.00000000509*cost(3.56809374595+28286.99048486120*x);
R0+=0.00000000600*cost(4.25927726907+41962.52073693740*x);
R0+=0.00000000601*cost(5.78144137895+213.29909543800*x);
R0+=0.00000000595*cost(2.83045104588+22805.73556599360*x);
R0+=0.00000000673*cost(6.06079908421+36949.23080842420*x);
R0+=0.00000000535*cost(5.85422519711+9103.90699411760*x);
R0+=0.00000000544*cost(5.44806074800+3723.50895892300*x);
R0+=0.00000000492*cost(3.83802404893+27991.40181316000*x);
R0+=0.00000000635*cost(0.76494024849+8094.52168583260*x);
R0+=0.00000000434*cost(6.22214487735+27197.28169366760*x);
R0+=0.00000000459*cost(3.55062885479+20213.27199698400*x);
R0+=0.00000000398*cost(6.16269975784+10426.58464164900*x);
R0+=0.00000000378*cost(2.41665947591+18844.61174413899*x);
R0+=0.00000000421*cost(4.86552697954+9146.79006902100*x);
R0+=0.00000000500*cost(4.20351458644+55022.93574707440*x);
R0+=0.00000000404*cost(4.95834410782+37410.56723987860*x);
R0+=0.00000000402*cost(2.97963246945+10220.39909321180*x);
R0+=0.00000000464*cost(2.59869499733+18734.40542291960*x);
R0+=0.00000000352*cost(0.08963076359+10103.07922499160*x);
R0+=0.00000000348*cost(4.90260339364+18830.38465013739*x);
R0+=0.00000000338*cost(3.22520096478+24150.08005134500*x);
R0+=0.00000000375*cost(6.17532088136+26087.90314157420*x);
R0+=0.00000000425*cost(1.20052578280+40879.44050464380*x);
R0+=0.00000000408*cost(3.12833060705+9050.81084180320*x);
R0+=0.00000000385*cost(1.94284690176+283.85931886520*x);
R0+=0.00000000337*cost(4.87838699272+12432.04265039780*x);
R0+=0.00000000326*cost(4.27369741426+26735.94526221320*x);
R0+=0.00000000309*cost(0.50597475053+38204.68735937100*x);
R0+=0.00000000329*cost(3.88430599153+29864.33402730900*x);
R0+=0.00000000313*cost(1.36138752543+10192.51015071860*x);
R0+=0.00000000347*cost(3.58439807209+27490.69247804480*x);
R0+=0.00000000251*cost(3.78618457047+10063.72234907640*x);
R0+=0.00000000244*cost(3.83523342668+9411.46461508720*x);
R0+=0.00000000281*cost(4.50895206233+32217.20018108080*x);
R0+=0.00000000237*cost(0.87748812245+6681.22485339960*x);
R0+=0.00000000315*cost(5.62657778233+58953.14544329400*x);
R0+=0.00000000311*cost(4.15626121491+10175.15251057320*x);
R0+=0.00000000247*cost(2.53637594113+16522.65971600220*x);
R0+=0.00000000219*cost(5.08729383251+7058.59846131540*x);
R0+=0.00000000291*cost(3.72567217056+29999.95935231900*x);
R0+=0.00000000267*cost(2.97685503991+19573.37471066999*x);
R0+=0.00000000280*cost(3.70200084294+47623.85278608960*x);
R0+=0.00000000239*cost(3.94545782067+9580.50180689780*x);
R0+=0.00000000246*cost(2.18244883930+9161.01716302260*x);
R0+=0.00000000253*cost(2.69506547016+3442.57494496540*x);
R0+=0.00000000265*cost(2.62811801237+44809.65020086340*x);
R0+=0.00000000194*cost(4.78926136175+33794.54372352860*x);
R0+=0.00000000187*cost(3.65620881095+20452.86941222180*x);
R0+=0.00000000224*cost(2.43601863127+9992.87290377220*x);
R0+=0.00000000193*cost(2.55112161845+2379.16447357160*x);
R0+=0.00000000201*cost(1.90356905733+1551.04522264800*x);
R0+=0.00000000176*cost(4.29837616553+10137.01947493540*x);
R0+=0.00000000184*cost(6.16061560223+36147.40987730040*x);
R0+=0.00000000175*cost(2.71984797040+20809.46762464520*x);
R0+=0.00000000186*cost(2.55098927966+14919.01785375460*x);
R0+=0.00000000161*cost(4.13272567123+23958.63178523340*x);
R0+=0.00000000221*cost(4.83552377614+20277.00789528740*x);
R0+=0.00000000160*cost(1.81472642729+10787.63034454580*x);
R0+=0.00000000199*cost(5.74259798330+30666.15495843280*x);
R0+=0.00000000160*cost(4.46270605493+18947.70451835760*x);
R0+=0.00000000187*cost(2.98688597588+2218.75710418680*x);
R0+=0.00000000189*cost(5.34607810282+10007.09999777380*x);
R0+=0.00000000198*cost(0.77846666692+62883.35513951360*x);
R0+=0.00000000144*cost(5.00261963924+9264.10993724120*x);
R0+=0.00000000171*cost(2.05212624568+7255.56965173440*x);
R0+=0.00000000188*cost(4.08173534559+48739.85989708300*x);
R0+=0.00000000146*cost(3.94191715702+6309.37416979120*x);
R0+=0.00000000146*cost(5.06313558118+39264.06928956020*x);
R0+=0.00000000135*cost(5.93689169614+37724.75341974820*x);
R0+=0.00000000139*cost(2.81266025896+20.77539549240*x);
R0+=0.00000000177*cost(5.16224804657+9835.91193829520*x);
R0+=0.00000000119*cost(1.37254262864+40077.61957352000*x);
R0+=0.00000000120*cost(0.21443767468+31022.75317085620*x);
R0+=0.00000000128*cost(2.92458887798+7.11354700080*x);
R0+=0.00000000150*cost(5.73646272556+632.78373931320*x);
R0+=0.00000000106*cost(0.62224833817+11272.66747640020*x);
R0+=0.00000000114*cost(2.63301326520+17468.85519794540*x);
R0+=0.00000000123*cost(6.22518843711+53285.18483524180*x);
R0+=0.00000000107*cost(1.17258978900+43071.89928903080*x);
R0+=0.00000000103*cost(1.09613781581+41654.96311596780*x);
R0+=0.00000000109*cost(2.01412667085+20419.45754542119*x);
R0+=0.00000000102*cost(4.23406964348+10251.31321884680*x);
R0+=0.00000000116*cost(1.27731728606+10199.05845220940*x);
R0+=0.00000000103*cost(5.25887538465+9830.38901398780*x);
R0+=0.00000000112*cost(2.24436894064+18204.71445782499*x);
R0+=0.00000000111*cost(2.23547857955+8521.11987670860*x);
R0+=0.00000000118*cost(0.23754207200+10497.14486507620*x);
R0+=0.00000000123*cost(0.88054816668+34596.36465465240*x);
R0+=0.00000000102*cost(4.39438646620+18300.69368504279*x);
R0+=0.00000000131*cost(6.01711652115+9367.20271145980*x);
R0+=0.00000000100*cost(5.00532389609+10175.25787357520*x);
R0+=0.00000000107*cost(0.41270197502+40853.14218484400*x);
R0+=0.00000000132*cost(5.45008342761+11506.76976979360*x);
R0+=0.00000000098*cost(1.07722950958+13553.89797291080*x);
R0+=0.00000000094*cost(2.91720097590+44007.82926973960*x);
R0+=0.00000000097*cost(1.04004223634+68050.42387851159*x);
R0+=0.00000000127*cost(2.20215372683+66813.56483573320*x);
R0+=0.00000000111*cost(1.57823839032+29043.67019634839*x);
R0+=0.00000000118*cost(2.33268176890+18314.92077904440*x);
R0+=0.00000000090*cost(2.42353056125+32858.61374281979*x);
R0+=0.00000000109*cost(3.82796787296+19470.28193645139*x);
R0+=0.00000000111*cost(4.47666957576+29057.89729034999*x);
R0+=0.00000000101*cost(3.41528493660+19264.09638801420*x);
R0+=0.00000000092*cost(3.66289799512+22645.32819660879*x);
R0+=0.00000000094*cost(6.07530805791+10846.06928552420*x);
R0+=0.00000000114*cost(4.02718653431+7576.56007357400*x);
R0+=0.00000000087*cost(6.01842459303+17085.95866572220*x);
R0+=0.00000000109*cost(5.46886607309+52670.06959330260*x);
R0+=0.00000000107*cost(0.54805946713+34363.36559755600*x);
R0+=0.00000000108*cost(5.44460610707+19050.79729257620*x);
R0+=0.00000000076*cost(6.15177368654+27682.14074415640*x);
R0+=0.00000000107*cost(4.80525404063+8144.27871130440*x);
R0+=0.00000000073*cost(1.60549217847+20956.26205751660*x);
R0+=0.00000000097*cost(5.13542051130+22779.43724619380*x);
R0+=0.00000000068*cost(2.31300447144+8631.32619792800*x);
R0+=0.00000000091*cost(4.28652743953+10110.19277199240*x);
R0+=0.00000000093*cost(5.27290609264+522.57741809380*x);
R0+=0.00000000071*cost(3.65565961690+11764.33076885900*x);
R0+=0.00000000089*cost(1.79712963206+45585.17281218740*x);
R0+=0.00000000067*cost(2.25900071584+9360.08916445900*x);
R0+=0.00000000085*cost(0.67062144972+56600.27928952220*x);
R0+=0.00000000080*cost(1.58278081077+19992.85935454519*x);
R0+=0.00000000065*cost(6.23472325597+10419.47109464820*x);
R0+=0.00000000064*cost(0.53356325917+17248.42530185440*x);
R0+=0.00000000085*cost(4.52011215904+29786.66025688100*x);
R0+=0.00000000068*cost(4.48235266554+10632.77019008620*x);
R0+=0.00000000064*cost(4.33495700921+47938.03896595920*x);
R0+=0.00000000071*cost(3.03858484137+11787.10597030980*x);
R0+=0.00000000087*cost(4.81823063172+2107.03450754240*x);
R0+=0.00000000070*cost(2.35648061034+11794.15220700780*x);
R0+=0.00000000080*cost(2.33248094128+38526.57435087200*x);
R0+=0.00000000070*cost(3.70454061100+8734.41897214660*x);
R0+=0.00000000077*cost(4.49569185467+20007.08644854680*x);
R0+=0.00000000072*cost(1.19410424468+10217.21769947410*x);
R0+=0.00000000068*cost(2.01841060183+14128.24277124560*x);
R0+=0.00000000064*cost(5.39293951654+7880.08915333899*x);
R0+=0.00000000066*cost(3.20467071127+14765.23904326980*x);
R0+=0.00000000080*cost(3.41620457770+48417.97290558199*x);
R0+=0.00000000080*cost(3.39651161571+245.83164622940*x);
R0+=0.00000000066*cost(5.85414440204+9793.80090233580*x);
R0+=0.00000000082*cost(3.62592908644+70743.77453195279*x);
R0+=0.00000000058*cost(4.95174942212+30110.16567353840*x);
R0+=0.00000000079*cost(6.24161471033+6037.24420376200*x);
R0+=0.00000000069*cost(5.50183658445+19793.78735310880*x);
R0+=0.00000000056*cost(1.24148350566+10207.76262190360*x);
R0+=0.00000000070*cost(2.45123308846+10218.80847051840*x);
R0+=0.00000000064*cost(5.53983104501+10735.86296430480*x);
R0+=0.00000000054*cost(3.62259713240+27461.71084806540*x);
R0+=0.00000000073*cost(1.75882480924+1589.07289528380*x);
R0+=0.00000000075*cost(3.38244819846+4214.06901508480*x);
R0+=0.00000000054*cost(0.64971567468+9929.42622734580*x);
R0+=0.00000000054*cost(3.40959637230+18418.01355326299*x);
R0+=0.00000000056*cost(3.65815006538+14169.79356223040*x);
R0+=0.00000000056*cost(0.71243223808+9896.89367655440*x);
R0+=0.00000000052*cost(1.33348131940+20400.27277262220*x);
R0+=0.00000000067*cost(3.12806595400+5481.25491886760*x);
R0+=0.00000000058*cost(0.54482893546+28313.28880466100*x);
R0+=0.00000000054*cost(0.15603935681+19580.48825767080*x);
R0+=0.00000000051*cost(3.37515473510+9256.99639024040*x);
R0+=0.00000000063*cost(3.38848970950+49515.38250840700*x);
R0+=0.00000000069*cost(4.90917651401+63498.47038145279*x);
R0+=0.00000000057*cost(5.07437742030+18521.10632748160*x);
R0+=0.00000000050*cost(1.59156823654+18631.31264870099*x);
R0+=0.00000000054*cost(6.25816208666+37674.99639427640*x);
R0+=0.00000000057*cost(5.48065460919+24383.07910844140*x);
R0+=0.00000000045*cost(1.10466490660+10408.25693067160*x);
R0+=0.00000000051*cost(3.61196470313+426.59819087600*x);
R0+=0.00000000057*cost(2.09567711267+60530.48898574180*x);
R0+=0.00000000060*cost(5.94659889997+13897.66359620120*x);
R0+=0.00000000051*cost(5.47238517720+57837.13833230060*x);
R0+=0.00000000051*cost(2.32438478428+19779.56025910719*x);
R0+=0.00000000052*cost(3.23766328818+18940.59097135679*x);
R0+=0.00000000043*cost(5.74921510909+51868.24866217880*x);
R0+=0.00000000048*cost(1.12206254877+9779.57380833420*x);
R0+=0.00000000058*cost(3.08646083897+12074.48840752400*x);
R0+=0.00000000046*cost(4.07536026888+7863.94251078820*x);
R0+=0.00000000045*cost(4.75746520642+7856.89627409019*x);
R0+=0.00000000054*cost(4.43528236634+8617.09910392640*x);
R0+=0.00000000050*cost(3.70569982975+42456.78404709160*x);
R0+=0.00000000044*cost(1.29248911155+69166.43098950500*x);
R0+=0.00000000046*cost(0.41229872114+7564.83072073800*x);
R0+=0.00000000044*cost(6.17937388307+13341.67431130680*x);
R0+=0.00000000053*cost(4.71388531889+53445.59220462660*x);
R0+=0.00000000041*cost(3.48003037828+37895.42629036740*x);
R0+=0.00000000040*cost(1.23305546260+10228.53801739600*x);
R0+=0.00000000053*cost(5.04979874661+74673.98422817240*x);
R0+=0.00000000039*cost(1.36646013032+21202.09370374600*x);
R0+=0.00000000039*cost(2.15376025201+8947.71806758460*x);
R0+=0.00000000041*cost(6.17532984460+65236.22129328540*x);
R0+=0.00000000052*cost(1.29052331493+90394.82301305079*x);
R0+=0.00000000039*cost(0.70253732683+18093.37469954999*x);
R0+=0.00000000052*cost(1.18164377451+10211.80107350270*x);
R0+=0.00000000047*cost(1.78672260794+10401.21069397360*x);
R0+=0.00000000040*cost(3.66961416802+10198.03307502600*x);
R0+=0.00000000051*cost(2.71698589018+94325.03270927040*x);
R0+=0.00000000036*cost(1.25091711620+10323.49186743040*x);
R0+=0.00000000049*cost(1.21335959420+9721.62225375220*x);
R0+=0.00000000042*cost(6.05968230173+105460.99111839019*x);
R0+=0.00000000046*cost(5.06978748275+20350.30502114640*x);
R0+=0.00000000040*cost(1.97645050921+32243.49850088060*x);
R0+=0.00000000036*cost(4.96702216961+36301.18868778519*x);
R0+=0.00000000037*cost(5.29642935562+38.02767263580*x);
R0+=0.00000000039*cost(0.52064327313+26709.64694241340*x);
R0+=0.00000000035*cost(2.34112124655+58946.51688439399*x);
R0+=0.00000000034*cost(1.82989750626+17675.02349273040*x);
R0+=0.00000000034*cost(0.76493664110+55798.45835839840*x);
R0+=0.00000000035*cost(1.09353675147+69159.80243060499*x);
R0+=0.00000000031*cost(5.59148330297+10639.88373708700*x);
R0+=0.00000000032*cost(3.32960781870+71519.29714327680*x);
R0+=0.00000000031*cost(5.98191446392+24341.52831745660*x);
R0+=0.00000000031*cost(0.68615213145+10202.23984594710*x);
R0+=0.00000000030*cost(4.42039942947+10459.11719244040*x);
R0+=0.00000000029*cost(1.30367701539+20103.06567576459*x);
R0+=0.00000000031*cost(4.51793347997+2957.71589447660*x);
R0+=0.00000000035*cost(4.05634321290+19903.99367432819*x);
R0+=0.00000000030*cost(1.32113757427+574.34479833480*x);
R0+=0.00000000029*cost(3.36506645849+10288.06714477830*x);
R0+=0.00000000029*cost(1.40019042576+9988.94075050910*x);
R0+=0.00000000032*cost(0.21932095318+24978.52458948080*x);
R0+=0.00000000034*cost(5.22945947227+8673.96967639900*x);
R0+=0.00000000039*cost(4.50883171158+16004.69810374360*x);
R0+=0.00000000028*cost(2.32945945641+11392.48008525060*x);
R0+=0.00000000034*cost(3.92498967835+536.80451209540*x);
R0+=0.00000000032*cost(5.46972716255+64607.84893354619*x);
R0+=0.00000000028*cost(2.38858990128+20235.12282631040*x);
R0+=0.00000000030*cost(3.34585843979+39793.76025465480*x);
R0+=0.00000000026*cost(5.36096904409+1478.86657406440*x);

double R1=0;
R1+=0.00034551039*cost(0.89198710598+10213.28554621100*x);
R1+=0.00000234203*cost(1.77224942714+20426.57109242200*x);
R1-=0.00000233998;
R1+=0.00000023864*cost(1.11274502648+9437.76293488700*x);
R1+=0.00000010568*cost(4.59168210921+1577.34354244780*x);
R1+=0.00000009124*cost(4.53540907003+10404.73381232260*x);
R1+=0.00000006599*cost(5.97703999838+5507.55323866740*x);
R1+=0.00000004667*cost(3.87683960551+9153.90361602180*x);
R1+=0.00000003840*cost(5.66196924375+13367.97263110660*x);
R1+=0.00000002666*cost(2.82413291285+10206.17199921020*x);
R1+=0.00000002194*cost(2.05314419626+775.52261132400*x);
R1+=0.00000002094*cost(2.55137285015+18837.49819713819*x);
R1+=0.00000001782*cost(2.64808558644+30639.85663863300*x);
R1+=0.00000001845*cost(1.87612936641+11015.10647733480*x);
R1+=0.00000001303*cost(0.20613045603+11322.66409830440*x);
R1+=0.00000001169*cost(0.79431893441+17298.18232732620*x);
R1+=0.00000001001*cost(6.16555101536+10239.58386601080*x);
R1+=0.00000000915*cost(4.59854496966+1109.37855209340*x);
R1+=0.00000000884*cost(0.66706834422+18073.70493865020*x);
R1+=0.00000000849*cost(5.58641571940+12566.15169998280*x);
R1+=0.00000001071*cost(4.94792017474+6283.07584999140*x);
R1+=0.00000000887*cost(2.47785193216+3154.68708489560*x);
R1+=0.00000000904*cost(0.81413053841+10596.18207843420*x);
R1+=0.00000000818*cost(0.90016838097+5661.33204915220*x);
R1+=0.00000000845*cost(5.48504338112+529.69096509460*x);
R1+=0.00000000824*cost(3.74837629121+7084.89678111520*x);
R1+=0.00000000652*cost(5.07444932607+22003.91463486980*x);
R1+=0.00000000847*cost(0.44119876869+8635.94200376320*x);
R1+=0.00000000638*cost(4.10125791268+191.44826611160*x);
R1+=0.00000000615*cost(3.14417599741+10186.98722641120*x);
R1+=0.00000000527*cost(5.86792949279+2352.86615377180*x);
R1+=0.00000000520*cost(5.33201358267+14143.49524243060*x);
R1+=0.00000000576*cost(2.25212731258+21228.39202354580*x);
R1+=0.00000000662*cost(2.86880467345+8624.21265092720*x);
R1+=0.00000000554*cost(2.17186191243+18307.80723204360*x);
R1+=0.00000000515*cost(4.34331395104+9786.68735533500*x);
R1+=0.00000000501*cost(5.56479589366+10742.97651130560*x);
R1+=0.00000000426*cost(1.02161443120+7064.12138562280*x);
R1+=0.00000000418*cost(1.26803034691+9676.48103411560*x);
R1+=0.00000000391*cost(0.78974645621+9690.70812811720*x);
R1+=0.00000000334*cost(3.18175822557+10988.80815753500*x);
R1+=0.00000000375*cost(0.66142254036+19360.07561523199*x);
R1+=0.00000000364*cost(0.19369831864+19374.30270923360*x);
R1+=0.00000000313*cost(1.09734397626+4551.95349705880*x);
R1+=0.00000000330*cost(0.58817502306+16496.36139620240*x);
R1+=0.00000000339*cost(5.76768761396+10021.83728009940*x);
R1+=0.00000000291*cost(3.65846764668+25158.60171976540*x);
R1+=0.00000000223*cost(4.33581625553+19786.67380610799*x);
R1+=0.00000000266*cost(3.57408827667+801.82093112380*x);
R1+=0.00000000274*cost(5.73346687248+11790.62908865880*x);
R1+=0.00000000275*cost(5.65814317085+19896.88012732740*x);
R1+=0.00000000212*cost(4.27038489878+4705.73230754360*x);
R1+=0.00000000230*cost(6.13406345590+1059.38193018920*x);
R1+=0.00000000204*cost(4.87348390351+7860.41939243920*x);
R1+=0.00000000241*cost(1.13551531894+26.29831979980*x);
R1+=0.00000000206*cost(0.31907973682+382.89653222320*x);
R1+=0.00000000216*cost(2.54741101724+19651.04848109800*x);
R1+=0.00000000212*cost(3.15264941106+14945.31617355440*x);
R1+=0.00000000163*cost(1.13604744392+13936.79450513400*x);
R1+=0.00000000151*cost(5.11341268743+28521.09277825460*x);
R1+=0.00000000151*cost(0.81278755582+6770.71060124560*x);
R1+=0.00000000150*cost(5.02227334847+29088.81141598500*x);
R1+=0.00000000146*cost(1.37568138685+10220.39909321180*x);
R1+=0.00000000127*cost(4.49298610074+3532.06069281140*x);
R1+=0.00000000121*cost(6.26589208179+29580.47470844380*x);
R1+=0.00000000147*cost(6.16092774714+8662.24032356300*x);
R1+=0.00000000114*cost(0.00114012635+25934.12433108940*x);
R1+=0.00000000115*cost(3.56897715344+24356.78078864160*x);
R1+=0.00000000124*cost(0.67547060274+3723.50895892300*x);
R1+=0.00000000145*cost(0.36415036222+9146.79006902100*x);
R1+=0.00000000104*cost(4.27865011376+9573.38825989700*x);
R1+=0.00000000136*cost(5.09581116181+19367.18916223280*x);
R1+=0.00000000102*cost(1.53637788668+17277.40693183380*x);
R1+=0.00000000117*cost(0.57543238496+9999.98645077300*x);
R1+=0.00000000092*cost(0.22936081655+18830.38465013739*x);
R1+=0.00000000112*cost(4.04771058036+9103.90699411760*x);
R1+=0.00000000098*cost(3.78447692407+213.29909543800*x);
R1+=0.00000000085*cost(5.84471458481+10234.06094170340*x);
R1+=0.00000000079*cost(0.64440357793+18844.61174413899*x);
R1+=0.00000000084*cost(0.56950139213+9683.59458111640*x);
R1+=0.00000000107*cost(1.77067111589+17778.11626694899*x);
R1+=0.00000000081*cost(6.19048382717+20618.01935853360*x);
R1+=0.00000000087*cost(0.15771136594+33019.02111220460*x);
R1+=0.00000000082*cost(4.80683817059+3930.20969621960*x);
R1+=0.00000000086*cost(2.21505615071+8094.52168583260*x);
R1+=0.00000000064*cost(2.69215119482+16983.99614745660*x);
R1+=0.00000000069*cost(0.83385751986+3128.38876509580*x);
R1+=0.00000000081*cost(4.88025042367+4732.03062734340*x);
R1+=0.00000000059*cost(3.34348033725+10787.63034454580*x);
R1+=0.00000000061*cost(0.04044699966+9161.01716302260*x);
R1+=0.00000000064*cost(4.13127333938+9992.87290377220*x);
R1+=0.00000000060*cost(6.24603986632+32217.20018108080*x);
R1+=0.00000000054*cost(3.38449893196+10426.58464164900*x);
R1+=0.00000000054*cost(5.15939119644+28286.99048486120*x);
R1+=0.00000000063*cost(4.32339245083+12592.45001978260*x);
R1+=0.00000000060*cost(4.48753846170+18875.52586977400*x);
R1+=0.00000000057*cost(3.64912085313+10007.09999777380*x);
R1+=0.00000000049*cost(5.10267262491+19573.37471066999*x);
R1+=0.00000000047*cost(5.79444960738+68050.42387851159*x);
R1+=0.00000000052*cost(3.56658420552+7255.56965173440*x);
R1+=0.00000000050*cost(1.61783309819+36949.23080842420*x);
R1+=0.00000000053*cost(2.64370544855+15874.61759536320*x);
R1+=0.00000000040*cost(3.93466530964+20419.45754542119*x);
R1+=0.00000000051*cost(0.79154899901+23581.25817731760*x);
R1+=0.00000000038*cost(1.77428239418+10103.07922499160*x);
R1+=0.00000000049*cost(1.12423644455+3442.57494496540*x);
R1+=0.00000000040*cost(5.22874487975+21535.94964451540*x);
R1+=0.00000000038*cost(1.12473430132+7.11354700080*x);
R1+=0.00000000038*cost(0.11510547453+11272.66747640020*x);
R1+=0.00000000036*cost(2.02476324983+7058.59846131540*x);
R1+=0.00000000047*cost(0.05589432390+12432.04265039780*x);
R1+=0.00000000034*cost(3.45481114998+9830.38901398780*x);
R1+=0.00000000045*cost(4.59817214088+10192.51015071860*x);
R1+=0.00000000037*cost(4.93959675364+3340.61242669980*x);
R1+=0.00000000044*cost(0.70533027806+20213.27199698400*x);
R1+=0.00000000034*cost(2.16487642765+64460.69868196140*x);
R1+=0.00000000031*cost(1.57612397319+36147.40987730040*x);
R1+=0.00000000028*cost(2.56454760402+94138.32702008578*x);
R1+=0.00000000033*cost(1.08907268562+29864.33402730900*x);
R1+=0.00000000029*cost(0.59718407064+59728.66805461800*x);
R1+=0.00000000031*cost(3.04423979263+40879.44050464380*x);
R1+=0.00000000035*cost(0.32247158762+1589.07289528380*x);
R1+=0.00000000031*cost(3.27727318906+19992.85935454519*x);
R1+=0.00000000027*cost(5.83705748551+17085.95866572220*x);
R1+=0.00000000032*cost(2.64260788260+41962.52073693740*x);
R1+=0.00000000028*cost(4.90613317287+29050.78374334920*x);
R1+=0.00000000025*cost(4.55050389739+14919.01785375460*x);
R1+=0.00000000028*cost(3.58851614957+40853.14218484400*x);
R1+=0.00000000029*cost(2.79705093386+20007.08644854680*x);
R1+=0.00000000033*cost(0.93862065616+15720.83878487840*x);
R1+=0.00000000024*cost(2.74970637101+18947.70451835760*x);
R1+=0.00000000024*cost(4.38966861409+46386.99374331120*x);
R1+=0.00000000024*cost(0.73361964525+9411.46461508720*x);
R1+=0.00000000028*cost(4.19559784013+37674.99639427640*x);
R1+=0.00000000023*cost(1.00023735538+22779.43724619380*x);
R1+=0.00000000026*cost(0.46990555736+13745.34623902240*x);
R1+=0.00000000028*cost(4.65181292126+1551.04522264800*x);
R1+=0.00000000025*cost(4.18690270765+44007.82926973960*x);
R1+=0.00000000022*cost(0.98102807789+426.59819087600*x);
R1+=0.00000000030*cost(1.24986033487+27461.71084806540*x);
R1+=0.00000000027*cost(3.94986823486+17468.85519794540*x);
R1+=0.00000000021*cost(6.09897508157+18300.69368504279*x);
R1+=0.00000000025*cost(4.75875623888+27991.40181316000*x);
R1+=0.00000000022*cost(2.95281481673+40077.61957352000*x);
R1+=0.00000000028*cost(6.12038264955+38500.27603107220*x);
R1+=0.00000000022*cost(4.11184201321+19779.56025910719*x);
R1+=0.00000000027*cost(3.72446446080+19793.78735310880*x);
R1+=0.00000000020*cost(4.27086627368+31441.67756975680*x);
R1+=0.00000000022*cost(4.99040169444+31022.75317085620*x);
R1+=0.00000000023*cost(1.33505132122+65236.22129328540*x);
R1+=0.00000000021*cost(4.46897353468+53285.18483524180*x);
R1+=0.00000000020*cost(4.15140915983+2218.75710418680*x);
R1+=0.00000000025*cost(2.18447182965+27511.46787353720*x);
R1+=0.00000000019*cost(1.43653410349+27197.28169366760*x);
R1+=0.00000000027*cost(1.22555218015+42430.48572729180*x);
R1+=0.00000000019*cost(3.65054338893+49515.38250840700*x);
R1+=0.00000000022*cost(5.88380811711+10218.80847051840*x);
R1+=0.00000000018*cost(2.29853355765+19264.09638801420*x);
R1+=0.00000000017*cost(5.44429906531+6681.22485339960*x);
R1+=0.00000000020*cost(3.68116637773+14128.24277124560*x);
R1+=0.00000000021*cost(4.30316190532+44809.65020086340*x);
R1+=0.00000000020*cost(2.48583613985+33794.54372352860*x);
R1+=0.00000000017*cost(3.02735393984+28528.20632525540*x);
R1+=0.00000000019*cost(5.92656850674+22805.73556599360*x);
R1+=0.00000000022*cost(5.30827572791+10207.76262190360*x);
R1+=0.00000000020*cost(0.75829381378+18314.92077904440*x);
R1+=0.00000000017*cost(5.63315744126+16522.65971600220*x);
R1+=0.00000000016*cost(1.71021408448+536.80451209540*x);
R1+=0.00000000015*cost(5.27016880041+53445.59220462660*x);
R1+=0.00000000017*cost(5.61443395877+47938.03896595920*x);
R1+=0.00000000015*cost(5.81110284451+43071.89928903080*x);
R1+=0.00000000015*cost(4.96237667003+19999.97290154599*x);
R1+=0.00000000018*cost(0.55618686515+14765.23904326980*x);
R1+=0.00000000014*cost(3.48144272414+29786.66025688100*x);
R1+=0.00000000015*cost(5.84132627836+10228.53801739600*x);
R1+=0.00000000016*cost(1.05720065324+26735.94526221320*x);
R1+=0.00000000014*cost(6.08462030302+35371.88726597640*x);
R1+=0.00000000014*cost(2.84532871890+574.34479833480*x);
R1+=0.00000000015*cost(5.34517715140+10198.03307502600*x);
R1+=0.00000000013*cost(0.45004137509+20452.86941222180*x);

double R2=0;
R2+=0.00001406587*cost(5.06366395190+10213.28554621100*x);
R2+=0.00000015529*cost(5.47321687981+20426.57109242200*x);
R2+=0.00000013059;
R2+=0.00000001099*cost(2.78883988292+9437.76293488700*x);
R2+=0.00000000488*cost(6.27806914496+1577.34354244780*x);
R2+=0.00000000361*cost(6.11914188253+10404.73381232260*x);
R2+=0.00000000310*cost(1.38984998403+5507.55323866740*x);
R2+=0.00000000389*cost(1.95017779915+11015.10647733480*x);
R2+=0.00000000372*cost(2.33222828423+775.52261132400*x);
R2+=0.00000000207*cost(5.63406721595+10239.58386601080*x);
R2+=0.00000000168*cost(1.10765197296+13367.97263110660*x);
R2+=0.00000000175*cost(6.16674652950+30639.85663863300*x);
R2+=0.00000000168*cost(3.64495311632+7084.89678111520*x);
R2+=0.00000000120*cost(5.85815843789+9153.90361602180*x);
R2+=0.00000000160*cost(2.21564938463+3154.68708489560*x);
R2+=0.00000000118*cost(2.62358866565+8635.94200376320*x);
R2+=0.00000000112*cost(2.36235956804+10596.18207843420*x);
R2+=0.00000000092*cost(0.72664449269+12566.15169998280*x);
R2+=0.00000000067*cost(3.76089669118+18837.49819713819*x);
R2+=0.00000000065*cost(2.47983709990+11790.62908865880*x);
R2+=0.00000000048*cost(4.26620187144+2352.86615377180*x);
R2+=0.00000000048*cost(5.50898189550+191.44826611160*x);
R2+=0.00000000048*cost(2.54730918293+17298.18232732620*x);
R2+=0.00000000046*cost(3.40293459332+14143.49524243060*x);
R2+=0.00000000041*cost(1.83997113019+11322.66409830440*x);
R2+=0.00000000037*cost(6.17871126027+1109.37855209340*x);
R2+=0.00000000039*cost(4.77190210316+18073.70493865020*x);
R2+=0.00000000035*cost(3.10133256432+4705.73230754360*x);
R2+=0.00000000046*cost(3.30090415967+6283.07584999140*x);
R2+=0.00000000034*cost(3.91721765773+10021.83728009940*x);
R2+=0.00000000034*cost(3.24663787383+22003.91463486980*x);
R2+=0.00000000042*cost(3.39360926939+14945.31617355440*x);
R2+=0.00000000044*cost(4.42979374073+7860.41939243920*x);
R2+=0.00000000034*cost(2.16381407025+16496.36139620240*x);
R2+=0.00000000031*cost(0.45714618479+26.29831979980*x);
R2+=0.00000000035*cost(3.62868651241+801.82093112380*x);
R2+=0.00000000032*cost(1.84138997078+382.89653222320*x);
R2+=0.00000000025*cost(3.32908650295+18307.80723204360*x);
R2+=0.00000000026*cost(3.64313769818+29088.81141598500*x);
R2+=0.00000000029*cost(3.82967178810+10186.98722641120*x);
R2+=0.00000000022*cost(3.17741520378+28521.09277825460*x);
R2+=0.00000000021*cost(2.52643834111+529.69096509460*x);
R2+=0.00000000025*cost(5.71401244457+21202.09370374600*x);
R2+=0.00000000021*cost(3.77813434325+21228.39202354580*x);
R2+=0.00000000019*cost(5.24505118517+19896.88012732740*x);
R2+=0.00000000018*cost(4.62463651925+19651.04848109800*x);
R2+=0.00000000016*cost(3.35893297896+28286.99048486120*x);
R2+=0.00000000015*cost(5.05571633205+33019.02111220460*x);
R2+=0.00000000014*cost(2.83786355803+19786.67380610799*x);
R2+=0.00000000014*cost(1.79922718553+9830.38901398780*x);
R2+=0.00000000014*cost(3.14801263138+19367.18916223280*x);
R2+=0.00000000014*cost(3.57896195191+10988.80815753500*x);
R2+=0.00000000013*cost(3.06303088617+10742.97651130560*x);
R2+=0.00000000013*cost(5.43981998532+25158.60171976540*x);
R2+=0.00000000015*cost(4.83166312889+18875.52586977400*x);
R2+=0.00000000012*cost(2.54141086214+7064.12138562280*x);
R2+=0.00000000012*cost(4.45255110769+15720.83878487840*x);
R2+=0.00000000010*cost(1.87933121728+24356.78078864160*x);
R2+=0.00000000011*cost(2.58708635685+9103.90699411760*x);
R2+=0.00000000010*cost(2.17901309900+3723.50895892300*x);
R2+=0.00000000008*cost(3.63520673832+1059.38193018920*x);
R2+=0.00000000008*cost(4.67523115598+25934.12433108940*x);
R2+=0.00000000009*cost(5.97856553283+9683.59458111640*x);

double R3=0;
R3+=0.00000049582*cost(3.22263554520+10213.28554621100*x);
R3+=0.00000000831*cost(3.21219077104+20426.57109242200*x);
R3-=0.00000000112;
R3+=0.00000000013*cost(3.77448689585+30639.85663863300*x);
R3+=0.00000000009*cost(4.19802043629+10239.58386601080*x);
R3+=0.00000000006*cost(0.20714935358+10186.98722641120*x);
R3+=0.00000000005*cost(0.68781956122+8635.94200376320*x);

double R4=0;
R4+=0.00000000573*cost(0.92229697820+10213.28554621100*x);
R4+=0.00000000040*cost(0.95468912157+20426.57109242200*x);
R4-=0.00000000006;

double R5=0;
R5+=0.00000000045*cost(0.30032866722+10213.28554621100*x);
R5+=0.00000000002*cost(5.29627718483+20426.57109242200*x);	

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
	
return (R0+R1*x+R2*x2+R3*x3+R4*x4+R5*x5); //END venus
}


//Heliocentric longitude of Mars
double Lmars(double x)
{
double L0=0;
L0+=6.20347711583;
L0+=0.18656368100*cost(5.05037100303+3340.61242669980*x);
L0+=0.01108216792*cost(5.40099836958+6681.22485339960*x);
L0+=0.00091798394*cost(5.75478745111+10021.83728009940*x);
L0+=0.00027744987*cost(5.97049512942+3.52311834900*x);
L0+=0.00010610230*cost(2.93958524973+2281.23049651060*x);
L0+=0.00012315897*cost(0.84956081238+2810.92146160520*x);
L0+=0.00008926772*cost(4.15697845939+0.01725365220*x);
L0+=0.00008715688*cost(6.11005159792+13362.44970679920*x);
L0+=0.00006797552*cost(0.36462243626+398.14900340820*x);
L0+=0.00007774867*cost(3.33968655074+5621.84292321040*x);
L0+=0.00003575079*cost(1.66186540141+2544.31441988340*x);
L0+=0.00004161101*cost(0.22814975330+2942.46342329160*x);
L0+=0.00003075250*cost(0.85696597082+191.44826611160*x);
L0+=0.00002628122*cost(0.64806143570+3337.08930835080*x);
L0+=0.00002937543*cost(6.07893711408+0.06731030280*x);
L0+=0.00002389420*cost(5.03896401349+796.29800681640*x);
L0+=0.00002579842*cost(0.02996706197+3344.13554504880*x);
L0+=0.00001528140*cost(1.14979306228+6151.53388830500*x);
L0+=0.00001798808*cost(0.65634026844+529.69096509460*x);
L0+=0.00001264356*cost(3.62275092231+5092.15195811580*x);
L0+=0.00001286232*cost(3.06795924626+2146.16541647520*x);
L0+=0.00001546408*cost(2.91579633392+1751.53953141600*x);
L0+=0.00001024907*cost(3.69334293555+8962.45534991020*x);
L0+=0.00000891567*cost(0.18293899090+16703.06213349900*x);
L0+=0.00000858760*cost(2.40093704204+2914.01423582380*x);
L0+=0.00000832718*cost(2.46418591282+3340.59517304760*x);
L0+=0.00000832724*cost(4.49495753458+3340.62968035200*x);
L0+=0.00000712899*cost(3.66336014788+1059.38193018920*x);
L0+=0.00000748724*cost(3.82248399468+155.42039943420*x);
L0+=0.00000723863*cost(0.67497565801+3738.76143010800*x);
L0+=0.00000635557*cost(2.92182704275+8432.76438481560*x);
L0+=0.00000655163*cost(0.48864075176+3127.31333126180*x);
L0+=0.00000550472*cost(3.81001205408+0.98032106820*x);
L0+=0.00000552746*cost(4.47478863016+1748.01641306700*x);
L0+=0.00000425972*cost(0.55365138172+6283.07584999140*x);
L0+=0.00000415132*cost(0.49662314774+213.29909543800*x);
L0+=0.00000472164*cost(3.62547819410+1194.44701022460*x);
L0+=0.00000306552*cost(0.38052862973+6684.74797174860*x);
L0+=0.00000312141*cost(0.99853322843+6677.70173505060*x);
L0+=0.00000293199*cost(4.22131277914+20.77539549240*x);
L0+=0.00000302377*cost(4.48618150321+3532.06069281140*x);
L0+=0.00000274028*cost(0.54222141841+3340.54511639700*x);
L0+=0.00000281073*cost(5.88163372945+1349.86740965880*x);
L0+=0.00000231185*cost(1.28240685294+3870.30339179440*x);
L0+=0.00000283600*cost(5.76885494123+3149.16416058820*x);
L0+=0.00000236114*cost(5.75504515576+3333.49887969900*x);
L0+=0.00000274035*cost(0.13372501211+3340.67973700260*x);
L0+=0.00000299396*cost(2.78323705697+6254.62666252360*x);
L0+=0.00000204161*cost(2.82133266185+1221.84856632140*x);
L0+=0.00000238857*cost(5.37155471672+4136.91043351620*x);
L0+=0.00000188639*cost(1.49103016486+9492.14631500480*x);
L0+=0.00000221225*cost(3.50466672203+382.89653222320*x);
L0+=0.00000179196*cost(1.00561112574+951.71840625060*x);
L0+=0.00000172110*cost(0.43943041719+5486.77784317500*x);
L0+=0.00000193126*cost(3.35715137745+3.59042865180*x);
L0+=0.00000144305*cost(1.41874193418+135.06508003540*x);
L0+=0.00000160011*cost(3.94854735192+4562.46099302120*x);
L0+=0.00000174068*cost(2.41360332576+553.56940284240*x);
L0+=0.00000130993*cost(4.04491720264+12303.06777661000*x);
L0+=0.00000138245*cost(4.30145176915+7.11354700080*x);
L0+=0.00000128062*cost(1.80665643332+5088.62883976680*x);
L0+=0.00000139897*cost(3.32592516164+2700.71514038580*x);
L0+=0.00000128102*cost(2.20806651008+1592.59601363280*x);
L0+=0.00000116945*cost(3.12805282207+7903.07341972100*x);
L0+=0.00000110375*cost(1.05195079687+242.72860397400*x);
L0+=0.00000113486*cost(3.70070798123+1589.07289528380*x);
L0+=0.00000100090*cost(3.24343740861+11773.37681151540*x);
L0+=0.00000095592*cost(0.53954181149+20043.67456019880*x);
L0+=0.00000098947*cost(4.84558294740+6681.24210705180*x);
L0+=0.00000104541*cost(0.78535382076+8827.39026987480*x);
L0+=0.00000084187*cost(3.98970720730+4399.99435688900*x);
L0+=0.00000086931*cost(2.20186740523+11243.68584642080*x);
L0+=0.00000071437*cost(2.80307550016+3185.19202726560*x);
L0+=0.00000072091*cost(5.84672102525+5884.92684658320*x);
L0+=0.00000073476*cost(2.18428012567+8429.24126646660*x);
L0+=0.00000098946*cost(2.81481140371+6681.20759974740*x);
L0+=0.00000068414*cost(2.73834914412+2288.34404351140*x);
L0+=0.00000086751*cost(1.02092221563+7079.37385680780*x);
L0+=0.00000065320*cost(2.68118597578+28.44918746780*x);
L0+=0.00000083749*cost(3.20256130990+4690.47983635860*x);
L0+=0.00000075034*cost(0.76643418252+6467.92575796160*x);
L0+=0.00000068984*cost(3.76399731788+6041.32756708560*x);
L0+=0.00000066706*cost(0.73630620766+3723.50895892300*x);
L0+=0.00000063314*cost(4.52771470470+426.59819087600*x);
L0+=0.00000061683*cost(6.16831509419+2274.11694950980*x);
L0+=0.00000052256*cost(0.89941531307+9623.68827669120*x);
L0+=0.00000055488*cost(4.60625467020+4292.33083295040*x);
L0+=0.00000051332*cost(4.14823636534+3341.59274776800*x);
L0+=0.00000056629*cost(5.06250410206+15.25247118500*x);
L0+=0.00000063376*cost(0.91296240798+3553.91152213780*x);
L0+=0.00000045829*cost(0.78784235062+1990.74501704100*x);
L0+=0.00000048542*cost(3.95670418719+4535.05943692440*x);
L0+=0.00000041223*cost(6.02019329922+3894.18182954220*x);
L0+=0.00000041939*cost(3.58326425115+8031.09226305840*x);
L0+=0.00000056396*cost(1.68727150304+6872.67311951120*x);
L0+=0.00000055909*cost(3.46260833495+263.08392337280*x);
L0+=0.00000051678*cost(2.81307492682+3339.63210563160*x);
L0+=0.00000040671*cost(3.13832621829+9595.23908922340*x);
L0+=0.00000038107*cost(0.73401946320+10025.36039844840*x);
L0+=0.00000039495*cost(5.63225392160+3097.88382272579*x);
L0+=0.00000044174*cost(3.19529736702+5628.95647021120*x);
L0+=0.00000036716*cost(2.63720775102+692.15760122680*x);
L0+=0.00000045905*cost(0.28718981497+5614.72937620960*x);
L0+=0.00000038352*cost(5.82880707426+3191.04922956520*x);
L0+=0.00000038206*cost(2.34835984063+162.46663613220*x);
L0+=0.00000032562*cost(0.48400659333+6681.29216370240*x);
L0+=0.00000037135*cost(0.68508150774+2818.03500860600*x);
L0+=0.00000031168*cost(3.98160912982+20.35531939880*x);
L0+=0.00000032561*cost(0.89250316888+6681.15754309680*x);
L0+=0.00000037752*cost(4.15482955299+2803.80791460440*x);
L0+=0.00000033626*cost(6.11992401052+6489.77658728800*x);
L0+=0.00000029007*cost(2.42707385674+3319.83703120740*x);
L0+=0.00000038790*cost(1.35198498795+10018.31416175040*x);
L0+=0.00000033148*cost(1.14023770004+5.52292430740*x);
L0+=0.00000027584*cost(1.59691203058+7210.91581849420*x);
L0+=0.00000028686*cost(5.72055456734+7477.52286021600*x);
L0+=0.00000034031*cost(2.59544082509+11769.85369316640*x);
L0+=0.00000025380*cost(0.52093116112+10.63666534980*x);
L0+=0.00000026357*cost(1.34532646574+3496.03282613400*x);
L0+=0.00000024554*cost(4.00323183088+11371.70468975820*x);
L0+=0.00000025637*cost(0.24963523420+522.57741809380*x);
L0+=0.00000027278*cost(4.55645328122+3361.38782219220*x);
L0+=0.00000023764*cost(1.84058377256+12832.75874170460*x);
L0+=0.00000022816*cost(3.52628212106+1648.44675719740*x);
L0+=0.00000022274*cost(0.72106133721+266.60704172180*x);
L0+=0.00000021202*cost(3.11824472284+2957.71589447660*x);
L0+=0.00000020158*cost(3.67131504946+1758.65307841680*x);
L0+=0.00000021530*cost(6.15388757177+3264.34635542420*x);
L0+=0.00000020093*cost(1.08247416065+7064.12138562280*x);
L0+=0.00000021343*cost(4.28218757863+4032.77002792660*x);
L0+=0.00000027540*cost(6.08389942337+6674.11130639880*x);
L0+=0.00000019849*cost(2.37668920745+10713.99488132620*x);
L0+=0.00000025512*cost(3.43242352804+3443.70520091840*x);
L0+=0.00000022542*cost(5.64861703438+2388.89402044920*x);
L0+=0.00000024378*cost(0.96994696413+632.78373931320*x);
L0+=0.00000023079*cost(4.74990214223+3347.72597370060*x);
L0+=0.00000017709*cost(3.69742343974+3344.20285535160*x);
L0+=0.00000022662*cost(3.95446324417+4989.05918389720*x);
L0+=0.00000022604*cost(5.24082917494+3205.54734666440*x);
L0+=0.00000016811*cost(5.48619684111+3.88133535800*x);
L0+=0.00000018422*cost(4.22535881468+2787.04302385740*x);
L0+=0.00000022737*cost(4.98520896596+7632.94325965020*x);
L0+=0.00000016648*cost(2.52823633184+14584.29827312060*x);
L0+=0.00000020963*cost(4.27878216453+5099.26550511660*x);
L0+=0.00000016042*cost(1.76786752521+3475.67750673520*x);
L0+=0.00000015816*cost(3.13240869691+59.37386191360*x);
L0+=0.00000018113*cost(3.25756020453+3337.02199804800*x);
L0+=0.00000019295*cost(3.23911854642+7.04623669800*x);
L0+=0.00000016772*cost(4.39731507110+15643.68020330980*x);
L0+=0.00000017555*cost(4.09197396097+74.78159856730*x);
L0+=0.00000013704*cost(2.54117018160+4933.20844033260*x);
L0+=0.00000016011*cost(1.54669633224+14054.60730802600*x);
L0+=0.00000013547*cost(4.04152185347+4929.68532198360*x);
L0+=0.00000014566*cost(3.45210993051+7373.38245462640*x);
L0+=0.00000013926*cost(5.40797129468+10973.55568635000*x);
L0+=0.00000014246*cost(0.59808746067+23.87843774780*x);
L0+=0.00000014023*cost(1.44218648988+10404.73381232260*x);
L0+=0.00000016051*cost(3.79409950488+2118.76386037840*x);
L0+=0.00000013714*cost(3.59050634457+15113.98923821520*x);
L0+=0.00000018038*cost(4.25391532000+2487.41604494780*x);
L0+=0.00000015846*cost(0.56901288692+103.09277421860*x);
L0+=0.00000013403*cost(5.16920432994+10213.28554621100*x);
L0+=0.00000016069*cost(2.36895958451+3265.83082813250*x);
L0+=0.00000012773*cost(0.10483085657+7234.79425624200*x);
L0+=0.00000012199*cost(1.73079687044+36.02786667740*x);
L0+=0.00000012283*cost(5.19940030635+10021.85453375160*x);
L0+=0.00000011945*cost(5.47997890162+2921.12778282460*x);
L0+=0.00000011890*cost(4.76593905835+5828.02847164760*x);
L0+=0.00000012283*cost(3.16862882612+10021.82002644720*x);
L0+=0.00000013274*cost(6.17806905340+1744.42598441520*x);
L0+=0.00000011777*cost(5.72731550900+0.42007609361*x);
L0+=0.00000012340*cost(2.52146766331+2906.90068882300*x);
L0+=0.00000014458*cost(4.38010658432+316.39186965660*x);
L0+=0.00000010639*cost(3.45016942919+639.89728631400*x);
L0+=0.00000010925*cost(0.60397688999+5085.03841111500*x);
L0+=0.00000010645*cost(5.47696728127+419.48464387520*x);
L0+=0.00000010797*cost(1.37191539718+10419.98628350760*x);
L0+=0.00000010565*cost(1.09061610786+12168.00269657460*x);
L0+=0.00000009578*cost(4.89489266197+3230.40610548040*x);
L0+=0.00000009808*cost(5.83632873998+14314.16811304980*x);
L0+=0.00000009720*cost(6.28282606427+9225.53927328300*x);
L0+=0.00000009146*cost(1.10220667397+9808.53818466140*x);
L0+=0.00000012733*cost(1.79883375851+13745.34623902240*x);
L0+=0.00000009779*cost(3.60056884868+206.18554843720*x);
L0+=0.00000012156*cost(4.42295240981+14712.31711645800*x);
L0+=0.00000008801*cost(3.97218590685+170.67287061920*x);
L0+=0.00000010685*cost(4.33894776374+7740.60678358880*x);
L0+=0.00000010041*cost(1.38294666830+3583.34103067380*x);
L0+=0.00000008499*cost(4.29275471153+0.42988312670*x);
L0+=0.00000009882*cost(2.69148019691+36.60536530420*x);
L0+=0.00000010585*cost(0.89641284928+23384.28698689860*x);
L0+=0.00000008478*cost(2.86886131803+9381.93999378540*x);
L0+=0.00000009560*cost(4.33382353581+131.54196168640*x);
L0+=0.00000008433*cost(3.15239733970+6525.80445396540*x);
L0+=0.00000007517*cost(1.24476310635+6894.52394883760*x);
L0+=0.00000006753*cost(1.58869332894+6836.64525283380*x);
L0+=0.00000006666*cost(4.38910103043+66.48740891440*x);
L0+=0.00000006697*cost(5.77315870484+5202.35827933520*x);
L0+=0.00000006188*cost(1.57847967850+3325.35995551480*x);
L0+=0.00000008392*cost(2.90734956761+43.71891230500*x);
L0+=0.00000006427*cost(6.03333185624+574.34479833480*x);
L0+=0.00000006296*cost(0.06976040737+1964.83862685400*x);
L0+=0.00000006144*cost(5.43713363624+1861.74585263540*x);
L0+=0.00000008180*cost(0.43967386003+2707.82868738660*x);
L0+=0.00000006532*cost(1.24907069366+12964.30070339100*x);
L0+=0.00000007341*cost(4.95693808975+3767.21061757580*x);
L0+=0.00000006134*cost(3.16322441707+6680.24453233140*x);
L0+=0.00000005937*cost(4.22752447794+4459.36821880260*x);
L0+=0.00000005848*cost(4.30379700916+7875.67186362420*x);
L0+=0.00000005895*cost(0.77226207039+2699.73481931760*x);
L0+=0.00000005962*cost(3.01318151415+3369.06161416760*x);
L0+=0.00000006307*cost(1.77830983983+2178.13772229200*x);
L0+=0.00000006103*cost(4.49866000852+6682.20517446780*x);
L0+=0.00000005770*cost(0.96127853878+13916.01910964160*x);
L0+=0.00000005725*cost(4.93042706875+2384.32327072920*x);
L0+=0.00000007576*cost(6.16308742022+6531.66165626500*x);
L0+=0.00000007285*cost(0.52756973131+10575.40668294180*x);
L0+=0.00000005212*cost(3.48999909365+12935.85151592320*x);
L0+=0.00000005266*cost(4.51201042373+6144.42034130420*x);
L0+=0.00000006632*cost(3.48100908925+1118.75579210280*x);
L0+=0.00000005182*cost(3.25459432228+2391.43681773000*x);
L0+=0.00000005214*cost(0.01023839897+533.21408344360*x);
L0+=0.00000005436*cost(6.18510045571+8425.65083781480*x);
L0+=0.00000005491*cost(3.42235890731+3134.42687826260*x);
L0+=0.00000005773*cost(3.55190490896+8969.56889691100*x);
L0+=0.00000005093*cost(0.60873962999+8955.34180290940*x);
L0+=0.00000004798*cost(4.63144694279+4569.57454002200*x);
L0+=0.00000005773*cost(5.92316959013+640.87760738220*x);
L0+=0.00000005661*cost(0.75892958537+3120.19978426100*x);
L0+=0.00000004912*cost(1.70762118141+13358.92658845020*x);
L0+=0.00000005438*cost(4.29256867866+3503.07906283200*x);
L0+=0.00000004631*cost(3.34058594066+3116.26763099790*x);
L0+=0.00000005823*cost(2.39009621568+3302.47939106200*x);
L0+=0.00000005095*cost(1.12497131307+5331.35744374080*x);
L0+=0.00000004409*cost(1.38708732950+17256.63153634140*x);
L0+=0.00000004193*cost(0.19116539271+9830.38901398780*x);
L0+=0.00000004164*cost(0.43798301495+1066.49547719000*x);
L0+=0.00000004220*cost(1.69427060019+13524.91634293140*x);
L0+=0.00000005192*cost(3.63500646439+536.80451209540*x);
L0+=0.00000005664*cost(0.50446281443+5305.45105355380*x);
L0+=0.00000005264*cost(5.40031180025+3355.86489788480*x);
L0+=0.00000005403*cost(5.96867227489+3074.00538497800*x);
L0+=0.00000004046*cost(0.83826342101+10021.90459040220*x);
L0+=0.00000004153*cost(3.14497570817+8439.87793181640*x);
L0+=0.00000004820*cost(1.09025983917+13365.97282514820*x);
L0+=0.00000004906*cost(3.73078406569+1228.96211332220*x);
L0+=0.00000004576*cost(0.99344843456+6158.64743530580*x);
L0+=0.00000004211*cost(3.87091723842+3312.16323923200*x);
L0+=0.00000004917*cost(6.25051681717+17654.78053974960*x);
L0+=0.00000003597*cost(6.07298181151+10818.13528691580*x);
L0+=0.00000003547*cost(1.87663674277+17395.21973472580*x);
L0+=0.00000003734*cost(1.37011069213+3973.39616601300*x);
L0+=0.00000004422*cost(2.89974680697+6247.51311552280*x);
L0+=0.00000003975*cost(4.03441621102+1052.26838318840*x);
L0+=0.00000004466*cost(4.59188422424+5518.75014899180*x);
L0+=0.00000003445*cost(4.26610076208+3178.14579056760*x);
L0+=0.00000003607*cost(4.24527056399+8329.67161059700*x);
L0+=0.00000003511*cost(1.95133364438+10177.25767953360*x);
L0+=0.00000003300*cost(0.68865737747+149.56319713460*x);
L0+=0.00000003235*cost(3.90171358031+27.40155609680*x);
L0+=0.00000003946*cost(5.81982010903+6261.74020952440*x);
L0+=0.00000003387*cost(0.14377701728+10014.72373309860*x);
L0+=0.00000003374*cost(0.74722238154+6048.44111408640*x);
L0+=0.00000003090*cost(3.98540766861+2648.45482547300*x);
L0+=0.00000003821*cost(5.23987859516+5724.93569742900*x);
L0+=0.00000003026*cost(0.34314724795+220.41264243880*x);
L0+=0.00000004052*cost(1.24671617482+10021.76996979660*x);
L0+=0.00000002937*cost(0.73100893561+2.75151061100*x);
L0+=0.00000003084*cost(3.79925632319+169.58018313300*x);
L0+=0.00000004040*cost(2.91258200196+22747.29071487440*x);
L0+=0.00000003246*cost(4.90760526525+6702.00024889200*x);
L0+=0.00000003223*cost(0.92640008610+16865.52876963120*x);
L0+=0.00000002879*cost(1.47180601483+3346.13535100720*x);
L0+=0.00000003723*cost(0.49978317761+1.48447270830*x);
L0+=0.00000002798*cost(3.26910698548+9168.64089834740*x);
L0+=0.00000003347*cost(0.68791690253+3863.18984479360*x);
L0+=0.00000003440*cost(2.77706064625+6660.44945790720*x);
L0+=0.00000002798*cost(2.79673379094+16858.48253293320*x);
L0+=0.00000002753*cost(4.41190782119+3415.39402526710*x);
L0+=0.00000002703*cost(0.19222683184+3237.51965248120*x);
L0+=0.00000002719*cost(3.26628341377+3914.95722503460*x);
L0+=0.00000002941*cost(3.76169133143+6784.31762761820*x);
L0+=0.00000003078*cost(5.48104322207+3335.08950239240*x);
L0+=0.00000002701*cost(5.08537226206+6688.33840040040*x);
L0+=0.00000002606*cost(4.83032556909+4672.66731424060*x);
L0+=0.00000002883*cost(2.64068086362+3320.25710730100*x);
L0+=0.00000003089*cost(4.39619824300+1332.05488754080*x);
L0+=0.00000003438*cost(1.93467064449+10551.52824519400*x);
L0+=0.00000003433*cost(0.20933510815+6604.95878212400*x);
L0+=0.00000002513*cost(2.88151502604+17924.91069982040*x);
L0+=0.00000002683*cost(3.68680362407+3603.69635007260*x);
L0+=0.00000002696*cost(2.66931776730+10184.30391623160*x);
L0+=0.00000002386*cost(1.05710815775+3607.21946842160*x);
L0+=0.00000002444*cost(3.46901444423+6298.32832117640*x);
L0+=0.00000002566*cost(5.55941956468+6546.15977336420*x);
L0+=0.00000002354*cost(0.85896789940+3351.24909204960*x);
L0+=0.00000002304*cost(6.07210985790+1214.73501932060*x);
L0+=0.00000002387*cost(4.30419979225+3360.96774609859*x);
L0+=0.00000003109*cost(2.18099805904+16173.37116840440*x);
L0+=0.00000002907*cost(3.43894993113+2693.60159338500*x);
L0+=0.00000002550*cost(4.18354174372+3546.79797513700*x);
L0+=0.00000002991*cost(2.37500894603+13517.87010623340*x);
L0+=0.00000002508*cost(5.99249607455+5729.50644714900*x);
L0+=0.00000002202*cost(5.58486973955+664.75604513000*x);
L0+=0.00000002467*cost(2.81052575497+15110.46611986620*x);
L0+=0.00000002154*cost(3.59696831702+6677.63442474780*x);
L0+=0.00000002166*cost(3.35965682842+589.06482700820*x);
L0+=0.00000002112*cost(4.57048853017+6127.65545055720*x);
L0+=0.00000002178*cost(3.21663279493+20199.09495963300*x);
L0+=0.00000002260*cost(3.62776666288+7799.98064550240*x);
L0+=0.00000002703*cost(5.89441421026+6438.49624942560*x);
L0+=0.00000002201*cost(4.69972051344+17277.40693183380*x);
L0+=0.00000002131*cost(2.51801264340+1545.35398297880*x);
L0+=0.00000002093*cost(4.03688419630+6684.81528205140*x);
L0+=0.00000002249*cost(5.26171743929+5618.31980486140*x);
L0+=0.00000002117*cost(4.80404492675+3657.00429635640*x);
L0+=0.00000002265*cost(3.87401620754+110.20632121940*x);
L0+=0.00000002521*cost(4.21237950687+2494.52959194860*x);
L0+=0.00000002492*cost(6.10452779411+3329.97576135000*x);
L0+=0.00000002154*cost(4.59093274516+5625.36604155940*x);
L0+=0.00000001929*cost(1.21920197307+21.85082932640*x);
L0+=0.00000002343*cost(0.90613584736+227.47613278900*x);
L0+=0.00000001871*cost(2.03707390080+56.89837493560*x);
L0+=0.00000001894*cost(4.12432529517+3399.98628861340*x);
L0+=0.00000002271*cost(3.78951734652+7910.18696672180*x);
L0+=0.00000001876*cost(3.02034887080+4885.96640967860*x);
L0+=0.00000002145*cost(4.74972617629+18984.29263000960*x);
L0+=0.00000002035*cost(2.75110234296+128.01884333740*x);
L0+=0.00000001770*cost(2.73496011079+6606.44325483230*x);
L0+=0.00000001733*cost(1.70571779606+6.68366387410*x);
L0+=0.00000001743*cost(2.22986352012+17085.95866572220*x);
L0+=0.00000001723*cost(1.98207274526+735.87651353180*x);
L0+=0.00000001814*cost(0.92405242552+4555.34744602040*x);
L0+=0.00000001661*cost(3.07319305915+1692.16566950240*x);
L0+=0.00000002332*cost(5.05223613332+20618.01935853360*x);
L0+=0.00000001653*cost(3.86316179052+699.27114822760*x);
L0+=0.00000001890*cost(4.14080522607+5459.37628707820*x);
L0+=0.00000001680*cost(3.49750704538+3347.65866339780*x);
L0+=0.00000001909*cost(2.11478314309+6816.28993343500*x);
L0+=0.00000001918*cost(3.31232891649+3333.56619000180*x);
L0+=0.00000001707*cost(4.88386665097+3407.09983561420*x);
L0+=0.00000001577*cost(3.51777131580+13362.43245314700*x);
L0+=0.00000001827*cost(1.14937084769+2807.39834325620*x);
L0+=0.00000002094*cost(1.78938870686+20597.24396304120*x);
L0+=0.00000001577*cost(5.54854302324+13362.46696045140*x);
L0+=0.00000001677*cost(4.39073937265+8270.29774868340*x);
L0+=0.00000001561*cost(0.80246904730+3017.10701004240*x);
L0+=0.00000001552*cost(2.66876850182+3024.22055704320*x);
L0+=0.00000001708*cost(2.09721350898+2814.44457995420*x);
L0+=0.00000002109*cost(1.48733908496+2679.37949991880*x);
L0+=0.00000001547*cost(2.12956399169+661.23292678100*x);
L0+=0.00000001764*cost(5.90517079295+3326.38533269820*x);
L0+=0.00000001503*cost(4.34389183170+13936.79450513400*x);
L0+=0.00000001504*cost(0.83367652471+4775.76008845920*x);
L0+=0.00000001543*cost(5.82417982389+3344.49376205780*x);
L0+=0.00000001458*cost(1.42630589706+15508.61512327440*x);
L0+=0.00000001648*cost(2.88801518612+8273.82086703240*x);
L0+=0.00000001527*cost(1.10261249454+2675.85638156980*x);
L0+=0.00000001800*cost(5.17144672709+38.13303563780*x);
L0+=0.00000001439*cost(0.48751113425+76.26607127560*x);
L0+=0.00000001478*cost(4.63008666184+19800.94595622480*x);
L0+=0.00000001770*cost(2.18315009072+2301.58581590939*x);
L0+=0.00000001712*cost(2.60291779744+29.42950853600*x);
L0+=0.00000001416*cost(2.46912016889+2597.62236616720*x);
L0+=0.00000001835*cost(3.93223068469+6843.69148953180*x);
L0+=0.00000001437*cost(3.48241890037+3281.23856478620*x);
L0+=0.00000001385*cost(4.18004525683+2284.75361485960*x);
L0+=0.00000001479*cost(3.88994194685+6034.21402008480*x);
L0+=0.00000001469*cost(2.91808856545+12722.55242048520*x);
L0+=0.00000001824*cost(3.94139541752+18454.60166491500*x);
L0+=0.00000001368*cost(1.71899681607+13760.59871020740*x);
L0+=0.00000001406*cost(2.42916192473+853.19638175200*x);
L0+=0.00000001361*cost(4.69126219798+11081.21921028860*x);
L0+=0.00000001375*cost(4.90787845983+3304.58456002240*x);
L0+=0.00000001544*cost(3.23251603238+156.40072050240*x);
L0+=0.00000001543*cost(1.13497136095+3336.73109134180*x);
L0+=0.00000001385*cost(2.90281983822+1581.95934828300*x);
L0+=0.00000001311*cost(6.21748423079+2547.83753823240*x);
L0+=0.00000001377*cost(2.56537541792+568.82187402740*x);
L0+=0.00000001474*cost(4.65215247212+394.62588505920*x);
L0+=0.00000001619*cost(0.07481583409+1435.14766175940*x);
L0+=0.00000001369*cost(0.08979359617+7895.95987272020*x);
L0+=0.00000001272*cost(5.84659079053+21.33564046700*x);
L0+=0.00000001331*cost(3.80007277718+13119.72110282519*x);
L0+=0.00000001202*cost(5.90681878458+187.92514776260*x);
L0+=0.00000001284*cost(5.30205682052+6571.01853218020*x);
L0+=0.00000001468*cost(5.91503888421+3339.12795399150*x);
L0+=0.00000001497*cost(2.57629850836+151.89728108520*x);
L0+=0.00000001270*cost(4.08996241400+4356.27544458400*x);
L0+=0.00000001159*cost(0.00546309207+799.82112516540*x);
L0+=0.00000001154*cost(1.81024985603+158.94351778320*x);
L0+=0.00000001170*cost(4.15567553953+14.22709400160*x);
L0+=0.00000001349*cost(0.39391022745+2540.79130153440*x);
L0+=0.00000001403*cost(4.89956428847+4039.88357492740*x);
L0+=0.00000001188*cost(3.46422365287+1015.66301788420*x);
L0+=0.00000001136*cost(5.54132891775+13553.89797291080*x);
L0+=0.00000001282*cost(4.52288421340+3929.67725370800*x);
L0+=0.00000001124*cost(1.40102701439+13149.15061136120*x);
L0+=0.00000001254*cost(3.84775964741+3980.50971301380*x);
L0+=0.00000001121*cost(5.04552583589+23141.55838292460*x);
L0+=0.00000001088*cost(0.89388884633+3340.19235060619*x);
L0+=0.00000001476*cost(4.20852908107+16460.33352952499*x);
L0+=0.00000001084*cost(5.70551481838+3760.09707057500*x);
L0+=0.00000001197*cost(1.24543578245+26724.89941359840*x);
L0+=0.00000001253*cost(5.82286965998+3344.54457996290*x);
L0+=0.00000001078*cost(6.24742453183+17.81252211800*x);
L0+=0.00000001462*cost(2.27467510211+369.69981594040*x);
L0+=0.00000001044*cost(4.34158344243+2277.70737816160*x);
L0+=0.00000001099*cost(4.08747611117+802.36392244620*x);
L0+=0.00000001122*cost(4.31726854418+107.66352393860*x);
L0+=0.00000001148*cost(0.42666214138+949.17560896980*x);
L0+=0.00000001183*cost(0.31560034120+1162.47470440780*x);
L0+=0.00000001130*cost(3.46061330657+5732.04924442980*x);
L0+=0.00000001059*cost(1.34075999078+2149.68853482420*x);
L0+=0.00000001126*cost(5.22902222299+194.97138446060*x);
L0+=0.00000000977*cost(3.44426658417+9779.10867612540*x);
L0+=0.00000001134*cost(0.13507173479+12566.15169998280*x);
L0+=0.00000001185*cost(3.65682936623+6456.88005769770*x);
L0+=0.00000000962*cost(4.85370284827+3510.19260983280*x);
L0+=0.00000001033*cost(2.47380728164+31.97230581680*x);
L0+=0.00000001172*cost(1.72927931309+6923.95345737360*x);
L0+=0.00000000986*cost(1.05152205629+16335.83780453660*x);
L0+=0.00000001292*cost(6.02388659607+3316.73398895200*x);
L0+=0.00000000932*cost(1.56812178735+111.18664228760*x);
L0+=0.00000001130*cost(2.06879370733+3376.64029337720*x);
L0+=0.00000000924*cost(0.82106390115+3364.49086444760*x);
L0+=0.00000001005*cost(5.48594935121+11236.57229942000*x);
L0+=0.00000000936*cost(1.58837554752+10235.13637553740*x);
L0+=0.00000001063*cost(1.93321644244+87.30820453981*x);
L0+=0.00000000945*cost(5.10393817688+8013.27974094040*x);
L0+=0.00000000957*cost(4.41421752360+433.71173787680*x);
L0+=0.00000000921*cost(1.71021166461+2067.93140107260*x);
L0+=0.00000000910*cost(1.91562889347+401.67212175720*x);
L0+=0.00000000931*cost(4.61327789373+5415.65737477320*x);
L0+=0.00000001033*cost(3.98512631089+10596.18207843420*x);
L0+=0.00000000908*cost(5.30549216988+7107.82304427560*x);
L0+=0.00000000945*cost(0.21610469082+9872.27408296480*x);
L0+=0.00000000991*cost(2.76931703924+5938.23479286700*x);
L0+=0.00000000918*cost(4.37217510741+1854.63230563460*x);
L0+=0.00000000889*cost(1.81025662091+2409.24933984800*x);
L0+=0.00000001058*cost(3.63303046818+7255.56965173440*x);
L0+=0.00000000860*cost(2.78826625605+5621.86017686260*x);
L0+=0.00000000860*cost(0.75749461239+5621.82566955820*x);
L0+=0.00000000850*cost(3.82228424021+272.67295735160*x);
L0+=0.00000000851*cost(0.25287875945+11766.26326451460*x);
L0+=0.00000000853*cost(1.84243320985+2142.64229812620*x);
L0+=0.00000001030*cost(0.42255009123+1596.18644228460*x);
L0+=0.00000000826*cost(1.26069501589+20206.14119633100*x);
L0+=0.00000000835*cost(4.64394754967+127.95153303460*x);
L0+=0.00000001046*cost(3.50232998647+9866.41688066520*x);
L0+=0.00000000824*cost(2.42928138519+11.04570026390*x);
L0+=0.00000001090*cost(6.06536924506+3341.03250279340*x);
L0+=0.00000000808*cost(1.17345081945+6460.81221096080*x);
L0+=0.00000000821*cost(0.19617131185+22743.40937951640*x);
L0+=0.00000000804*cost(5.03144428114+2.54279728080*x);
L0+=0.00000001074*cost(2.80025232939+3077.52850332700*x);
L0+=0.00000000794*cost(4.57067003887+5223.69391980220*x);
L0+=0.00000000822*cost(0.90150471199+8646.06348025360*x);
L0+=0.00000000884*cost(1.71007411939+3.93215326310*x);
L0+=0.00000000850*cost(1.24977903471+12295.95422960920*x);
L0+=0.00000000926*cost(3.02847055739+3377.21779200400*x);
L0+=0.00000000779*cost(1.97930055918+5408.54382777240*x);
L0+=0.00000000960*cost(6.16414205869+8542.97070603500*x);
L0+=0.00000000785*cost(4.63077378309+3341.04230982650*x);
L0+=0.00000000752*cost(3.51125131831+10020.85695903120*x);
L0+=0.00000000749*cost(2.50286751020+2295.45759051220*x);
L0+=0.00000000801*cost(4.54004277501+1039.02661079040*x);
L0+=0.00000000735*cost(3.91703254169+12310.18132361080*x);
L0+=0.00000000784*cost(3.24368310213+3384.33133900480*x);
L0+=0.00000000719*cost(3.35536995801+11780.49035851620*x);
L0+=0.00000000940*cost(3.58974561600+23539.70738633280*x);
L0+=0.00000000865*cost(1.12444569157+206.70073729660*x);
L0+=0.00000000731*cost(5.61232905415+16062.18452611680*x);
L0+=0.00000000823*cost(2.65316808033+3169.93955608060*x);
L0+=0.00000000903*cost(4.86743346013+931.36308685180*x);
L0+=0.00000000705*cost(1.46305394620+792.77488846740*x);
L0+=0.00000000754*cost(2.89691411536+3296.89351439480*x);
L0+=0.00000000736*cost(2.21038016464+146.81168652360*x);
L0+=0.00000000785*cost(2.32844966721+3340.18254357310*x);
L0+=0.00000000685*cost(2.34948834397+1.18064265210*x);
L0+=0.00000000677*cost(4.33803507050+3877.41693879520*x);
L0+=0.00000000729*cost(3.56726385957+485.97205278960*x);
L0+=0.00000000668*cost(5.16798891078+12721.57209941700*x);
L0+=0.00000000713*cost(4.80558699772+4142.97634914600*x);
L0+=0.00000000842*cost(1.59708732155+16304.91313009080*x);
L0+=0.00000000698*cost(1.91829605833+6665.97238221460*x);
L0+=0.00000000698*cost(4.64681188157+11216.28429032400*x);
L0+=0.00000000684*cost(3.88514563357+846.08283475120*x);
L0+=0.00000000666*cost(2.23927960017+20735.83216142559*x);
L0+=0.00000000638*cost(2.05380863176+16699.53901514999*x);
L0+=0.00000000726*cost(5.04566216294+3329.56672643590*x);
L0+=0.00000000697*cost(0.30680314664+19676.45023123640*x);
L0+=0.00000000650*cost(3.23944472757+9588.12554222260*x);
L0+=0.00000000736*cost(2.24443728739+11250.79939342160*x);
L0+=0.00000000692*cost(1.76465916332+51.28033786241*x);
L0+=0.00000000645*cost(0.07661067442+52.26031491280*x);
L0+=0.00000000685*cost(2.72118140264+6643.09181776180*x);
L0+=0.00000000684*cost(1.26157751115+142.17862703620*x);
L0+=0.00000000635*cost(3.85231847116+6.06591562980*x);
L0+=0.00000000819*cost(6.04967230806+19402.79695281660*x);
L0+=0.00000000664*cost(3.60223930010+1903.43681250120*x);
L0+=0.00000000613*cost(4.96450118774+8859.36257569160*x);
L0+=0.00000000615*cost(5.74467417840+6696.47732458460*x);
L0+=0.00000000622*cost(1.64154132852+24150.08005134500*x);
L0+=0.00000000659*cost(0.12506816965+8116.37251515900*x);
L0+=0.00000000679*cost(1.94943016061+12995.22537783680*x);
L0+=0.00000000616*cost(4.94607504516+9485.03276800400*x);
L0+=0.00000000793*cost(2.84922599989+29.49181830340*x);
L0+=0.00000000597*cost(5.72067567055+3113.13629391080*x);
L0+=0.00000000763*cost(0.42513533173+3873.82651014340*x);
L0+=0.00000000587*cost(1.31684217558+9499.25986200560*x);
L0+=0.00000000592*cost(4.34796024028+3826.58447948940*x);
L0+=0.00000000652*cost(5.53658742492+9065.54812412880*x);
L0+=0.00000000583*cost(0.59190068342+26084.02180621620*x);
L0+=0.00000000603*cost(0.77135566630+3342.09689940810*x);
L0+=0.00000000701*cost(3.35897774328+6709.67404086740*x);
L0+=0.00000000574*cost(1.08976979801+6357.71943674220*x);
L0+=0.00000000750*cost(4.84737198179+10022.81760116760*x);
L0+=0.00000000588*cost(5.65927128604+2171.02417529120*x);
L0+=0.00000000632*cost(3.84852695407+16276.46394262300*x);
L0+=0.00000000632*cost(1.43230388645+16706.58525184800*x);
L0+=0.00000000780*cost(1.15181502540+377.37360791580*x);
L0+=0.00000000554*cost(4.18192049239+382.87927857100*x);
L0+=0.00000000568*cost(0.03816333919+6414.61781167780*x);
L0+=0.00000000569*cost(2.57704345512+35.56273446860*x);
L0+=0.00000000566*cost(0.62804830762+3189.56475685690*x);
L0+=0.00000000687*cost(5.61456944029+155.35308913140*x);
L0+=0.00000000563*cost(2.57358138188+19406.67828817460*x);
L0+=0.00000000693*cost(1.15645091892+966.97087743560*x);
L0+=0.00000000576*cost(1.60357663736+3192.53370227350*x);
L0+=0.00000000621*cost(2.23214771591+3274.12501778540*x);
L0+=0.00000000586*cost(6.17266280012+9602.35263622420*x);
L0+=0.00000000541*cost(0.53968808391+13171.00144068760*x);
L0+=0.00000000570*cost(3.11852290115+2221.85663459700*x);
L0+=0.00000000542*cost(0.41889651002+1641.33321019660*x);
L0+=0.00000000532*cost(0.16606105669+5511.63660199100*x);
L0+=0.00000000530*cost(3.78205188174+7270.28968040780*x);
L0+=0.00000000575*cost(5.48929613719+2075.04494807340*x);
L0+=0.00000000670*cost(3.67090656417+6475.03930496240*x);
L0+=0.00000000509*cost(4.21526585284+7380.49600162720*x);
L0+=0.00000000510*cost(1.59587338243+13362.38239649640*x);
L0+=0.00000000494*cost(2.13711598060+2604.73591316800*x);
L0+=0.00000000534*cost(1.03109772656+1478.86657406440*x);
L0+=0.00000000506*cost(5.92145494356+685.04405422600*x);
L0+=0.00000000469*cost(0.83917541691+3041.48603243060*x);
L0+=0.00000000468*cost(1.97135671591+2412.77245819700*x);
L0+=0.00000000468*cost(4.57635781664+11670.28403729680*x);
L0+=0.00000000559*cost(1.47641018288+8671.96987044060*x);
L0+=0.00000000475*cost(2.07517976424+5835.14201864840*x);
L0+=0.00000000466*cost(2.92801596791+2277.29834324750*x);
L0+=0.00000000478*cost(6.13550464878+4825.54491639400*x);
L0+=0.00000000502*cost(0.77928275348+4407.10790388980*x);
L0+=0.00000000462*cost(3.80503324215+11140.59307220220*x);
L0+=0.00000000499*cost(3.25557381873+1744.49329471800*x);
L0+=0.00000000525*cost(0.74022979976+1265.56747862640*x);
L0+=0.00000000521*cost(6.27577138682+3981.49003408200*x);
L0+=0.00000000482*cost(0.14820337530+14158.74771361560*x);
L0+=0.00000000460*cost(2.03348517376+25685.87280280800*x);
L0+=0.00000000510*cost(4.27704405425+3472.15438838620*x);
L0+=0.00000000444*cost(1.95486223268+3226.21331978640*x);
L0+=0.00000000575*cost(0.59007504383+2766.26762836500*x);
L0+=0.00000000437*cost(5.63861950911+8958.93223156120*x);
L0+=0.00000000492*cost(6.10071747922+2285.16264977370*x);
L0+=0.00000000572*cost(5.10308842466+8564.30634650200*x);
L0+=0.00000000430*cost(4.12851356192+13.24177239800*x);
L0+=0.00000000544*cost(4.78254843814+9380.95967271720*x);
L0+=0.00000000430*cost(3.83861916944+1765.76662541760*x);
L0+=0.00000000499*cost(4.26055736809+6652.77566593180*x);
L0+=0.00000000541*cost(0.84245625839+4981.94563689640*x);
L0+=0.00000000591*cost(2.01874828234+27490.69247804480*x);
L0+=0.00000000438*cost(1.36437546581+12509.25332504720*x);
L0+=0.00000000470*cost(4.70961176845+3723.49170527080*x);
L0+=0.00000000421*cost(1.76100140625+956.28915597060*x);
L0+=0.00000000413*cost(0.49206034039+13355.33615979840*x);
L0+=0.00000000412*cost(0.29353415123+2810.93871525740*x);
L0+=0.00000000412*cost(3.24865417750+18451.07854656599*x);
L0+=0.00000000412*cost(1.70721395764+7314.00859271280*x);
L0+=0.00000000412*cost(4.54594776716+2810.90420795300*x);
L0+=0.00000000448*cost(3.04254429984+5636.07001721200*x);
L0+=0.00000000510*cost(1.18739936388+13362.51701710200*x);
L0+=0.00000000408*cost(1.32068176489+20809.46762464520*x);
L0+=0.00000000427*cost(1.16100742040+19004.64794940840*x);
L0+=0.00000000420*cost(3.49180180953+1655.56030419820*x);
L0+=0.00000000433*cost(0.55429134487+9945.57120882380*x);
L0+=0.00000000424*cost(4.60854671688+6518.75821726740*x);
L0+=0.00000000415*cost(5.67120343816+99.56965586960*x);
L0+=0.00000000476*cost(5.94537443289+48835.19385644859*x);
L0+=0.00000000405*cost(5.63206200287+3450.81874791920*x);
L0+=0.00000000495*cost(4.38317490235+2480.30249794700*x);
L0+=0.00000000415*cost(3.61905205961+2089.78223039900*x);
L0+=0.00000000395*cost(0.25208772249+1375.77379984580*x);
L0+=0.00000000421*cost(2.26337694295+13892.14067189380*x);
L0+=0.00000000391*cost(5.25566087245+10042.61267559180*x);
L0+=0.00000000504*cost(4.91016850189+8965.97846825920*x);
L0+=0.00000000417*cost(3.45088934666+279.78650435240*x);
L0+=0.00000000389*cost(0.98703891513+7203.80227149340*x);
L0+=0.00000000431*cost(2.11881719623+56.80326216980*x);
L0+=0.00000000497*cost(1.63121523594+22345.26037610820*x);
L0+=0.00000000377*cost(4.06263841184+10124.93005431800*x);
L0+=0.00000000377*cost(3.16019395941+224.34479570190*x);
L0+=0.00000000378*cost(5.82532048605+6675.70192909220*x);
L0+=0.00000000377*cost(0.05833226835+905.45669666480*x);
L0+=0.00000000445*cost(0.33560120738+515.46387109300*x);
L0+=0.00000000426*cost(2.66458973231+4076.48894023160*x);
L0+=0.00000000489*cost(0.75760372851+3561.02506913860*x);
L0+=0.00000000389*cost(0.50283826580+2825.14855560680*x);
L0+=0.00000000396*cost(5.14198726837+5195.24473233440*x);
L0+=0.00000000414*cost(3.12530321804+10001.06188460700*x);
L0+=0.00000000502*cost(5.02356488339+73.29712585900*x);
L0+=0.00000000432*cost(3.31538359140+5617.91076994730*x);
L0+=0.00000000359*cost(4.97622870666+5820.91492464680*x);
L0+=0.00000000359*cost(5.42072227300+6019.99192661860*x);
L0+=0.00000000449*cost(3.79544854612+4996.17273089800*x);
L0+=0.00000000374*cost(2.85563965649+2111.65031337760*x);
L0+=0.00000000426*cost(0.24129917209+5625.77507647350*x);
L0+=0.00000000423*cost(3.60507971235+8226.57883637840*x);
L0+=0.00000000402*cost(4.51813719510+4392.88080988820*x);
L0+=0.00000000391*cost(4.26714089799+21795.21409161479*x);
L0+=0.00000000447*cost(4.25776540974+18052.92954315780*x);
L0+=0.00000000355*cost(4.17584780659+6740.59871531320*x);
L0+=0.00000000353*cost(1.81574804066+6686.74777770700*x);
L0+=0.00000000462*cost(3.22304237134+2011.10033643980*x);
L0+=0.00000000341*cost(3.22071023668+4253.18267036540*x);
L0+=0.00000000475*cost(4.28822688035+367.22432896240*x);
L0+=0.00000000462*cost(2.91312544527+418.92439890060*x);
L0+=0.00000000416*cost(4.83203726375+8535.85715903420*x);
L0+=0.00000000431*cost(3.22440150226+21265.52312652020*x);
L0+=0.00000000333*cost(3.99300815003+1353.39052800780*x);
L0+=0.00000000340*cost(0.71636465254+15664.03552270859*x);
L0+=0.00000000416*cost(2.58443168474+5753.38488489680*x);
L0+=0.00000000356*cost(2.35639379021+4.57074972000*x);
L0+=0.00000000330*cost(4.04831945983+3.10304225540*x);
L0+=0.00000000381*cost(4.06283076724+1062.90504853820*x);
L0+=0.00000000431*cost(5.42246026973+26482.17080962440*x);
L0+=0.00000000328*cost(4.06276954550+6944.30877677240*x);
L0+=0.00000000334*cost(5.10221163477+22324.90505670940*x);
L0+=0.00000000400*cost(2.28211698182+3209.07046501340*x);
L0+=0.00000000420*cost(2.44159662565+6155.05700665400*x);
L0+=0.00000000375*cost(1.09229714548+4246.06912336460*x);
L0+=0.00000000449*cost(4.38183542571+5106.37905211740*x);
L0+=0.00000000330*cost(2.55172725319+19513.98359510420*x);
L0+=0.00000000319*cost(4.05704496382+5430.39465709880*x);
L0+=0.00000000310*cost(4.99907184482+5095.67507646480*x);
L0+=0.00000000344*cost(0.62691832180+9389.05354078620*x);
L0+=0.00000000319*cost(3.31673970253+596.17837400900*x);
L0+=0.00000000305*cost(4.66942910910+6756.00645196690*x);
L0+=0.00000000409*cost(6.07568936266+50.83245930580*x);
L0+=0.00000000377*cost(5.42211267415+1190.92389187560*x);
L0+=0.00000000342*cost(2.67821304845+6148.01076995600*x);
L0+=0.00000000298*cost(5.91093444215+9886.77220006400*x);
L0+=0.00000000299*cost(5.44077050156+10028.95082710020*x);
L0+=0.00000000315*cost(1.03304445564+3490.17562383440*x);
L0+=0.00000000369*cost(3.93279262125+1879.55837475340*x);
L0+=0.00000000304*cost(4.56372485787+7483.58877584580*x);
L0+=0.00000000330*cost(3.29725079066+286.96236112060*x);
L0+=0.00000000290*cost(3.43850024020+6418.14093002680*x);
L0+=0.00000000289*cost(2.82766045300+3171.03224356680*x);
L0+=0.00000000317*cost(4.13345374602+1883.08149310240*x);
L0+=0.00000000294*cost(0.01906732590+202.25339517410*x);
L0+=0.00000000310*cost(4.37565854379+2796.69436760360*x);
L0+=0.00000000364*cost(0.54935210242+290.48547946960*x);
L0+=0.00000000291*cost(2.39413982848+29026.48522950779*x);
L0+=0.00000000286*cost(5.76562894312+5642.19824260920*x);
L0+=0.00000000392*cost(3.01171327788+10721.10842832700*x);
L0+=0.00000000318*cost(4.93376925851+1197.97012857360*x);
L0+=0.00000000315*cost(2.84437840100+10610.90210710760*x);
L0+=0.00000000299*cost(1.18299169304+550.04628449340*x);
L0+=0.00000000336*cost(4.30769818760+5989.06725217280*x);
L0+=0.00000000315*cost(1.41407863340+6947.83189512140*x);
L0+=0.00000000294*cost(6.16453752963+8982.81066930900*x);
L0+=0.00000000285*cost(2.82644088669+9654.61295113700*x);
L0+=0.00000000281*cost(0.27739627997+8166.15734309380*x);
L0+=0.00000000279*cost(4.08648927643+5355.23588148860*x);
L0+=0.00000000330*cost(3.11968019451+41.55079098480*x);
L0+=0.00000000275*cost(5.89019272334+3337.86091608880*x);
L0+=0.00000000275*cost(4.00268079937+3620.39893105220*x);
L0+=0.00000000292*cost(3.06830662617+4.36203638980*x);
L0+=0.00000000317*cost(0.01919037405+2267.00340250900*x);
L0+=0.00000000272*cost(1.70373580224+3742.28454845700*x);
L0+=0.00000000294*cost(0.16019381973+6670.58818804980*x);
L0+=0.00000000264*cost(2.07967576148+3735.23831175900*x);
L0+=0.00000000262*cost(4.49437120405+6887.41040183680*x);
L0+=0.00000000307*cost(3.03375977801+6660.86953400080*x);
L0+=0.00000000280*cost(0.47728086796+5401.43028077160*x);
L0+=0.00000000268*cost(0.46331887242+6578.13207918100*x);
L0+=0.00000000312*cost(3.62016422039+255.97037637200*x);
L0+=0.00000000278*cost(5.62032972822+3378.74546233760*x);
L0+=0.00000000268*cost(2.97528422526+21947.11137270000*x);
L0+=0.00000000303*cost(2.71946492092+3313.21087060300*x);
L0+=0.00000000263*cost(3.85883671333+28628.33622609960*x);
L0+=0.00000000257*cost(0.25607724431+19146.75926614180*x);
L0+=0.00000000282*cost(2.29169514758+2008.55753915900*x);
L0+=0.00000000301*cost(0.83275594655+2806.98930834210*x);
L0+=0.00000000264*cost(3.78635346388+3936.79080070880*x);
L0+=0.00000000254*cost(1.28062508539+95.97922721780*x);
L0+=0.00000000250*cost(5.58493858560+412.37109687440*x);
L0+=0.00000000284*cost(4.71065509252+5621.91023351320*x);
L0+=0.00000000286*cost(5.11854366190+5621.77561290760*x);
L0+=0.00000000254*cost(5.77068701321+5813.29118932200*x);
L0+=0.00000000311*cost(2.67573060947+912.57024366560*x);
L0+=0.00000000252*cost(4.19548440341+24.85875881600*x);
L0+=0.00000000255*cost(1.80023727978+3193.80074017620*x);
L0+=0.00000000247*cost(2.94199704738+310.84079886840*x);
L0+=0.00000000261*cost(5.68285399692+3133.91168940320*x);
L0+=0.00000000255*cost(4.46589323429+5490.30096152400*x);
L0+=0.00000000247*cost(2.28207487665+246.25172232300*x);
L0+=0.00000000257*cost(5.64335704456+10706.88133432540*x);
L0+=0.00000000246*cost(0.26910281348+22.76849660940*x);
L0+=0.00000000241*cost(0.03931394254+9070.11887384880*x);
L0+=0.00000000283*cost(1.30585259585+4025.65648092580*x);
L0+=0.00000000272*cost(1.28327911416+1442.26120876020*x);
L0+=0.00000000294*cost(4.02082336381+2814.85361486830*x);
L0+=0.00000000249*cost(4.92144829429+31022.75317085620*x);
L0+=0.00000000237*cost(3.07683243726+9947.05568153210*x);
L0+=0.00000000236*cost(6.05766380360+948.19528790160*x);
L0+=0.00000000309*cost(3.45153658664+25287.72379939980*x);
L0+=0.00000000232*cost(4.99538565545+1505.28780909299*x);
L0+=0.00000000275*cost(1.20294105507+6691.86151874940*x);
L0+=0.00000000305*cost(2.73902403412+176.69373013380*x);
L0+=0.00000000231*cost(5.13610567818+6997.61672305620*x);
L0+=0.00000000237*cost(0.90339496046+8.09386806900*x);
L0+=0.00000000229*cost(0.63250047970+23017.06265793620*x);
L0+=0.00000000249*cost(6.05357589804+2060.81785407180*x);
L0+=0.00000000270*cost(2.14769161882+2973.38809773740*x);
L0+=0.00000000241*cost(4.63019900075+1612.95133303160*x);
L0+=0.00000000227*cost(5.94537053649+2942.48067694380*x);
L0+=0.00000000269*cost(5.93687481153+4005.36847182980*x);
L0+=0.00000000227*cost(3.91459879933+2942.44616963940*x);
L0+=0.00000000238*cost(5.14570745178+721.13923120620*x);
L0+=0.00000000275*cost(1.06902528739+3343.36393731080*x);
L0+=0.00000000232*cost(3.52110290510+6674.17861670160*x);
L0+=0.00000000277*cost(0.19619249083+270.19747037360*x);
L0+=0.00000000274*cost(0.30235979008+5607.61582920880*x);
L0+=0.00000000233*cost(5.75237138576+604.84974070480*x);
L0+=0.00000000214*cost(3.38626276995+647.01083331480*x);
L0+=0.00000000282*cost(0.29694635625+12323.42309600880*x);
L0+=0.00000000282*cost(3.18114716742+6364.83298374300*x);
L0+=0.00000000264*cost(4.64751563064+1346.34429130980*x);
L0+=0.00000000280*cost(4.64995184564+6701.58017279840*x);
L0+=0.00000000246*cost(3.03036675631+3304.00706139560*x);
L0+=0.00000000213*cost(4.80555095681+8830.91338822380*x);
L0+=0.00000000220*cost(1.54642908481+23546.75362303080*x);
L0+=0.00000000214*cost(1.35475764936+184.84990797020*x);
L0+=0.00000000228*cost(4.29420876593+2970.91261075940*x);
L0+=0.00000000229*cost(2.53361265404+3710.31224264020*x);
L0+=0.00000000273*cost(1.89943168433+270.13016007080*x);
L0+=0.00000000284*cost(3.28345980607+16063.16484718500*x);
L0+=0.00000000211*cost(5.84341192825+1971.95217385480*x);
L0+=0.00000000214*cost(0.22905754741+5.19919116580*x);
L0+=0.00000000246*cost(4.55971876123+6040.34724601740*x);
L0+=0.00000000229*cost(1.24432891752+3568.08855948880*x);
L0+=0.00000000216*cost(3.20098680120+362.12113673080*x);
L0+=0.00000000201*cost(2.45025935972+20426.57109242200*x);
L0+=0.00000000223*cost(2.07804482295+17101.21113690720*x);
L0+=0.00000000271*cost(3.49210901141+3436.59165391760*x);
L0+=0.00000000226*cost(0.42945734871+557.09252119140*x);
L0+=0.00000000264*cost(5.05794940070+2938.94030494260*x);
L0+=0.00000000207*cost(6.03491870748+22487.37169284160*x);
L0+=0.00000000197*cost(5.62923956977+5209.47182633600*x);
L0+=0.00000000211*cost(2.26445749553+765.79306444640*x);
L0+=0.00000000202*cost(0.88670673933+767.84881934860*x);
L0+=0.00000000212*cost(1.85965510753+4782.87363546000*x);
L0+=0.00000000194*cost(4.77420671032+6850.80503653260*x);
L0+=0.00000000192*cost(0.51565572072+323.50541665740*x);
L0+=0.00000000209*cost(4.79794980231+14047.49376102520*x);
L0+=0.00000000193*cost(2.56057288512+18606.49894600020*x);
L0+=0.00000000209*cost(1.46088434217+5.85720229960*x);
L0+=0.00000000214*cost(0.97578687412+17468.85519794540*x);
L0+=0.00000000196*cost(4.08789826861+3262.86188271590*x);
L0+=0.00000000198*cost(3.99111216230+10018.24685144760*x);
L0+=0.00000000235*cost(1.11133081576+625.67019231240*x);
L0+=0.00000000197*cost(0.48692287381+15106.87569121440*x);
L0+=0.00000000214*cost(5.33581901309+955.24152459960*x);
L0+=0.00000000199*cost(0.40088144456+7586.68155006440*x);
L0+=0.00000000251*cost(5.57906426342+138.58819838440*x);
L0+=0.00000000208*cost(4.11480858445+1755.06264976500*x);
L0+=0.00000000210*cost(2.30499661227+53.30794628380*x);
L0+=0.00000000253*cost(1.27099771143+309.27832265580*x);
L0+=0.00000000242*cost(3.71426781511+3212.59358336240*x);
L0+=0.00000000178*cost(3.06961783443+1437.17561419860*x);
L0+=0.00000000203*cost(0.28410501881+582.99891137840*x);
L0+=0.00000000190*cost(0.10457198807+26087.90314157420*x);
L0+=0.00000000178*cost(0.53068485806+7366.26890762560*x);
L0+=0.00000000245*cost(4.20195166994+8436.28750316460*x);
L0+=0.00000000176*cost(3.66697456425+6688.27109009760*x);
L0+=0.00000000177*cost(4.48104044431+8799.98871377800*x);
L0+=0.00000000181*cost(3.57461078885+15121.10278521600*x);
L0+=0.00000000198*cost(3.55065962909+24606.13555322000*x);
L0+=0.00000000187*cost(3.45440079747+1329.51209026000*x);
L0+=0.00000000176*cost(5.81532365473+12406.16055082860*x);
L0+=0.00000000235*cost(1.28568802052+4427.39591298580*x);
L0+=0.00000000179*cost(1.55718466444+3362.46325602620*x);
L0+=0.00000000174*cost(1.61086801253+30065.51184029820*x);
L0+=0.00000000199*cost(0.07164714815+375.76573157020*x);
L0+=0.00000000174*cost(4.58412775793+3283.71405176420*x);
L0+=0.00000000171*cost(5.82189798695+23937.85638974100*x);
L0+=0.00000000182*cost(2.57146189845+418.50432280700*x);
L0+=0.00000000168*cost(5.13131619552+21393.54196985760*x);
L0+=0.00000000183*cost(4.93161962050+9468.26787725700*x);
L0+=0.00000000167*cost(1.48091400654+2619.47319549360*x);
L0+=0.00000000169*cost(5.12437031125+3223.29255847960*x);
L0+=0.00000000188*cost(3.41823914376+5032.77809620220*x);
L0+=0.00000000181*cost(0.50010974122+2125.87740737920*x);
L0+=0.00000000164*cost(1.71077130702+15849.86575174700*x);
L0+=0.00000000202*cost(6.21085922593+3909.43430072720*x);
L0+=0.00000000171*cost(5.86158194602+625.62513619720*x);
L0+=0.00000000165*cost(3.85569118220+13207.02930736500*x);
L0+=0.00000000163*cost(2.04373367430+3347.29609057390*x);
L0+=0.00000000160*cost(2.83784244321+5888.44996493220*x);
L0+=0.00000000212*cost(2.32801112252+3232.94890276120*x);
L0+=0.00000000163*cost(4.23488695195+31968.94865279940*x);
L0+=0.00000000159*cost(1.48046671186+249.90446074220*x);
L0+=0.00000000160*cost(0.21960307161+12942.96506292400*x);
L0+=0.00000000220*cost(3.90787704883+9638.94074787620*x);
L0+=0.00000000161*cost(2.94093367568+3370.04193523580*x);
L0+=0.00000000159*cost(5.59017475732+1442.27846241240*x);
L0+=0.00000000221*cost(3.82548751198+1954.71715036360*x);
L0+=0.00000000192*cost(4.62595272276+3336.68027343670*x);
L0+=0.00000000164*cost(1.59200641542+386.41965057220*x);
L0+=0.00000000169*cost(5.45784867095+259.56080502380*x);
L0+=0.00000000201*cost(0.95077053594+29424.63423291600*x);
L0+=0.00000000174*cost(1.15216485688+6382.09845913040*x);
L0+=0.00000000163*cost(1.16606667991+4289.78803566960*x);
L0+=0.00000000187*cost(3.22135956460+2751.54759969160*x);
L0+=0.00000000162*cost(4.79372588575+24889.57479599160*x);
L0+=0.00000000192*cost(0.88040946364+5244.04923920100*x);
L0+=0.00000000160*cost(2.85034784370+9374.82644678460*x);
L0+=0.00000000172*cost(2.38601254063+2281.24775016280*x);
L0+=0.00000000202*cost(4.12164786769+7321.12213971360*x);
L0+=0.00000000156*cost(4.55171204694+27682.14074415640*x);
L0+=0.00000000170*cost(4.62851491273+10824.20120254560*x);
L0+=0.00000000157*cost(0.91363725609+4503.08713110760*x);
L0+=0.00000000156*cost(5.58255618318+10448.43547097540*x);
L0+=0.00000000157*cost(0.92229160815+15636.56665630900*x);
L0+=0.00000000171*cost(5.43820628341+11904.91877320180*x);
L0+=0.00000000180*cost(1.89091405241+13575.74880223720*x);
L0+=0.00000000198*cost(4.42539692212+10025.42770875120*x);
L0+=0.00000000158*cost(4.12087914642+11240.16272807180*x);
L0+=0.00000000211*cost(2.42218772392+8749.15625447220*x);
L0+=0.00000000183*cost(1.47934835951+6677.34351804160*x);
L0+=0.00000000197*cost(1.43469282909+14061.72085502680*x);
L0+=0.00000000170*cost(4.32424842659+742.99006053260*x);
L0+=0.00000000170*cost(2.92905324873+9093.99731159660*x);
L0+=0.00000000160*cost(2.79797608932+1461.05405194640*x);
L0+=0.00000000174*cost(5.37738922471+3318.76159737340*x);
L0+=0.00000000172*cost(0.35524089578+2281.21324285840*x);
L0+=0.00000000147*cost(2.76602235522+4193.80880845180*x);
L0+=0.00000000151*cost(4.23962231148+3368.01398279660*x);
L0+=0.00000000157*cost(1.01295201512+24336.00539314920*x);
L0+=0.00000000165*cost(0.58335652806+15906.76412668260*x);
L0+=0.00000000149*cost(5.69553079999+31570.79964939120*x);
L0+=0.00000000154*cost(5.28504381510+1481.40937134520*x);
L0+=0.00000000163*cost(1.81288628510+18849.22754997420*x);
L0+=0.00000000145*cost(3.57053080979+3497.01314720220*x);
L0+=0.00000000156*cost(3.56978076425+21791.69097326579*x);
L0+=0.00000000143*cost(0.56704903096+13212.88650966460*x);
L0+=0.00000000155*cost(0.08429188155+6657.34641565180*x);
L0+=0.00000000184*cost(2.54999403339+24076.44458812540*x);
L0+=0.00000000146*cost(1.16594990123+526.16784674560*x);
L0+=0.00000000144*cost(4.19229335185+2771.79055267240*x);
L0+=0.00000000169*cost(3.10771037057+239.20548562500*x);
L0+=0.00000000144*cost(6.26688878164+6679.74038069130*x);
L0+=0.00000000174*cost(2.37509025280+3397.51080163540*x);
L0+=0.00000000163*cost(3.88047919138+16703.04487984680*x);
L0+=0.00000000161*cost(1.73958633312+2185.25126929280*x);
L0+=0.00000000164*cost(0.62146994730+1538.24043597800*x);
L0+=0.00000000182*cost(6.16856014864+6685.10618875760*x);
L0+=0.00000000140*cost(4.08200595943+4186.69526145100*x);
L0+=0.00000000192*cost(4.47709998867+57.87869600380*x);
L0+=0.00000000151*cost(3.06451266512+838.96928775040*x);
L0+=0.00000000139*cost(1.12767399649+6682.70932610790*x);
L0+=0.00000000187*cost(4.97174626997+6681.65473652630*x);
L0+=0.00000000150*cost(5.69209290362+9360.60435331840*x);
L0+=0.00000000160*cost(5.66336382679+10927.29397676420*x);
L0+=0.00000000137*cost(3.46860408347+5562.46906129680*x);
L0+=0.00000000192*cost(5.27908098216+34363.36559755600*x);
L0+=0.00000000137*cost(5.87023088486+2945.98654164060*x);
L0+=0.00000000180*cost(1.07686767816+15806.14683944200*x);
L0+=0.00000000135*cost(0.34109799474+7322.10246078180*x);
L0+=0.00000000169*cost(2.27408583150+379.37341387420*x);
L0+=0.00000000172*cost(3.83276777655+6621.85099148600*x);
L0+=0.00000000134*cost(0.89486611090+13286.18363552360*x);
L0+=0.00000000168*cost(3.24434245132+11614.43329373220*x);
L0+=0.00000000135*cost(6.03727673544+1214.80232962340*x);
L0+=0.00000000150*cost(0.81912738038+3416.87849797540*x);
L0+=0.00000000136*cost(5.06627117467+14421.83163698840*x);
L0+=0.00000000138*cost(5.19336961955+13363.43002786740*x);
L0+=0.00000000163*cost(5.91124428824+16703.07938715119*x);
L0+=0.00000000181*cost(3.31978654659+139.69813952280*x);
L0+=0.00000000162*cost(4.05905033891+1795.25844372100*x);
L0+=0.00000000132*cost(0.40901506100+1083.26036793700*x);
L0+=0.00000000156*cost(0.12304144640+1107.13880568480*x);
L0+=0.00000000158*cost(6.25022915072+6666.99775939800*x);
L0+=0.00000000131*cost(3.95250083817+3.45580804620*x);
L0+=0.00000000147*cost(4.94673462086+15010.89646399660*x);
L0+=0.00000000140*cost(6.13853404667+12729.66596748600*x);
L0+=0.00000000131*cost(5.43398849473+25665.51748340920*x);
L0+=0.00000000135*cost(5.06017183369+11876.46958573400*x);
L0+=0.00000000128*cost(2.86969332730+6549.68289171320*x);
L0+=0.00000000174*cost(5.18169887171+28230.18722269139*x);
L0+=0.00000000179*cost(3.25589354429+4922.57177498280*x);
L0+=0.00000000139*cost(5.33624615245+23958.63178523340*x);
L0+=0.00000000127*cost(5.78406495652+14577.18472611980*x);
L0+=0.00000000128*cost(1.27276688747+8584.66166590080*x);
L0+=0.00000000133*cost(0.39052474466+12410.73130054860*x);
L0+=0.00000000134*cost(1.09641189843+8962.43809625800*x);
L0+=0.00000000125*cost(3.20445201519+29.88204361020*x);
L0+=0.00000000136*cost(3.62250122667+3511.28529731900*x);
L0+=0.00000000162*cost(5.36465149996+2472.67876262220*x);
L0+=0.00000000150*cost(0.40179894287+1111.64224510200*x);
L0+=0.00000000129*cost(1.94909076932+19645.52555679060*x);
L0+=0.00000000172*cost(5.21328160366+6747.71226231400*x);
L0+=0.00000000126*cost(4.39378462616+21548.96236929180*x);
L0+=0.00000000146*cost(3.85987749053+13361.46938573100*x);
L0+=0.00000000156*cost(5.24740844581+6645.19698672220*x);
L0+=0.00000000137*cost(4.94588047257+20995.39296644940*x);
L0+=0.00000000131*cost(1.72431469184+11925.27409260060*x);
L0+=0.00000000136*cost(2.04268940441+10654.62101941260*x);
L0+=0.00000000140*cost(1.54439148652+8219.46528937760*x);
L0+=0.00000000127*cost(6.16695075115+10016.31435579200*x);
L0+=0.00000000155*cost(5.47145482987+2.96894541660*x);
L0+=0.00000000132*cost(6.25626202928+13227.38462676380*x);
L0+=0.00000000121*cost(3.74135485334+10294.51023745100*x);
L0+=0.00000000134*cost(3.12718351732+8962.47260356240*x);
L0+=0.00000000122*cost(0.77282907794+4936.79886898440*x);
L0+=0.00000000125*cost(4.23213631052+15650.79375031060*x);
L0+=0.00000000157*cost(1.79175545524+16489.76303806100*x);
L0+=0.00000000155*cost(4.15655698197+56.38318607620*x);
L0+=0.00000000134*cost(1.53268827347+708.98980227659*x);
L0+=0.00000000136*cost(4.01025697673+9797.49248439750*x);
L0+=0.00000000156*cost(4.61556268820+3354.83952070140*x);
L0+=0.00000000131*cost(4.47476808853+11776.89992986440*x);
L0+=0.00000000118*cost(1.17466010141+4606.17990532620*x);
L0+=0.00000000128*cost(0.12648796247+6681.64492949320*x);
L0+=0.00000000122*cost(0.13511377940+8322.55806359620*x);
L0+=0.00000000119*cost(1.29139116350+10544.41469819320*x);
L0+=0.00000000128*cost(4.44966050740+13465.54248101780*x);
L0+=0.00000000119*cost(4.01709629990+14481.20549890200*x);
L0+=0.00000000147*cost(1.81590279650+685.11136452880*x);
L0+=0.00000000137*cost(4.78402836071+3613.28538405140*x);
L0+=0.00000000151*cost(1.48428558337+9698.33186344200*x);
L0+=0.00000000136*cost(2.47757608387+10156.90236013480*x);
L0+=0.00000000123*cost(2.42353206298+6.13322593260*x);
L0+=0.00000000117*cost(5.40635440024+688.63448287780*x);
L0+=0.00000000153*cost(5.00372030984+14556.89671702380*x);
L0+=0.00000000133*cost(3.15773785434+1125.86933910360*x);
L0+=0.00000000153*cost(1.94292660454+6533.14612897330*x);
L0+=0.00000000124*cost(4.94608245253+12825.64519470380*x);
L0+=0.00000000117*cost(1.13528750738+4452.25467180180*x);
L0+=0.00000000115*cost(3.34121813462+10001.48196070061*x);
L0+=0.00000000115*cost(3.44586362144+7696.88787128380*x);
L0+=0.00000000117*cost(0.72489390402+27.46886639960*x);
L0+=0.00000000132*cost(2.41318250916+6717.25272007700*x);
L0+=0.00000000118*cost(0.35995031424+27832.03821928320*x);
L0+=0.00000000157*cost(1.73929012934+11560.07771607740*x);
L0+=0.00000000148*cost(2.14023976341+15265.88651930040*x);
L0+=0.00000000113*cost(1.29183863745+26880.31981303260*x);
L0+=0.00000000151*cost(0.95890610457+6530.17718355670*x);
L0+=0.00000000153*cost(5.62679784282+9911.63095888000*x);
L0+=0.00000000157*cost(0.09791378159+138.51749687070*x);
L0+=0.00000000119*cost(2.16883964744+7082.89697515680*x);
L0+=0.00000000113*cost(5.43102427558+422.02744115600*x);
L0+=0.00000000130*cost(2.13493506322+117.81280289200*x);
L0+=0.00000000140*cost(2.51194591630+28.98162997940*x);
L0+=0.00000000128*cost(1.23822751200+6680.80477730600*x);
L0+=0.00000000111*cost(4.60294776614+25135.82651831460*x);
L0+=0.00000000118*cost(0.34226497704+4140.43355186520*x);
L0+=0.00000000112*cost(4.02233737541+6314.00052443720*x);
L0+=0.00000000134*cost(3.35926214730+11247.20896476980*x);
L0+=0.00000000120*cost(6.09430372868+4106.40549114620*x);
L0+=0.00000000117*cost(0.03006245187+7.67379197540*x);
L0+=0.00000000109*cost(3.62630036582+3344.11829139661*x);
L0+=0.00000000109*cost(1.94277745743+16702.99482319620*x);
L0+=0.00000000114*cost(4.87315937546+6151.51663465280*x);
L0+=0.00000000109*cost(5.65707270595+3344.15279870100*x);
L0+=0.00000000108*cost(0.72637519191+10.56935504700*x);
L0+=0.00000000128*cost(5.77326416186+13369.56325380000*x);
L0+=0.00000000147*cost(4.73848506543+11610.91017538320*x);
L0+=0.00000000145*cost(4.95495312886+9859.37064396720*x);
L0+=0.00000000111*cost(3.28808788953+257.01800774300*x);
L0+=0.00000000112*cost(4.79777726412+12140.60114047780*x);
L0+=0.00000000109*cost(3.73199687068+13635.12266415080*x);
L0+=0.00000000117*cost(1.20057736014+6705.10329114740*x);
L0+=0.00000000149*cost(4.91688353237+277.03499374140*x);
L0+=0.00000000108*cost(3.37299798972+6717.83021870380*x);
L0+=0.00000000106*cost(0.53379407701+5085.10572141780*x);
L0+=0.00000000125*cost(4.62770076269+9329.67967887260*x);
L0+=0.00000000107*cost(4.60288570375+1957.72507985320*x);
L0+=0.00000000113*cost(4.04786119569+6953.89781075120*x);
L0+=0.00000000106*cost(0.75378922686+149.89747512680*x);
L0+=0.00000000114*cost(0.62074562387+6151.55114195720*x);
L0+=0.00000000108*cost(5.22204692781+1556.56814695540*x);
L0+=0.00000000104*cost(1.02502614223+4878.85286267780*x);
L0+=0.00000000133*cost(1.15811543786+816.65332621520*x);
L0+=0.00000000134*cost(1.69834857217+183.86958690200*x);
L0+=0.00000000104*cost(2.58832774275+14591.41182012140*x);
L0+=0.00000000107*cost(4.42117075795+7.13080065300*x);
L0+=0.00000000126*cost(0.03750399181+16.83220104979*x);
L0+=0.00000000102*cost(1.20624870972+11986.67590695340*x);
L0+=0.00000000102*cost(2.97579561878+29822.78323632420*x);
L0+=0.00000000116*cost(4.73049067619+13366.04013545100*x);
L0+=0.00000000130*cost(4.10484632841+35.60779058380*x);
L0+=0.00000000113*cost(3.69200525056+44.65383324020*x);
L0+=0.00000000111*cost(5.12900291511+146.79443287140*x);
L0+=0.00000000126*cost(1.82187459534+26887.36604973060*x);
L0+=0.00000000121*cost(6.08309355316+7100.70949727480*x);
L0+=0.00000000105*cost(6.16606590276+9175.75444534820*x);
L0+=0.00000000132*cost(2.97955203077+1250.83019630080*x);
L0+=0.00000000106*cost(5.08419485009+8742.04270747140*x);
L0+=0.00000000120*cost(0.59116561391+31172.65064598300*x);
L0+=0.00000000112*cost(3.70888430091+10050.28646756720*x);
L0+=0.00000000100*cost(1.82077956276+12012.58229714040*x);
L0+=0.00000000107*cost(4.86100312387+7899.55030137200*x);
L0+=0.00000000099*cost(0.72997085174+18977.17908300880*x);
L0+=0.00000000107*cost(5.25025570307+63.73589830340*x);
L0+=0.00000000099*cost(2.79139996703+17932.02424682120*x);
L0+=0.00000000097*cost(4.94370173613+28109.21461605200*x);
L0+=0.00000000122*cost(4.18676567644+19617.07636932279*x);
L0+=0.00000000121*cost(3.14207351411+9278.84721956680*x);
L0+=0.00000000112*cost(1.43537110436+16232.74503031800*x);
L0+=0.00000000096*cost(2.57929371627+12715.43887348440*x);
L0+=0.00000000096*cost(2.51396484677+3535.58381116040*x);
L0+=0.00000000112*cost(6.19137312195+6685.15700666270*x);
L0+=0.00000000109*cost(1.53428110338+16703.12944380180*x);
L0+=0.00000000096*cost(4.29245810274+7906.59653807000*x);
L0+=0.00000000096*cost(3.08847844641+3468.63127003720*x);
L0+=0.00000000095*cost(6.09186084700+10037.08975128440*x);
L0+=0.00000000094*cost(1.79812841802+20047.19767854780*x);
L0+=0.00000000110*cost(4.24859410294+3337.07205469860*x);
L0+=0.00000000093*cost(2.17945548408+16066.06586147480*x);
L0+=0.00000000115*cost(5.44548079869+11353.89216764020*x);
L0+=0.00000000098*cost(1.89605054783+33406.12426699800*x);
L0+=0.00000000101*cost(3.00793005829+3528.53757446240*x);
L0+=0.00000000096*cost(5.40659912420+5749.86176654780*x);
L0+=0.00000000113*cost(3.93443805059+7167.19690618920*x);
L0+=0.00000000092*cost(3.58985964414+6724.94376570460*x);
L0+=0.00000000119*cost(3.90561570260+11346.77862063940*x);
L0+=0.00000000097*cost(2.57280790230+1747.60737815290*x);
L0+=0.00000000118*cost(3.82111723459+9072.66167112960*x);
L0+=0.00000000096*cost(0.72646224606+3152.68727893721*x);
L0+=0.00000000092*cost(6.23928508055+24491.42579258340*x);
L0+=0.00000000099*cost(1.86991802881+72.05573335480*x);
L0+=0.00000000094*cost(1.51091806861+9801.42463766060*x);
L0+=0.00000000091*cost(4.94377681711+8756.26980147300*x);
L0+=0.00000000095*cost(2.58771497236+11663.17049029600*x);
L0+=0.00000000093*cost(0.66092443320+30.99198474860*x);
L0+=0.00000000088*cost(2.47386826588+17232.75309859360*x);
L0+=0.00000000100*cost(0.19616913512+11883.58313273480*x);
L0+=0.00000000094*cost(0.61277732908+73.63546321960*x);
L0+=0.00000000091*cost(6.04139177526+153.92523352440*x);
L0+=0.00000000095*cost(0.30865798871+29168.59654624120*x);
L0+=0.00000000110*cost(6.27936643935+3337.10656200300*x);
L0+=0.00000000087*cost(2.09287965409+10264.56588407340*x);
L0+=0.00000000089*cost(3.27633365389+3002.36972771680*x);
L0+=0.00000000091*cost(1.89622049447+37895.42629036740*x);
L0+=0.00000000118*cost(3.88268323672+1236.07566032300*x);
L0+=0.00000000094*cost(2.27819061990+4845.90023579280*x);
L0+=0.00000000085*cost(3.07438636612+9983.70424446160*x);
L0+=0.00000000086*cost(3.94463425808+16.76489074700*x);
L0+=0.00000000099*cost(4.58890225582+3774.32416457660*x);
L0+=0.00000000086*cost(1.27758598252+34513.26307268280*x);
L0+=0.00000000118*cost(6.10625309129+454.90936652730*x);
L0+=0.00000000096*cost(6.08772700197+1755.47168467910*x);
L0+=0.00000000085*cost(4.73193631802+4576.68808702280*x);
L0+=0.00000000116*cost(0.88573303872+16511.61386738740*x);
L0+=0.00000000083*cost(3.13948373813+10191.41746323240*x);
L0+=0.00000000083*cost(0.36972674664+9755.23023837760*x);
L0+=0.00000000112*cost(2.26524635842+10006.58480891440*x);
L0+=0.00000000087*cost(4.25461508452+8.16813658240*x);
L0+=0.00000000087*cost(5.31716927554+1868.85939963620*x);
L0+=0.00000000115*cost(3.30507830050+14157.70008224460*x);
L0+=0.00000000087*cost(2.90507350729+36.99559061100*x);
L0+=0.00000000083*cost(3.58400049244+12928.73796892240*x);
L0+=0.00000000086*cost(2.46839611271+113.72943956840*x);
L0+=0.00000000096*cost(2.99829695985+6510.55198278040*x);
L0+=0.00000000084*cost(1.34333260788+4133.38731516720*x);
L0+=0.00000000093*cost(2.41895388985+20040.15144184979*x);
L0+=0.00000000085*cost(5.92093268818+12299.54465826100*x);
L0+=0.00000000082*cost(4.71321236549+7733.49323658800*x);
L0+=0.00000000081*cost(5.26971110105+12199.97500239140*x);
L0+=0.00000000080*cost(4.34410099751+7218.02936549500*x);
L0+=0.00000000095*cost(0.02613500045+2.90101428980*x);
L0+=0.00000000094*cost(6.22018441621+20043.69181385099*x);
L0+=0.00000000085*cost(4.66573809999+8638.94993325280*x);
L0+=0.00000000079*cost(2.89839604813+22854.59602180400*x);
L0+=0.00000000104*cost(0.94882888784+2735.76268599500*x);
L0+=0.00000000080*cost(1.68097745917+12839.87228870540*x);
L0+=0.00000000085*cost(1.95515305721+4686.95671800959*x);
L0+=0.00000000094*cost(0.58147434179+14128.24277124560*x);
L0+=0.00000000091*cost(1.16317999954+3495.96551583120*x);
L0+=0.00000000084*cost(4.04104644774+9815.65173166220*x);
L0+=0.00000000082*cost(1.83662951627+19190.47817844680*x);
L0+=0.00000000080*cost(4.04733274699+3188.71514561460*x);
L0+=0.00000000084*cost(2.71620952175+12089.76868117200*x);
L0+=0.00000000080*cost(2.77363158210+9495.66943335380*x);
L0+=0.00000000078*cost(5.77285430206+10397.60301166960*x);
L0+=0.00000000084*cost(0.78188080031+7214.43893684320*x);
L0+=0.00000000094*cost(2.14762315943+13532.02988993220*x);
L0+=0.00000000101*cost(5.76349087526+1484.93248969420*x);
L0+=0.00000000082*cost(3.11421789241+8446.99147881720*x);
L0+=0.00000000096*cost(5.85152670536+3492.50970778500*x);
L0+=0.00000000079*cost(4.69625309523+5298.33750655300*x);
L0+=0.00000000097*cost(3.97960395898+18208.34994259200*x);
L0+=0.00000000105*cost(1.74376904536+36.64856292950*x);
L0+=0.00000000094*cost(4.18941238607+20043.65730654660*x);
L0+=0.00000000075*cost(3.46629875063+13341.67431130680*x);
L0+=0.00000000092*cost(2.67278833288+6680.79497027290*x);
L0+=0.00000000075*cost(4.59723160021+9993.38809263160*x);
L0+=0.00000000087*cost(0.91979096638+8425.71814811760*x);
L0+=0.00000000074*cost(0.42228487063+48429.28218232440*x);
L0+=0.00000000074*cost(0.48470953224+11456.98494185880*x);
L0+=0.00000000077*cost(0.10707484151+1371.41176345600*x);
L0+=0.00000000093*cost(1.38010528069+3145.64104223920*x);
L0+=0.00000000075*cost(5.28061257070+12306.59089495900*x);
L0+=0.00000000079*cost(3.78666386040+7.57867920960*x);
L0+=0.00000000073*cost(4.42902162523+14.73728232560*x);
L0+=0.00000000084*cost(3.41538432898+6637.50594109460*x);
L0+=0.00000000093*cost(3.41302342683+1596.11913198180*x);
L0+=0.00000000071*cost(3.13537213242+9488.62319665580*x);
L0+=0.00000000079*cost(2.33442828498+12465.53441274220*x);
L0+=0.00000000078*cost(2.21525134547+2810.98877190800*x);
L0+=0.00000000099*cost(0.48801369293+17499.36014031540*x);
L0+=0.00000000075*cost(4.10299895268+5525.86369599260*x);
L0+=0.00000000071*cost(4.04186021414+259.49349472100*x);
L0+=0.00000000073*cost(2.20102876718+30774.50164257480*x);
L0+=0.00000000074*cost(4.93439968296+13517.80279593060*x);
L0+=0.00000000071*cost(5.32625652676+6670.17915313570*x);
L0+=0.00000000078*cost(2.17664185326+13421.82356871280*x);
L0+=0.00000000088*cost(5.38469204503+17762.44406368820*x);
L0+=0.00000000081*cost(2.48353174238+73.60095591520*x);
L0+=0.00000000092*cost(1.13088448190+7747.72033058960*x);
L0+=0.00000000070*cost(1.16361323015+5220.17080145320*x);
L0+=0.00000000084*cost(5.83220387910+22.37827130260*x);
L0+=0.00000000076*cost(5.21065604639+4271.97551355160*x);
L0+=0.00000000080*cost(4.01817623627+3311.18291816379*x);
L0+=0.00000000068*cost(2.45937697940+6279.55273164240*x);
L0+=0.00000000067*cost(4.31723563048+2281.29780681340*x);
L0+=0.00000000067*cost(4.88776321797+4379.63903749020*x);
L0+=0.00000000069*cost(3.57006764536+14955.04572043200*x);
L0+=0.00000000078*cost(2.62374773232+2810.85415130240*x);
L0+=0.00000000067*cost(4.76301301456+6812.76681508600*x);
L0+=0.00000000070*cost(5.60319851277+13383.22510229160*x);
L0+=0.00000000070*cost(3.05647570196+10081.21114201300*x);
L0+=0.00000000081*cost(4.91537623765+3333.92876282570*x);
L0+=0.00000000082*cost(5.49204987110+5483.25472482600*x);
L0+=0.00000000065*cost(3.50466797067+9161.52735134660*x);
L0+=0.00000000065*cost(2.79212460026+13497.51478683460*x);
L0+=0.00000000070*cost(0.93640431668+6106.88005506480*x);
L0+=0.00000000073*cost(2.57583496978+6614.73744448520*x);
L0+=0.00000000070*cost(0.84170070580+16695.94858649819*x);
L0+=0.00000000069*cost(1.10040627005+2544.33167353560*x);
L0+=0.00000000063*cost(6.05841309176+6453.74872061060*x);
L0+=0.00000000069*cost(2.67053540192+2641.34127847220*x);
L0+=0.00000000086*cost(1.73112264739+6286.59896834040*x);
L0+=0.00000000062*cost(5.49002783256+4957.08687808040*x);
L0+=0.00000000072*cost(3.38857910283+3184.21170619740*x);
L0+=0.00000000069*cost(5.35281990892+2544.29716623120*x);
L0+=0.00000000064*cost(4.79175268505+3181.66890891660*x);
L0+=0.00000000060*cost(6.18449904353+3361.94806716680*x);
L0+=0.00000000065*cost(1.48236627574+4819.47900076420*x);
L0+=0.00000000054*cost(3.66018290396+2917.53735417280*x);
L0+=0.00000000064*cost(4.72286914683+2281.16318620780*x);
L0+=0.00000000053*cost(4.65521663671+3448.27595063840*x);
L0+=0.00000000060*cost(0.77450276964+3319.27678623280*x);
L0+=0.00000000051*cost(1.45142985881+3547.31316399640*x);
L0+=0.00000000051*cost(4.81258158513+4403.51747523800*x);
L0+=0.00000000050*cost(0.37366902835+3322.79990458180*x);
L0+=0.00000000050*cost(4.68787711774+3253.30422216000*x);
L0+=0.00000000067*cost(4.63578431535+4694.00295470760*x);
L0+=0.00000000049*cost(3.17471347671+5452.26274007740*x);
L0+=0.00000000051*cost(2.54791773443+4001.84535348080*x);
L0+=0.00000000048*cost(2.81171553464+3372.58473251660*x);
L0+=0.00000000054*cost(4.45945188023+10284.92120347220*x);
L0+=0.00000000053*cost(3.85131213520+9758.75335672660*x);
L0+=0.00000000051*cost(1.11244863072+6901.63749583840*x);
L0+=0.00000000062*cost(1.42198009630+6830.78805053420*x);
L0+=0.00000000055*cost(5.61672988180+45494.58142974879*x);
L0+=0.00000000054*cost(0.61701959453+4716.38622654560*x);
L0+=0.00000000054*cost(4.28556326526+2910.49111747480*x);
L0+=0.00000000045*cost(3.14626081312+13951.51453380740*x);
L0+=0.00000000050*cost(4.16235480519+12979.55317457600*x);
L0+=0.00000000046*cost(1.66182208107+7768.00833968560*x);
L0+=0.00000000045*cost(5.07701425888+14951.52260208300*x);
L0+=0.00000000043*cost(4.31723459530+5881.40372823420*x);
L0+=0.00000000045*cost(2.39713581676+8852.24902869080*x);
L0+=0.00000000043*cost(2.10202660495+3337.15661865360*x);
L0+=0.00000000048*cost(0.19934255781+1905.46476494040*x);
L0+=0.00000000056*cost(5.25687695855+12808.88030395680*x);
L0+=0.00000000049*cost(2.06320966659+4296.90158267040*x);
L0+=0.00000000042*cost(6.07282126953+4295.85395129940*x);
L0+=0.00000000043*cost(1.74571613780+3130.83644961080*x);
L0+=0.00000000050*cost(2.27112469544+3427.92063123960*x);
L0+=0.00000000050*cost(0.30214747765+3358.42494881780*x);
L0+=0.00000000043*cost(5.05297177283+3229.42578441220*x);
L0+=0.00000000054*cost(6.11998016428+16894.51039961060*x);
L0+=0.00000000043*cost(1.90603004035+3451.79906898740*x);
L0+=0.00000000039*cost(0.50727886431+10011.20061474960*x);
L0+=0.00000000052*cost(3.17851184154+2324.94940881560*x);
L0+=0.00000000038*cost(4.88249540246+3499.55594448300*x);
L0+=0.00000000039*cost(5.28113083211+3343.15522398060*x);
L0+=0.00000000039*cost(4.98185580267+3468.56395973440*x);
L0+=0.00000000047*cost(2.16244218985+10027.36020440680*x);
L0+=0.00000000037*cost(5.84953090935+6791.43117461900*x);
L0+=0.00000000048*cost(5.03779546898+7064.10413197060*x);
L0+=0.00000000038*cost(0.58076516432+8966.38750317330*x);
L0+=0.00000000051*cost(3.36181117037+8976.68244391180*x);
L0+=0.00000000042*cost(4.13725767158+8336.78515759780*x);
L0+=0.00000000038*cost(5.75425648893+4531.53631857540*x);
L0+=0.00000000038*cost(3.55681323215+5351.71276313960*x);
L0+=0.00000000040*cost(2.79414141035+3067.93946934820*x);
L0+=0.00000000040*cost(4.99798468494+10042.19259949820*x);
L0+=0.00000000037*cost(1.82286411009+10017.95594474140*x);
L0+=0.00000000036*cost(6.02115369796+6474.52411610300*x);
L0+=0.00000000044*cost(3.01299253859+7417.10136693140*x);
L0+=0.00000000045*cost(2.33470159894+3123.79021291280*x);
L0+=0.00000000039*cost(4.91767933978+8034.61538140740*x);

double L1=0;
L1+=3340.85627474342;
L1+=0.01458227051*cost(3.60426053609+3340.61242669980*x);
L1+=0.00164901343*cost(3.92631250962+6681.22485339960*x);
L1+=0.00019963338*cost(4.26594061030+10021.83728009940*x);
L1+=0.00003452399*cost(4.73210386365+3.52311834900*x);
L1+=0.00002485480*cost(4.61277567318+13362.44970679920*x);
L1+=0.00000841551*cost(4.45858256765+2281.23049651060*x);
L1+=0.00000537566*cost(5.01589727492+398.14900340820*x);
L1+=0.00000521041*cost(4.99422678175+3344.13554504880*x);
L1+=0.00000432614*cost(2.56066402860+191.44826611160*x);
L1+=0.00000429656*cost(5.31646162367+155.42039943420*x);
L1+=0.00000381747*cost(3.53881289437+796.29800681640*x);
L1+=0.00000314129*cost(4.96335266049+16703.06213349900*x);
L1+=0.00000282804*cost(3.15967518204+2544.31441988340*x);
L1+=0.00000205664*cost(4.56891455660+2146.16541647520*x);
L1+=0.00000168805*cost(1.32894813366+3337.08930835080*x);
L1+=0.00000157587*cost(4.18501035954+1751.53953141600*x);
L1+=0.00000133686*cost(2.23325104196+0.98032106820*x);
L1+=0.00000116561*cost(2.21347652545+1059.38193018920*x);
L1+=0.00000117591*cost(6.02407213861+6151.53388830500*x);
L1+=0.00000113595*cost(5.42803224317+3738.76143010800*x);
L1+=0.00000133563*cost(5.97421903927+1748.01641306700*x);
L1+=0.00000091098*cost(1.09627836591+1349.86740965880*x);
L1+=0.00000083301*cost(5.29636626272+6684.74797174860*x);
L1+=0.00000113876*cost(2.12869455089+1194.44701022460*x);
L1+=0.00000080776*cost(4.42813405865+529.69096509460*x);
L1+=0.00000079531*cost(2.24864266330+8962.45534991020*x);
L1+=0.00000072505*cost(5.84208163240+242.72860397400*x);
L1+=0.00000072946*cost(2.50189460554+951.71840625060*x);
L1+=0.00000071487*cost(3.85636094435+2914.01423582380*x);
L1+=0.00000085342*cost(3.90854841008+553.56940284240*x);
L1+=0.00000067582*cost(5.02327686473+382.89653222320*x);
L1+=0.00000065089*cost(1.01802439311+3340.59517304760*x);
L1+=0.00000065089*cost(3.04879603978+3340.62968035200*x);
L1+=0.00000061508*cost(4.15183159800+3149.16416058820*x);
L1+=0.00000048477*cost(4.87362121538+213.29909543800*x);
L1+=0.00000046584*cost(1.31452419914+3185.19202726560*x);
L1+=0.00000056520*cost(3.88813699320+4136.91043351620*x);
L1+=0.00000047613*cost(1.18238046057+3333.49887969900*x);
L1+=0.00000041343*cost(0.71385375517+1592.59601363280*x);
L1+=0.00000040055*cost(5.31611875491+20043.67456019880*x);
L1+=0.00000040272*cost(2.72542480614+7.11354700080*x);
L1+=0.00000032886*cost(5.41067411968+6283.07584999140*x);
L1+=0.00000028244*cost(0.04534124888+9492.14631500480*x);
L1+=0.00000022294*cost(5.88516997273+3870.30339179440*x);
L1+=0.00000022431*cost(5.46592525433+20.35531939880*x);
L1+=0.00000022612*cost(0.83775884934+3097.88382272579*x);
L1+=0.00000021418*cost(5.37934044204+3340.54511639700*x);
L1+=0.00000023335*cost(6.16762213077+3532.06069281140*x);
L1+=0.00000026579*cost(3.88960724782+1221.84856632140*x);
L1+=0.00000022797*cost(1.54504711003+2274.11694950980*x);
L1+=0.00000020431*cost(2.36353950189+1589.07289528380*x);
L1+=0.00000020186*cost(3.36375535766+5088.62883976680*x);
L1+=0.00000026554*cost(5.11271747607+2700.71514038580*x);
L1+=0.00000019675*cost(2.57805423988+12303.06777661000*x);
L1+=0.00000019468*cost(0.49216434489+6677.70173505060*x);
L1+=0.00000021104*cost(3.52525428062+15.25247118500*x);
L1+=0.00000021425*cost(4.97081508139+3340.67973700260*x);
L1+=0.00000018505*cost(5.57863503922+1990.74501704100*x);
L1+=0.00000017811*cost(6.12537931996+4292.33083295040*x);
L1+=0.00000016472*cost(2.60291845066+3341.59274776800*x);
L1+=0.00000016599*cost(1.25519718278+3894.18182954220*x);
L1+=0.00000019455*cost(2.53112676345+4399.99435688900*x);
L1+=0.00000015000*cost(1.03464802434+2288.34404351140*x);
L1+=0.00000020029*cost(4.73119428749+4690.47983635860*x);
L1+=0.00000015381*cost(2.47009470350+4535.05943692440*x);
L1+=0.00000019964*cost(5.78652958398+7079.37385680780*x);
L1+=0.00000015307*cost(2.26515985343+3723.50895892300*x);
L1+=0.00000014705*cost(3.36979890389+6681.24210705180*x);
L1+=0.00000013535*cost(2.12334410410+5486.77784317500*x);
L1+=0.00000012950*cost(5.61929676688+10025.36039844840*x);
L1+=0.00000012682*cost(2.95022113262+3496.03282613400*x);
L1+=0.00000013644*cost(1.97739547259+5614.72937620960*x);
L1+=0.00000013013*cost(1.51424752315+5628.95647021120*x);
L1+=0.00000014705*cost(1.33902715586+6681.20759974740*x);
L1+=0.00000011353*cost(6.23438193885+135.06508003540*x);
L1+=0.00000013275*cost(3.42243595774+5621.84292321040*x);
L1+=0.00000010867*cost(5.28184140482+2818.03500860600*x);
L1+=0.00000011850*cost(3.12701832949+426.59819087600*x);
L1+=0.00000010472*cost(2.73581537999+2787.04302385740*x);
L1+=0.00000011132*cost(5.84178807242+2803.80791460440*x);
L1+=0.00000011764*cost(2.58551521265+8432.76438481560*x);
L1+=0.00000011854*cost(5.47630686910+3553.91152213780*x);
L1+=0.00000008490*cost(1.91378007528+11773.37681151540*x);
L1+=0.00000009708*cost(4.52957217749+6489.77658728800*x);
L1+=0.00000008562*cost(3.16141186861+162.46663613220*x);
L1+=0.00000010958*cost(4.15771850822+2388.89402044920*x);
L1+=0.00000008133*cost(1.61295625304+2957.71589447660*x);
L1+=0.00000008840*cost(4.23294294197+7477.52286021600*x);
L1+=0.00000008034*cost(5.69983564288+6041.32756708560*x);
L1+=0.00000008344*cost(2.18273563186+23.87843774780*x);
L1+=0.00000007696*cost(5.71877332978+9623.68827669120*x);
L1+=0.00000008695*cost(4.43542512603+5092.15195811580*x);
L1+=0.00000008434*cost(3.16292250873+3347.72597370060*x);
L1+=0.00000006664*cost(5.07517838003+8031.09226305840*x);
L1+=0.00000008650*cost(4.33256981793+3339.63210563160*x);
L1+=0.00000007372*cost(6.17831593269+3583.34103067380*x);
L1+=0.00000005726*cost(3.68120120299+8429.24126646660*x);
L1+=0.00000006186*cost(3.54165967734+692.15760122680*x);
L1+=0.00000005438*cost(1.05129689580+4933.20844033260*x);
L1+=0.00000006108*cost(1.66240879939+6525.80445396540*x);
L1+=0.00000005154*cost(1.14703246368+28.44918746780*x);
L1+=0.00000004850*cost(5.29254832907+6681.29216370240*x);
L1+=0.00000005467*cost(6.12511022569+2487.41604494780*x);
L1+=0.00000004866*cost(3.10475368803+5.52292430740*x);
L1+=0.00000006360*cost(2.11896608283+5884.92684658320*x);
L1+=0.00000005223*cost(0.37446264120+12832.75874170460*x);
L1+=0.00000004710*cost(0.23326120326+36.02786667740*x);
L1+=0.00000004954*cost(2.44806818502+5099.26550511660*x);
L1+=0.00000004861*cost(5.60505298870+6467.92575796160*x);
L1+=0.00000004706*cost(0.02998416568+7210.91581849420*x);
L1+=0.00000004845*cost(5.70115105957+6681.15754309680*x);
L1+=0.00000005496*cost(2.01006612503+522.57741809380*x);
L1+=0.00000004964*cost(1.51006845561+1744.42598441520*x);
L1+=0.00000004443*cost(0.31208413867+10018.31416175040*x);
L1+=0.00000005381*cost(0.18359380473+2942.46342329160*x);
L1+=0.00000004075*cost(3.95582108330+3.88133535800*x);
L1+=0.00000005462*cost(0.19274227117+7632.94325965020*x);
L1+=0.00000004110*cost(1.59535768711+7234.79425624200*x);
L1+=0.00000004287*cost(2.87635993968+2810.92146160520*x);
L1+=0.00000005276*cost(2.22638595594+3127.31333126180*x);
L1+=0.00000004450*cost(4.17005729081+2906.90068882300*x);
L1+=0.00000005144*cost(5.66878565669+23384.28698689860*x);
L1+=0.00000003844*cost(2.26442183160+2699.73481931760*x);
L1+=0.00000003514*cost(1.76463961051+1758.65307841680*x);
L1+=0.00000003351*cost(2.66194137496+4929.68532198360*x);
L1+=0.00000004299*cost(4.43057446968+640.87760738220*x);
L1+=0.00000003140*cost(1.75866226873+9595.23908922340*x);
L1+=0.00000003716*cost(2.91969220147+15643.68020330980*x);
L1+=0.00000003249*cost(6.13937134379+10419.98628350760*x);
L1+=0.00000003077*cost(2.56115174488+7064.12138562280*x);
L1+=0.00000003208*cost(2.32519453080+5085.03841111500*x);
L1+=0.00000002930*cost(1.27797225349+574.34479833480*x);
L1+=0.00000002771*cost(1.75664216142+639.89728631400*x);
L1+=0.00000003325*cost(2.58945297384+2118.76386037840*x);
L1+=0.00000003187*cost(2.86646751510+7740.60678358880*x);
L1+=0.00000002780*cost(0.43157089331+5828.02847164760*x);
L1+=0.00000002824*cost(0.98500544471+3191.04922956520*x);
L1+=0.00000003016*cost(1.86555882509+7.04623669800*x);
L1+=0.00000003364*cost(1.52847138842+6674.11130639880*x);
L1+=0.00000002672*cost(3.70855172347+10021.85453375160*x);
L1+=0.00000002636*cost(3.11790581052+6836.64525283380*x);
L1+=0.00000002672*cost(1.67778079449+10021.82002644720*x);
L1+=0.00000002563*cost(3.77294986894+2921.12778282460*x);
L1+=0.00000002509*cost(0.30454165124+3475.67750673520*x);
L1+=0.00000002400*cost(0.96972421975+3319.83703120740*x);
L1+=0.00000002262*cost(2.81394314950+7875.67186362420*x);
L1+=0.00000002395*cost(2.96002707485+6682.20517446780*x);
L1+=0.00000002210*cost(0.61263930586+10973.55568635000*x);
L1+=0.00000002248*cost(4.12382007742+59.37386191360*x);
L1+=0.00000002426*cost(5.91508357946+5331.35744374080*x);
L1+=0.00000002158*cost(2.17583545077+15113.98923821520*x);
L1+=0.00000001941*cost(5.47668312685+11371.70468975820*x);
L1+=0.00000001903*cost(5.11165653855+1066.49547719000*x);
L1+=0.00000002370*cost(3.87889340214+3355.86489788480*x);
L1+=0.00000002299*cost(1.15914205086+3320.25710730100*x);
L1+=0.00000001944*cost(5.89081872133+6894.52394883760*x);
L1+=0.00000001843*cost(3.07643314617+3325.35995551480*x);
L1+=0.00000001809*cost(4.97905218276+1648.44675719740*x);
L1+=0.00000002136*cost(1.91364787635+8969.56889691100*x);
L1+=0.00000002099*cost(3.00410255642+6254.62666252360*x);
L1+=0.00000001915*cost(3.55907431740+3767.21061757580*x);
L1+=0.00000001991*cost(5.37274107053+206.18554843720*x);
L1+=0.00000001685*cost(5.49701299817+266.60704172180*x);
L1+=0.00000001646*cost(1.31923405548+3264.34635542420*x);
L1+=0.00000001732*cost(1.81361103995+536.80451209540*x);
L1+=0.00000001723*cost(3.25900379342+7903.07341972100*x);
L1+=0.00000001564*cost(5.75428852012+3360.96774609859*x);
L1+=0.00000001589*cost(1.73273563259+3134.42687826260*x);
L1+=0.00000001690*cost(2.43213510013+3120.19978426100*x);
L1+=0.00000001549*cost(1.54016426558+8425.65083781480*x);
L1+=0.00000001536*cost(5.88431472627+20.77539549240*x);
L1+=0.00000001460*cost(4.89733072879+9830.38901398780*x);
L1+=0.00000002023*cost(5.94808387002+13365.97282514820*x);
L1+=0.00000001991*cost(3.11613326265+3361.38782219220*x);
L1+=0.00000001401*cost(2.24482184868+3344.20285535160*x);
L1+=0.00000001365*cost(4.58006320751+10818.13528691580*x);
L1+=0.00000001392*cost(5.48931017516+170.67287061920*x);
L1+=0.00000001360*cost(3.07974035205+6127.65545055720*x);
L1+=0.00000001345*cost(1.18653158091+14584.29827312060*x);
L1+=0.00000001717*cost(5.62501515015+6158.64743530580*x);
L1+=0.00000001408*cost(1.82072980335+3337.02199804800*x);
L1+=0.00000001736*cost(2.01921900546+10575.40668294180*x);
L1+=0.00000001402*cost(4.50079374387+5729.50644714900*x);
L1+=0.00000001266*cost(5.91088435118+9808.53818466140*x);
L1+=0.00000001433*cost(6.05024653324+12964.30070339100*x);
L1+=0.00000001223*cost(0.82796258263+419.48464387520*x);
L1+=0.00000001393*cost(1.05117949107+6438.49624942560*x);
L1+=0.00000001272*cost(1.50116723856+8439.87793181640*x);
L1+=0.00000001143*cost(4.89747373731+220.41264243880*x);
L1+=0.00000001183*cost(3.52587190041+6688.33840040040*x);
L1+=0.00000001132*cost(6.19236255633+6144.42034130420*x);
L1+=0.00000001154*cost(2.23058485970+8955.34180290940*x);
L1+=0.00000001129*cost(3.44264300692+10177.25767953360*x);
L1+=0.00000001152*cost(5.29913300616+27.40155609680*x);
L1+=0.00000001274*cost(4.58421238440+6247.51311552280*x);
L1+=0.00000001093*cost(2.82623332360+4569.57454002200*x);
L1+=0.00000001303*cost(0.44350560735+87.30820453981*x);
L1+=0.00000001335*cost(2.14204457730+11243.68584642080*x);
L1+=0.00000001102*cost(1.96260837539+6298.32832117640*x);
L1+=0.00000001066*cost(2.89865914321+10404.73381232260*x);
L1+=0.00000001027*cost(4.79269049654+3914.95722503460*x);
L1+=0.00000001015*cost(0.22847818730+3230.40610548040*x);
L1+=0.00000001041*cost(3.73274497451+10213.28554621100*x);
L1+=0.00000001154*cost(4.14326179244+6261.74020952440*x);
L1+=0.00000001306*cost(3.67645557029+2301.58581590939*x);
L1+=0.00000001145*cost(5.12292846748+4562.46099302120*x);
L1+=0.00000001275*cost(5.14333847164+2693.60159338500*x);
L1+=0.00000000914*cost(1.22398892152+103.09277421860*x);
L1+=0.00000000955*cost(1.52875141393+3369.06161416760*x);
L1+=0.00000000908*cost(0.48223420834+13358.92658845020*x);
L1+=0.00000000892*cost(1.35161136807+1214.73501932060*x);
L1+=0.00000000998*cost(3.29665881950+3178.14579056760*x);
L1+=0.00000000980*cost(1.69212466625+43.71891230500*x);
L1+=0.00000000919*cost(2.45445889752+13916.01910964160*x);
L1+=0.00000000899*cost(5.94990531529+12168.00269657460*x);
L1+=0.00000000891*cost(5.63297246408+10021.90459040220*x);
L1+=0.00000000922*cost(3.91483430303+9225.53927328300*x);
L1+=0.00000000930*cost(0.24073004700+6923.95345737360*x);
L1+=0.00000000923*cost(1.10396074450+29.42950853600*x);
L1+=0.00000000816*cost(4.65198282005+2707.82868738660*x);
L1+=0.00000000791*cost(6.08595583868+2384.32327072920*x);
L1+=0.00000000820*cost(4.80968546763+533.21408344360*x);
L1+=0.00000000758*cost(2.06012386134+12935.85151592320*x);
L1+=0.00000000738*cost(1.03564559078+14314.16811304980*x);
L1+=0.00000000908*cost(0.69862047595+16173.37116840440*x);
L1+=0.00000000700*cost(4.08788234610+5202.35827933520*x);
L1+=0.00000000829*cost(2.01062325398+9866.41688066520*x);
L1+=0.00000000887*cost(6.04145842617+10021.76996979660*x);
L1+=0.00000000768*cost(1.39532897827+8273.82086703240*x);
L1+=0.00000000873*cost(4.45446600602+3316.73398895200*x);
L1+=0.00000000673*cost(3.02440642752+1039.02661079040*x);
L1+=0.00000000660*cost(2.83410276989+107.66352393860*x);
L1+=0.00000000838*cost(0.39195370222+10551.52824519400*x);
L1+=0.00000000708*cost(3.27560955336+18984.29263000960*x);
L1+=0.00000000658*cost(6.01853128902+26724.89941359840*x);
L1+=0.00000000685*cost(1.98132615912+1228.96211332220*x);
L1+=0.00000000595*cost(0.10260171285+111.18664228760*x);
L1+=0.00000000563*cost(1.59138368358+2391.43681773000*x);
L1+=0.00000000555*cost(2.70801962190+4555.34744602040*x);
L1+=0.00000000696*cost(2.89276686038+2648.45482547300*x);
L1+=0.00000000587*cost(4.56017988729+6680.24453233140*x);
L1+=0.00000000540*cost(2.86002662919+5459.37628707820*x);
L1+=0.00000000530*cost(5.64877399946+6034.21402008480*x);
L1+=0.00000000520*cost(0.20012848836+13760.59871020740*x);
L1+=0.00000000552*cost(5.08766140543+1903.43681250120*x);
L1+=0.00000000512*cost(3.21411265909+11081.21921028860*x);
L1+=0.00000000641*cost(5.19459033638+6048.44111408640*x);
L1+=0.00000000677*cost(3.87723948458+13517.87010623340*x);
L1+=0.00000000534*cost(0.23224033336+51.28033786241*x);
L1+=0.00000000670*cost(3.69368226469+3335.08950239240*x);
L1+=0.00000000486*cost(2.41879628327+3364.49086444760*x);
L1+=0.00000000500*cost(4.31447859057+3344.49376205780*x);
L1+=0.00000000481*cost(1.56481992611+1964.83862685400*x);
L1+=0.00000000504*cost(2.47456295599+3863.18984479360*x);
L1+=0.00000000523*cost(0.65856269237+853.19638175200*x);
L1+=0.00000000481*cost(0.12971954679+66.48740891440*x);
L1+=0.00000000535*cost(2.98601678918+8270.29774868340*x);
L1+=0.00000000450*cost(2.02303462834+13362.43245314700*x);
L1+=0.00000000448*cost(5.59827312967+149.56319713460*x);
L1+=0.00000000519*cost(2.75931838722+3503.07906283200*x);
L1+=0.00000000534*cost(4.77352933347+1118.75579210280*x);
L1+=0.00000000450*cost(4.05380888708+13362.46696045140*x);
L1+=0.00000000439*cost(4.83194205477+3116.26763099790*x);
L1+=0.00000000567*cost(5.67483490268+227.47613278900*x);
L1+=0.00000000459*cost(3.44555998004+6702.00024889200*x);
L1+=0.00000000545*cost(2.01193901951+7910.18696672180*x);
L1+=0.00000000425*cost(2.79854459343+433.71173787680*x);
L1+=0.00000000429*cost(4.30113040289+16858.48253293320*x);
L1+=0.00000000409*cost(0.05448009540+3304.58456002240*x);
L1+=0.00000000434*cost(5.70806855136+21.85082932640*x);
L1+=0.00000000399*cost(4.93233684937+9779.10867612540*x);
L1+=0.00000000532*cost(1.31038986189+6660.44945790720*x);
L1+=0.00000000398*cost(5.31345458361+13119.72110282519*x);
L1+=0.00000000459*cost(2.53671963587+74.78159856730*x);
L1+=0.00000000384*cost(2.29906801437+12310.18132361080*x);
L1+=0.00000000467*cost(5.12562716972+1596.18644228460*x);
L1+=0.00000000516*cost(5.84767782422+1052.26838318840*x);
L1+=0.00000000414*cost(4.75409582610+3981.49003408200*x);
L1+=0.00000000365*cost(3.73271671549+5518.75014899180*x);
L1+=0.00000000367*cost(0.13506394328+56.89837493560*x);
L1+=0.00000000459*cost(0.15582180531+9381.93999378540*x);
L1+=0.00000000392*cost(2.15845463651+3980.50971301380*x);
L1+=0.00000000396*cost(1.48538591462+17924.91069982040*x);
L1+=0.00000000456*cost(0.64517343174+6816.28993343500*x);
L1+=0.00000000358*cost(5.87219240658+3607.21946842160*x);
L1+=0.00000000490*cost(0.65766946042+3376.64029337720*x);
L1+=0.00000000365*cost(1.91816243676+3347.65866339780*x);
L1+=0.00000000397*cost(1.80006148744+7895.95987272020*x);
L1+=0.00000000336*cost(2.14687780119+6677.63442474780*x);
L1+=0.00000000340*cost(2.88185925998+17256.63153634140*x);
L1+=0.00000000334*cost(6.13670038311+5724.93569742900*x);
L1+=0.00000000339*cost(4.08527025169+664.75604513000*x);
L1+=0.00000000432*cost(2.52188285182+18454.60166491500*x);
L1+=0.00000000336*cost(4.22863444521+6696.47732458460*x);
L1+=0.00000000342*cost(5.96724705923+3546.79797513700*x);
L1+=0.00000000326*cost(4.02557052581+6872.67311951120*x);
L1+=0.00000000323*cost(5.05444843838+3237.51965248120*x);
L1+=0.00000000324*cost(2.89151245241+8329.67161059700*x);
L1+=0.00000000321*cost(6.25886976298+10235.13637553740*x);
L1+=0.00000000333*cost(2.57725424455+6684.81528205140*x);
L1+=0.00000000356*cost(6.27424874986+8671.96987044060*x);
L1+=0.00000000319*cost(5.05665355586+36.60536530420*x);
L1+=0.00000000305*cost(3.88755666972+7107.82304427560*x);
L1+=0.00000000322*cost(6.28125601341+16706.58525184800*x);
L1+=0.00000000334*cost(3.15240620873+11216.28429032400*x);
L1+=0.00000000287*cost(6.16467002771+3973.39616601300*x);
L1+=0.00000000283*cost(2.67802456636+3877.41693879520*x);
L1+=0.00000000283*cost(1.66293157090+1692.16566950240*x);
L1+=0.00000000276*cost(2.94210551399+3415.39402526710*x);
L1+=0.00000000275*cost(0.53418048945+17395.21973472580*x);
L1+=0.00000000355*cost(3.31406527401+10022.81760116760*x);
L1+=0.00000000311*cost(1.50310910269+6660.86953400080*x);
L1+=0.00000000269*cost(1.84517097065+11780.49035851620*x);
L1+=0.00000000270*cost(4.42425307819+310.84079886840*x);
L1+=0.00000000275*cost(3.58464612058+128.01884333740*x);
L1+=0.00000000275*cost(2.22523539580+3017.10701004240*x);
L1+=0.00000000312*cost(5.15950395287+7255.56965173440*x);
L1+=0.00000000299*cost(0.72552273097+155.35308913140*x);
L1+=0.00000000353*cost(5.70047798350+16460.33352952499*x);
L1+=0.00000000267*cost(5.97864271046+9499.25986200560*x);
L1+=0.00000000270*cost(0.77063210836+11236.57229942000*x);
L1+=0.00000000339*cost(3.36092148900+5625.36604155940*x);
L1+=0.00000000315*cost(2.33795159922+3281.23856478620*x);
L1+=0.00000000247*cost(3.71002922076+7373.38245462640*x);
L1+=0.00000000328*cost(0.18162415648+5618.31980486140*x);
L1+=0.00000000247*cost(6.27486009856+15508.61512327440*x);
L1+=0.00000000292*cost(0.14989609091+16304.91313009080*x);
L1+=0.00000000326*cost(4.53606745007+2178.13772229200*x);
L1+=0.00000000286*cost(5.47710043383+9168.64089834740*x);
L1+=0.00000000246*cost(1.49838712480+15110.46611986620*x);
L1+=0.00000000262*cost(2.58821936465+3336.73109134180*x);
L1+=0.00000000244*cost(0.84015413449+16062.18452611680*x);
L1+=0.00000000245*cost(0.37772563756+12721.57209941700*x);
L1+=0.00000000250*cost(2.26824758119+6784.31762761820*x);
L1+=0.00000000248*cost(6.22740483254+13149.15061136120*x);
L1+=0.00000000255*cost(4.93078809107+14158.74771361560*x);
L1+=0.00000000240*cost(6.15843594225+19800.94595622480*x);
L1+=0.00000000249*cost(5.47044926479+4407.10790388980*x);
L1+=0.00000000235*cost(5.38750866169+76.26607127560*x);
L1+=0.00000000258*cost(6.10384464886+2480.30249794700*x);
L1+=0.00000000306*cost(5.35546231697+2766.26762836500*x);
L1+=0.00000000236*cost(5.25670707064+13171.00144068760*x);
L1+=0.00000000224*cost(4.52466909993+12566.15169998280*x);
L1+=0.00000000220*cost(5.83694256642+13936.79450513400*x);
L1+=0.00000000271*cost(1.42460945147+14054.60730802600*x);
L1+=0.00000000213*cost(0.21127914063+1505.28780909299*x);
L1+=0.00000000267*cost(5.16501015011+3205.54734666440*x);
L1+=0.00000000212*cost(4.26202838353+6546.15977336420*x);
L1+=0.00000000211*cost(6.21401684263+3253.30422216000*x);
L1+=0.00000000233*cost(3.72007597749+3346.13535100720*x);
L1+=0.00000000274*cost(2.91986569135+10713.99488132620*x);
L1+=0.00000000201*cost(3.36695295492+6.68366387410*x);
L1+=0.00000000223*cost(3.08788599159+401.67212175720*x);
L1+=0.00000000234*cost(2.24268269202+110.20632121940*x);
L1+=0.00000000264*cost(2.08178742740+6475.03930496240*x);
L1+=0.00000000231*cost(4.53806384480+9602.35263622420*x);
L1+=0.00000000213*cost(2.85452302656+5415.65737477320*x);
L1+=0.00000000195*cost(0.99589439506+5642.19824260920*x);
L1+=0.00000000259*cost(0.00464351114+9380.95967271720*x);
L1+=0.00000000197*cost(3.32573550633+3657.00429635640*x);
L1+=0.00000000228*cost(5.33299975472+3561.02506913860*x);
L1+=0.00000000193*cost(1.25502846507+6606.44325483230*x);
L1+=0.00000000199*cost(1.13665869139+685.04405422600*x);
L1+=0.00000000227*cost(4.49610509002+589.06482700820*x);
L1+=0.00000000217*cost(5.48740879816+10596.18207843420*x);
L1+=0.00000000192*cost(4.26501800444+3333.56619000180*x);
L1+=0.00000000188*cost(1.44301618203+4885.96640967860*x);
L1+=0.00000000178*cost(4.82506490541+9070.11887384880*x);
L1+=0.00000000184*cost(5.69637552141+3351.24909204960*x);
L1+=0.00000000187*cost(0.76021337348+16699.53901514999*x);
L1+=0.00000000226*cost(0.82767654373+3265.83082813250*x);
L1+=0.00000000204*cost(6.20933387021+394.62588505920*x);
L1+=0.00000000176*cost(3.89567349231+10028.95082710020*x);
L1+=0.00000000174*cost(3.68843293982+735.87651353180*x);
L1+=0.00000000173*cost(2.44269377255+3603.69635007260*x);
L1+=0.00000000177*cost(1.24154853329+12722.55242048520*x);
L1+=0.00000000184*cost(4.77203925989+286.96236112060*x);
L1+=0.00000000171*cost(4.67140116008+20199.09495963300*x);
L1+=0.00000000170*cost(5.13753345526+1332.05488754080*x);
L1+=0.00000000201*cost(2.37863157745+16276.46394262300*x);
L1+=0.00000000209*cost(0.57156268506+11250.79939342160*x);
L1+=0.00000000164*cost(1.98441291396+10014.72373309860*x);
L1+=0.00000000191*cost(0.60250751218+56.80326216980*x);
L1+=0.00000000171*cost(6.22556266993+17277.40693183380*x);
L1+=0.00000000166*cost(1.05948008727+19513.98359510420*x);
L1+=0.00000000163*cost(1.59661610701+1437.17561419860*x);
L1+=0.00000000165*cost(3.36308723589+6665.97238221460*x);
L1+=0.00000000184*cost(3.20554894393+263.08392337280*x);
L1+=0.00000000212*cost(3.10485836003+4039.88357492740*x);
L1+=0.00000000176*cost(3.41768939214+9468.26787725700*x);
L1+=0.00000000163*cost(1.39275730949+8982.81066930900*x);
L1+=0.00000000213*cost(3.39734274482+931.36308685180*x);
L1+=0.00000000189*cost(4.54004144896+8542.97070603500*x);
L1+=0.00000000191*cost(1.15555618959+3169.93955608060*x);
L1+=0.00000000155*cost(1.41249963094+22.76849660940*x);
L1+=0.00000000153*cost(5.14168081601+156.40072050240*x);
L1+=0.00000000159*cost(3.64996617906+8013.27974094040*x);
L1+=0.00000000151*cost(1.93804487507+3384.33133900480*x);
L1+=0.00000000157*cost(0.58554505759+158.94351778320*x);
L1+=0.00000000173*cost(2.72517427493+2807.39834325620*x);
L1+=0.00000000159*cost(0.67192454133+13892.14067189380*x);
L1+=0.00000000150*cost(2.66045714174+19004.64794940840*x);
L1+=0.00000000192*cost(5.73782632783+206.70073729660*x);
L1+=0.00000000143*cost(3.19213280913+6843.69148953180*x);
L1+=0.00000000194*cost(1.32358882667+19402.79695281660*x);
L1+=0.00000000143*cost(2.36478163720+13207.02930736500*x);
L1+=0.00000000140*cost(1.88800568840+11766.26326451460*x);
L1+=0.00000000144*cost(0.69018080218+17085.95866572220*x);
L1+=0.00000000183*cost(5.98085295555+13362.51701710200*x);
L1+=0.00000000161*cost(2.92764155222+5.85720229960*x);
L1+=0.00000000162*cost(6.07051064413+6701.58017279840*x);
L1+=0.00000000192*cost(0.86266150575+2814.44457995420*x);
L1+=0.00000000182*cost(5.26446797092+3873.82651014340*x);
L1+=0.00000000137*cost(0.41563614709+5820.91492464680*x);
L1+=0.00000000144*cost(3.02314051168+708.98980227659*x);
L1+=0.00000000184*cost(4.61314496499+3329.97576135000*x);
L1+=0.00000000131*cost(3.48156082643+367.22432896240*x);
L1+=0.00000000173*cost(3.09922849765+12295.95422960920*x);
L1+=0.00000000135*cost(2.23311632892+15664.03552270859*x);
L1+=0.00000000147*cost(1.95810911154+5732.04924442980*x);
L1+=0.00000000158*cost(1.48909254724+29.49181830340*x);
L1+=0.00000000127*cost(5.55534080040+3368.01398279660*x);
L1+=0.00000000129*cost(1.78002583252+22743.40937951640*x);
L1+=0.00000000132*cost(2.81496895377+21795.21409161479*x);
L1+=0.00000000127*cost(5.73090203501+3340.19235060619*x);
L1+=0.00000000164*cost(1.87613918877+6709.67404086740*x);
L1+=0.00000000123*cost(3.61238958991+22324.90505670940*x);
L1+=0.00000000129*cost(4.92064308735+2540.79130153440*x);
L1+=0.00000000121*cost(6.16922638434+20206.14119633100*x);
L1+=0.00000000122*cost(5.79901866314+1854.63230563460*x);
L1+=0.00000000133*cost(0.50941998058+3274.12501778540*x);
L1+=0.00000000151*cost(1.61342807879+1107.13880568480*x);
L1+=0.00000000165*cost(2.02795177586+290.48547946960*x);
L1+=0.00000000125*cost(0.52719797619+2604.73591316800*x);
L1+=0.00000000144*cost(5.68526782434+8827.39026987480*x);
L1+=0.00000000126*cost(3.80246508251+765.79306444640*x);
L1+=0.00000000116*cost(1.79450246249+647.01083331480*x);
L1+=0.00000000126*cost(2.00195272473+699.27114822760*x);
L1+=0.00000000147*cost(6.22619740782+6040.34724601740*x);
L1+=0.00000000119*cost(2.05840518265+15121.10278521600*x);
L1+=0.00000000114*cost(2.74877091470+6460.81221096080*x);
L1+=0.00000000155*cost(1.78154091696+21265.52312652020*x);
L1+=0.00000000146*cost(3.37351237411+1861.74585263540*x);
L1+=0.00000000118*cost(4.07281676691+418.50432280700*x);
L1+=0.00000000116*cost(0.10434606071+13362.38239649640*x);
L1+=0.00000000129*cost(0.78419803719+3427.92063123960*x);
L1+=0.00000000152*cost(0.32620694442+3443.70520091840*x);
L1+=0.00000000110*cost(0.56398082486+661.23292678100*x);
L1+=0.00000000111*cost(4.05380946072+568.82187402740*x);
L1+=0.00000000108*cost(3.17700641574+3448.27595063840*x);
L1+=0.00000000138*cost(4.47698517191+3326.38533269820*x);
L1+=0.00000000108*cost(4.89922372003+9588.12554222260*x);
L1+=0.00000000114*cost(4.80828825403+6657.34641565180*x);
L1+=0.00000000108*cost(4.10637483972+13553.89797291080*x);
L1+=0.00000000125*cost(0.33573243959+18849.22754997420*x);
L1+=0.00000000115*cost(3.18885465852+2409.24933984800*x);
L1+=0.00000000104*cost(3.23074163851+3472.15438838620*x);
L1+=0.00000000104*cost(0.09799515047+30065.51184029820*x);
L1+=0.00000000112*cost(1.64487733528+10001.06188460700*x);
L1+=0.00000000143*cost(3.53781769283+6518.75821726740*x);
L1+=0.00000000113*cost(5.20979306912+2125.87740737920*x);
L1+=0.00000000104*cost(2.77582098882+38.13303563780*x);
L1+=0.00000000133*cost(5.88513337452+5835.14201864840*x);
L1+=0.00000000105*cost(4.11662579413+6675.70192909220*x);
L1+=0.00000000102*cost(0.60100887043+10264.56588407340*x);
L1+=0.00000000101*cost(3.78636130664+10042.61267559180*x);
L1+=0.00000000139*cost(1.80936944447+12323.42309600880*x);
L1+=0.00000000101*cost(2.47217208753+7380.49600162720*x);
L1+=0.00000000130*cost(2.53454569863+11769.85369316640*x);
L1+=0.00000000100*cost(5.72291104291+14.22709400160*x);
L1+=0.00000000135*cost(4.20237564510+4672.66731424060*x);
L1+=0.00000000133*cost(0.34413768012+16489.76303806100*x);
L1+=0.00000000098*cost(1.44874403589+3370.04193523580*x);
L1+=0.00000000131*cost(1.31336606248+3313.21087060300*x);
L1+=0.00000000111*cost(3.12463539337+309.27832265580*x);
L1+=0.00000000101*cost(3.15369992044+24150.08005134500*x);
L1+=0.00000000102*cost(6.13479937096+2277.70737816160*x);
L1+=0.00000000099*cost(0.10085261274+12839.87228870540*x);
L1+=0.00000000134*cost(2.91637947295+57.87869600380*x);
L1+=0.00000000104*cost(3.30283052330+3399.98628861340*x);
L1+=0.00000000108*cost(4.92699760221+802.36392244620*x);
L1+=0.00000000106*cost(2.89298330043+7799.98064550240*x);
L1+=0.00000000112*cost(3.12761163915+5989.06725217280*x);
L1+=0.00000000094*cost(3.42562596561+3510.19260983280*x);
L1+=0.00000000102*cost(0.94285421551+3209.07046501340*x);
L1+=0.00000000096*cost(0.79636181668+3024.22055704320*x);
L1+=0.00000000093*cost(1.08979608844+14577.18472611980*x);
L1+=0.00000000097*cost(3.56551535742+14421.83163698840*x);
L1+=0.00000000092*cost(5.02279637510+2494.52959194860*x);
L1+=0.00000000123*cost(5.83481108101+7747.72033058960*x);
L1+=0.00000000111*cost(3.31406538379+11610.91017538320*x);
L1+=0.00000000118*cost(5.00845322960+1581.95934828300*x);
L1+=0.00000000091*cost(2.36839307589+11140.59307220220*x);
L1+=0.00000000099*cost(2.93269536697+2067.93140107260*x);
L1+=0.00000000124*cost(3.15220420912+22345.26037610820*x);
L1+=0.00000000090*cost(0.85462370851+17232.75309859360*x);
L1+=0.00000000125*cost(1.54866979468+1435.14766175940*x);
L1+=0.00000000113*cost(4.57220387105+14712.31711645800*x);
L1+=0.00000000103*cost(0.11158194413+11.04570026390*x);
L1+=0.00000000113*cost(2.41110151532+5244.04923920100*x);
L1+=0.00000000091*cost(1.77184730280+2221.85663459700*x);
L1+=0.00000000114*cost(1.92696878615+8226.57883637840*x);
L1+=0.00000000118*cost(0.29322259611+2945.98654164060*x);
L1+=0.00000000089*cost(4.49875865671+21947.11137270000*x);
L1+=0.00000000104*cost(1.36766858693+4032.77002792660*x);
L1+=0.00000000116*cost(4.67476277278+272.67295735160*x);
L1+=0.00000000105*cost(3.73327973850+4989.05918389720*x);
L1+=0.00000000095*cost(0.34653808205+13517.80279593060*x);
L1+=0.00000000086*cost(2.70925448214+7218.02936549500*x);
L1+=0.00000000112*cost(5.27572276726+17499.36014031540*x);
L1+=0.00000000114*cost(3.37335971932+2938.94030494260*x);
L1+=0.00000000090*cost(0.26623024836+9485.03276800400*x);
L1+=0.00000000086*cost(3.66786582491+6997.61672305620*x);
L1+=0.00000000087*cost(4.07823608680+18606.49894600020*x);
L1+=0.00000000117*cost(5.61863859185+16511.61386738740*x);
L1+=0.00000000084*cost(2.80171829534+8584.66166590080*x);
L1+=0.00000000086*cost(5.87459621301+73.60095591520*x);
L1+=0.00000000090*cost(1.07789160729+10721.10842832700*x);
L1+=0.00000000084*cost(0.78729386249+146.81168652360*x);
L1+=0.00000000112*cost(2.31690430881+9638.94074787620*x);
L1+=0.00000000083*cost(5.90575201511+16858.41522263039*x);
L1+=0.00000000082*cost(4.31690557700+9374.82644678460*x);
L1+=0.00000000083*cost(1.41315204958+22854.59602180400*x);
L1+=0.00000000084*cost(0.90320571725+2171.02417529120*x);
L1+=0.00000000082*cost(1.59442952041+9947.05568153210*x);
L1+=0.00000000082*cost(0.44163602941+4782.87363546000*x);
L1+=0.00000000086*cost(5.18335054161+12410.73130054860*x);
L1+=0.00000000085*cost(3.61669636863+8965.97846825920*x);
L1+=0.00000000097*cost(5.35511765140+4996.17273089800*x);
L1+=0.00000000085*cost(2.36814442737+1062.90504853820*x);
L1+=0.00000000078*cost(1.75580354602+2060.81785407180*x);
L1+=0.00000000087*cost(0.98702744399+10156.90236013480*x);
L1+=0.00000000098*cost(0.35294347682+23546.75362303080*x);
L1+=0.00000000101*cost(1.03298143418+20040.15144184979*x);
L1+=0.00000000088*cost(0.56201084357+17101.21113690720*x);
L1+=0.00000000082*cost(2.65765057749+12979.55317457600*x);
L1+=0.00000000085*cost(1.07007237991+10706.88133432540*x);
L1+=0.00000000082*cost(0.80588396320+20735.83216142559*x);
L1+=0.00000000092*cost(4.87180501294+9389.05354078620*x);
L1+=0.00000000078*cost(3.22869264518+11925.27409260060*x);
L1+=0.00000000074*cost(5.59171946181+8535.85715903420*x);
L1+=0.00000000080*cost(0.42260849968+956.28915597060*x);
L1+=0.00000000082*cost(1.47379060963+16.83220104979*x);
L1+=0.00000000073*cost(3.76950560688+8859.36257569160*x);
L1+=0.00000000073*cost(4.59130182630+362.12113673080*x);
L1+=0.00000000072*cost(5.15373872266+9872.27408296480*x);
L1+=0.00000000098*cost(2.47740242208+5401.43028077160*x);
L1+=0.00000000071*cost(0.08395696279+15849.86575174700*x);
L1+=0.00000000078*cost(0.04212599783+16703.12944380180*x);
L1+=0.00000000075*cost(3.77172360793+4845.90023579280*x);
L1+=0.00000000072*cost(2.01742377451+1329.51209026000*x);
L1+=0.00000000076*cost(0.30413402871+72.05573335480*x);
L1+=0.00000000097*cost(5.15109318550+1.48447270830*x);
L1+=0.00000000070*cost(0.33648335823+23141.55838292460*x);
L1+=0.00000000068*cost(0.34828385806+20047.19767854780*x);
L1+=0.00000000078*cost(1.42772075938+16063.16484718500*x);
L1+=0.00000000081*cost(2.37498404818+16703.04487984680*x);
L1+=0.00000000069*cost(3.66727984195+13363.43002786740*x);
L1+=0.00000000067*cost(1.77194706681+18451.07854656599*x);
L1+=0.00000000073*cost(0.41181711796+33406.12426699800*x);
L1+=0.00000000067*cost(3.15946840380+8799.98871377800*x);
L1+=0.00000000067*cost(4.07602260745+10448.43547097540*x);
L1+=0.00000000068*cost(1.78981361818+224.34479570190*x);
L1+=0.00000000066*cost(1.01449371817+4193.80880845180*x);
L1+=0.00000000067*cost(4.89249339125+12082.65513417120*x);
L1+=0.00000000081*cost(0.61914094848+949.17560896980*x);
L1+=0.00000000066*cost(3.39914635235+10184.30391623160*x);
L1+=0.00000000064*cost(5.50528849889+4936.79886898440*x);
L1+=0.00000000064*cost(1.82608235490+3077.52850332700*x);
L1+=0.00000000069*cost(2.48571574894+10018.24685144760*x);
L1+=0.00000000064*cost(2.80447322320+20809.46762464520*x);
L1+=0.00000000068*cost(0.97907335430+6717.25272007700*x);
L1+=0.00000000087*cost(2.45966764758+7321.12213971360*x);
L1+=0.00000000062*cost(1.69131771765+632.78373931320*x);
L1+=0.00000000081*cost(4.40575713075+16703.07938715119*x);
L1+=0.00000000063*cost(3.63625395496+25685.87280280800*x);
L1+=0.00000000075*cost(5.54907590704+16872.64231663200*x);
L1+=0.00000000061*cost(0.33159827734+12012.58229714040*x);
L1+=0.00000000063*cost(3.16314818302+11670.28403729680*x);
L1+=0.00000000062*cost(0.23148800541+7314.00859271280*x);
L1+=0.00000000078*cost(1.65377731167+11614.43329373220*x);
L1+=0.00000000068*cost(1.10866475394+6155.05700665400*x);
L1+=0.00000000068*cost(4.45713540461+9175.75444534820*x);
L1+=0.00000000081*cost(3.66553577428+15265.88651930040*x);
L1+=0.00000000068*cost(5.59792852411+377.37360791580*x);
L1+=0.00000000059*cost(6.25689995147+41427.48698317880*x);
L1+=0.00000000072*cost(3.39739853142+685.11136452880*x);
L1+=0.00000000062*cost(0.11206359088+14047.49376102520*x);
L1+=0.00000000057*cost(4.31819630987+95.97922721780*x);
L1+=0.00000000070*cost(5.98596344975+6531.66165626500*x);
L1+=0.00000000066*cost(5.93804470886+3490.17562383440*x);
L1+=0.00000000056*cost(5.11205539684+7322.10246078180*x);
L1+=0.00000000056*cost(3.36788837326+4379.63903749020*x);
L1+=0.00000000056*cost(2.20908914878+6688.27109009760*x);
L1+=0.00000000057*cost(4.57828186723+10037.08975128440*x);
L1+=0.00000000057*cost(0.04695703833+24889.57479599160*x);
L1+=0.00000000065*cost(2.70973517401+19617.07636932279*x);
L1+=0.00000000068*cost(3.51423189318+14556.89671702380*x);
L1+=0.00000000056*cost(5.94452825242+21548.96236929180*x);
L1+=0.00000000056*cost(3.94541346495+25665.51748340920*x);
L1+=0.00000000055*cost(0.45166365461+16702.99482319620*x);
L1+=0.00000000062*cost(0.05229160039+14061.72085502680*x);
L1+=0.00000000055*cost(1.14774475393+4459.36821880260*x);
L1+=0.00000000065*cost(6.21442820689+6947.83189512140*x);
L1+=0.00000000056*cost(5.01712943722+485.97205278960*x);
L1+=0.00000000065*cost(1.51615558729+5511.63660199100*x);
L1+=0.00000000072*cost(4.90742373357+25287.72379939980*x);
L1+=0.00000000057*cost(5.31542907454+28628.33622609960*x);
L1+=0.00000000055*cost(4.02023620788+4005.36847182980*x);
L1+=0.00000000054*cost(5.51196184505+44.65383324020*x);
L1+=0.00000000053*cost(0.46840976995+19645.52555679060*x);
L1+=0.00000000053*cost(4.51539970261+9886.77220006400*x);
L1+=0.00000000069*cost(3.37092084432+41.55079098480*x);
L1+=0.00000000072*cost(4.66520155151+6685.10618875760*x);
L1+=0.00000000052*cost(2.05209599225+7366.26890762560*x);
L1+=0.00000000052*cost(6.25882226723+12509.25332504720*x);
L1+=0.00000000060*cost(0.33350021257+13575.74880223720*x);
L1+=0.00000000059*cost(5.94433755684+625.67019231240*x);
L1+=0.00000000050*cost(2.65624501709+10124.93005431800*x);
L1+=0.00000000068*cost(2.92105834159+10025.42770875120*x);
L1+=0.00000000051*cost(2.88289068067+39601.89191244960*x);
L1+=0.00000000069*cost(1.09637075565+24076.44458812540*x);
L1+=0.00000000052*cost(2.65290577481+15650.79375031060*x);
L1+=0.00000000052*cost(3.28683313010+6756.00645196690*x);
L1+=0.00000000054*cost(5.34683925496+6578.13207918100*x);
L1+=0.00000000054*cost(2.77410607136+6705.10329114740*x);
L1+=0.00000000049*cost(2.65700209900+6944.30877677240*x);
L1+=0.00000000053*cost(5.67436244967+1883.08149310240*x);
L1+=0.00000000048*cost(5.68336050679+8646.06348025360*x);
L1+=0.00000000051*cost(0.11390643300+17402.33328172660*x);
L1+=0.00000000065*cost(1.03099992649+4106.40549114620*x);
L1+=0.00000000060*cost(1.00159365247+151.89728108520*x);
L1+=0.00000000050*cost(3.84651247899+45494.58142974879*x);
L1+=0.00000000047*cost(3.03959709242+5408.54382777240*x);
L1+=0.00000000063*cost(4.16165369755+8186.51266249260*x);
L1+=0.00000000046*cost(2.69368087378+16547.64173406480*x);
L1+=0.00000000051*cost(2.99576014378+3774.32416457660*x);
L1+=0.00000000044*cost(2.00664763411+6418.14093002680*x);
L1+=0.00000000045*cost(4.01853755929+19406.67828817460*x);
L1+=0.00000000058*cost(3.14474753550+4025.65648092580*x);
L1+=0.00000000050*cost(2.59881540437+6621.85099148600*x);
L1+=0.00000000043*cost(4.87912487459+6414.61781167780*x);
L1+=0.00000000042*cost(5.20400092044+4447.75123238460*x);
L1+=0.00000000051*cost(1.99634375899+5032.77809620220*x);
L1+=0.00000000043*cost(1.28813888865+6643.09181776180*x);
L1+=0.00000000040*cost(0.96801618560+14591.41182012140*x);
L1+=0.00000000039*cost(1.84985100829+10001.48196070061*x);
L1+=0.00000000039*cost(5.69967200167+6106.88005506480*x);
L1+=0.00000000038*cost(3.27498743518+18052.92954315780*x);
L1+=0.00000000039*cost(2.84167905068+6652.77566593180*x);
L1+=0.00000000044*cost(0.57891618854+16865.52876963120*x);
L1+=0.00000000043*cost(4.61937364869+3341.03250279340*x);
L1+=0.00000000042*cost(6.02555835659+6691.86151874940*x);
L1+=0.00000000034*cost(4.97734992350+6670.58818804980*x);
L1+=0.00000000033*cost(1.39167727215+4825.54491639400*x);
L1+=0.00000000035*cost(6.02955363644+3568.08855948880*x);
L1+=0.00000000035*cost(0.31961016732+6645.19698672220*x);
L1+=0.00000000032*cost(5.63043769073+3511.28529731900*x);
L1+=0.00000000031*cost(5.42978464210+9945.57120882380*x);
L1+=0.00000000038*cost(5.66461657503+3416.87849797540*x);
L1+=0.00000000030*cost(0.98518793666+20426.57109242200*x);
L1+=0.00000000038*cost(0.12870962242+6604.95878212400*x);
L1+=0.00000000037*cost(5.48374357342+3311.18291816379*x);
L1+=0.00000000032*cost(6.11106979810+4392.88080988820*x);
L1+=0.00000000031*cost(3.18481282781+3341.04230982650*x);
L1+=0.00000000034*cost(2.32358226279+9072.66167112960*x);
L1+=0.00000000039*cost(4.11042361929+3312.16323923200*x);
L1+=0.00000000027*cost(0.57810321636+3391.89276456221*x);
L1+=0.00000000029*cost(2.48646403166+9815.65173166220*x);
L1+=0.00000000031*cost(0.44265747667+3451.79906898740*x);
L1+=0.00000000027*cost(6.13498177783+3362.46325602620*x);
L1+=0.00000000027*cost(6.21846173482+5223.69391980220*x);
L1+=0.00000000027*cost(2.94945830517+7203.80227149340*x);
L1+=0.00000000027*cost(3.26179855800+8756.26980147300*x);
L1+=0.00000000027*cost(3.94385271700+23958.63178523340*x);
L1+=0.00000000033*cost(3.77237326006+12808.88030395680*x);
L1+=0.00000000030*cost(4.75096367323+15906.76412668260*x);
L1+=0.00000000031*cost(0.88248871193+3340.18254357310*x);
L1+=0.00000000025*cost(0.31303295413+6571.01853218020*x);
L1+=0.00000000031*cost(4.29076841627+10020.85695903120*x);
L1+=0.00000000026*cost(2.22427360058+10050.28646756720*x);
L1+=0.00000000025*cost(0.67881122439+23937.85638974100*x);
L1+=0.00000000031*cost(1.72899093511+13745.34623902240*x);
L1+=0.00000000024*cost(0.20355912395+3229.42578441220*x);
L1+=0.00000000032*cost(3.37195631109+2284.75361485960*x);

double L2=0;
L2+=0.00058015791*cost(2.04979463279+3340.61242669980*x);
L2+=0.00054187645;
L2+=0.00013908426*cost(2.45742359888+6681.22485339960*x);
L2+=0.00002465104*cost(2.80000020929+10021.83728009940*x);
L2+=0.00000398379*cost(3.14118428289+13362.44970679920*x);
L2+=0.00000222022*cost(3.19436080019+3.52311834900*x);
L2+=0.00000120957*cost(0.54325292454+155.42039943420*x);
L2+=0.00000061517*cost(3.48529427371+16703.06213349900*x);
L2+=0.00000053638*cost(3.54191121461+3344.13554504880*x);
L2+=0.00000034268*cost(6.00188499119+2281.23049651060*x);
L2+=0.00000031665*cost(4.14015171788+191.44826611160*x);
L2+=0.00000029839*cost(1.99870679845+796.29800681640*x);
L2+=0.00000023168*cost(4.33403365928+242.72860397400*x);
L2+=0.00000021659*cost(3.44532466378+398.14900340820*x);
L2+=0.00000016044*cost(6.11000472441+2146.16541647520*x);
L2+=0.00000020370*cost(5.42191375400+553.56940284240*x);
L2+=0.00000014927*cost(6.09541783564+3185.19202726560*x);
L2+=0.00000016227*cost(0.65678953303+0.98032106820*x);
L2+=0.00000014317*cost(2.61851897591+1349.86740965880*x);
L2+=0.00000014416*cost(4.01923812101+951.71840625060*x);
L2+=0.00000011934*cost(3.86122163021+6684.74797174860*x);
L2+=0.00000015648*cost(1.22086121940+1748.01641306700*x);
L2+=0.00000011260*cost(4.71822363671+2544.31441988340*x);
L2+=0.00000013352*cost(0.60189008414+1194.44701022460*x);
L2+=0.00000010396*cost(0.25038714677+382.89653222320*x);
L2+=0.00000009468*cost(0.68170713564+1059.38193018920*x);
L2+=0.00000009229*cost(3.83209092321+20043.67456019880*x);
L2+=0.00000009005*cost(3.88271826102+3738.76143010800*x);
L2+=0.00000007501*cost(5.46498630412+1751.53953141600*x);
L2+=0.00000006497*cost(5.47773072872+1592.59601363280*x);
L2+=0.00000006311*cost(2.34104793674+3097.88382272579*x);
L2+=0.00000006859*cost(2.57522504136+3149.16416058820*x);
L2+=0.00000005870*cost(1.14783576679+7.11354700080*x);
L2+=0.00000006681*cost(2.37843690339+4136.91043351620*x);
L2+=0.00000004647*cost(4.42957708526+6151.53388830500*x);
L2+=0.00000004166*cost(3.68631477611+5614.72937620960*x);
L2+=0.00000004764*cost(2.89684755585+3333.49887969900*x);
L2+=0.00000004045*cost(6.12493402657+5628.95647021120*x);
L2+=0.00000003653*cost(4.06679068397+1990.74501704100*x);
L2+=0.00000003618*cost(2.46868561769+529.69096509460*x);
L2+=0.00000003277*cost(0.68101740787+8962.45534991020*x);
L2+=0.00000003253*cost(2.79565340390+3894.18182954220*x);
L2+=0.00000003091*cost(4.56861203364+3496.03282613400*x);
L2+=0.00000002921*cost(5.41458945995+2914.01423582380*x);
L2+=0.00000002921*cost(1.23050883841+2787.04302385740*x);
L2+=0.00000002784*cost(1.38911141844+4292.33083295040*x);
L2+=0.00000002620*cost(1.04061894134+3341.59274776800*x);
L2+=0.00000002888*cost(3.41062353663+3337.08930835080*x);
L2+=0.00000002418*cost(0.96341462666+4535.05943692440*x);
L2+=0.00000002357*cost(4.84628239765+9492.14631500480*x);
L2+=0.00000002593*cost(5.74934234498+3340.59517304760*x);
L2+=0.00000002191*cost(3.26449527357+213.29909543800*x);
L2+=0.00000002594*cost(1.49510566123+3340.62968035200*x);
L2+=0.00000002344*cost(4.18104725028+10025.36039844840*x);
L2+=0.00000002630*cost(4.67640929857+3583.34103067380*x);
L2+=0.00000002602*cost(2.64911714813+2388.89402044920*x);
L2+=0.00000001830*cost(0.97181050149+1589.07289528380*x);
L2+=0.00000002416*cost(1.04749173375+4399.99435688900*x);
L2+=0.00000002386*cost(4.27072575550+7079.37385680780*x);
L2+=0.00000002187*cost(0.16036551231+6525.80445396540*x);
L2+=0.00000002344*cost(0.01425578204+4690.47983635860*x);
L2+=0.00000001617*cost(4.95614491689+5088.62883976680*x);
L2+=0.00000001633*cost(1.10703599922+12303.06777661000*x);
L2+=0.00000002126*cost(0.48290227706+2700.71514038580*x);
L2+=0.00000001629*cost(4.94267977718+1221.84856632140*x);
L2+=0.00000001504*cost(0.11031912519+2957.71589447660*x);
L2+=0.00000001759*cost(3.81170701376+3723.50895892300*x);
L2+=0.00000001401*cost(3.85907867678+6283.07584999140*x);
L2+=0.00000001338*cost(5.29685392418+6677.70173505060*x);
L2+=0.00000001763*cost(2.51660121293+2810.92146160520*x);
L2+=0.00000001392*cost(2.73498041122+7477.52286021600*x);
L2+=0.00000001431*cost(2.97747408389+6489.77658728800*x);
L2+=0.00000001236*cost(3.77245965590+2699.73481931760*x);
L2+=0.00000001234*cost(1.88931735265+6681.24210705180*x);
L2+=0.00000001513*cost(2.92614134711+640.87760738220*x);
L2+=0.00000001234*cost(6.14168429036+6681.20759974740*x);
L2+=0.00000001408*cost(1.54395721611+3347.72597370060*x);
L2+=0.00000001038*cost(5.82880072933+4933.20844033260*x);
L2+=0.00000001156*cost(1.50825464304+426.59819087600*x);
L2+=0.00000001362*cost(4.17794297520+23384.28698689860*x);
L2+=0.00000001135*cost(3.77506455273+3870.30339179440*x);
L2+=0.00000000916*cost(3.81726339298+5092.15195811580*x);
L2+=0.00000000853*cost(3.82520490669+3340.54511639700*x);
L2+=0.00000001077*cost(5.05062828760+5621.84292321040*x);
L2+=0.00000001074*cost(3.81446920470+3553.91152213780*x);
L2+=0.00000000847*cost(3.41702696402+3340.67973700260*x);
L2+=0.00000000920*cost(1.91108056416+3532.06069281140*x);
L2+=0.00000000738*cost(4.25786145387+9623.68827669120*x);
L2+=0.00000000908*cost(4.12911006922+162.46663613220*x);
L2+=0.00000000647*cost(3.10301033831+7234.79425624200*x);
L2+=0.00000000800*cost(5.20674574801+87.30820453981*x);
L2+=0.00000000657*cost(1.57895580467+2487.41604494780*x);
L2+=0.00000000650*cost(2.78932995437+574.34479833480*x);
L2+=0.00000000659*cost(5.16655918817+12832.75874170460*x);
L2+=0.00000000712*cost(5.79288230676+3339.63210563160*x);
L2+=0.00000000660*cost(0.25125103909+8969.56889691100*x);
L2+=0.00000000527*cost(4.62218528897+10419.98628350760*x);
L2+=0.00000000607*cost(3.84724721085+5486.77784317500*x);
L2+=0.00000000500*cost(4.66323134619+6836.64525283380*x);
L2+=0.00000000509*cost(0.32548381735+8031.09226305840*x);
L2+=0.00000000613*cost(1.72250879737+7632.94325965020*x);
L2+=0.00000000516*cost(1.37906978509+7740.60678358880*x);
L2+=0.00000000469*cost(1.31324778369+7875.67186362420*x);
L2+=0.00000000442*cost(5.34515135225+10018.31416175040*x);
L2+=0.00000000496*cost(4.49656852602+692.15760122680*x);
L2+=0.00000000544*cost(1.44465369200+15643.68020330980*x);
L2+=0.00000000467*cost(1.40928870138+6682.20517446780*x);
L2+=0.00000000547*cost(4.42021065522+5331.35744374080*x);
L2+=0.00000000433*cost(1.25048504108+4929.68532198360*x);
L2+=0.00000000409*cost(3.80689273098+6681.29216370240*x);
L2+=0.00000000403*cost(1.57190239310+6127.65545055720*x);
L2+=0.00000000401*cost(4.59976459753+7210.91581849420*x);
L2+=0.00000000406*cost(0.60945437905+11773.37681151540*x);
L2+=0.00000000367*cost(0.97726583907+6041.32756708560*x);
L2+=0.00000000361*cost(0.13117924893+639.89728631400*x);
L2+=0.00000000411*cost(4.21323421517+6681.15754309680*x);
L2+=0.00000000441*cost(4.49050100878+13365.97282514820*x);
L2+=0.00000000474*cost(5.18562524130+2301.58581590939*x);
L2+=0.00000000334*cost(2.21001303889+10021.85453375160*x);
L2+=0.00000000370*cost(5.02880065186+6923.95345737360*x);
L2+=0.00000000333*cost(0.18229887483+10021.82002644720*x);
L2+=0.00000000342*cost(2.49988747611+6438.49624942560*x);
L2+=0.00000000320*cost(1.32374476890+2118.76386037840*x);
L2+=0.00000000330*cost(2.98027481579+5729.50644714900*x);
L2+=0.00000000340*cost(0.51409045792+9866.41688066520*x);
L2+=0.00000000283*cost(4.03219455446+8955.34180290940*x);
L2+=0.00000000281*cost(3.33891891806+9830.38901398780*x);
L2+=0.00000000271*cost(1.53144358045+1039.02661079040*x);
L2+=0.00000000252*cost(3.04356928941+10818.13528691580*x);
L2+=0.00000000270*cost(2.22972724035+5828.02847164760*x);
L2+=0.00000000259*cost(4.24406546278+6894.52394883760*x);
L2+=0.00000000237*cost(5.07818982743+8429.24126646660*x);
L2+=0.00000000263*cost(2.00552313665+3767.21061757580*x);
L2+=0.00000000241*cost(4.06396704332+7064.12138562280*x);
L2+=0.00000000250*cost(0.45422818547+6298.32832117640*x);
L2+=0.00000000240*cost(1.94655459341+6688.33840040040*x);
L2+=0.00000000209*cost(0.03043017984+3914.95722503460*x);
L2+=0.00000000218*cost(4.53201818250+26724.89941359840*x);
L2+=0.00000000246*cost(3.85272742042+4562.46099302120*x);
L2+=0.00000000254*cost(1.19313236635+8432.76438481560*x);
L2+=0.00000000231*cost(1.70340106651+2942.46342329160*x);
L2+=0.00000000209*cost(3.82345999055+6467.92575796160*x);
L2+=0.00000000175*cost(3.26444055581+3981.49003408200*x);
L2+=0.00000000210*cost(3.55052707697+10575.40668294180*x);
L2+=0.00000000162*cost(5.95176683701+310.84079886840*x);
L2+=0.00000000165*cost(5.04267055142+10177.25767953360*x);
L2+=0.00000000198*cost(0.80464315638+15113.98923821520*x);
L2+=0.00000000188*cost(1.99007233842+3127.31333126180*x);
L2+=0.00000000188*cost(4.55406803143+12964.30070339100*x);
L2+=0.00000000163*cost(2.14874886056+10973.55568635000*x);
L2+=0.00000000154*cost(4.35708331036+3360.96774609859*x);
L2+=0.00000000169*cost(2.40504327781+3355.86489788480*x);
L2+=0.00000000164*cost(5.53875620970+16173.37116840440*x);
L2+=0.00000000144*cost(0.30186831602+1903.43681250120*x);
L2+=0.00000000161*cost(3.18977924032+6674.11130639880*x);
L2+=0.00000000135*cost(1.65570006128+3325.35995551480*x);
L2+=0.00000000143*cost(6.25825818399+9595.23908922340*x);
L2+=0.00000000158*cost(6.14255608340+8273.82086703240*x);
L2+=0.00000000170*cost(5.98413937993+3320.25710730100*x);
L2+=0.00000000124*cost(1.74571336137+11081.21921028860*x);
L2+=0.00000000146*cost(2.22851709304+3178.14579056760*x);
L2+=0.00000000126*cost(5.02927593525+3475.67750673520*x);
L2+=0.00000000123*cost(4.99342648375+13760.59871020740*x);
L2+=0.00000000141*cost(4.56735815490+10021.76996979660*x);
L2+=0.00000000118*cost(5.42945437851+13358.92658845020*x);
L2+=0.00000000116*cost(4.22080571309+5884.92684658320*x);
L2+=0.00000000119*cost(4.09962692144+10021.90459040220*x);
L2+=0.00000000124*cost(1.79723243306+18984.29263000960*x);
L2+=0.00000000135*cost(1.00085140609+18454.60166491500*x);
L2+=0.00000000106*cost(5.76342924005+2288.34404351140*x);
L2+=0.00000000103*cost(0.63812052706+12310.18132361080*x);
L2+=0.00000000100*cost(4.37946945260+9808.53818466140*x);
L2+=0.00000000104*cost(4.01151451052+13916.01910964160*x);
L2+=0.00000000125*cost(4.94825577002+10551.52824519400*x);
L2+=0.00000000098*cost(5.91086068785+14584.29827312060*x);
L2+=0.00000000126*cost(1.55752034021+8270.29774868340*x);
L2+=0.00000000098*cost(2.52869810530+3191.04922956520*x);
L2+=0.00000000095*cost(5.50808311620+3319.83703120740*x);
L2+=0.00000000108*cost(1.67115668669+11216.28429032400*x);
L2+=0.00000000090*cost(1.71281301325+1505.28780909299*x);
L2+=0.00000000088*cost(0.42472333366+11371.70468975820*x);
L2+=0.00000000089*cost(4.83867235269+16706.58525184800*x);
L2+=0.00000000106*cost(1.78998252916+10022.81760116760*x);
L2+=0.00000000087*cost(5.89602688150+16858.48253293320*x);
L2+=0.00000000085*cost(0.55423657166+13362.43245314700*x);
L2+=0.00000000091*cost(1.61117547913+24093.27678917520*x);
L2+=0.00000000083*cost(0.55328893146+3344.20285535160*x);
L2+=0.00000000083*cost(1.06830368571+3364.49086444760*x);
L2+=0.00000000084*cost(6.22980173043+3369.06161416760*x);
L2+=0.00000000085*cost(2.58442459869+13362.46696045140*x);
L2+=0.00000000079*cost(3.08636079495+2818.03500860600*x);
L2+=0.00000000077*cost(1.53791408869+5459.37628707820*x);
L2+=0.00000000075*cost(3.34890581175+9070.11887384880*x);
L2+=0.00000000097*cost(2.99973987655+3316.73398895200*x);
L2+=0.00000000084*cost(5.55309637085+3427.92063123960*x);
L2+=0.00000000089*cost(4.16432726564+6158.64743530580*x);
L2+=0.00000000078*cost(3.72375730390+13171.00144068760*x);
L2+=0.00000000083*cost(0.11917380846+3337.02199804800*x);
L2+=0.00000000073*cost(4.91632010974+13362.38239649640*x);
L2+=0.00000000076*cost(4.52961122356+708.98980227659*x);
L2+=0.00000000071*cost(5.37905772348+10264.56588407340*x);
L2+=0.00000000084*cost(1.93007660929+9468.26787725700*x);
L2+=0.00000000073*cost(5.28498987702+4845.90023579280*x);
L2+=0.00000000080*cost(4.81193020727+13149.15061136120*x);
L2+=0.00000000076*cost(4.77873149036+8671.96987044060*x);
L2+=0.00000000069*cost(0.86312560839+13207.02930736500*x);
L2+=0.00000000070*cost(1.22001285505+2274.11694950980*x);
L2+=0.00000000070*cost(0.53977528244+13119.72110282519*x);
L2+=0.00000000070*cost(0.09801356525+1437.17561419860*x);
L2+=0.00000000069*cost(2.23597403243+7107.82304427560*x);
L2+=0.00000000074*cost(0.67876411085+16460.33352952499*x);
L2+=0.00000000068*cost(0.54393617190+12935.85151592320*x);
L2+=0.00000000084*cost(5.11617356640+13892.14067189380*x);
L2+=0.00000000078*cost(5.27206373031+853.19638175200*x);
L2+=0.00000000065*cost(4.74504626032+6144.42034130420*x);
L2+=0.00000000065*cost(2.89744951086+7903.07341972100*x);
L2+=0.00000000089*cost(5.44755326514+13517.87010623340*x);
L2+=0.00000000073*cost(3.81554166604+3503.07906283200*x);
L2+=0.00000000066*cost(0.47312197978+3980.50971301380*x);
L2+=0.00000000065*cost(1.38901912957+3253.30422216000*x);
L2+=0.00000000086*cost(5.44050231013+6816.28993343500*x);
L2+=0.00000000072*cost(3.44697351738+14158.74771361560*x);
L2+=0.00000000086*cost(4.50213985772+13362.51701710200*x);
L2+=0.00000000074*cost(1.34701853675+3361.38782219220*x);
L2+=0.00000000076*cost(6.04002959430+5085.03841111500*x);
L2+=0.00000000065*cost(0.07623776004+5099.26550511660*x);
L2+=0.00000000066*cost(2.09160717290+14421.83163698840*x);
L2+=0.00000000077*cost(2.75740817982+19402.79695281660*x);
L2+=0.00000000059*cost(3.61679189501+7322.10246078180*x);
L2+=0.00000000060*cost(4.67079289372+10235.13637553740*x);
L2+=0.00000000064*cost(6.17220244155+9381.93999378540*x);
L2+=0.00000000066*cost(0.35824154106+7255.56965173440*x);
L2+=0.00000000059*cost(4.52818219212+9499.25986200560*x);
L2+=0.00000000065*cost(1.86765892646+11610.91017538320*x);
L2+=0.00000000074*cost(3.12276411101+1107.13880568480*x);
L2+=0.00000000060*cost(1.35069679183+19800.94595622480*x);
L2+=0.00000000055*cost(0.64581579779+6677.63442474780*x);
L2+=0.00000000055*cost(0.65206957868+7373.38245462640*x);
L2+=0.00000000055*cost(0.41979092764+9779.10867612540*x);
L2+=0.00000000074*cost(3.85276242820+2766.26762836500*x);
L2+=0.00000000056*cost(2.49261586879+5642.19824260920*x);
L2+=0.00000000055*cost(2.62555306434+14314.16811304980*x);
L2+=0.00000000054*cost(3.95212835807+4032.77002792660*x);
L2+=0.00000000055*cost(0.51062350773+15110.46611986620*x);
L2+=0.00000000053*cost(5.88757767795+21265.52312652020*x);
L2+=0.00000000051*cost(5.99253934388+21947.11137270000*x);
L2+=0.00000000049*cost(5.16723732129+20047.19767854780*x);
L2+=0.00000000067*cost(1.53758821512+9380.95967271720*x);
L2+=0.00000000057*cost(5.34893894346+17101.21113690720*x);
L2+=0.00000000049*cost(1.92678602770+12721.57209941700*x);
L2+=0.00000000046*cost(2.31590320480+10028.95082710020*x);
L2+=0.00000000052*cost(4.92463460288+16304.91313009080*x);
L2+=0.00000000050*cost(1.69803302925+9225.53927328300*x);
L2+=0.00000000045*cost(2.91271003676+8982.81066930900*x);
L2+=0.00000000044*cost(4.38728556203+12168.00269657460*x);
L2+=0.00000000047*cost(4.44933635857+6872.67311951120*x);
L2+=0.00000000043*cost(2.13295656057+22324.90505670940*x);
L2+=0.00000000050*cost(1.34759191325+8439.87793181640*x);
L2+=0.00000000044*cost(0.89037464728+20752.66436247540*x);
L2+=0.00000000041*cost(2.76164156557+6696.47732458460*x);
L2+=0.00000000042*cost(4.45031185062+10404.73381232260*x);
L2+=0.00000000044*cost(3.20262780268+22743.40937951640*x);
L2+=0.00000000042*cost(3.54559408987+30376.35263916660*x);
L2+=0.00000000042*cost(0.82118836477+20597.24396304120*x);
L2+=0.00000000052*cost(4.59037852162+22345.26037610820*x);
L2+=0.00000000042*cost(3.79872109079+28628.33622609960*x);
L2+=0.00000000041*cost(2.36253602080+16062.18452611680*x);
L2+=0.00000000050*cost(1.48377570574+6040.34724601740*x);
L2+=0.00000000041*cost(5.33088551342+765.79306444640*x);
L2+=0.00000000039*cost(1.57984331116+24889.57479599160*x);
L2+=0.00000000038*cost(0.21571600948+9168.64089834740*x);
L2+=0.00000000038*cost(3.47667842127+1066.49547719000*x);
L2+=0.00000000052*cost(0.81427285458+9638.94074787620*x);
L2+=0.00000000041*cost(0.04356010851+6660.86953400080*x);
L2+=0.00000000046*cost(0.89345529755+16703.04487984680*x);
L2+=0.00000000044*cost(0.85335841824+17468.85519794540*x);
L2+=0.00000000039*cost(0.27098916103+11614.43329373220*x);
L2+=0.00000000036*cost(3.93388136028+33716.96506586640*x);
L2+=0.00000000047*cost(3.90896957151+5244.04923920100*x);
L2+=0.00000000034*cost(2.37310468308+10213.28554621100*x);
L2+=0.00000000034*cost(4.85454495742+14469.58851248400*x);
L2+=0.00000000035*cost(1.96497348634+6702.00024889200*x);
L2+=0.00000000033*cost(2.14488758889+13363.43002786740*x);
L2+=0.00000000046*cost(2.92422266239+16703.07938715119*x);
L2+=0.00000000035*cost(1.78692835372+2648.45482547300*x);
L2+=0.00000000033*cost(4.24484480826+8584.66166590080*x);
L2+=0.00000000043*cost(6.09391349922+6660.44945790720*x);
L2+=0.00000000035*cost(5.72426647579+16699.53901514999*x);
L2+=0.00000000031*cost(1.95254273311+6665.97238221460*x);
L2+=0.00000000028*cost(5.88548900893+19513.98359510420*x);
L2+=0.00000000030*cost(4.38908125588+12295.95422960920*x);
L2+=0.00000000029*cost(6.25276686131+17924.91069982040*x);
L2+=0.00000000025*cost(4.89000247975+30065.51184029820*x);
L2+=0.00000000026*cost(2.43119321236+6518.75821726740*x);
L2+=0.00000000028*cost(3.97032105354+4407.10790388980*x);
L2+=0.00000000025*cost(1.88631752737+4379.63903749020*x);
L2+=0.00000000028*cost(3.06196380356+6247.51311552280*x);
L2+=0.00000000029*cost(5.98057498931+6680.24453233140*x);
L2+=0.00000000032*cost(4.65556810177+6701.58017279840*x);
L2+=0.00000000026*cost(0.76018385758+3863.18984479360*x);
L2+=0.00000000023*cost(0.31107548102+8827.39026987480*x);
L2+=0.00000000022*cost(1.11553014451+6684.81528205140*x);
L2+=0.00000000020*cost(4.81193192299+15508.61512327440*x);
L2+=0.00000000019*cost(5.11656455993+12012.58229714040*x);
L2+=0.00000000026*cost(1.07254469525+8425.65083781480*x);
L2+=0.00000000021*cost(2.68436255141+6261.74020952440*x);
L2+=0.00000000022*cost(2.15631095909+3335.08950239240*x);
L2+=0.00000000017*cost(0.03684125273+3877.41693879520*x);
L2+=0.00000000017*cost(2.84467149903+3344.49376205780*x);
L2+=0.00000000020*cost(5.41519706836+3205.54734666440*x);

double L3=0;
L3+=0.00001482423*cost(0.44434694876+3340.61242669980*x);
L3+=0.00000662095*cost(0.88469178686+6681.22485339960*x);
L3+=0.00000188268*cost(1.28799982497+10021.83728009940*x);
L3+=0.00000041474*cost(1.64850786997+13362.44970679920*x);
L3+=0.00000022661*cost(2.05267665262+155.42039943420*x);
L3+=0.00000025994;
L3+=0.00000008024*cost(1.99858757687+16703.06213349900*x);
L3+=0.00000010454*cost(1.58006906385+3.52311834900*x);
L3+=0.00000004900*cost(2.82452457966+242.72860397400*x);
L3+=0.00000003782*cost(2.01914272515+3344.13554504880*x);
L3+=0.00000003176*cost(4.59144897927+3185.19202726560*x);
L3+=0.00000003134*cost(0.65044714325+553.56940284240*x);
L3+=0.00000001684*cost(5.53835848782+951.71840625060*x);
L3+=0.00000001511*cost(5.71795850828+191.44826611160*x);
L3+=0.00000001448*cost(0.45869142895+796.29800681640*x);
L3+=0.00000001442*cost(2.34368495577+20043.67456019880*x);
L3+=0.00000001302*cost(5.36284013048+0.98032106820*x);
L3+=0.00000001169*cost(4.14601161433+1349.86740965880*x);
L3+=0.00000001133*cost(2.38180830662+6684.74797174860*x);
L3+=0.00000001037*cost(1.76892750558+382.89653222320*x);
L3+=0.00000000894*cost(5.33688328934+1194.44701022460*x);
L3+=0.00000000807*cost(2.74798886181+1748.01641306700*x);
L3+=0.00000000640*cost(6.10665147849+3496.03282613400*x);
L3+=0.00000000558*cost(1.85212342360+398.14900340820*x);
L3+=0.00000000567*cost(5.85922384979+7.11354700080*x);
L3+=0.00000000647*cost(3.17645475605+3583.34103067380*x);
L3+=0.00000000452*cost(5.98109989317+2787.04302385740*x);
L3+=0.00000000508*cost(1.01139298015+3149.16416058820*x);
L3+=0.00000000519*cost(4.93376176788+6525.80445396540*x);
L3+=0.00000000405*cost(1.27295444059+2281.23049651060*x);
L3+=0.00000000399*cost(2.32888685659+3738.76143010800*x);
L3+=0.00000000472*cost(0.84411483892+4136.91043351620*x);
L3+=0.00000000333*cost(5.42704539231+1059.38193018920*x);
L3+=0.00000000313*cost(3.70599897858+3097.88382272579*x);
L3+=0.00000000281*cost(5.74581724084+3341.59274776800*x);
L3+=0.00000000287*cost(2.69304799864+10025.36039844840*x);
L3+=0.00000000237*cost(5.68519881994+4535.05943692440*x);
L3+=0.00000000215*cost(2.49494803822+1990.74501704100*x);
L3+=0.00000000260*cost(2.67996877129+23384.28698689860*x);
L3+=0.00000000269*cost(1.10390153866+2388.89402044920*x);
L3+=0.00000000186*cost(4.86408411823+2957.71589447660*x);
L3+=0.00000000176*cost(3.86618588087+1592.59601363280*x);
L3+=0.00000000177*cost(0.85374318134+3894.18182954220*x);
L3+=0.00000000191*cost(4.58805692093+3337.08930835080*x);
L3+=0.00000000185*cost(5.80899316550+4399.99435688900*x);
L3+=0.00000000143*cost(1.15592612974+7477.52286021600*x);
L3+=0.00000000173*cost(2.70622920014+7079.37385680780*x);
L3+=0.00000000146*cost(1.37569151302+6489.77658728800*x);
L3+=0.00000000121*cost(3.24333934982+9492.14631500480*x);
L3+=0.00000000116*cost(5.71639819530+12303.06777661000*x);
L3+=0.00000000111*cost(2.69566947038+6151.53388830500*x);
L3+=0.00000000103*cost(3.53587741373+6923.95345737360*x);
L3+=0.00000000097*cost(5.23712981002+8962.45534991020*x);
L3+=0.00000000089*cost(0.05951324220+6127.65545055720*x);
L3+=0.00000000093*cost(5.29818155587+9866.41688066520*x);
L3+=0.00000000084*cost(5.68544044325+4292.33083295040*x);
L3+=0.00000000091*cost(6.16223680965+6682.20517446780*x);
L3+=0.00000000081*cost(4.32723330620+4933.20844033260*x);
L3+=0.00000000077*cost(5.63189824170+1589.07289528380*x);
L3+=0.00000000102*cost(6.26937663026+3347.72597370060*x);
L3+=0.00000000076*cost(3.05724276091+13365.97282514820*x);
L3+=0.00000000063*cost(3.12770931753+10419.98628350760*x);
L3+=0.00000000062*cost(1.45647168723+7234.79425624200*x);
L3+=0.00000000069*cost(4.82266605869+6677.70173505060*x);
L3+=0.00000000064*cost(1.73713448446+3870.30339179440*x);
L3+=0.00000000058*cost(4.85723088492+5486.77784317500*x);
L3+=0.00000000058*cost(6.09849516790+7875.67186362420*x);
L3+=0.00000000063*cost(4.14716431158+3340.59517304760*x);
L3+=0.00000000065*cost(6.17932665318+3340.62968035200*x);
L3+=0.00000000057*cost(1.48905992502+5729.50644714900*x);
L3+=0.00000000060*cost(6.08710604997+7740.60678358880*x);
L3+=0.00000000056*cost(1.96253427165+3553.91152213780*x);
L3+=0.00000000059*cost(0.89874385953+3339.63210563160*x);
L3+=0.00000000053*cost(3.04776975379+26724.89941359840*x);
L3+=0.00000000061*cost(3.63390789623+12832.75874170460*x);
L3+=0.00000000059*cost(0.22989746040+6681.24210705180*x);
L3+=0.00000000053*cost(3.97996929188+5092.15195811580*x);
L3+=0.00000000059*cost(4.48255178273+6681.20759974740*x);
L3+=0.00000000045*cost(3.88055745121+10264.56588407340*x);
L3+=0.00000000058*cost(4.85371375265+5621.84292321040*x);
L3+=0.00000000049*cost(4.03623343126+16173.37116840440*x);
L3+=0.00000000061*cost(2.90942510134+5331.35744374080*x);
L3+=0.00000000043*cost(1.80990718340+9830.38901398780*x);
L3+=0.00000000044*cost(4.10828944542+4690.47983635860*x);
L3+=0.00000000044*cost(3.49332765553+13760.59871020740*x);
L3+=0.00000000048*cost(1.81207342615+3723.50895892300*x);
L3+=0.00000000041*cost(1.59906754314+10818.13528691580*x);
L3+=0.00000000041*cost(2.05797417369+6681.29216370240*x);
L3+=0.00000000038*cost(3.38619280993+16706.58525184800*x);
L3+=0.00000000041*cost(2.53336616026+6681.15754309680*x);
L3+=0.00000000041*cost(1.79026132252+3340.54511639700*x);
L3+=0.00000000050*cost(4.70324784090+8273.82086703240*x);
L3+=0.00000000037*cost(3.37898394417+30065.51184029820*x);
L3+=0.00000000039*cost(2.65566008587+6894.52394883760*x);
L3+=0.00000000035*cost(2.58475025674+9623.68827669120*x);
L3+=0.00000000037*cost(6.07442797404+4929.68532198360*x);
L3+=0.00000000042*cost(3.04642561189+12964.30070339100*x);
L3+=0.00000000037*cost(5.23784488646+6298.32832117640*x);
L3+=0.00000000043*cost(6.17835198533+15643.68020330980*x);
L3+=0.00000000034*cost(2.44806511268+7210.91581849420*x);
L3+=0.00000000038*cost(0.26295105909+10022.81760116760*x);
L3+=0.00000000028*cost(0.74281728305+10021.85453375160*x);
L3+=0.00000000028*cost(4.99536302577+10021.82002644720*x);
L3+=0.00000000034*cost(5.04118058624+8969.56889691100*x);
L3+=0.00000000025*cost(2.59849002421+8955.34180290940*x);
L3+=0.00000000030*cost(1.14354290938+2146.16541647520*x);
L3+=0.00000000027*cost(0.26980783576+18984.29263000960*x);
L3+=0.00000000025*cost(0.39810308575+6688.33840040040*x);
L3+=0.00000000024*cost(5.64558695441+13207.02930736500*x);
L3+=0.00000000027*cost(6.24398988438+5088.62883976680*x);
L3+=0.00000000024*cost(0.25455613132+11081.21921028860*x);
L3+=0.00000000023*cost(0.53673547304+3333.49887969900*x);
L3+=0.00000000024*cost(1.80155161992+6674.11130639880*x);
L3+=0.00000000029*cost(4.39953507920+10018.31416175040*x);
L3+=0.00000000023*cost(2.91040060956+10551.52824519400*x);
L3+=0.00000000022*cost(1.20895727897+529.69096509460*x);
L3+=0.00000000026*cost(0.08254324904+7632.94325965020*x);
L3+=0.00000000026*cost(1.81668969835+6283.07584999140*x);
L3+=0.00000000021*cost(0.67232850824+6836.64525283380*x);
L3+=0.00000000017*cost(5.19518401928+2914.01423582380*x);
L3+=0.00000000017*cost(5.16488977775+8031.09226305840*x);
L3+=0.00000000021*cost(3.62973082412+5884.92684658320*x);
L3+=0.00000000018*cost(5.06870872024+2544.31441988340*x);
L3+=0.00000000014*cost(2.50522181917+7064.12138562280*x);
L3+=0.00000000017*cost(0.41835598950+9468.26787725700*x);
L3+=0.00000000011*cost(2.21363101654+6438.49624942560*x);
L3+=0.00000000013*cost(1.38424462832+3340.67973700260*x);
L3+=0.00000000012*cost(3.28248484262+8671.96987044060*x);
L3+=0.00000000014*cost(0.23027665815+3767.21061757580*x);

double L4=0;
L4-=0.00000113969;
L4+=0.00000028725*cost(5.63662412043+6681.22485339960*x);
L4+=0.00000024447*cost(5.13868481454+3340.61242669980*x);
L4+=0.00000011187*cost(6.03161074431+10021.83728009940*x);
L4+=0.00000003190*cost(3.56267988299+155.42039943420*x);
L4+=0.00000003252*cost(0.13228350651+13362.44970679920*x);
L4+=0.00000000787*cost(0.49340783377+16703.06213349900*x);
L4+=0.00000000776*cost(1.31734531594+242.72860397400*x);
L4+=0.00000000494*cost(3.06356214498+3185.19202726560*x);
L4+=0.00000000374*cost(2.15785846355+553.56940284240*x);
L4+=0.00000000331*cost(6.23159792887+3.52311834900*x);
L4+=0.00000000197*cost(0.44350153983+3344.13554504880*x);
L4+=0.00000000181*cost(0.81531283571+20043.67456019880*x);
L4+=0.00000000168*cost(3.73509781785+3496.03282613400*x);
L4+=0.00000000086*cost(0.79259553758+6684.74797174860*x);
L4+=0.00000000115*cost(1.66898531261+3583.34103067380*x);
L4+=0.00000000092*cost(3.40530361815+6525.80445396540*x);
L4+=0.00000000064*cost(4.47443580658+2787.04302385740*x);
L4+=0.00000000045*cost(5.17216217058+3097.88382272579*x);
L4+=0.00000000041*cost(1.21875027733+23384.28698689860*x);
L4+=0.00000000036*cost(5.53975653407+3149.16416058820*x);
L4+=0.00000000039*cost(5.40966345885+4136.91043351620*x);
L4+=0.00000000028*cost(4.85378781404+6127.65545055720*x);
L4+=0.00000000027*cost(0.42811091036+3738.76143010800*x);
L4+=0.00000000032*cost(1.22337093927+10025.36039844840*x);
L4+=0.00000000025*cost(1.56348878811+26724.89941359840*x);
L4+=0.00000000029*cost(2.40178626971+3894.18182954220*x);
L4+=0.00000000023*cost(4.16371253947+3341.59274776800*x);
L4+=0.00000000022*cost(5.98429191667+7477.52286021600*x);
L4+=0.00000000019*cost(2.03228980685+6923.95345737360*x);
L4+=0.00000000020*cost(3.79275573433+9866.41688066520*x);
L4+=0.00000000021*cost(4.27532111122+6836.64525283380*x);
L4+=0.00000000015*cost(1.56315497374+13365.97282514820*x);
L4+=0.00000000011*cost(1.33261955275+2281.23049651060*x);
L4+=0.00000000009*cost(6.15390464542+6489.77658728800*x);
L4+=0.00000000007*cost(4.23894194106+4535.05943692440*x);

double L5=0;
L5+=0.00000000710*cost(4.04089996521+6681.22485339960*x);
L5-=0.00000000868;
L5+=0.00000000510*cost(4.49214901625+10021.83728009940*x);
L5+=0.00000000357*cost(5.07435505061+155.42039943420*x);
L5+=0.00000000223*cost(3.51351884241+3340.61242669980*x);
L5+=0.00000000199*cost(4.85313666795+13362.44970679920*x);
L5+=0.00000000100*cost(6.09089356066+242.72860397400*x);
L5+=0.00000000069*cost(5.19017483537+16703.06213349900*x);
L5+=0.00000000064*cost(1.55783055571+3185.19202726560*x);
L5+=0.00000000035*cost(3.68246171643+553.56940284240*x);
L5+=0.00000000025*cost(5.22079788019+3496.03282613400*x);
L5+=0.00000000024*cost(0.17861991485+3583.34103067380*x);
L5+=0.00000000019*cost(5.59184714460+20043.67456019880*x);
L5+=0.00000000014*cost(5.95565787085+23384.28698689860*x);
L5+=0.00000000012*cost(1.93859256739+6525.80445396540*x);

double rtd=180/3.141592653589793;
double x2 = x*x;
double x3 = x2*x;
double x4 = x3*x;
double x5 = x4*x;

return rtd*trunc2(L0+L1*x+L2*x2+L3*x3+L4*x4+L5*x5); //END mars
}

//Heliocentric latitude of Mars
double Bmars(double x)
{
double  Bx0=0;
 Bx0+=0.03197134986*cost(3.76832042432+3340.61242669980*x);
 Bx0+=0.00298033234*cost(4.10616996243+6681.22485339960*x);
 Bx0+=0.00289104742;
 Bx0+=0.00031365538*cost(4.44651052853+10021.83728009940*x);
 Bx0+=0.00003484100*cost(4.78812547889+13362.44970679920*x);
 Bx0+=0.00000442999*cost(5.65233015876+3337.08930835080*x);
 Bx0+=0.00000443401*cost(5.02642620491+3344.13554504880*x);
 Bx0+=0.00000399109*cost(5.13056814700+16703.06213349900*x);
 Bx0+=0.00000292506*cost(3.79290644595+2281.23049651060*x);
 Bx0+=0.00000181982*cost(6.13648011704+6151.53388830500*x);
 Bx0+=0.00000163159*cost(4.26399626634+529.69096509460*x);
 Bx0+=0.00000159678*cost(2.23194610246+1059.38193018920*x);
 Bx0+=0.00000139323*cost(2.41796344238+8962.45534991020*x);
 Bx0+=0.00000149297*cost(2.16501209917+5621.84292321040*x);
 Bx0+=0.00000142686*cost(1.18215016110+3340.59517304760*x);
 Bx0+=0.00000142685*cost(3.21292180820+3340.62968035200*x);
 Bx0+=0.00000082544*cost(5.36667872319+6684.74797174860*x);
 Bx0+=0.00000073640*cost(5.09187524843+398.14900340820*x);
 Bx0+=0.00000072660*cost(5.53775710437+6283.07584999140*x);
 Bx0+=0.00000086377*cost(5.74429648412+3738.76143010800*x);
 Bx0+=0.00000083276*cost(5.98866315739+6677.70173505060*x);
 Bx0+=0.00000060116*cost(3.67960808826+796.29800681640*x);
 Bx0+=0.00000063111*cost(0.73049113369+5884.92684658320*x);
 Bx0+=0.00000062338*cost(4.85071999184+2942.46342329160*x);
 Bx0+=0.00000046951*cost(5.54339723804+3340.54511639700*x);
 Bx0+=0.00000046953*cost(5.13486627234+3340.67973700260*x);
 Bx0+=0.00000046630*cost(5.47361665459+20043.67456019880*x);
 Bx0+=0.00000045588*cost(2.13262507507+2810.92146160520*x);
 Bx0+=0.00000041269*cost(0.20003189001+9492.14631500480*x);
 Bx0+=0.00000047199*cost(4.52184736343+3149.16416058820*x);
 Bx0+=0.00000038540*cost(4.08008443274+4136.91043351620*x);
 Bx0+=0.00000033069*cost(4.06581918329+1751.53953141600*x);
 Bx0+=0.00000029694*cost(5.92218297386+3532.06069281140*x);
 Bx0+=0.00000032736*cost(2.62071056958+2914.01423582380*x);
 Bx0+=0.00000029521*cost(2.75342566734+12303.06777661000*x);
 Bx0+=0.00000028169*cost(2.06282533993+5486.77784317500*x);
 Bx0+=0.00000028618*cost(4.94710527914+3870.30339179440*x);
 Bx0+=0.00000026603*cost(3.55085844020+6681.24210705180*x);
 Bx0+=0.00000026603*cost(1.52008675291+6681.20759974740*x);
 Bx0+=0.00000023336*cost(2.27624532707+1589.07289528380*x);
 Bx0+=0.00000026052*cost(2.60064548916+4399.99435688900*x);
 Bx0+=0.00000022637*cost(2.27507466406+1194.44701022460*x);
 Bx0+=0.00000018887*cost(6.04416196149+7079.37385680780*x);
 Bx0+=0.00000014846*cost(3.41358603159+5088.62883976680*x);
 Bx0+=0.00000019947*cost(2.67365368471+8432.76438481560*x);
 Bx0+=0.00000014682*cost(5.89211938785+9623.68827669120*x);
 Bx0+=0.00000014152*cost(2.42512744356+3333.49887969900*x);
 Bx0+=0.00000013310*cost(2.62839773036+426.59819087600*x);
 Bx0+=0.00000014008*cost(1.67425558329+6254.62666252360*x);
 Bx0+=0.00000015104*cost(2.81013535571+3496.03282613400*x);
 Bx0+=0.00000013011*cost(5.70759434129+10025.36039844840*x);
 Bx0+=0.00000012080*cost(1.51804981987+3185.19202726560*x);
 Bx0+=0.00000013183*cost(0.04521207632+10018.31416175040*x);
 Bx0+=0.00000011554*cost(5.57418971820+191.44826611160*x);
 Bx0+=0.00000011196*cost(0.55829576311+5092.15195811580*x);
 Bx0+=0.00000011530*cost(2.13314819584+11773.37681151540*x);
 Bx0+=0.00000010435*cost(5.72414012635+6467.92575796160*x);
 Bx0+=0.00000009846*cost(0.86942245495+1592.59601363280*x);
 Bx0+=0.00000009761*cost(1.09342288660+2544.31441988340*x);
 Bx0+=0.00000008754*cost(5.47281660412+6681.29216370240*x);
 Bx0+=0.00000008937*cost(4.83790385610+6489.77658728800*x);
 Bx0+=0.00000008652*cost(4.72118876809+213.29909543800*x);
 Bx0+=0.00000008797*cost(2.86597575792+3341.59274776800*x);
 Bx0+=0.00000008384*cost(2.65895230037+4535.05943692440*x);
 Bx0+=0.00000008213*cost(4.82608134710+3553.91152213780*x);
 Bx0+=0.00000008799*cost(1.52910882795+3339.63210563160*x);
 Bx0+=0.00000008103*cost(1.00994045172+9225.53927328300*x);
 Bx0+=0.00000008754*cost(5.88131160438+6681.15754309680*x);
 Bx0+=0.00000007209*cost(4.41679446871+7477.52286021600*x);
 Bx0+=0.00000008560*cost(4.79003986337+4690.47983635860*x);
 Bx0+=0.00000006087*cost(1.89071507516+9595.23908922340*x);
 Bx0+=0.00000006974*cost(0.53246284561+12832.75874170460*x);
 Bx0+=0.00000005584*cost(6.18909308524+4292.33083295040*x);
 Bx0+=0.00000005038*cost(6.06393121994+7210.91581849420*x);
 Bx0+=0.00000005126*cost(0.11856805000+4562.46099302120*x);
 Bx0+=0.00000004863*cost(1.33051301524+3894.18182954220*x);
 Bx0+=0.00000005592*cost(3.97792577165+3127.31333126180*x);
 Bx0+=0.00000004965*cost(5.74589127183+1990.74501704100*x);
 Bx0+=0.00000005530*cost(5.81711987294+23384.28698689860*x);
 Bx0+=0.00000004184*cost(3.88899446923+10021.85453375160*x);
 Bx0+=0.00000004184*cost(1.85821885540+10021.82002644720*x);
 Bx0+=0.00000004685*cost(1.11750235736+3319.83703120740*x);
 Bx0+=0.00000003954*cost(2.65573703692+4929.68532198360*x);
 Bx0+=0.00000005174*cost(3.62343554596+2700.71514038580*x);
 Bx0+=0.00000004639*cost(6.14089337232+7.11354700080*x);
 Bx0+=0.00000004686*cost(3.27731664264+3361.38782219220*x);
 Bx0+=0.00000004999*cost(3.09121636067+15643.68020330980*x);
 Bx0+=0.00000003919*cost(2.96552252075+7740.60678358880*x);
 Bx0+=0.00000003361*cost(1.85016770821+2957.71589447660*x);
 Bx0+=0.00000004246*cost(4.19639278630+2146.16541647520*x);
 Bx0+=0.00000004101*cost(6.22532797325+10213.28554621100*x);
 Bx0+=0.00000003124*cost(0.08536218671+10419.98628350760*x);
 Bx0+=0.00000003079*cost(2.41163389513+3344.20285535160*x);
 Bx0+=0.00000003093*cost(1.98041729732+3337.02199804800*x);
 Bx0+=0.00000003044*cost(4.38894419912+1221.84856632140*x);
 Bx0+=0.00000002879*cost(2.93292197885+2787.04302385740*x);
 Bx0+=0.00000003372*cost(4.45558202843+6674.11130639880*x);
 Bx0+=0.00000002510*cost(4.06249795775+6872.67311951120*x);
 Bx0+=0.00000002616*cost(1.23659420897+4933.20844033260*x);
 Bx0+=0.00000003011*cost(4.33965766608+2388.89402044920*x);
 Bx0+=0.00000003094*cost(2.40385309455+2118.76386037840*x);
 Bx0+=0.00000002516*cost(2.30275910483+3723.50895892300*x);
 Bx0+=0.00000002192*cost(1.68877598700+639.89728631400*x);
 Bx0+=0.00000002157*cost(6.07600403318+9808.53818466140*x);
 Bx0+=0.00000002686*cost(2.38172448359+15113.98923821520*x);
 Bx0+=0.00000002156*cost(2.87771528495+6041.32756708560*x);
 Bx0+=0.00000002495*cost(3.87395320804+7903.07341972100*x);
 Bx0+=0.00000002253*cost(0.47469626036+3475.67750673520*x);
 Bx0+=0.00000002443*cost(3.02632351975+3767.21061757580*x);
 Bx0+=0.00000001937*cost(0.38000997629+13358.92658845020*x);
 Bx0+=0.00000002213*cost(3.91982326360+3205.54734666440*x);
 Bx0+=0.00000002385*cost(6.23883456815+12964.30070339100*x);
 Bx0+=0.00000001806*cost(2.38408432339+11243.68584642080*x);
 Bx0+=0.00000002265*cost(1.85773885180+6525.80445396540*x);
 Bx0+=0.00000001642*cost(1.86812936557+6680.24453233140*x);
 Bx0+=0.00000001616*cost(3.39954231101+8429.24126646660*x);
 Bx0+=0.00000001646*cost(0.73261192032+2274.11694950980*x);
 Bx0+=0.00000001910*cost(6.04319894051+13365.97282514820*x);
 Bx0+=0.00000001492*cost(2.99360929050+7875.67186362420*x);
 Bx0+=0.00000001567*cost(1.76860259924+382.89653222320*x);
 Bx0+=0.00000001459*cost(1.40571286543+14584.29827312060*x);
 Bx0+=0.00000001527*cost(5.79343536555+6894.52394883760*x);
 Bx0+=0.00000001409*cost(5.17099876287+9830.38901398780*x);
 Bx0+=0.00000001665*cost(3.60183854165+2288.34404351140*x);
 Bx0+=0.00000001616*cost(2.19447775480+8827.39026987480*x);
 Bx0+=0.00000001746*cost(0.10485504333+3583.34103067380*x);
 Bx0+=0.00000001637*cost(3.20410489018+6682.20517446780*x);
 Bx0+=0.00000001269*cost(2.02253791623+155.42039943420*x);
 Bx0+=0.00000001507*cost(5.80795976424+1748.01641306700*x);
 Bx0+=0.00000001296*cost(2.92899986522+9381.93999378540*x);
 Bx0+=0.00000001291*cost(2.98932404463+6836.64525283380*x);
 Bx0+=0.00000001377*cost(5.80980821450+10021.90459040220*x);
 Bx0+=0.00000001357*cost(0.32856318286+4032.77002792660*x);
 Bx0+=0.00000001377*cost(6.21830533138+10021.76996979660*x);
 Bx0+=0.00000001227*cost(2.20421067322+12935.85151592320*x);
 Bx0+=0.00000001080*cost(4.75502761725+10818.13528691580*x);
 Bx0+=0.00000001016*cost(1.33950348904+12566.15169998280*x);
 Bx0+=0.00000001083*cost(0.87622049125+16173.37116840440*x);
 Bx0+=0.00000000957*cost(5.29505019432+1066.49547719000*x);
 Bx0+=0.00000001035*cost(2.44286811558+1052.26838318840*x);
 Bx0+=0.00000001153*cost(4.73786864168+8031.09226305840*x);
 Bx0+=0.00000001042*cost(1.73541825729+3369.06161416760*x);
 Bx0+=0.00000000899*cost(1.87265511538+3077.52850332700*x);
 Bx0+=0.00000000892*cost(2.51347636401+3603.69635007260*x);
 Bx0+=0.00000000904*cost(0.27361540197+3325.35995551480*x);
 Bx0+=0.00000000883*cost(5.46537936740+5614.72937620960*x);
 Bx0+=0.00000000949*cost(0.04595688771+7064.12138562280*x);
 Bx0+=0.00000000872*cost(3.61205859852+6702.00024889200*x);
 Bx0+=0.00000000842*cost(5.61713543212+8955.34180290940*x);
 Bx0+=0.00000000842*cost(0.57536275896+3191.04922956520*x);
 Bx0+=0.00000000904*cost(4.11832249537+3355.86489788480*x);
 Bx0+=0.00000001044*cost(2.65889542110+3312.16323923200*x);
 Bx0+=0.00000000807*cost(2.26443259820+8969.56889691100*x);
 Bx0+=0.00000001046*cost(6.11317298058+5331.35744374080*x);
 Bx0+=0.00000000933*cost(0.82551054416+3503.07906283200*x);
 Bx0+=0.00000000946*cost(1.92368414869+5628.95647021120*x);
 Bx0+=0.00000000978*cost(4.55697167317+3097.88382272579*x);
 Bx0+=0.00000000846*cost(4.65096242323+6438.49624942560*x);
 Bx0+=0.00000000901*cost(1.46788821922+6660.44945790720*x);
 Bx0+=0.00000000739*cost(4.97716008834+10014.72373309860*x);
 Bx0+=0.00000000762*cost(3.42576079312+18984.29263000960*x);
 Bx0+=0.00000000934*cost(0.35014113954+3264.34635542420*x);
 Bx0+=0.00000000894*cost(0.34991139502+10551.52824519400*x);
 Bx0+=0.00000000665*cost(6.05561837558+7632.94325965020*x);
 Bx0+=0.00000000605*cost(4.68480399923+5729.50644714900*x);
 Bx0+=0.00000000593*cost(2.97207045977+3178.14579056760*x);
 Bx0+=0.00000000617*cost(2.19529512598+13362.43245314700*x);
 Bx0+=0.00000000579*cost(3.32303439858+11081.21921028860*x);
 Bx0+=0.00000000579*cost(2.31217959727+6677.63442474780*x);
 Bx0+=0.00000000572*cost(4.27984088783+6546.15977336420*x);
 Bx0+=0.00000000584*cost(4.51625727923+1648.44675719740*x);
 Bx0+=0.00000000626*cost(4.60715188203+2487.41604494780*x);
 Bx0+=0.00000000649*cost(2.17894376907+6298.32832117640*x);
 Bx0+=0.00000000617*cost(4.22635718375+13362.46696045140*x);
 Bx0+=0.00000000550*cost(3.11161314141+6144.42034130420*x);
 Bx0+=0.00000000551*cost(3.27081871281+6127.65545055720*x);
 Bx0+=0.00000000536*cost(0.18973312148+3346.13535100720*x);
 Bx0+=0.00000000557*cost(6.13686769377+26724.89941359840*x);
 Bx0+=0.00000000571*cost(5.65341463660+2921.12778282460*x);
 Bx0+=0.00000000552*cost(5.75724124958+149.56319713460*x);
 Bx0+=0.00000000638*cost(4.49647258906+3.52311834900*x);
 Bx0+=0.00000000552*cost(1.07795672495+536.80451209540*x);
 Bx0+=0.00000000537*cost(4.19207200801+3335.08950239240*x);
 Bx0+=0.00000000567*cost(2.62806466971+2648.45482547300*x);
 Bx0+=0.00000000641*cost(3.24534699403+3347.72597370060*x);
 Bx0+=0.00000000546*cost(2.76744357149+5459.37628707820*x);
 Bx0+=0.00000000556*cost(4.98610303145+6531.66165626500*x);
 Bx0+=0.00000000578*cost(2.74445077242+6684.81528205140*x);
 Bx0+=0.00000000613*cost(3.01718810256+8270.29774868340*x);
 Bx0+=0.00000000558*cost(5.89236366633+6158.64743530580*x);
 Bx0+=0.00000000489*cost(4.59082197201+522.57741809380*x);
 Bx0+=0.00000000445*cost(3.64293918046+10713.99488132620*x);
 Bx0+=0.00000000539*cost(0.59284523316+553.56940284240*x);
 Bx0+=0.00000000434*cost(1.99641894213+26087.90314157420*x);
 Bx0+=0.00000000459*cost(4.84216944554+1758.65307841680*x);
 Bx0+=0.00000000423*cost(3.77854586358+6688.33840040040*x);
 Bx0+=0.00000000421*cost(3.10245838137+8329.67161059700*x);
 Bx0+=0.00000000421*cost(4.43540354818+103.09277421860*x);
 Bx0+=0.00000000502*cost(3.03141512630+3360.96774609859*x);
 Bx0+=0.00000000422*cost(5.99158563064+242.72860397400*x);
 Bx0+=0.00000000401*cost(2.06012045711+3980.50971301380*x);
 Bx0+=0.00000000410*cost(5.85255605682+3351.24909204960*x);
 Bx0+=0.00000000375*cost(2.50803340920+6784.31762761820*x);
 Bx0+=0.00000000407*cost(0.30117328390+16304.91313009080*x);
 Bx0+=0.00000000507*cost(1.35016417800+3320.25710730100*x);
 Bx0+=0.00000000385*cost(1.06248122739+7234.79425624200*x);
 Bx0+=0.00000000519*cost(4.61705823333+7373.38245462640*x);
 Bx0+=0.00000000401*cost(0.51161484292+17085.95866572220*x);
 Bx0+=0.00000000371*cost(0.41707432281+13760.59871020740*x);
 Bx0+=0.00000000476*cost(0.81142637639+6816.28993343500*x);
 Bx0+=0.00000000348*cost(3.36497054127+8439.87793181640*x);
 Bx0+=0.00000000366*cost(6.05186692577+3607.21946842160*x);
 Bx0+=0.00000000402*cost(2.67375675473+18454.60166491500*x);
 Bx0+=0.00000000439*cost(0.41122589061+10404.73381232260*x);
 Bx0+=0.00000000412*cost(4.81039654306+3329.97576135000*x);
 Bx0+=0.00000000413*cost(0.21011211689+13149.15061136120*x);
 Bx0+=0.00000000363*cost(2.19017574725+9866.41688066520*x);
 Bx0+=0.00000000337*cost(5.46398740226+6604.95878212400*x);
 Bx0+=0.00000000340*cost(1.73392662280+1692.16566950240*x);
 Bx0+=0.00000000344*cost(3.58310197017+7107.82304427560*x);
 Bx0+=0.00000000420*cost(2.77274750272+2906.90068882300*x);
 Bx0+=0.00000000335*cost(2.02339633221+3333.56619000180*x);
 Bx0+=0.00000000336*cost(2.78173647754+4989.05918389720*x);
 Bx0+=0.00000000354*cost(5.41265456299+951.71840625060*x);
 Bx0+=0.00000000328*cost(0.43464916253+6923.95345737360*x);
 Bx0+=0.00000000422*cost(1.57591737080+8273.82086703240*x);
 Bx0+=0.00000000324*cost(4.99165215532+11371.70468975820*x);
 Bx0+=0.00000000351*cost(4.60766539695+3074.00538497800*x);
 Bx0+=0.00000000333*cost(4.86991808664+3863.18984479360*x);
 Bx0+=0.00000000319*cost(1.44510282827+11769.85369316640*x);
 Bx0+=0.00000000296*cost(5.25637576704+76.26607127560*x);
 Bx0+=0.00000000349*cost(1.62483962938+17924.91069982040*x);
 Bx0+=0.00000000293*cost(2.20643287367+3347.65866339780*x);
 Bx0+=0.00000000315*cost(4.55227306770+5828.02847164760*x);
 Bx0+=0.00000000280*cost(1.42134291540+6606.44325483230*x);
 Bx0+=0.00000000336*cost(1.56854533505+1581.95934828300*x);
 Bx0+=0.00000000343*cost(0.27605726543+10973.55568635000*x);
 Bx0+=0.00000000271*cost(0.08314924409+10235.13637553740*x);
 Bx0+=0.00000000280*cost(0.76436434398+853.19638175200*x);
 Bx0+=0.00000000317*cost(4.91466081381+3443.70520091840*x);
 Bx0+=0.00000000257*cost(0.15709629188+12168.00269657460*x);
 Bx0+=0.00000000237*cost(3.13380421805+74.78159856730*x);
 Bx0+=0.00000000271*cost(1.83008759256+3399.98628861340*x);
 Bx0+=0.00000000233*cost(3.20163702613+10177.25767953360*x);
 Bx0+=0.00000000312*cost(0.28436027987+13745.34623902240*x);
 Bx0+=0.00000000273*cost(4.53535816659+3344.49376205780*x);
 Bx0+=0.00000000235*cost(0.67980074869+17395.21973472580*x);
 Bx0+=0.00000000262*cost(3.84436620806+9168.64089834740*x);
 Bx0+=0.00000000271*cost(4.94509131052+692.15760122680*x);
 Bx0+=0.00000000254*cost(2.19491751584+3281.23856478620*x);
 Bx0+=0.00000000220*cost(1.65400798925+3546.79797513700*x);
 Bx0+=0.00000000283*cost(5.57884389098+3973.39616601300*x);
 Bx0+=0.00000000229*cost(5.93153003758+3364.49086444760*x);
 Bx0+=0.00000000223*cost(4.82744958322+9779.10867612540*x);
 Bx0+=0.00000000222*cost(0.71788606092+16699.53901514999*x);
 Bx0+=0.00000000219*cost(0.09831940529+16706.58525184800*x);
 Bx0+=0.00000000221*cost(1.66596576205+10575.40668294180*x);
 Bx0+=0.00000000259*cost(1.10208840059+1744.42598441520*x);
 Bx0+=0.00000000243*cost(1.52425310144+14054.60730802600*x);
 Bx0+=0.00000000273*cost(6.12932898811+3336.73109134180*x);
 Bx0+=0.00000000232*cost(4.73422268172+3316.73398895200*x);
 Bx0+=0.00000000210*cost(5.97305256642+419.48464387520*x);
 Bx0+=0.00000000213*cost(5.35378111313+1596.18644228460*x);
 Bx0+=0.00000000197*cost(3.32400761027+5085.03841111500*x);
 Bx0+=0.00000000193*cost(0.90522037315+14314.16811304980*x);
 Bx0+=0.00000000192*cost(2.63243342989+433.71173787680*x);
 Bx0+=0.00000000188*cost(1.14983778034+13892.14067189380*x);
 Bx0+=0.00000000200*cost(4.79567916236+6261.74020952440*x);
 Bx0+=0.00000000204*cost(2.32272167710+13916.01910964160*x);
 Bx0+=0.00000000191*cost(5.08454560792+2178.13772229200*x);
 Bx0+=0.00000000191*cost(5.88821293073+3340.19235060619*x);
 Bx0+=0.00000000236*cost(0.97341490472+3230.40610548040*x);
 Bx0+=0.00000000200*cost(3.60041329896+3304.58456002240*x);
 Bx0+=0.00000000165*cost(2.91701234796+3415.39402526710*x);
 Bx0+=0.00000000191*cost(4.77647338120+3341.03250279340*x);
 Bx0+=0.00000000174*cost(2.20549134205+10020.85695903120*x);
 Bx0+=0.00000000161*cost(2.64795288862+3304.00706139560*x);
 Bx0+=0.00000000173*cost(3.54115285115+10022.81760116760*x);
 Bx0+=0.00000000154*cost(2.45916882835+12722.55242048520*x);
 Bx0+=0.00000000160*cost(1.73968020026+3377.21779200400*x);
 Bx0+=0.00000000196*cost(0.78013533938+3376.64029337720*x);
 Bx0+=0.00000000153*cost(0.27328628499+13362.38239649640*x);
 Bx0+=0.00000000190*cost(2.65143864216+3657.00429635640*x);
 Bx0+=0.00000000172*cost(5.71092117488+2384.32327072920*x);
 Bx0+=0.00000000157*cost(1.00235389487+3209.07046501340*x);
 Bx0+=0.00000000150*cost(3.39592748537+3472.15438838620*x);
 Bx0+=0.00000000165*cost(5.86551673354+2803.80791460440*x);
 Bx0+=0.00000000154*cost(0.32136196834+6665.97238221460*x);
 Bx0+=0.00000000178*cost(3.34059693754+11216.28429032400*x);
 Bx0+=0.00000000192*cost(0.66079944629+3134.42687826260*x);
 Bx0+=0.00000000161*cost(2.87915391245+4392.88080988820*x);
 Bx0+=0.00000000159*cost(3.72249746113+13517.87010623340*x);
 Bx0+=0.00000000168*cost(0.55746622745+110.20632121940*x);
 Bx0+=0.00000000158*cost(5.67248197213+4407.10790388980*x);
 Bx0+=0.00000000161*cost(1.76789928464+6709.67404086740*x);
 Bx0+=0.00000000158*cost(5.50643845256+13171.00144068760*x);
 Bx0+=0.00000000129*cost(1.21297315367+19513.98359510420*x);
 Bx0+=0.00000000173*cost(0.17070148373+3024.22055704320*x);
 Bx0+=0.00000000132*cost(4.25407099272+16858.48253293320*x);
 Bx0+=0.00000000125*cost(2.88510294667+17256.63153634140*x);
 Bx0+=0.00000000124*cost(2.59724598646+12310.18132361080*x);
 Bx0+=0.00000000170*cost(4.05945259741+2818.03500860600*x);
 Bx0+=0.00000000121*cost(5.23997785185+9872.27408296480*x);
 Bx0+=0.00000000142*cost(3.02798835989+3511.28529731900*x);
 Bx0+=0.00000000165*cost(2.53171951288+16276.46394262300*x);
 Bx0+=0.00000000153*cost(6.14783670557+13362.51701710200*x);
 Bx0+=0.00000000119*cost(4.15694365082+3760.09707057500*x);
 Bx0+=0.00000000120*cost(0.64287725481+4459.36821880260*x);
 Bx0+=0.00000000130*cost(4.95002309460+13553.89797291080*x);
 Bx0+=0.00000000120*cost(0.17087854222+8671.96987044060*x);
 Bx0+=0.00000000112*cost(0.16822264326+135.06508003540*x);
 Bx0+=0.00000000137*cost(3.34809361979+3341.04230982650*x);
 Bx0+=0.00000000125*cost(1.32195559043+1349.86740965880*x);
 Bx0+=0.00000000111*cost(3.14151030451+13524.91634293140*x);
 Bx0+=0.00000000119*cost(5.95361348050+12295.95422960920*x);
 Bx0+=0.00000000131*cost(5.09769375731+14158.74771361560*x);
 Bx0+=0.00000000141*cost(1.37128440708+3169.93955608060*x);
 Bx0+=0.00000000112*cost(3.35831868034+5989.06725217280*x);
 Bx0+=0.00000000104*cost(5.00696041032+13119.72110282519*x);
 Bx0+=0.00000000110*cost(5.23317664736+1375.77379984580*x);
 Bx0+=0.00000000105*cost(2.72692368303+1162.47470440780*x);
 Bx0+=0.00000000104*cost(1.73769165705+2221.85663459700*x);
 Bx0+=0.00000000137*cost(1.04576950390+3340.18254357310*x);
 Bx0+=0.00000000106*cost(6.13415161313+162.46663613220*x);
 Bx0+=0.00000000119*cost(2.63312561442+7321.12213971360*x);
 Bx0+=0.00000000105*cost(3.09551802365+20618.01935853360*x);
 Bx0+=0.00000000099*cost(4.25515697974+23539.70738633280*x);
 Bx0+=0.00000000108*cost(1.01854506729+3265.83082813250*x);
 Bx0+=0.00000000119*cost(4.07277528003+10184.30391623160*x);
 Bx0+=0.00000000096*cost(1.81122023425+10001.06188460700*x);
 Bx0+=0.00000000093*cost(3.58905885066+5099.26550511660*x);
 Bx0+=0.00000000095*cost(4.94756054764+3981.49003408200*x);
 Bx0+=0.00000000094*cost(5.37493368020+13355.33615979840*x);
 Bx0+=0.00000000095*cost(0.13037485775+15508.61512327440*x);
 Bx0+=0.00000000103*cost(0.43484130196+1861.74585263540*x);
 Bx0+=0.00000000090*cost(3.76370412628+22324.90505670940*x);
 Bx0+=0.00000000091*cost(3.95041101283+10042.61267559180*x);
 Bx0+=0.00000000106*cost(4.30186500383+640.87760738220*x);
 Bx0+=0.00000000109*cost(6.18873749839+1478.86657406440*x);
 Bx0+=0.00000000088*cost(1.79608901332+6247.51311552280*x);
 Bx0+=0.00000000102*cost(5.58754073056+2766.26762836500*x);
 Bx0+=0.00000000110*cost(0.94707767481+3274.12501778540*x);
 Bx0+=0.00000000084*cost(4.45487801845+6696.47732458460*x);
 Bx0+=0.00000000085*cost(2.74791518135+3407.09983561420*x);
 Bx0+=0.00000000087*cost(4.51145821088+220.41264243880*x);
 Bx0+=0.00000000101*cost(5.94930983227+8425.65083781480*x);
 Bx0+=0.00000000082*cost(0.01837230371+9499.25986200560*x);
 Bx0+=0.00000000080*cost(0.42550989980+18052.92954315780*x);
 Bx0+=0.00000000083*cost(2.96589752213+6652.77566593180*x);
 Bx0+=0.00000000080*cost(4.61446168762+3914.95722503460*x);
 Bx0+=0.00000000079*cost(1.50228636499+2111.65031337760*x);
 Bx0+=0.00000000089*cost(3.52977975496+9485.03276800400*x);
 Bx0+=0.00000000086*cost(0.41976545794+956.28915597060*x);
 Bx0+=0.00000000088*cost(5.46013317934+16460.33352952499*x);
 Bx0+=0.00000000091*cost(2.09965252231+949.17560896980*x);
 Bx0+=0.00000000104*cost(1.72206104768+3296.89351439480*x);
 Bx0+=0.00000000103*cost(1.25691413032+3384.33133900480*x);
 Bx0+=0.00000000084*cost(5.78647729498+5518.75014899180*x);
 Bx0+=0.00000000079*cost(1.79313426804+38.13303563780*x);
 Bx0+=0.00000000073*cost(0.10667695992+29822.78323632420*x);
 Bx0+=0.00000000087*cost(2.11654357529+3450.81874791920*x);
 Bx0+=0.00000000072*cost(3.89476829327+9380.95967271720*x);
 Bx0+=0.00000000075*cost(2.59340305340+1964.83862685400*x);
 Bx0+=0.00000000098*cost(4.01577665825+6843.69148953180*x);
 Bx0+=0.00000000074*cost(5.32032289064+11766.26326451460*x);
 Bx0+=0.00000000068*cost(0.04775525953+2125.87740737920*x);
 Bx0+=0.00000000069*cost(6.07427052412+26482.17080962440*x);
 Bx0+=0.00000000069*cost(2.05018999200+29424.63423291600*x);
 Bx0+=0.00000000084*cost(0.16960920719+263.08392337280*x);
 Bx0+=0.00000000068*cost(5.03013252197+9070.11887384880*x);
 Bx0+=0.00000000076*cost(2.00296087293+224.34479570190*x);
 Bx0+=0.00000000078*cost(2.17362706851+30220.93223973240*x);
 Bx0+=0.00000000066*cost(3.85497672006+19406.67828817460*x);
 Bx0+=0.00000000066*cost(5.70059718737+33561.54466643220*x);
 Bx0+=0.00000000067*cost(0.16600936321+22743.40937951640*x);
 Bx0+=0.00000000065*cost(4.65423392949+2807.39834325620*x);
 Bx0+=0.00000000069*cost(3.34387224268+11670.28403729680*x);
 Bx0+=0.00000000087*cost(4.97838021880+1118.75579210280*x);
 Bx0+=0.00000000063*cost(0.18907106180+30065.51184029820*x);
 Bx0+=0.00000000064*cost(4.61909647015+9886.77220006400*x);
 Bx0+=0.00000000073*cost(0.93706647938+20735.83216142559*x);
 Bx0+=0.00000000060*cost(5.83757395809+8646.06348025360*x);
 Bx0+=0.00000000062*cost(4.81389895867+20199.09495963300*x);
 Bx0+=0.00000000059*cost(5.00150762621+6414.61781167780*x);
 Bx0+=0.00000000068*cost(3.84252763135+6571.01853218020*x);
 Bx0+=0.00000000062*cost(2.81689634717+6944.30877677240*x);
 Bx0+=0.00000000065*cost(4.49078808776+632.78373931320*x);
 Bx0+=0.00000000058*cost(5.64889513615+9945.57120882380*x);
 Bx0+=0.00000000070*cost(2.51605694403+9638.94074787620*x);
 Bx0+=0.00000000057*cost(3.28105791201+206.18554843720*x);
 Bx0+=0.00000000057*cost(2.97448265957+21795.21409161479*x);
 Bx0+=0.00000000056*cost(2.23565630779+20995.39296644940*x);
 Bx0+=0.00000000057*cost(1.88614831237+18451.07854656599*x);
 Bx0+=0.00000000071*cost(4.82445647307+8542.97070603500*x);
 Bx0+=0.00000000061*cost(3.65945073900+14421.83163698840*x);
 Bx0+=0.00000000056*cost(3.13789031275+8799.98871377800*x);
 Bx0+=0.00000000057*cost(4.89927831599+9602.35263622420*x);
 Bx0+=0.00000000065*cost(3.37109873211+11610.91017538320*x);
 Bx0+=0.00000000067*cost(1.92945007459+21265.52312652020*x);
 Bx0+=0.00000000055*cost(1.95164531764+9588.12554222260*x);
 Bx0+=0.00000000057*cost(2.82240075154+10124.93005431800*x);
 Bx0+=0.00000000057*cost(6.10407356832+19800.94595622480*x);
 Bx0+=0.00000000055*cost(5.20976473824+3237.51965248120*x);
 Bx0+=0.00000000057*cost(4.12235760406+10028.95082710020*x);
 Bx0+=0.00000000055*cost(1.41700952855+15906.76412668260*x);
 Bx0+=0.00000000053*cost(2.16328741039+6418.14093002680*x);
 Bx0+=0.00000000060*cost(2.64683840328+10018.24685144760*x);
 Bx0+=0.00000000068*cost(5.36539876845+1228.96211332220*x);
 Bx0+=0.00000000051*cost(5.73824213507+6048.44111408640*x);
 Bx0+=0.00000000053*cost(0.31937174553+12721.57209941700*x);
 Bx0+=0.00000000051*cost(0.06312524105+20206.14119633100*x);
 Bx0+=0.00000000049*cost(4.53401402385+6675.70192909220*x);
 Bx0+=0.00000000051*cost(1.15475560534+10156.90236013480*x);
 Bx0+=0.00000000064*cost(4.56332268770+16703.07938715119*x);
 Bx0+=0.00000000060*cost(3.61007443614+9468.26787725700*x);
 Bx0+=0.00000000059*cost(3.08413561767+10025.42770875120*x);
 Bx0+=0.00000000064*cost(2.53229538141+16703.04487984680*x);
 Bx0+=0.00000000056*cost(3.31988072467+6518.75821726740*x);
 Bx0+=0.00000000047*cost(1.44559165677+6643.09181776180*x);
 Bx0+=0.00000000050*cost(1.92342238827+11614.43329373220*x);
 Bx0+=0.00000000047*cost(4.03794177027+23958.63178523340*x);
 Bx0+=0.00000000046*cost(3.70927352724+8859.36257569160*x);
 Bx0+=0.00000000060*cost(2.55506470511+11780.49035851620*x);
 Bx0+=0.00000000047*cost(1.69256878711+6660.86953400080*x);
 Bx0+=0.00000000044*cost(6.09481217162+6460.81221096080*x);
 Bx0+=0.00000000044*cost(2.63040622140+13936.79450513400*x);
 Bx0+=0.00000000053*cost(0.77878945764+16865.52876963120*x);
 Bx0+=0.00000000049*cost(1.83368544550+17654.78053974960*x);
 Bx0+=0.00000000048*cost(0.52828042378+6686.74777770700*x);
 Bx0+=0.00000000042*cost(4.30347553493+9065.54812412880*x);
 Bx0+=0.00000000042*cost(5.71964550673+7203.80227149340*x);
 Bx0+=0.00000000041*cost(0.98427208931+20426.57109242200*x);
 Bx0+=0.00000000051*cost(3.54335413699+20597.24396304120*x);
 Bx0+=0.00000000041*cost(0.21219617682+7314.00859271280*x);
 Bx0+=0.00000000038*cost(2.53074981011+13207.02930736500*x);
 Bx0+=0.00000000039*cost(5.15577369902+6670.58818804980*x);
 Bx0+=0.00000000051*cost(3.25271478667+7799.98064550240*x);
 Bx0+=0.00000000049*cost(0.77060706107+17101.21113690720*x);
 Bx0+=0.00000000038*cost(6.06684699984+9389.05354078620*x);
 Bx0+=0.00000000043*cost(0.51983815091+16489.76303806100*x);
 Bx0+=0.00000000036*cost(0.84102576439+23937.85638974100*x);

double B1=0;
B1+=0.00350068845*cost(5.36847836211+3340.61242669980*x);
B1-=0.00014116030;
B1+=0.00009670755*cost(5.47877786506+6681.22485339960*x);
B1+=0.00001471918*cost(3.20205766795+10021.83728009940*x);
B1+=0.00000425864*cost(3.40843812875+13362.44970679920*x);
B1+=0.00000102039*cost(0.77617286189+3337.08930835080*x);
B1+=0.00000078848*cost(3.71768293865+16703.06213349900*x);
B1+=0.00000026171*cost(2.48293558065+2281.23049651060*x);
B1+=0.00000032708*cost(3.45803723682+5621.84292321040*x);
B1+=0.00000020712*cost(1.44120802297+6151.53388830500*x);
B1+=0.00000018294*cost(6.03102943125+529.69096509460*x);
B1+=0.00000015680*cost(3.93075566599+8962.45534991020*x);
B1+=0.00000016975*cost(4.81115186866+3344.13554504880*x);
B1+=0.00000013067*cost(0.97324736181+6677.70173505060*x);
B1+=0.00000015622*cost(2.78241383265+3340.59517304760*x);
B1+=0.00000015622*cost(4.81318636318+3340.62968035200*x);
B1+=0.00000013771*cost(1.67983063909+3532.06069281140*x);
B1+=0.00000012711*cost(4.04546734935+20043.67456019880*x);
B1+=0.00000014268*cost(0.24640247719+2942.46342329160*x);
B1+=0.00000012493*cost(2.25620513522+5884.92684658320*x);
B1+=0.00000008800*cost(0.34079528233+398.14900340820*x);
B1+=0.00000008637*cost(1.75213704409+2544.31441988340*x);
B1+=0.00000008903*cost(5.95437916504+2810.92146160520*x);
B1+=0.00000008102*cost(0.84279830287+6283.07584999140*x);
B1+=0.00000009250*cost(4.35071778619+3496.03282613400*x);
B1+=0.00000008085*cost(4.29614034209+6684.74797174860*x);
B1+=0.00000005811*cost(3.55479498415+5092.15195811580*x);
B1+=0.00000005864*cost(3.69652093329+5486.77784317500*x);
B1+=0.00000005618*cost(0.03475872145+3185.19202726560*x);
B1+=0.00000005148*cost(0.85886443528+3340.54511639700*x);
B1+=0.00000005145*cost(0.45169791514+3340.67973700260*x);
B1+=0.00000004898*cost(4.12922007874+1059.38193018920*x);
B1+=0.00000003471*cost(5.07253485267+5088.62883976680*x);
B1+=0.00000003102*cost(3.11487063736+3339.63210563160*x);
B1+=0.00000003013*cost(1.00910437496+2914.01423582380*x);
B1+=0.00000003171*cost(1.24730004776+3738.76143010800*x);
B1+=0.00000003194*cost(2.86899092087+1751.53953141600*x);
B1+=0.00000002304*cost(1.38460565999+3870.30339179440*x);
B1+=0.00000002233*cost(2.91238180064+3894.18182954220*x);
B1+=0.00000002792*cost(4.27117916474+8432.76438481560*x);
B1+=0.00000002431*cost(0.14615904873+4690.47983635860*x);
B1+=0.00000002577*cost(2.78651098185+6254.62666252360*x);
B1+=0.00000001996*cost(1.51200589223+4292.33083295040*x);
B1+=0.00000001860*cost(5.15222219319+796.29800681640*x);
B1+=0.00000002014*cost(5.48528849094+3127.31333126180*x);
B1+=0.00000001922*cost(4.37668623732+23384.28698689860*x);
B1+=0.00000002248*cost(4.46756441051+10025.36039844840*x);
B1+=0.00000001782*cost(2.70229954651+4136.91043351620*x);
B1+=0.00000001621*cost(2.26742355334+3149.16416058820*x);
B1+=0.00000001452*cost(1.53948251192+9492.14631500480*x);
B1+=0.00000001373*cost(3.20232312108+2146.16541647520*x);
B1+=0.00000001332*cost(5.67966837010+1592.59601363280*x);
B1+=0.00000001378*cost(4.12087865376+3723.50895892300*x);
B1+=0.00000001215*cost(0.33914405698+6674.11130639880*x);
B1+=0.00000001168*cost(3.52407129935+11773.37681151540*x);
B1+=0.00000001179*cost(6.15475441355+213.29909543800*x);
B1+=0.00000001173*cost(1.26036608440+3341.59274776800*x);
B1+=0.00000001211*cost(0.97241747335+6467.92575796160*x);
B1+=0.00000001204*cost(0.95200561837+10018.31416175040*x);
B1+=0.00000001107*cost(1.44142157852+2787.04302385740*x);
B1+=0.00000001194*cost(0.84501638145+1194.44701022460*x);
B1+=0.00000001043*cost(3.98123209815+12303.06777661000*x);
B1+=0.00000001029*cost(1.21951732572+4535.05943692440*x);
B1+=0.00000000939*cost(2.99716248257+7477.52286021600*x);
B1+=0.00000001303*cost(1.12409937702+4399.99435688900*x);
B1+=0.00000001032*cost(4.26592917807+1990.74501704100*x);
B1+=0.00000001230*cost(0.37904885593+6525.80445396540*x);
B1+=0.00000000989*cost(2.37220445455+9225.53927328300*x);
B1+=0.00000000946*cost(3.14940196742+6489.77658728800*x);
B1+=0.00000001013*cost(5.90131661122+3097.88382272579*x);
B1+=0.00000000913*cost(2.86098924372+2388.89402044920*x);
B1+=0.00000000954*cost(4.90448639106+3583.34103067380*x);
B1+=0.00000000866*cost(4.92421595837+6681.24210705180*x);
B1+=0.00000000797*cost(4.53307543814+7079.37385680780*x);
B1+=0.00000000866*cost(2.89344915945+6681.20759974740*x);
B1+=0.00000000659*cost(0.33901474348+2957.71589447660*x);
B1+=0.00000000670*cost(3.23650405278+9595.23908922340*x);
B1+=0.00000000782*cost(1.56739177814+3333.49887969900*x);
B1+=0.00000000641*cost(4.46918721250+6836.64525283380*x);
B1+=0.00000000611*cost(3.97393774087+6041.32756708560*x);
B1+=0.00000000738*cost(3.78715624780+4562.46099302120*x);
B1+=0.00000000558*cost(2.92718433901+1589.07289528380*x);
B1+=0.00000000513*cost(0.96852780537+9623.68827669120*x);
B1+=0.00000000508*cost(4.07262127921+7.11354700080*x);
B1+=0.00000000512*cost(1.53960708348+7740.60678358880*x);
B1+=0.00000000481*cost(3.51023225206+155.42039943420*x);
B1+=0.00000000528*cost(6.06190721770+4933.20844033260*x);
B1+=0.00000000558*cost(2.09491968451+2288.34404351140*x);
B1+=0.00000000445*cost(3.42439886280+6680.24453233140*x);
B1+=0.00000000482*cost(4.73460866232+13365.97282514820*x);
B1+=0.00000000534*cost(4.88536251621+3361.38782219220*x);
B1+=0.00000000520*cost(6.19100285186+6438.49624942560*x);
B1+=0.00000000441*cost(1.82408206251+3325.35995551480*x);
B1+=0.00000000487*cost(2.72879191049+3319.83703120740*x);
B1+=0.00000000417*cost(4.48716253276+7903.07341972100*x);
B1+=0.00000000430*cost(0.62845892205+5614.72937620960*x);
B1+=0.00000000395*cost(4.89021898045+10419.98628350760*x);
B1+=0.00000000380*cost(1.91138845097+3553.91152213780*x);
B1+=0.00000000358*cost(4.21584518245+426.59819087600*x);
B1+=0.00000000409*cost(4.53421956625+3360.96774609859*x);
B1+=0.00000000426*cost(5.47172830908+3205.54734666440*x);
B1+=0.00000000330*cost(1.00078638665+8955.34180290940*x);
B1+=0.00000000322*cost(2.42607399606+2274.11694950980*x);
B1+=0.00000000316*cost(3.22064089430+1221.84856632140*x);
B1+=0.00000000312*cost(3.66073476074+3337.02199804800*x);
B1+=0.00000000310*cost(4.09100416919+3344.20285535160*x);
B1+=0.00000000295*cost(2.87635162282+7210.91581849420*x);
B1+=0.00000000329*cost(5.64440592793+12832.75874170460*x);
B1+=0.00000000306*cost(1.52567836482+7875.67186362420*x);
B1+=0.00000000284*cost(0.56373187712+6681.29216370240*x);
B1+=0.00000000358*cost(4.21258737082+1052.26838318840*x);
B1+=0.00000000347*cost(1.52200237477+10213.28554621100*x);
B1+=0.00000000268*cost(3.57749600251+9830.38901398780*x);
B1+=0.00000000346*cost(1.65247014273+6682.20517446780*x);
B1+=0.00000000269*cost(4.45182417080+9381.93999378540*x);
B1+=0.00000000285*cost(0.97118840317+6681.15754309680*x);
B1+=0.00000000256*cost(3.67744143301+1066.49547719000*x);
B1+=0.00000000269*cost(1.78448639785+6127.65545055720*x);
B1+=0.00000000312*cost(4.63751658715+5331.35744374080*x);
B1+=0.00000000317*cost(6.15274242841+3320.25710730100*x);
B1+=0.00000000245*cost(4.71030710599+26724.89941359840*x);
B1+=0.00000000249*cost(3.31328995337+10818.13528691580*x);
B1+=0.00000000240*cost(4.87364672707+6144.42034130420*x);
B1+=0.00000000239*cost(1.35709001659+7064.12138562280*x);
B1+=0.00000000237*cost(3.19837233399+5729.50644714900*x);
B1+=0.00000000278*cost(1.50842060340+4929.68532198360*x);
B1+=0.00000000274*cost(3.61160906396+191.44826611160*x);
B1+=0.00000000248*cost(3.93789974497+11243.68584642080*x);
B1+=0.00000000242*cost(2.57630671866+3355.86489788480*x);
B1+=0.00000000241*cost(1.89683861728+15643.68020330980*x);
B1+=0.00000000228*cost(0.71217112323+9866.41688066520*x);
B1+=0.00000000246*cost(0.16913226579+2700.71514038580*x);
B1+=0.00000000219*cost(0.03864812268+522.57741809380*x);
B1+=0.00000000215*cost(3.44260776071+8827.39026987480*x);
B1+=0.00000000206*cost(5.23615052385+6923.95345737360*x);
B1+=0.00000000202*cost(0.60277862639+10021.82002644720*x);
B1+=0.00000000226*cost(2.43332503270+8429.24126646660*x);
B1+=0.00000000202*cost(2.63373646725+10021.85453375160*x);
B1+=0.00000000199*cost(3.26545613445+382.89653222320*x);
B1+=0.00000000198*cost(4.50685315424+242.72860397400*x);
B1+=0.00000000215*cost(2.12744795327+553.56940284240*x);
B1+=0.00000000177*cost(3.92599588022+8031.09226305840*x);
B1+=0.00000000162*cost(3.94498519498+2921.12778282460*x);
B1+=0.00000000199*cost(4.22948972595+3312.16323923200*x);
B1+=0.00000000188*cost(0.67072289565+6298.32832117640*x);
B1+=0.00000000160*cost(2.90951395323+6872.67311951120*x);
B1+=0.00000000155*cost(1.24529852403+3364.49086444760*x);
B1+=0.00000000186*cost(2.44723831367+3503.07906283200*x);
B1+=0.00000000139*cost(5.75493557040+7632.94325965020*x);
B1+=0.00000000149*cost(0.49665393273+8969.56889691100*x);
B1+=0.00000000132*cost(4.97828413367+1748.01641306700*x);
B1+=0.00000000130*cost(0.66881298338+10014.72373309860*x);
B1+=0.00000000128*cost(2.80753554051+14584.29827312060*x);
B1+=0.00000000176*cost(2.37291314099+2118.76386037840*x);
B1+=0.00000000127*cost(1.76223414864+11081.21921028860*x);
B1+=0.00000000127*cost(0.26234206855+13358.92658845020*x);
B1+=0.00000000163*cost(5.83356697025+639.89728631400*x);
B1+=0.00000000129*cost(2.02607662846+3346.13535100720*x);
B1+=0.00000000155*cost(1.57189307640+3767.21061757580*x);
B1+=0.00000000133*cost(4.20989922795+11371.70468975820*x);
B1+=0.00000000114*cost(2.12636383988+6688.33840040040*x);
B1+=0.00000000130*cost(1.33114943655+3347.72597370060*x);
B1+=0.00000000110*cost(5.78893316282+16173.37116840440*x);
B1+=0.00000000105*cost(3.27202438053+15113.98923821520*x);
B1+=0.00000000117*cost(5.66812806862+536.80451209540*x);
B1+=0.00000000106*cost(1.21268139587+7234.79425624200*x);
B1+=0.00000000108*cost(0.94652521237+9808.53818466140*x);
B1+=0.00000000121*cost(4.22204758443+6158.64743530580*x);
B1+=0.00000000124*cost(4.92495255567+12964.30070339100*x);
B1+=0.00000000142*cost(3.85764234922+6894.52394883760*x);
B1+=0.00000000099*cost(5.62543167000+10973.55568635000*x);
B1+=0.00000000100*cost(2.56456804207+3178.14579056760*x);
B1+=0.00000000131*cost(0.08971075365+8273.82086703240*x);
B1+=0.00000000112*cost(3.14240135508+3316.73398895200*x);
B1+=0.00000000095*cost(0.64723185059+2487.41604494780*x);
B1+=0.00000000087*cost(4.14322802003+3603.69635007260*x);
B1+=0.00000000087*cost(3.50260474148+3077.52850332700*x);
B1+=0.00000000096*cost(5.13010621713+3304.58456002240*x);
B1+=0.00000000082*cost(4.87880877413+5828.02847164760*x);
B1+=0.00000000083*cost(2.04400907684+18984.29263000960*x);
B1+=0.00000000085*cost(3.33671991814+1758.65307841680*x);
B1+=0.00000000099*cost(3.28955694324+17654.78053974960*x);
B1+=0.00000000078*cost(0.89238228021+2699.73481931760*x);
B1+=0.00000000095*cost(0.32948273562+3863.18984479360*x);
B1+=0.00000000083*cost(0.80327899268+5085.03841111500*x);
B1+=0.00000000091*cost(1.48623539837+8270.29774868340*x);
B1+=0.00000000075*cost(4.91191036053+10021.76996979660*x);
B1+=0.00000000079*cost(4.25171159471+7373.38245462640*x);
B1+=0.00000000084*cost(2.16662156833+12566.15169998280*x);
B1+=0.00000000088*cost(2.78893554858+11769.85369316640*x);
B1+=0.00000000095*cost(0.29428946155+5628.95647021120*x);
B1+=0.00000000076*cost(5.23354729169+13760.59871020740*x);
B1+=0.00000000092*cost(1.40883592065+3336.73109134180*x);
B1+=0.00000000069*cost(3.50477916910+10713.99488132620*x);
B1+=0.00000000079*cost(0.61833410504+951.71840625060*x);
B1+=0.00000000070*cost(1.93458925881+3475.67750673520*x);
B1+=0.00000000066*cost(5.01996258363+16706.58525184800*x);
B1+=0.00000000067*cost(3.68731475523+4032.77002792660*x);
B1+=0.00000000071*cost(1.71691035008+10575.40668294180*x);
B1+=0.00000000086*cost(1.82073461894+10404.73381232260*x);
B1+=0.00000000064*cost(2.43149744819+2648.45482547300*x);
B1+=0.00000000062*cost(0.25250107112+3980.50971301380*x);
B1+=0.00000000062*cost(3.16420520010+13517.87010623340*x);
B1+=0.00000000078*cost(1.41762772678+3.52311834900*x);
B1+=0.00000000086*cost(3.34935714534+1581.95934828300*x);
B1+=0.00000000064*cost(3.75812808116+1596.18644228460*x);
B1+=0.00000000061*cost(1.37421861116+419.48464387520*x);
B1+=0.00000000055*cost(1.11154560464+433.71173787680*x);
B1+=0.00000000061*cost(5.33515994167+853.19638175200*x);
B1+=0.00000000059*cost(0.80382380790+13362.43245314700*x);
B1+=0.00000000055*cost(0.37478855406+149.56319713460*x);
B1+=0.00000000053*cost(0.55329112916+14314.16811304980*x);
B1+=0.00000000059*cost(0.07234691744+6531.66165626500*x);
B1+=0.00000000059*cost(2.83458587563+13362.46696045140*x);
B1+=0.00000000059*cost(4.13409540555+4407.10790388980*x);
B1+=0.00000000057*cost(5.57913927474+3376.64029337720*x);
B1+=0.00000000049*cost(4.58036235824+10551.52824519400*x);
B1+=0.00000000050*cost(2.01769015785+10022.81760116760*x);
B1+=0.00000000055*cost(1.36081433917+21393.54196985760*x);
B1+=0.00000000048*cost(1.59939595487+18052.92954315780*x);
B1+=0.00000000045*cost(4.97928157994+8671.96987044060*x);
B1+=0.00000000044*cost(2.58542985685+13916.01910964160*x);
B1+=0.00000000047*cost(1.40206686464+8425.65083781480*x);
B1+=0.00000000043*cost(0.21864618144+9779.10867612540*x);
B1+=0.00000000042*cost(6.22365857047+3914.95722503460*x);
B1+=0.00000000048*cost(3.44104044998+692.15760122680*x);
B1+=0.00000000043*cost(3.21191030055+6247.51311552280*x);
B1+=0.00000000055*cost(4.01321481700+10177.25767953360*x);
B1+=0.00000000053*cost(2.93285711320+3981.49003408200*x);
B1+=0.00000000039*cost(5.54634215618+6702.00024889200*x);
B1+=0.00000000041*cost(2.46188112193+6660.44945790720*x);
B1+=0.00000000049*cost(3.04236065330+640.87760738220*x);
B1+=0.00000000039*cost(1.62689158397+3335.08950239240*x);
B1+=0.00000000038*cost(3.31198341709+1744.42598441520*x);
B1+=0.00000000038*cost(6.16317067723+2818.03500860600*x);
B1+=0.00000000038*cost(4.03534957207+103.09277421860*x);
B1+=0.00000000044*cost(0.91040525278+5459.37628707820*x);
B1+=0.00000000049*cost(1.88325571471+11216.28429032400*x);
B1+=0.00000000046*cost(5.62762941168+9168.64089834740*x);
B1+=0.00000000035*cost(1.65976191407+12168.00269657460*x);
B1+=0.00000000047*cost(4.52334272666+10021.90459040220*x);
B1+=0.00000000039*cost(2.08367076229+13745.34623902240*x);
B1+=0.00000000039*cost(4.76186135572+20597.24396304120*x);
B1+=0.00000000039*cost(3.00951950244+3344.49376205780*x);
B1+=0.00000000037*cost(1.33065895739+12295.95422960920*x);
B1+=0.00000000040*cost(3.96893429107+13171.00144068760*x);
B1+=0.00000000032*cost(0.91212661789+12310.18132361080*x);
B1+=0.00000000032*cost(2.22618836835+7107.82304427560*x);
B1+=0.00000000032*cost(4.96078703650+24734.15439655740*x);
B1+=0.00000000037*cost(3.30085609301+20995.39296644940*x);
B1+=0.00000000033*cost(3.70858397913+10020.85695903120*x);
B1+=0.00000000031*cost(4.18674524484+17256.63153634140*x);
B1+=0.00000000034*cost(3.25657016622+14054.60730802600*x);
B1+=0.00000000032*cost(5.75360661734+6546.15977336420*x);
B1+=0.00000000031*cost(3.16209740784+12935.85151592320*x);
B1+=0.00000000037*cost(2.14901622101+6665.97238221460*x);
B1+=0.00000000030*cost(0.21926429217+6660.86953400080*x);
B1+=0.00000000030*cost(3.55459460301+9070.11887384880*x);
B1+=0.00000000029*cost(2.97927335664+2766.26762836500*x);
B1+=0.00000000029*cost(4.65051930186+10235.13637553740*x);
B1+=0.00000000030*cost(5.16882435400+16304.91313009080*x);
B1+=0.00000000032*cost(5.01760544488+3191.04922956520*x);
B1+=0.00000000029*cost(2.93988761068+6696.47732458460*x);
B1+=0.00000000029*cost(5.06447742493+5099.26550511660*x);
B1+=0.00000000029*cost(5.68073325802+3329.97576135000*x);
B1+=0.00000000029*cost(0.43949269085+3351.24909204960*x);
B1+=0.00000000032*cost(1.37056688814+6040.34724601740*x);
B1+=0.00000000032*cost(1.42334455474+76.26607127560*x);
B1+=0.00000000033*cost(0.36423446435+6604.95878212400*x);
B1+=0.00000000033*cost(4.85478789063+6701.58017279840*x);
B1+=0.00000000030*cost(3.33348460172+3369.06161416760*x);
B1+=0.00000000028*cost(0.60182098585+11766.26326451460*x);
B1+=0.00000000026*cost(1.05197848649+13207.02930736500*x);
B1+=0.00000000026*cost(5.03535225585+30065.51184029820*x);
B1+=0.00000000034*cost(3.65553061498+14158.74771361560*x);
B1+=0.00000000025*cost(4.60925601393+8329.67161059700*x);
B1+=0.00000000025*cost(2.05970140678+17395.21973472580*x);
B1+=0.00000000030*cost(5.22285260441+9485.03276800400*x);
B1+=0.00000000025*cost(4.84964369679+1648.44675719740*x);
B1+=0.00000000026*cost(5.47626814223+3074.00538497800*x);
B1+=0.00000000024*cost(2.45239543931+17085.95866572220*x);
B1+=0.00000000029*cost(5.36428737888+2707.82868738660*x);
B1+=0.00000000024*cost(5.57488544800+10264.56588407340*x);
B1+=0.00000000025*cost(4.22744782935+1692.16566950240*x);
B1+=0.00000000023*cost(6.09244870438+20199.09495963300*x);
B1+=0.00000000028*cost(1.30366587075+8439.87793181640*x);
B1+=0.00000000032*cost(2.13597148493+9468.26787725700*x);

double B2=0;
B2+=0.00016726690*cost(0.60221392419+3340.61242669980*x);
B2-=0.00004986799;
B2+=0.00000302141*cost(5.55871276021+6681.22485339960*x);
B2+=0.00000025767*cost(1.89662673499+13362.44970679920*x);
B2+=0.00000021452*cost(0.91749968618+10021.83728009940*x);
B2+=0.00000011820*cost(2.24240738700+3337.08930835080*x);
B2+=0.00000007985*cost(2.24892866611+16703.06213349900*x);
B2+=0.00000002960*cost(5.89425825808+3496.03282613400*x);
B2+=0.00000002445*cost(5.18770525274+5621.84292321040*x);
B2+=0.00000001428*cost(1.25238140580+2281.23049651060*x);
B2+=0.00000001779*cost(2.58759968520+20043.67456019880*x);
B2+=0.00000001501*cost(3.18533003542+3532.06069281140*x);
B2+=0.00000001259*cost(4.80695172904+3185.19202726560*x);
B2+=0.00000001029*cost(2.35029907056+6677.70173505060*x);
B2+=0.00000001109*cost(3.80982317372+5884.92684658320*x);
B2+=0.00000000928*cost(0.29719160927+3344.13554504880*x);
B2+=0.00000000860*cost(3.11698318930+6151.53388830500*x);
B2+=0.00000000853*cost(1.33003321402+529.69096509460*x);
B2+=0.00000000883*cost(5.18681316017+5486.77784317500*x);
B2+=0.00000001100*cost(1.82962075794+2942.46342329160*x);
B2+=0.00000000815*cost(3.40910567373+2544.31441988340*x);
B2+=0.00000000702*cost(5.49076132554+8962.45534991020*x);
B2+=0.00000000644*cost(0.31400306761+5088.62883976680*x);
B2+=0.00000000745*cost(4.30248377111+3340.59517304760*x);
B2+=0.00000000586*cost(4.48071459693+3894.18182954220*x);
B2+=0.00000000681*cost(5.40951261308+2810.92146160520*x);
B2+=0.00000000745*cost(0.05006463495+3340.62968035200*x);
B2+=0.00000000542*cost(4.68895461946+3339.63210563160*x);
B2+=0.00000000497*cost(4.65665197749+5092.15195811580*x);
B2+=0.00000000460*cost(1.06670343610+3097.88382272579*x);
B2+=0.00000000423*cost(3.08034568777+4292.33083295040*x);
B2+=0.00000000381*cost(2.24933115190+6283.07584999140*x);
B2+=0.00000000429*cost(1.70668733378+4690.47983635860*x);
B2+=0.00000000339*cost(2.92195933142+23384.28698689860*x);
B2+=0.00000000310*cost(5.63324402105+3723.50895892300*x);
B2+=0.00000000287*cost(1.98619629868+398.14900340820*x);
B2+=0.00000000298*cost(2.58990636818+6684.74797174860*x);
B2+=0.00000000323*cost(5.15230144390+6525.80445396540*x);
B2+=0.00000000247*cost(2.36923535528+3340.54511639700*x);
B2+=0.00000000247*cost(1.96071951597+3340.67973700260*x);
B2+=0.00000000223*cost(4.75562842441+2146.16541647520*x);
B2+=0.00000000240*cost(3.53331653789+3583.34103067380*x);
B2+=0.00000000238*cost(4.69268478666+6254.62666252360*x);
B2+=0.00000000198*cost(6.21548965568+2787.04302385740*x);
B2+=0.00000000202*cost(4.25439775032+3333.49887969900*x);
B2+=0.00000000158*cost(1.89216973387+6674.11130639880*x);
B2+=0.00000000185*cost(2.99350590687+10025.36039844840*x);
B2+=0.00000000177*cost(1.41002572971+6438.49624942560*x);
B2+=0.00000000138*cost(1.23172102079+3127.31333126180*x);
B2+=0.00000000153*cost(5.93528616595+6836.64525283380*x);
B2+=0.00000000106*cost(5.35414400998+3738.76143010800*x);
B2+=0.00000000102*cost(3.67040445208+1059.38193018920*x);
B2+=0.00000000136*cost(1.06039656714+2388.89402044920*x);
B2+=0.00000000093*cost(5.04434801864+155.42039943420*x);
B2+=0.00000000093*cost(2.70817394910+8955.34180290940*x);
B2+=0.00000000108*cost(6.13917250674+1748.01641306700*x);
B2+=0.00000000116*cost(5.97739483530+2914.01423582380*x);
B2+=0.00000000099*cost(1.50221319099+1751.53953141600*x);
B2+=0.00000000092*cost(2.68470906437+1990.74501704100*x);
B2+=0.00000000077*cost(4.01966292109+1592.59601363280*x);
B2+=0.00000000076*cost(4.49660101731+4562.46099302120*x);
B2+=0.00000000076*cost(5.67354102576+6041.32756708560*x);
B2+=0.00000000078*cost(0.79220883728+2288.34404351140*x);
B2+=0.00000000074*cost(5.84795427965+3341.59274776800*x);
B2+=0.00000000080*cost(5.48556941416+8432.76438481560*x);
B2+=0.00000000065*cost(2.11705931744+10018.31416175040*x);
B2+=0.00000000066*cost(5.08073805943+2957.71589447660*x);
B2+=0.00000000059*cost(3.79695096075+6923.95345737360*x);
B2+=0.00000000061*cost(4.51116100631+4933.20844033260*x);
B2+=0.00000000059*cost(0.27765984344+6127.65545055720*x);
B2+=0.00000000052*cost(5.84885902302+4535.05943692440*x);
B2+=0.00000000051*cost(1.45495904398+7477.52286021600*x);
B2+=0.00000000054*cost(1.50278239577+6489.77658728800*x);
B2+=0.00000000056*cost(5.23212313891+9866.41688066520*x);
B2+=0.00000000057*cost(4.73711357046+2274.11694950980*x);
B2+=0.00000000051*cost(2.48654805044+6467.92575796160*x);
B2+=0.00000000047*cost(3.25899585469+26724.89941359840*x);
B2+=0.00000000048*cost(1.12255878532+1349.86740965880*x);
B2+=0.00000000048*cost(2.87122326236+242.72860397400*x);
B2+=0.00000000045*cost(1.61358524585+5729.50644714900*x);
B2+=0.00000000043*cost(2.24334731490+7.11354700080*x);
B2+=0.00000000044*cost(4.61065704096+11773.37681151540*x);
B2+=0.00000000042*cost(3.32038536161+13365.97282514820*x);
B2+=0.00000000047*cost(5.10736479739+8969.56889691100*x);
B2+=0.00000000044*cost(4.64194663616+4399.99435688900*x);
B2+=0.00000000039*cost(5.45779680648+8031.09226305840*x);
B2+=0.00000000044*cost(5.21409542420+4136.91043351620*x);
B2+=0.00000000045*cost(4.26206063790+796.29800681640*x);
B2+=0.00000000048*cost(3.04342098072+5331.35744374080*x);
B2+=0.00000000042*cost(2.12882700518+213.29909543800*x);
B2+=0.00000000038*cost(2.49365585516+951.71840625060*x);
B2+=0.00000000037*cost(3.44816851943+3325.35995551480*x);
B2+=0.00000000038*cost(3.13981385980+3149.16416058820*x);
B2+=0.00000000039*cost(3.64984946180+553.56940284240*x);
B2+=0.00000000036*cost(0.54858124109+7632.94325965020*x);
B2+=0.00000000032*cost(4.29985057106+3355.86489788480*x);
B2+=0.00000000037*cost(6.26349600634+6682.20517446780*x);
B2+=0.00000000037*cost(3.83188032092+3870.30339179440*x);
B2+=0.00000000031*cost(4.94959395405+6680.24453233140*x);
B2+=0.00000000035*cost(6.14813219827+3360.96774609859*x);
B2+=0.00000000029*cost(0.54115054572+6681.29216370240*x);
B2+=0.00000000035*cost(1.49899662719+3320.25710730100*x);
B2+=0.00000000033*cost(0.19183878029+3347.72597370060*x);
B2+=0.00000000036*cost(3.28055425527+1589.07289528380*x);
B2+=0.00000000031*cost(5.66015228291+1066.49547719000*x);
B2+=0.00000000028*cost(4.18178455540+7210.91581849420*x);
B2+=0.00000000025*cost(1.21627749818+9492.14631500480*x);
B2+=0.00000000029*cost(2.02283118033+7234.79425624200*x);
B2+=0.00000000024*cost(2.96777681837+7064.12138562280*x);
B2+=0.00000000024*cost(2.16823248221+10419.98628350760*x);
B2+=0.00000000022*cost(4.67496434823+1194.44701022460*x);
B2+=0.00000000022*cost(5.01797528499+9595.23908922340*x);
B2+=0.00000000028*cost(4.19843924702+8429.24126646660*x);
B2+=0.00000000023*cost(6.21195010050+7740.60678358880*x);
B2+=0.00000000025*cost(1.45100528915+6872.67311951120*x);
B2+=0.00000000024*cost(1.93342510858+2699.73481931760*x);
B2+=0.00000000028*cost(5.87009898150+1052.26838318840*x);
B2+=0.00000000025*cost(2.49707182259+2118.76386037840*x);
B2+=0.00000000020*cost(0.15682384975+3205.54734666440*x);
B2+=0.00000000019*cost(3.82087005916+12303.06777661000*x);
B2+=0.00000000020*cost(6.26534330674+7875.67186362420*x);
B2+=0.00000000019*cost(0.99282533197+522.57741809380*x);
B2+=0.00000000018*cost(4.11668144665+426.59819087600*x);
B2+=0.00000000020*cost(3.28531167827+9225.53927328300*x);
B2+=0.00000000019*cost(5.72169822815+11371.70468975820*x);
B2+=0.00000000018*cost(4.76871968197+382.89653222320*x);
B2+=0.00000000017*cost(0.96519535826+191.44826611160*x);
B2+=0.00000000017*cost(0.86184324841+10973.55568635000*x);
B2+=0.00000000018*cost(6.22706341047+9381.93999378540*x);
B2+=0.00000000015*cost(0.54135050421+640.87760738220*x);

double B3=0;
B3+=0.00000606506*cost(1.98050633529+3340.61242669980*x);
B3+=0.00000042611;
B3+=0.00000013652*cost(1.79588228800+6681.22485339960*x);
B3+=0.00000002730*cost(3.45377082121+10021.83728009940*x);
B3+=0.00000000929*cost(3.75226159072+3337.08930835080*x);
B3+=0.00000000607*cost(0.10618486408+13362.44970679920*x);
B3+=0.00000000617*cost(1.14471772765+3496.03282613400*x);
B3+=0.00000000479*cost(0.70504966293+16703.06213349900*x);
B3+=0.00000000185*cost(3.28778562029+3185.19202726560*x);
B3+=0.00000000169*cost(0.29980532608+5621.84292321040*x);
B3+=0.00000000158*cost(1.09025317222+20043.67456019880*x);
B3+=0.00000000123*cost(2.55664973413+3097.88382272579*x);
B3+=0.00000000126*cost(4.74517022983+3532.06069281140*x);
B3+=0.00000000093*cost(6.03607685759+3894.18182954220*x);
B3+=0.00000000099*cost(4.92257049901+2544.31441988340*x);
B3+=0.00000000106*cost(3.41315845439+2942.46342329160*x);
B3+=0.00000000062*cost(6.25738949900+3339.63210563160*x);
B3+=0.00000000058*cost(4.64867983361+4292.33083295040*x);
B3+=0.00000000050*cost(3.75358626972+6677.70173505060*x);
B3+=0.00000000050*cost(1.89408668049+5088.62883976680*x);
B3+=0.00000000058*cost(3.65295480755+6525.80445396540*x);
B3+=0.00000000045*cost(0.38295906298+5486.77784317500*x);
B3+=0.00000000052*cost(3.25535694335+4690.47983635860*x);
B3+=0.00000000044*cost(1.89342588822+3583.34103067380*x);
B3+=0.00000000037*cost(0.04871920725+2146.16541647520*x);
B3+=0.00000000039*cost(0.91787211117+3723.50895892300*x);
B3+=0.00000000051*cost(5.24063514394+5884.92684658320*x);
B3+=0.00000000036*cost(2.79633276263+529.69096509460*x);
B3+=0.00000000032*cost(1.44641701752+23384.28698689860*x);
B3+=0.00000000024*cost(5.41362501363+3340.59517304760*x);
B3+=0.00000000023*cost(4.70639896508+2787.04302385740*x);
B3+=0.00000000021*cost(1.12581894224+3340.62968035200*x);
B3+=0.00000000021*cost(0.51744721589+8962.45534991020*x);
B3+=0.00000000018*cost(0.36433365806+155.42039943420*x);
B3+=0.00000000018*cost(5.53170427847+3333.49887969900*x);
B3+=0.00000000019*cost(4.34401282378+6151.53388830500*x);
B3+=0.00000000021*cost(2.94765501590+398.14900340820*x);
B3+=0.00000000020*cost(5.96181389299+5092.15195811580*x);
B3+=0.00000000017*cost(0.80891817293+1194.44701022460*x);
B3+=0.00000000011*cost(0.43817745316+1059.38193018920*x);
B3+=0.00000000014*cost(1.06654064248+6836.64525283380*x);

double B4=0;
B4+=0.00000011334*cost(3.45724352586+3340.61242669980*x);
B4+=0.00000013369;
B4+=0.00000000744*cost(0.50445805257+6681.22485339960*x);
B4+=0.00000000148*cost(1.05056602649+10021.83728009940*x);
B4+=0.00000000102*cost(2.66185835593+3496.03282613400*x);
B4+=0.00000000053*cost(5.27888218929+3337.08930835080*x);
B4+=0.00000000022*cost(4.09971603267+3097.88382272579*x);
B4+=0.00000000023*cost(1.72422342130+3185.19202726560*x);
B4+=0.00000000013*cost(5.41704779112+16703.06213349900*x);
B4+=0.00000000013*cost(2.06957065662+13362.44970679920*x);
B4+=0.00000000010*cost(0.95989595600+3894.18182954220*x);

double B5=0;
B5+=0.00000000457*cost(4.86794125358+3340.61242669980*x);
B5+=0.00000000053*cost(5.30547050586+6681.22485339960*x);
B5+=0.00000000012*cost(5.75114070583+10021.83728009940*x);
B5+=0.00000000013*cost(4.17736925293+3496.03282613400*x);
B5+=0.00000000007;
	
double rtd=180/3.141592653589793;
double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
	
return rtd*( Bx0+B1*x+B2*x2+B3*x3+B4*x4+B5*x5); //END MARS
}

//Distance Mars-Sun [AU]
double Rmars(double x)
{
double R0=0;
R0+=1.53033488276;
R0+=0.14184953153*cost(3.47971283519+3340.61242669980*x);
R0+=0.00660776357*cost(3.81783442097+6681.22485339960*x);
R0+=0.00046179117*cost(4.15595316284+10021.83728009940*x);
R0+=0.00008109738*cost(5.55958460165+2810.92146160520*x);
R0+=0.00007485315*cost(1.77238998069+5621.84292321040*x);
R0+=0.00005523193*cost(1.36436318880+2281.23049651060*x);
R0+=0.00003825160*cost(4.49407182408+13362.44970679920*x);
R0+=0.00002306539*cost(0.09081742493+2544.31441988340*x);
R0+=0.00001999399*cost(5.36059605227+3337.08930835080*x);
R0+=0.00002484385*cost(4.92545577893+2942.46342329160*x);
R0+=0.00001960198*cost(4.74249386323+3344.13554504880*x);
R0+=0.00001167115*cost(2.11261501155+5092.15195811580*x);
R0+=0.00001102828*cost(5.00908264160+398.14900340820*x);
R0+=0.00000899077*cost(4.40790433994+529.69096509460*x);
R0+=0.00000992252*cost(5.83862401067+6151.53388830500*x);
R0+=0.00000807348*cost(2.10216647104+1059.38193018920*x);
R0+=0.00000797910*cost(3.44839026172+796.29800681640*x);
R0+=0.00000740980*cost(1.49906336892+2146.16541647520*x);
R0+=0.00000692340*cost(2.13378814785+8962.45534991020*x);
R0+=0.00000633144*cost(0.89353285018+3340.59517304760*x);
R0+=0.00000725583*cost(1.24516913473+8432.76438481560*x);
R0+=0.00000633140*cost(2.92430448169+3340.62968035200*x);
R0+=0.00000574352*cost(0.82896196337+2914.01423582380*x);
R0+=0.00000526187*cost(5.38292276228+3738.76143010800*x);
R0+=0.00000629976*cost(1.28738135858+1751.53953141600*x);
R0+=0.00000472776*cost(5.19850457873+3127.31333126180*x);
R0+=0.00000348095*cost(4.83219198908+16703.06213349900*x);
R0+=0.00000283702*cost(2.90692294913+3532.06069281140*x);
R0+=0.00000279552*cost(5.25749247548+6283.07584999140*x);
R0+=0.00000233827*cost(5.10546492529+5486.77784317500*x);
R0+=0.00000219428*cost(5.58340248784+191.44826611160*x);
R0+=0.00000269891*cost(3.76394728622+5884.92684658320*x);
R0+=0.00000208333*cost(5.25476080773+3340.54511639700*x);
R0+=0.00000275224*cost(2.90818883832+1748.01641306700*x);
R0+=0.00000275501*cost(1.21767967781+6254.62666252360*x);
R0+=0.00000239133*cost(2.03669896238+1194.44701022460*x);
R0+=0.00000223190*cost(4.19861593779+3149.16416058820*x);
R0+=0.00000182686*cost(5.08062683355+6684.74797174860*x);
R0+=0.00000186213*cost(5.69871555748+6677.70173505060*x);
R0+=0.00000175995*cost(5.95341786369+3870.30339179440*x);
R0+=0.00000178613*cost(4.18423025538+3333.49887969900*x);
R0+=0.00000208336*cost(4.84626442122+3340.67973700260*x);
R0+=0.00000228128*cost(3.25529020620+6872.67311951120*x);
R0+=0.00000144286*cost(0.21296012258+5088.62883976680*x);
R0+=0.00000163534*cost(3.79889068111+4136.91043351620*x);
R0+=0.00000133120*cost(1.53910106710+7903.07341972100*x);
R0+=0.00000141759*cost(2.47790321309+4562.46099302120*x);
R0+=0.00000114941*cost(4.31745088059+1349.86740965880*x);
R0+=0.00000118781*cost(2.12178071222+1589.07289528380*x);
R0+=0.00000102096*cost(6.18138550087+9492.14631500480*x);
R0+=0.00000128555*cost(5.49883294915+8827.39026987480*x);
R0+=0.00000111538*cost(0.55339169625+11243.68584642080*x);
R0+=0.00000082498*cost(1.62227044590+11773.37681151540*x);
R0+=0.00000083212*cost(0.61553380568+8429.24126646660*x);
R0+=0.00000084470*cost(0.62274593110+1592.59601363280*x);
R0+=0.00000086659*cost(1.74988330093+2700.71514038580*x);
R0+=0.00000071826*cost(2.47489899385+12303.06777661000*x);
R0+=0.00000085312*cost(1.61621097912+4690.47983635860*x);
R0+=0.00000063641*cost(2.67334126661+426.59819087600*x);
R0+=0.00000068599*cost(2.40197828418+4399.99435688900*x);
R0+=0.00000058559*cost(4.72052787516+213.29909543800*x);
R0+=0.00000062015*cost(1.10065866221+1221.84856632140*x);
R0+=0.00000066509*cost(2.21307705185+6041.32756708560*x);
R0+=0.00000055811*cost(1.23288325946+3185.19202726560*x);
R0+=0.00000054989*cost(5.72691385306+951.71840625060*x);
R0+=0.00000052418*cost(3.02366828926+4292.33083295040*x);
R0+=0.00000055686*cost(5.44686699242+3723.50895892300*x);
R0+=0.00000058959*cost(3.26242666052+6681.24210705180*x);
R0+=0.00000044629*cost(2.01473640390+8031.09226305840*x);
R0+=0.00000058959*cost(1.23165502899+6681.20759974740*x);
R0+=0.00000042444*cost(2.26551590902+155.42039943420*x);
R0+=0.00000038956*cost(2.57760416009+3341.59274776800*x);
R0+=0.00000051561*cost(5.72326937712+7079.37385680780*x);
R0+=0.00000048939*cost(5.61614696751+3553.91152213780*x);
R0+=0.00000045414*cost(5.43290921705+6467.92575796160*x);
R0+=0.00000036435*cost(4.43921812388+3894.18182954220*x);
R0+=0.00000035980*cost(1.15966567007+2288.34404351140*x);
R0+=0.00000035265*cost(5.49029710802+1990.74501704100*x);
R0+=0.00000042191*cost(1.63253742760+5628.95647021120*x);
R0+=0.00000044292*cost(5.00341366850+5614.72937620960*x);
R0+=0.00000033623*cost(5.17029029766+20043.67456019880*x);
R0+=0.00000043256*cost(1.03732072925+11769.85369316640*x);
R0+=0.00000039237*cost(1.24237122859+3339.63210563160*x);
R0+=0.00000031943*cost(4.59258406791+2274.11694950980*x);
R0+=0.00000030345*cost(2.44177670130+11371.70468975820*x);
R0+=0.00000032259*cost(2.38215172582+4535.05943692440*x);
R0+=0.00000031870*cost(4.37521442752+3.52311834900*x);
R0+=0.00000029350*cost(4.06034813442+3097.88382272579*x);
R0+=0.00000031972*cost(1.93970478412+382.89653222320*x);
R0+=0.00000026166*cost(5.58466944895+9623.68827669120*x);
R0+=0.00000027904*cost(4.25805969214+3191.04922956520*x);
R0+=0.00000033065*cost(0.85467740581+553.56940284240*x);
R0+=0.00000027543*cost(1.57668567401+9595.23908922340*x);
R0+=0.00000025159*cost(0.81355213242+10713.99488132620*x);
R0+=0.00000022070*cost(0.85747723964+3319.83703120740*x);
R0+=0.00000024772*cost(5.38970742761+2818.03500860600*x);
R0+=0.00000023359*cost(6.01453778225+3496.03282613400*x);
R0+=0.00000024732*cost(2.58034797703+2803.80791460440*x);
R0+=0.00000019365*cost(5.18528750472+6681.29216370240*x);
R0+=0.00000019122*cost(5.41968559451+10025.36039844840*x);
R0+=0.00000019364*cost(5.59378382138+6681.15754309680*x);
R0+=0.00000018330*cost(5.79567324240+7064.12138562280*x);
R0+=0.00000018193*cost(5.61307426173+7.11354700080*x);
R0+=0.00000020392*cost(4.53637816869+6489.77658728800*x);
R0+=0.00000021260*cost(6.19160142215+14054.60730802600*x);
R0+=0.00000017094*cost(1.55004739305+2957.71589447660*x);
R0+=0.00000022791*cost(3.41709388606+7632.94325965020*x);
R0+=0.00000020585*cost(2.98697279083+3361.38782219220*x);
R0+=0.00000018005*cost(2.81431094394+4032.77002792660*x);
R0+=0.00000017049*cost(6.15528099726+10404.73381232260*x);
R0+=0.00000016488*cost(3.84534700818+10973.55568635000*x);
R0+=0.00000016052*cost(0.92823508003+14584.29827312060*x);
R0+=0.00000021027*cost(2.38474290907+4989.05918389720*x);
R0+=0.00000016267*cost(1.92321585819+7373.38245462640*x);
R0+=0.00000016291*cost(6.28233085307+7210.91581849420*x);
R0+=0.00000018585*cost(4.07325116588+2388.89402044920*x);
R0+=0.00000015977*cost(4.58368417141+3264.34635542420*x);
R0+=0.00000019913*cost(2.73518445950+5099.26550511660*x);
R0+=0.00000019661*cost(1.86285979000+3443.70520091840*x);
R0+=0.00000016500*cost(4.14061745086+7477.52286021600*x);
R0+=0.00000019495*cost(6.03778234182+10018.31416175040*x);
R0+=0.00000015104*cost(2.65433427561+2787.04302385740*x);
R0+=0.00000019099*cost(0.22623441108+13745.34623902240*x);
R0+=0.00000017163*cost(3.18825562972+3347.72597370060*x);
R0+=0.00000013423*cost(2.12818658793+3344.20285535160*x);
R0+=0.00000015410*cost(2.20773507960+2118.76386037840*x);
R0+=0.00000017238*cost(3.67067776368+3205.54734666440*x);
R0+=0.00000013113*cost(4.27490214998+14314.16811304980*x);
R0+=0.00000016451*cost(2.86641622696+14712.31711645800*x);
R0+=0.00000013734*cost(1.68629769646+3337.02199804800*x);
R0+=0.00000016659*cost(4.52130808861+6674.11130639880*x);
R0+=0.00000011830*cost(0.19684525299+3475.67750673520*x);
R0+=0.00000011767*cost(3.22897247987+5828.02847164760*x);
R0+=0.00000011886*cost(4.82057654742+7234.79425624200*x);
R0+=0.00000010609*cost(1.73997337551+639.89728631400*x);
R0+=0.00000011154*cost(0.23859830185+12832.75874170460*x);
R0+=0.00000011030*cost(0.44541706440+10213.28554621100*x);
R0+=0.00000010240*cost(5.74758340632+242.72860397400*x);
R0+=0.00000010051*cost(2.45102946726+4929.68532198360*x);
R0+=0.00000010061*cost(0.78907665448+9381.93999378540*x);
R0+=0.00000010065*cost(5.37506605762+5085.03841111500*x);
R0+=0.00000011902*cost(0.79897698904+3265.83082813250*x);
R0+=0.00000008990*cost(0.96463418322+4933.20844033260*x);
R0+=0.00000008970*cost(4.18326774405+9225.53927328300*x);
R0+=0.00000008982*cost(1.98501418026+15113.98923821520*x);
R0+=0.00000008324*cost(1.93694866513+1648.44675719740*x);
R0+=0.00000007833*cost(2.04997447879+1758.65307841680*x);
R0+=0.00000007957*cost(3.92331072722+2921.12778282460*x);
R0+=0.00000010224*cost(2.66497189021+2487.41604494780*x);
R0+=0.00000008277*cost(0.94860765546+2906.90068882300*x);
R0+=0.00000007371*cost(0.84378341481+692.15760122680*x);
R0+=0.00000007545*cost(5.68031160782+13916.01910964160*x);
R0+=0.00000007912*cost(2.81294761885+15643.68020330980*x);
R0+=0.00000006958*cost(3.32193127272+3230.40610548040*x);
R0+=0.00000007426*cost(6.09656283295+3583.34103067380*x);
R0+=0.00000006402*cost(4.19806996774+5202.35827933520*x);
R0+=0.00000006529*cost(6.11929252710+135.06508003540*x);
R0+=0.00000006130*cost(0.00117252232+6836.64525283380*x);
R0+=0.00000006226*cost(6.10683955669+17256.63153634140*x);
R0+=0.00000008193*cost(5.24811458833+10575.40668294180*x);
R0+=0.00000006168*cost(3.60069207439+10021.85453375160*x);
R0+=0.00000006169*cost(1.56992114335+10021.82002644720*x);
R0+=0.00000005671*cost(0.13650306660+13524.91634293140*x);
R0+=0.00000006257*cost(4.50450768937+8425.65083781480*x);
R0+=0.00000005249*cost(2.70122358603+4459.36821880260*x);
R0+=0.00000006479*cost(2.74267498287+7740.60678358880*x);
R0+=0.00000005530*cost(6.06408145092+10419.98628350760*x);
R0+=0.00000005536*cost(5.74996063243+12168.00269657460*x);
R0+=0.00000006826*cost(4.69327545839+17654.78053974960*x);
R0+=0.00000005005*cost(4.68382632238+522.57741809380*x);
R0+=0.00000006328*cost(3.31896726895+3767.21061757580*x);
R0+=0.00000004734*cost(0.00755678425+3325.35995551480*x);
R0+=0.00000005032*cost(2.33696685608+1052.26838318840*x);
R0+=0.00000004661*cost(5.15051711401+1066.49547719000*x);
R0+=0.00000004724*cost(5.77956037309+9808.53818466140*x);
R0+=0.00000005136*cost(1.57259709878+6525.80445396540*x);
R0+=0.00000004522*cost(1.44218620352+3369.06161416760*x);
R0+=0.00000006189*cost(4.58996159356+6531.66165626500*x);
R0+=0.00000006205*cost(4.48164856516+22747.29071487440*x);
R0+=0.00000005329*cost(4.55145599182+1744.42598441520*x);
R0+=0.00000004511*cost(5.94511266539+6894.52394883760*x);
R0+=0.00000004330*cost(3.10901365758+4569.57454002200*x);
R0+=0.00000005366*cost(5.08043436437+2707.82868738660*x);
R0+=0.00000005134*cost(1.28568358496+8439.87793181640*x);
R0+=0.00000004127*cost(5.48538052912+2699.73481931760*x);
R0+=0.00000005394*cost(5.21695066244+5305.45105355380*x);
R0+=0.00000004449*cost(5.56764082611+16865.52876963120*x);
R0+=0.00000003898*cost(1.48782434790+9168.64089834740*x);
R0+=0.00000003863*cost(1.23050803930+16858.48253293320*x);
R0+=0.00000003766*cost(0.27090392616+17395.21973472580*x);
R0+=0.00000004683*cost(3.05668892586+5518.75014899180*x);
R0+=0.00000004258*cost(2.79090145790+3503.07906283200*x);
R0+=0.00000003864*cost(0.37957291785+10177.25767953360*x);
R0+=0.00000003992*cost(1.84424768030+3134.42687826260*x);
R0+=0.00000003643*cost(2.95318600206+6144.42034130420*x);
R0+=0.00000003654*cost(1.58063207414+6680.24453233140*x);
R0+=0.00000003931*cost(1.98436570971+8969.56889691100*x);
R0+=0.00000003350*cost(2.72637081667+7875.67186362420*x);
R0+=0.00000003623*cost(2.91544991631+6682.20517446780*x);
R0+=0.00000004392*cost(0.81931997702+3302.47939106200*x);
R0+=0.00000004062*cost(5.46935175827+3120.19978426100*x);
R0+=0.00000003319*cost(1.77193665786+3116.26763099790*x);
R0+=0.00000003510*cost(1.18027333874+10184.30391623160*x);
R0+=0.00000004008*cost(1.33675167812+6247.51311552280*x);
R0+=0.00000003603*cost(0.15469852619+2178.13772229200*x);
R0+=0.00000003313*cost(3.12853663982+17277.40693183380*x);
R0+=0.00000004138*cost(4.39568891039+3074.00538497800*x);
R0+=0.00000003201*cost(3.36492925275+2384.32327072920*x);
R0+=0.00000003991*cost(3.82867836910+3355.86489788480*x);
R0+=0.00000004205*cost(1.90532279170+263.08392337280*x);
R0+=0.00000003743*cost(4.25458024187+6261.74020952440*x);
R0+=0.00000003111*cost(1.65445053349+20199.09495963300*x);
R0+=0.00000003634*cost(5.55063049451+632.78373931320*x);
R0+=0.00000002892*cost(1.91514920700+12935.85151592320*x);
R0+=0.00000003373*cost(5.50812408522+23384.28698689860*x);
R0+=0.00000003312*cost(5.83174680245+5331.35744374080*x);
R0+=0.00000003124*cost(5.44069658195+6048.44111408640*x);
R0+=0.00000003813*cost(0.80274487430+13517.87010623340*x);
R0+=0.00000003612*cost(3.68140265686+5724.93569742900*x);
R0+=0.00000002813*cost(1.68598843422+2391.43681773000*x);
R0+=0.00000002902*cost(5.30666239739+8955.34180290940*x);
R0+=0.00000003225*cost(2.29832592489+3312.16323923200*x);
R0+=0.00000003863*cost(3.48188264725+20618.01935853360*x);
R0+=0.00000002738*cost(5.49768261369+149.56319713460*x);
R0+=0.00000002809*cost(4.76933217397+1964.83862685400*x);
R0+=0.00000002711*cost(2.69244730345+3178.14579056760*x);
R0+=0.00000002711*cost(2.38275660721+2648.45482547300*x);
R0+=0.00000002743*cost(1.09492569851+536.80451209540*x);
R0+=0.00000002821*cost(5.91845472246+12964.30070339100*x);
R0+=0.00000002716*cost(6.10377796874+3973.39616601300*x);
R0+=0.00000002487*cost(3.87703916286+1861.74585263540*x);
R0+=0.00000002617*cost(2.65526535627+8329.67161059700*x);
R0+=0.00000002938*cost(5.68402398615+6158.64743530580*x);
R0+=0.00000002336*cost(3.24847913311+4672.66731424060*x);
R0+=0.00000002318*cost(1.69214259672+3914.95722503460*x);
R0+=0.00000002371*cost(4.75067664712+103.09277421860*x);
R0+=0.00000002963*cost(0.23381699914+20597.24396304120*x);
R0+=0.00000002190*cost(6.18344448099+3346.13535100720*x);
R0+=0.00000002444*cost(1.92547995169+7799.98064550240*x);
R0+=0.00000002121*cost(4.87491216115+9830.38901398780*x);
R0+=0.00000002532*cost(5.39550087270+3863.18984479360*x);
R0+=0.00000002101*cost(2.84309138388+3415.39402526710*x);
R0+=0.00000002176*cost(0.58632570025+162.46663613220*x);
R0+=0.00000002106*cost(3.06229353931+19800.94595622480*x);
R0+=0.00000002347*cost(3.90795942709+3335.08950239240*x);
R0+=0.00000002031*cost(5.52057907797+10021.90459040220*x);
R0+=0.00000001997*cost(2.77243710569+13936.79450513400*x);
R0+=0.00000002139*cost(5.40620646615+266.60704172180*x);
R0+=0.00000002147*cost(0.08966987600+13358.92658845020*x);
R0+=0.00000001996*cost(2.62541669265+20.77539549240*x);
R0+=0.00000001961*cost(4.88521794174+3237.51965248120*x);
R0+=0.00000002216*cost(1.06829128652+3320.25710730100*x);
R0+=0.00000002131*cost(3.02112533027+5625.36604155940*x);
R0+=0.00000002124*cost(3.68620121537+5618.31980486140*x);
R0+=0.00000001938*cost(1.29006691721+17924.91069982040*x);
R0+=0.00000002555*cost(4.91826220321+6604.95878212400*x);
R0+=0.00000002561*cost(2.10055088914+7910.18696672180*x);
R0+=0.00000001820*cost(5.57528712663+3351.24909204960*x);
R0+=0.00000001786*cost(5.77310414452+3607.21946842160*x);
R0+=0.00000001780*cost(4.48010071981+10818.13528691580*x);
R0+=0.00000002106*cost(5.75526661975+13365.97282514820*x);
R0+=0.00000001987*cost(2.61151965233+3546.79797513700*x);
R0+=0.00000001799*cost(2.73192475257+3360.96774609859*x);
R0+=0.00000001715*cost(1.50805385053+1692.16566950240*x);
R0+=0.00000001752*cost(2.21455466761+13119.72110282519*x);
R0+=0.00000001913*cost(3.32230688971+6702.00024889200*x);
R0+=0.00000001724*cost(1.43449979531+4885.96640967860*x);
R0+=0.00000002050*cost(1.19293239093+6660.44945790720*x);
R0+=0.00000001774*cost(2.18404386388+6784.31762761820*x);
R0+=0.00000001722*cost(4.86031154305+10014.72373309860*x);
R0+=0.00000001773*cost(2.09448668554+3603.69635007260*x);
R0+=0.00000001606*cost(3.48105136801+23141.55838292460*x);
R0+=0.00000001621*cost(5.73820120882+4555.34744602040*x);
R0+=0.00000001579*cost(1.88769198841+6298.32832117640*x);
R0+=0.00000001530*cost(5.16381564230+76.26607127560*x);
R0+=0.00000001615*cost(3.24110713658+3657.00429635640*x);
R0+=0.00000001576*cost(3.52622401575+6688.33840040040*x);
R0+=0.00000002034*cost(2.63620520451+16460.33352952499*x);
R0+=0.00000002025*cost(5.92907541624+10021.76996979660*x);
R0+=0.00000001689*cost(4.41053057494+5729.50644714900*x);
R0+=0.00000001878*cost(4.53291044847+3329.97576135000*x);
R0+=0.00000001530*cost(4.76331644411+7895.95987272020*x);
R0+=0.00000001529*cost(1.35289110986+1581.95934828300*x);
R0+=0.00000001807*cost(1.86212004697+2693.60159338500*x);
R0+=0.00000001855*cost(2.38561742394+6843.69148953180*x);
R0+=0.00000001518*cost(3.98476157750+6546.15977336420*x);
R0+=0.00000001389*cost(1.82099537095+9779.10867612540*x);
R0+=0.00000001447*cost(2.35649936427+6034.21402008480*x);
R0+=0.00000001386*cost(5.55304113895+4775.76008845920*x);
R0+=0.00000001372*cost(1.07224580315+12722.55242048520*x);
R0+=0.00000001423*cost(4.46530428193+574.34479833480*x);
R0+=0.00000001424*cost(2.57162391016+3399.98628861340*x);
R0+=0.00000001380*cost(5.76156315252+16335.83780453660*x);
R0+=0.00000001338*cost(2.97604558638+6127.65545055720*x);
R0+=0.00000001479*cost(4.74310691166+12566.15169998280*x);
R0+=0.00000001706*cost(0.30579918494+10551.52824519400*x);
R0+=0.00000001281*cost(2.00285974432+6677.63442474780*x);
R0+=0.00000001350*cost(0.78892333409+853.19638175200*x);
R0+=0.00000001534*cost(4.33326399444+640.87760738220*x);
R0+=0.00000001247*cost(1.02503908468+3024.22055704320*x);
R0+=0.00000001289*cost(1.92786975543+3347.65866339780*x);
R0+=0.00000001243*cost(2.44217806237+6684.81528205140*x);
R0+=0.00000001453*cost(1.74218016403+3333.56619000180*x);
R0+=0.00000001675*cost(1.79693456330+1118.75579210280*x);
R0+=0.00000001491*cost(2.59386711806+2494.52959194860*x);
R0+=0.00000001293*cost(3.31710472549+3407.09983561420*x);
R0+=0.00000001188*cost(4.92989260576+22743.40937951640*x);
R0+=0.00000001329*cost(1.99426530402+1228.96211332220*x);
R0+=0.00000001373*cost(2.53354987340+5459.37628707820*x);
R0+=0.00000001183*cost(4.25338096667+3344.49376205780*x);
R0+=0.00000001231*cost(2.50206227837+4356.27544458400*x);
R0+=0.00000001243*cost(2.65176267860+74.78159856730*x);
R0+=0.00000001285*cost(4.34087881585+3326.38533269820*x);
R0+=0.00000001119*cost(1.91321862491+3281.23856478620*x);
R0+=0.00000001094*cost(5.50748655535+3017.10701004240*x);
R0+=0.00000001259*cost(3.77654662830+11236.57229942000*x);
R0+=0.00000001285*cost(1.38335267684+3077.52850332700*x);
R0+=0.00000001100*cost(1.17130732373+6606.44325483230*x);
R0+=0.00000001115*cost(5.81275569652+2675.85638156980*x);
R0+=0.00000001380*cost(5.70641426169+2807.39834325620*x);
R0+=0.00000001256*cost(3.35479933251+4039.88357492740*x);
R0+=0.00000001187*cost(2.41348693872+10596.18207843420*x);
R0+=0.00000001052*cost(3.33521939538+3304.58456002240*x);
R0+=0.00000001188*cost(5.84735836632+3336.73109134180*x);
R0+=0.00000001072*cost(2.78383184435+8270.29774868340*x);
R0+=0.00000001105*cost(3.03463252672+3929.67725370800*x);
R0+=0.00000001013*cost(3.52026711847+8013.27974094040*x);
R0+=0.00000001079*cost(0.51857999039+2814.44457995420*x);
R0+=0.00000000999*cost(4.72734008760+533.21408344360*x);
R0+=0.00000001131*cost(0.52584038526+6816.28993343500*x);
R0+=0.00000001191*cost(0.60874292520+2301.58581590939*x);
R0+=0.00000001313*cost(2.07273299121+23539.70738633280*x);
R0+=0.00000000996*cost(4.03971126547+16062.18452611680*x);
R0+=0.00000000954*cost(5.90340414098+20206.14119633100*x);
R0+=0.00000000993*cost(0.07132588892+24150.08005134500*x);
R0+=0.00000001051*cost(2.22096534870+3980.50971301380*x);
R0+=0.00000001089*cost(1.25512213569+5938.23479286700*x);
R0+=0.00000000912*cost(2.54221161167+433.71173787680*x);
R0+=0.00000001249*cost(0.60003625956+16173.37116840440*x);
R0+=0.00000001027*cost(4.95999945094+19676.45023123640*x);
R0+=0.00000001108*cost(4.34209448160+3339.12795399150*x);
R0+=0.00000001188*cost(6.21563747433+2679.37949991880*x);
R0+=0.00000000849*cost(0.82548606454+2597.62236616720*x);
R0+=0.00000001145*cost(4.48151980872+19402.79695281660*x);
R0+=0.00000000948*cost(1.30280088857+8273.82086703240*x);
R0+=0.00000001016*cost(5.14464815830+1596.18644228460*x);
R0+=0.00000000832*cost(5.60623652030+3340.19235060619*x);
R0+=0.00000001035*cost(4.71893106874+419.48464387520*x);
R0+=0.00000000903*cost(0.45419000582+12995.22537783680*x);
R0+=0.00000001089*cost(0.51294377637+11250.79939342160*x);
R0+=0.00000000840*cost(5.30858028008+26084.02180621620*x);
R0+=0.00000000990*cost(2.06776368865+7255.56965173440*x);
R0+=0.00000000808*cost(6.25630819993+15508.61512327440*x);
R0+=0.00000000806*cost(3.09007612135+5415.65737477320*x);
R0+=0.00000000782*cost(4.62274599734+2547.83753823240*x);
R0+=0.00000000963*cost(2.10680539916+6456.88005769770*x);
R0+=0.00000000778*cost(3.56602161857+12721.57209941700*x);
R0+=0.00000000873*cost(5.09097164784+2540.79130153440*x);
R0+=0.00000000772*cost(3.08101797047+11081.21921028860*x);
R0+=0.00000000965*cost(2.33106703115+18454.60166491500*x);
R0+=0.00000000859*cost(4.14788214122+6438.49624942560*x);
R0+=0.00000001012*cost(4.45011664540+3316.73398895200*x);
R0+=0.00000000906*cost(4.29336078401+3344.54457996290*x);
R0+=0.00000000741*cost(2.61446403580+2284.75361485960*x);
R0+=0.00000000790*cost(6.03436225041+12509.25332504720*x);
R0+=0.00000000738*cost(0.52092422137+18052.92954315780*x);
R0+=0.00000000737*cost(4.11165247543+3760.09707057500*x);
R0+=0.00000000727*cost(3.28066632751+3510.19260983280*x);
R0+=0.00000001006*cost(0.45037465289+27490.69247804480*x);
R0+=0.00000000923*cost(2.78717931388+1332.05488754080*x);
R0+=0.00000000756*cost(0.86881841787+1545.35398297880*x);
R0+=0.00000000774*cost(3.71535541900+6571.01853218020*x);
R0+=0.00000000900*cost(2.74944190055+316.39186965660*x);
R0+=0.00000000704*cost(1.89617185328+13362.43245314700*x);
R0+=0.00000000701*cost(2.21328293796+20995.39296644940*x);
R0+=0.00000000701*cost(3.92689438700+13362.46696045140*x);
R0+=0.00000000695*cost(5.52658147215+3364.49086444760*x);
R0+=0.00000000764*cost(1.88253040972+5732.04924442980*x);
R0+=0.00000000693*cost(0.34849213821+5835.14201864840*x);
R0+=0.00000000698*cost(1.79132650081+206.18554843720*x);
R0+=0.00000000687*cost(0.11649928911+13760.59871020740*x);
R0+=0.00000000827*cost(0.49766945172+3376.64029337720*x);
R0+=0.00000000686*cost(0.23965591265+2409.24933984800*x);
R0+=0.00000000672*cost(0.51352450554+25685.87280280800*x);
R0+=0.00000000699*cost(5.90167595080+19004.64794940840*x);
R0+=0.00000000647*cost(3.01091875955+5223.69391980220*x);
R0+=0.00000000643*cost(4.88507402785+11766.26326451460*x);
R0+=0.00000000723*cost(3.28296530537+4142.97634914600*x);
R0+=0.00000000660*cost(4.27334393830+1214.73501932060*x);
R0+=0.00000000675*cost(0.48874492682+5408.54382777240*x);
R0+=0.00000000809*cost(3.13310075522+18984.29263000960*x);
R0+=0.00000000646*cost(3.63004914186+7107.82304427560*x);
R0+=0.00000000831*cost(4.49449658957+3341.03250279340*x);
R0+=0.00000000680*cost(0.16949964513+110.20632121940*x);
R0+=0.00000000592*cost(6.03272224596+20809.46762464520*x);
R0+=0.00000000627*cost(4.93438097728+9872.27408296480*x);
R0+=0.00000000698*cost(1.45709305452+3377.21779200400*x);
R0+=0.00000000583*cost(4.01887095237+664.75604513000*x);
R0+=0.00000000591*cost(4.01381288194+19406.67828817460*x);
R0+=0.00000000571*cost(1.20823284619+5621.86017686260*x);
R0+=0.00000000680*cost(4.72905586557+8116.37251515900*x);
R0+=0.00000000739*cost(3.19765996917+9380.95967271720*x);
R0+=0.00000000571*cost(5.46064659057+5621.82566955820*x);
R0+=0.00000000702*cost(0.14107083764+6923.95345737360*x);
R0+=0.00000000598*cost(3.05986754375+3341.04230982650*x);
R0+=0.00000000601*cost(2.17944973698+7270.28968040780*x);
R0+=0.00000000572*cost(0.42001145821+15110.46611986620*x);
R0+=0.00000000655*cost(1.08706089359+3169.93955608060*x);
R0+=0.00000000582*cost(1.68224967199+26087.90314157420*x);
R0+=0.00000000543*cost(2.42716241058+170.67287061920*x);
R0+=0.00000000543*cost(1.68460678113+11780.49035851620*x);
R0+=0.00000000533*cost(2.63982684952+2277.70737816160*x);
R0+=0.00000000550*cost(2.54220679987+7380.49600162720*x);
R0+=0.00000000576*cost(1.69042028754+3384.33133900480*x);
R0+=0.00000000535*cost(5.01279223460+1375.77379984580*x);
R0+=0.00000000579*cost(5.99182453047+2149.68853482420*x);
R0+=0.00000000598*cost(0.75754342787+3340.18254357310*x);
R0+=0.00000000575*cost(1.33793171924+3296.89351439480*x);
R0+=0.00000000689*cost(0.02993986536+22345.26037610820*x);
R0+=0.00000000526*cost(6.14212516186+13149.15061136120*x);
R0+=0.00000000540*cost(5.54137118955+8646.06348025360*x);
R0+=0.00000000528*cost(2.74183495775+3826.58447948940*x);
R0+=0.00000000689*cost(6.28205551764+12295.95422960920*x);
R0+=0.00000000499*cost(0.25665224668+2142.64229812620*x);
R0+=0.00000000498*cost(5.91370528026+6460.81221096080*x);
R0+=0.00000000588*cost(3.39977690249+3329.56672643590*x);
R0+=0.00000000507*cost(0.63367870048+20735.83216142559*x);
R0+=0.00000000590*cost(3.87951788923+9065.54812412880*x);
R0+=0.00000000509*cost(2.59333214746+3877.41693879520*x);
R0+=0.00000000486*cost(4.01113864377+23937.85638974100*x);
R0+=0.00000000541*cost(1.55072392536+2221.85663459700*x);
R0+=0.00000000482*cost(0.00200643783+10235.13637553740*x);
R0+=0.00000000474*cost(4.14503805378+3113.13629391080*x);
R0+=0.00000000523*cost(2.89171162726+6040.34724601740*x);
R0+=0.00000000458*cost(4.08131432844+1162.47470440780*x);
R0+=0.00000000493*cost(2.98933582802+1039.02661079040*x);
R0+=0.00000000489*cost(4.88201647585+5511.63660199100*x);
R0+=0.00000000537*cost(1.24870344441+48835.19385644859*x);
R0+=0.00000000585*cost(5.53384919340+4981.94563689640*x);
R0+=0.00000000462*cost(5.38999453893+15664.03552270859*x);
R0+=0.00000000531*cost(1.22287288928+10721.10842832700*x);
R0+=0.00000000440*cost(4.69966067585+799.82112516540*x);
R0+=0.00000000588*cost(5.15076051189+3873.82651014340*x);
R0+=0.00000000465*cost(5.49236978535+3342.09689940810*x);
R0+=0.00000000545*cost(5.91813092143+1478.86657406440*x);
R0+=0.00000000440*cost(2.28287871244+12310.18132361080*x);
R0+=0.00000000436*cost(0.12478564862+956.28915597060*x);
R0+=0.00000000573*cost(3.86388572602+26482.17080962440*x);
R0+=0.00000000429*cost(1.20474317285+28.44918746780*x);
R0+=0.00000000435*cost(3.75437730899+5195.24473233440*x);
R0+=0.00000000457*cost(1.45606713663+5636.07001721200*x);
R0+=0.00000000553*cost(5.30628175145+2766.26762836500*x);
R0+=0.00000000494*cost(0.63303483918+3274.12501778540*x);
R0+=0.00000000530*cost(3.18458612574+8535.85715903420*x);
R0+=0.00000000535*cost(1.89165024367+9866.41688066520*x);
R0+=0.00000000433*cost(0.33270291162+6665.97238221460*x);
R0+=0.00000000404*cost(4.67939964590+4825.54491639400*x);
R0+=0.00000000402*cost(3.25727658426+5820.91492464680*x);
R0+=0.00000000415*cost(1.41915166067+21947.11137270000*x);
R0+=0.00000000414*cost(3.32843373219+8859.36257569160*x);
R0+=0.00000000403*cost(1.68400791606+9588.12554222260*x);
R0+=0.00000000399*cost(0.93465630912+2295.45759051220*x);
R0+=0.00000000402*cost(0.85364636108+29026.48522950779*x);
R0+=0.00000000494*cost(4.57792960199+8542.97070603500*x);
R0+=0.00000000413*cost(2.60545132222+38.13303563780*x);
R0+=0.00000000413*cost(5.44081623497+4407.10790388980*x);
R0+=0.00000000404*cost(5.33168348188+3189.56475685690*x);
R0+=0.00000000385*cost(1.90313951519+10020.85695903120*x);
R0+=0.00000000454*cost(1.18358809702+10610.90210710760*x);
R0+=0.00000000381*cost(4.90212003667+19146.75926614180*x);
R0+=0.00000000415*cost(3.07892141478+11216.28429032400*x);
R0+=0.00000000378*cost(0.19461412344+2067.93140107260*x);
R0+=0.00000000418*cost(1.14626975196+6643.09181776180*x);
R0+=0.00000000426*cost(4.33863084563+220.41264243880*x);
R0+=0.00000000412*cost(0.02314567339+3192.53370227350*x);
R0+=0.00000000391*cost(4.75902617217+6414.61781167780*x);
R0+=0.00000000399*cost(1.37708573980+9654.61295113700*x);
R0+=0.00000000381*cost(2.74120772781+1854.63230563460*x);
R0+=0.00000000378*cost(4.16366866018+13553.89797291080*x);
R0+=0.00000000409*cost(3.12117409635+3723.49170527080*x);
R0+=0.00000000379*cost(5.87578711682+6357.71943674220*x);
R0+=0.00000000375*cost(3.29175394061+31022.75317085620*x);
R0+=0.00000000358*cost(3.99134138048+8958.93223156120*x);
R0+=0.00000000390*cost(2.01175211992+1903.43681250120*x);
R0+=0.00000000373*cost(1.27018251531+2111.65031337760*x);
R0+=0.00000000493*cost(4.66294641806+1435.14766175940*x);
R0+=0.00000000379*cost(4.08720452061+10706.88133432540*x);
R0+=0.00000000461*cost(1.90122301470+25287.72379939980*x);
R0+=0.00000000364*cost(3.25231136840+5095.67507646480*x);
R0+=0.00000000382*cost(2.18684874688+16276.46394262300*x);
R0+=0.00000000359*cost(2.29096599931+28628.33622609960*x);
R0+=0.00000000362*cost(4.15084528423+6696.47732458460*x);
R0+=0.00000000374*cost(5.78780163439+3490.17562383440*x);
R0+=0.00000000386*cost(4.73230339383+3981.49003408200*x);
R0+=0.00000000344*cost(5.79156714790+26880.31981303260*x);
R0+=0.00000000368*cost(3.44405073824+15.25247118500*x);
R0+=0.00000000410*cost(1.76294940448+6709.67404086740*x);
R0+=0.00000000339*cost(1.71242500987+224.34479570190*x);
R0+=0.00000000373*cost(2.71286157688+3472.15438838620*x);
R0+=0.00000000334*cost(1.10569460106+59.37386191360*x);
R0+=0.00000000394*cost(4.02046774116+2075.04494807340*x);
R0+=0.00000000402*cost(3.27520695853+931.36308685180*x);
R0+=0.00000000318*cost(3.28892524780+9485.03276800400*x);
R0+=0.00000000319*cost(4.05344391333+3450.81874791920*x);
R0+=0.00000000341*cost(6.08567978892+17085.95866572220*x);
R0+=0.00000000378*cost(0.71609301686+3209.07046501340*x);
R0+=0.00000000326*cost(4.58257191106+8982.81066930900*x);
R0+=0.00000000369*cost(6.17228742886+8671.96987044060*x);
R0+=0.00000000308*cost(1.01924467785+18606.49894600020*x);
R0+=0.00000000370*cost(2.84011243059+4392.88080988820*x);
R0+=0.00000000303*cost(5.00239879717+2810.93871525740*x);
R0+=0.00000000303*cost(2.97162741204+2810.90420795300*x);
R0+=0.00000000419*cost(2.79830562400+5106.37905211740*x);
R0+=0.00000000358*cost(1.15955325186+4076.48894023160*x);
R0+=0.00000000360*cost(5.83226123310+26724.89941359840*x);
R0+=0.00000000298*cost(5.57160706753+3041.48603243060*x);
R0+=0.00000000298*cost(3.06970285022+11670.28403729680*x);
R0+=0.00000000388*cost(5.01197738185+12323.42309600880*x);
R0+=0.00000000336*cost(4.60208332758+9602.35263622420*x);
R0+=0.00000000371*cost(2.23508025241+4996.17273089800*x);
R0+=0.00000000300*cost(6.04069385215+9499.25986200560*x);
R0+=0.00000000345*cost(1.74260482164+5617.91076994730*x);
R0+=0.00000000302*cost(3.01127349940+7483.58877584580*x);
R0+=0.00000000289*cost(0.39479288685+2412.77245819700*x);
R0+=0.00000000289*cost(2.21430640344+11140.59307220220*x);
R0+=0.00000000330*cost(5.81605457596+4246.06912336460*x);
R0+=0.00000000394*cost(2.12229107240+6475.03930496240*x);
R0+=0.00000000301*cost(5.26147877814+9945.57120882380*x);
R0+=0.00000000338*cost(4.94717046909+5625.77507647350*x);
R0+=0.00000000372*cost(5.46968662800+3561.02506913860*x);
R0+=0.00000000279*cost(0.54063870001+3226.21331978640*x);
R0+=0.00000000291*cost(5.21021494024+13171.00144068760*x);
R0+=0.00000000384*cost(3.23921380878+10022.81760116760*x);
R0+=0.00000000309*cost(3.17514941939+14047.49376102520*x);
R0+=0.00000000273*cost(1.68203034215+4253.18267036540*x);
R0+=0.00000000272*cost(0.11218647217+7314.00859271280*x);
R0+=0.00000000281*cost(5.15132055967+2825.14855560680*x);
R0+=0.00000000292*cost(3.33720586058+9468.26787725700*x);
R0+=0.00000000316*cost(1.41719074976+589.06482700820*x);
R0+=0.00000000264*cost(0.48845594730+16699.53901514999*x);
R0+=0.00000000266*cost(1.69694779915+647.01083331480*x);
R0+=0.00000000318*cost(2.47072726153+8436.28750316460*x);
R0+=0.00000000260*cost(2.54459932529+20.35531939880*x);
R0+=0.00000000275*cost(2.78608579994+2970.91261075940*x);
R0+=0.00000000295*cost(5.96367554548+4025.65648092580*x);
R0+=0.00000000268*cost(3.01034973031+6518.75821726740*x);
R0+=0.00000000259*cost(5.20888482695+7366.26890762560*x);
R0+=0.00000000298*cost(2.71010678192+6652.77566593180*x);
R0+=0.00000000276*cost(0.78545108300+3735.23831175900*x);
R0+=0.00000000305*cost(6.19137255377+6677.34351804160*x);
R0+=0.00000000265*cost(3.25145629239+24889.57479599160*x);
R0+=0.00000000260*cost(3.99612605351+2171.02417529120*x);
R0+=0.00000000252*cost(4.14773813625+5642.19824260920*x);
R0+=0.00000000254*cost(1.38470256851+846.08283475120*x);
R0+=0.00000000258*cost(2.03261985834+2089.78223039900*x);
R0+=0.00000000298*cost(3.81212222628+28230.18722269139*x);
R0+=0.00000000241*cost(2.96550398155+27682.14074415640*x);
R0+=0.00000000259*cost(4.79545870271+6657.34641565180*x);
R0+=0.00000000238*cost(1.18977479528+3171.03224356680*x);
R0+=0.00000000256*cost(1.01427800277+568.82187402740*x);
R0+=0.00000000236*cost(5.56425829084+14.22709400160*x);
R0+=0.00000000304*cost(3.81556245925+1190.92389187560*x);
R0+=0.00000000237*cost(1.37222961867+2277.29834324750*x);
R0+=0.00000000239*cost(2.47752611026+5430.39465709880*x);
R0+=0.00000000234*cost(4.34929504798+6675.70192909220*x);
R0+=0.00000000239*cost(0.14012746335+3742.28454845700*x);
R0+=0.00000000286*cost(5.04045301355+5607.61582920880*x);
R0+=0.00000000305*cost(4.59739079660+6685.10618875760*x);
R0+=0.00000000254*cost(5.03693878366+1905.46476494040*x);
R0+=0.00000000323*cost(1.67390215145+4922.57177498280*x);
R0+=0.00000000232*cost(4.82565548677+9070.11887384880*x);
R0+=0.00000000236*cost(2.40662610715+3620.39893105220*x);
R0+=0.00000000260*cost(5.72282468723+17468.85519794540*x);
R0+=0.00000000259*cost(6.15179402778+16706.58525184800*x);
R0+=0.00000000263*cost(0.63922292958+2008.55753915900*x);
R0+=0.00000000300*cost(3.78527265088+34363.36559755600*x);
R0+=0.00000000226*cost(1.86970344963+6418.14093002680*x);
R0+=0.00000000239*cost(0.04616997400+13362.38239649640*x);
R0+=0.00000000241*cost(4.85896907298+14158.74771361560*x);
R0+=0.00000000225*cost(1.70179250908+18451.07854656599*x);
R0+=0.00000000288*cost(2.26316945288+6621.85099148600*x);
R0+=0.00000000231*cost(2.19861265305+3936.79080070880*x);
R0+=0.00000000251*cost(5.51232121883+3416.87849797540*x);
R0+=0.00000000245*cost(3.30613942274+1197.97012857360*x);
R0+=0.00000000253*cost(4.54308131689+2285.16264977370*x);
R0+=0.00000000225*cost(5.50822507089+4936.79886898440*x);
R0+=0.00000000249*cost(1.06089727346+3313.21087060300*x);
R0+=0.00000000309*cost(6.21936675838+16304.91313009080*x);
R0+=0.00000000244*cost(1.94855224181+3.59042865180*x);
R0+=0.00000000287*cost(5.70461951656+792.77488846740*x);
R0+=0.00000000254*cost(5.34446995416+5401.43028077160*x);
R0+=0.00000000263*cost(1.49663212332+6364.83298374300*x);
R0+=0.00000000223*cost(2.66825139116+31968.94865279940*x);
R0+=0.00000000222*cost(2.48370132727+5355.23588148860*x);
R0+=0.00000000220*cost(5.20799024654+23017.06265793620*x);
R0+=0.00000000215*cost(2.72743996418+6740.59871531320*x);
R0+=0.00000000218*cost(1.30797197521+29822.78323632420*x);
R0+=0.00000000270*cost(0.90714939427+6155.05700665400*x);
R0+=0.00000000216*cost(4.73975263349+6679.74038069130*x);
R0+=0.00000000211*cost(3.72756562629+10042.61267559180*x);
R0+=0.00000000211*cost(2.61999755641+10124.93005431800*x);
R0+=0.00000000293*cost(6.07059383381+14061.72085502680*x);
R0+=0.00000000219*cost(2.98472846458+131.54196168640*x);
R0+=0.00000000210*cost(5.27496906319+13355.33615979840*x);
R0+=0.00000000259*cost(1.25267305830+2641.34127847220*x);
R0+=0.00000000208*cost(3.30241021109+6850.80503653260*x);
R0+=0.00000000226*cost(5.48438086246+7203.80227149340*x);
R0+=0.00000000243*cost(2.44748800604+3311.18291816379*x);
R0+=0.00000000208*cost(1.13500579457+5888.44996493220*x);
R0+=0.00000000251*cost(4.67012983729+6666.99775939800*x);
R0+=0.00000000227*cost(1.59926413307+10001.06188460700*x);
R0+=0.00000000264*cost(3.72622435628+6747.71226231400*x);
R0+=0.00000000216*cost(0.34122804918+6686.74777770700*x);
R0+=0.00000000260*cost(3.67749190896+6645.19698672220*x);
R0+=0.00000000209*cost(4.31928920378+3337.86091608880*x);
R0+=0.00000000218*cost(4.08068730999+3378.74546233760*x);
R0+=0.00000000275*cost(1.64274205426+2011.10033643980*x);
R0+=0.00000000204*cost(0.73237459784+3.93215326310*x);
R0+=0.00000000219*cost(0.88584017263+19513.98359510420*x);
R0+=0.00000000205*cost(2.60851826933+2771.79055267240*x);
R0+=0.00000000215*cost(2.99299817517+10824.20120254560*x);
R0+=0.00000000249*cost(0.99914444136+5753.38488489680*x);
R0+=0.00000000225*cost(0.23309143434+4782.87363546000*x);
R0+=0.00000000275*cost(0.86215660461+8749.15625447220*x);
R0+=0.00000000201*cost(2.87118854159+21548.96236929180*x);
R0+=0.00000000246*cost(3.34468800742+3333.92876282570*x);
R0+=0.00000000203*cost(4.11410443276+31570.79964939120*x);
R0+=0.00000000202*cost(4.96805650734+8166.15734309380*x);
R0+=0.00000000232*cost(2.69372584349+5989.06725217280*x);
R0+=0.00000000214*cost(4.83852070026+6681.64492949320*x);
R0+=0.00000000258*cost(2.66551831451+1062.90504853820*x);
R0+=0.00000000197*cost(0.55202541352+735.87651353180*x);
R0+=0.00000000256*cost(2.76274941586+2480.30249794700*x);
R0+=0.00000000216*cost(4.02506717011+3133.91168940320*x);
R0+=0.00000000193*cost(1.52645682146+949.17560896980*x);
R0+=0.00000000209*cost(0.67348618655+13892.14067189380*x);
R0+=0.00000000220*cost(1.52502617699+6660.86953400080*x);
R0+=0.00000000223*cost(1.09348882524+6148.01076995600*x);
R0+=0.00000000192*cost(2.90571322264+8799.98871377800*x);
R0+=0.00000000243*cost(3.36420301442+8965.97846825920*x);
R0+=0.00000000206*cost(5.11175800472+4140.43355186520*x);
R0+=0.00000000189*cost(1.06641624209+9374.82644678460*x);
R0+=0.00000000240*cost(5.92078519032+13362.51701710200*x);
R0+=0.00000000248*cost(5.79997873732+15806.14683944200*x);
R0+=0.00000000193*cost(3.19008521814+6756.00645196690*x);
R0+=0.00000000237*cost(4.11979030463+22487.37169284160*x);
R0+=0.00000000218*cost(0.84212090761+6717.25272007700*x);
R0+=0.00000000200*cost(2.43100846630+10018.24685144760*x);
R0+=0.00000000199*cost(5.81238461796+4289.78803566960*x);
R0+=0.00000000214*cost(5.95026024979+6680.80477730600*x);
R0+=0.00000000192*cost(3.06285109033+32765.24665961580*x);
R0+=0.00000000229*cost(1.68884404323+11614.43329373220*x);
R0+=0.00000000185*cost(3.13072183492+3253.30422216000*x);
R0+=0.00000000246*cost(2.58151525126+1795.25844372100*x);
R0+=0.00000000187*cost(4.06797969837+14577.18472611980*x);
R0+=0.00000000185*cost(0.96747889626+2604.73591316800*x);
R0+=0.00000000184*cost(1.46731725339+1437.17561419860*x);
R0+=0.00000000186*cost(2.55094700069+3188.71514561460*x);
R0+=0.00000000211*cost(4.23522784526+16703.07938715119*x);
R0+=0.00000000196*cost(2.80582160764+2796.69436760360*x);
R0+=0.00000000198*cost(5.92372067560+4133.38731516720*x);
R0+=0.00000000238*cost(2.30957041178+1879.55837475340*x);
R0+=0.00000000224*cost(3.13550652378+3613.28538405140*x);
R0+=0.00000000223*cost(1.81801741599+3184.21170619740*x);
R0+=0.00000000199*cost(3.64983703995+4271.97551355160*x);
R0+=0.00000000181*cost(2.71721121316+4186.69526145100*x);
R0+=0.00000000184*cost(2.03051030984+6674.17861670160*x);
R0+=0.00000000182*cost(1.54431442810+9947.05568153210*x);
R0+=0.00000000179*cost(4.38762678121+9886.77220006400*x);
R0+=0.00000000181*cost(1.80044971979+6717.83021870380*x);
R0+=0.00000000190*cost(4.97714900529+6670.58818804980*x);
R0+=0.00000000247*cost(5.77972128678+29424.63423291600*x);
R0+=0.00000000194*cost(5.90745451439+6705.10329114740*x);
R0+=0.00000000224*cost(5.61893896091+227.47613278900*x);
R0+=0.00000000182*cost(2.77233344458+6887.41040183680*x);
R0+=0.00000000224*cost(1.94094757956+8226.57883637840*x);
R0+=0.00000000181*cost(4.61381081330+3361.94806716680*x);
R0+=0.00000000203*cost(5.24659800837+7586.68155006440*x);
R0+=0.00000000183*cost(5.23826533455+6578.13207918100*x);
R0+=0.00000000207*cost(0.88292186428+10156.90236013480*x);
R0+=0.00000000232*cost(0.75375986797+3232.94890276120*x);
R0+=0.00000000179*cost(5.89794151802+4452.25467180180*x);
R0+=0.00000000177*cost(6.16223629155+3547.31316399640*x);
R0+=0.00000000177*cost(0.19292898030+401.67212175720*x);
R0+=0.00000000173*cost(3.89814064100+6019.99192661860*x);
R0+=0.00000000172*cost(2.42933586666+6944.30877677240*x);
R0+=0.00000000201*cost(6.18392570315+6947.83189512140*x);
R0+=0.00000000183*cost(5.82189570737+8962.43809625800*x);
R0+=0.00000000189*cost(2.71231990816+742.99006053260*x);
R0+=0.00000000172*cost(3.86810071059+10028.95082710020*x);
R0+=0.00000000188*cost(5.22462530948+2125.87740737920*x);
R0+=0.00000000196*cost(1.88388569900+5032.77809620220*x);
R0+=0.00000000209*cost(5.78130707501+3343.36393731080*x);
R0+=0.00000000167*cost(6.26758992296+15849.86575174700*x);
R0+=0.00000000189*cost(2.38894304278+3212.59358336240*x);
R0+=0.00000000208*cost(5.62485439431+31172.65064598300*x);
R0+=0.00000000170*cost(1.07346401060+20426.57109242200*x);
R0+=0.00000000183*cost(5.21160560654+27832.03821928320*x);
R0+=0.00000000181*cost(2.19756653553+16703.04487984680*x);
R0+=0.00000000214*cost(1.66101921272+21265.52312652020*x);
R0+=0.00000000165*cost(2.10517924574+6688.27109009760*x);
R0+=0.00000000172*cost(0.85495655009+14591.41182012140*x);
R0+=0.00000000164*cost(1.68898542913+3468.63127003720*x);
R0+=0.00000000183*cost(1.56948199057+8962.47260356240*x);
R0+=0.00000000191*cost(5.54553650068+2806.98930834210*x);
R0+=0.00000000162*cost(4.06699160265+5209.47182633600*x);
R0+=0.00000000165*cost(3.44003333876+14421.83163698840*x);
R0+=0.00000000163*cost(2.42152585351+6314.00052443720*x);
R0+=0.00000000189*cost(0.57681608522+2973.38809773740*x);
R0+=0.00000000169*cost(2.86190807726+5490.30096152400*x);
R0+=0.00000000174*cost(1.69333072403+1744.49329471800*x);
R0+=0.00000000224*cost(2.35886332922+9638.94074787620*x);
R0+=0.00000000207*cost(3.13737248079+3336.68027343670*x);
R0+=0.00000000221*cost(3.14807587279+11610.91017538320*x);
R0+=0.00000000158*cost(5.87599422932+4606.17990532620*x);
R0+=0.00000000166*cost(4.61834424167+9175.75444534820*x);
R0+=0.00000000162*cost(5.40045489036+23.87843774780*x);
R0+=0.00000000158*cost(5.57047764661+4503.08713110760*x);
R0+=0.00000000156*cost(3.08339691033+3448.27595063840*x);
R0+=0.00000000202*cost(2.56469307457+7321.12213971360*x);
R0+=0.00000000164*cost(1.10347159072+3710.31224264020*x);
R0+=0.00000000158*cost(3.65995745934+6997.61672305620*x);
R0+=0.00000000169*cost(1.85985317117+1329.51209026000*x);
R0+=0.00000000211*cost(1.66624816725+3304.00706139560*x);
R0+=0.00000000206*cost(1.81572746145+1596.11913198180*x);
R0+=0.00000000169*cost(0.46310427277+17101.21113690720*x);
R0+=0.00000000159*cost(5.73384451559+1265.56747862640*x);
R0+=0.00000000159*cost(0.92643196778+4001.84535348080*x);
R0+=0.00000000189*cost(2.74163850920+2910.49111747480*x);
R0+=0.00000000181*cost(5.48699984659+3319.27678623280*x);
R0+=0.00000000156*cost(5.95462118470+8584.66166590080*x);
R0+=0.00000000158*cost(3.38732507447+8742.04270747140*x);
R0+=0.00000000171*cost(3.11406750626+5621.91023351320*x);
R0+=0.00000000199*cost(2.86370198218+10025.42770875120*x);
R0+=0.00000000173*cost(4.73384838991+9389.05354078620*x);
R0+=0.00000000160*cost(3.06861532268+1612.95133303160*x);
R0+=0.00000000203*cost(1.71629299113+699.27114822760*x);
R0+=0.00000000198*cost(0.56267868345+15265.88651930040*x);
R0+=0.00000000186*cost(2.44573687199+2814.85361486830*x);
R0+=0.00000000167*cost(0.44417942260+37895.42629036740*x);
R0+=0.00000000152*cost(5.08616610530+3322.79990458180*x);
R0+=0.00000000162*cost(2.58982908935+1883.08149310240*x);
R0+=0.00000000178*cost(4.58774508034+6685.15700666270*x);
R0+=0.00000000191*cost(4.12771141768+9911.63095888000*x);
R0+=0.00000000185*cost(4.32284898739+323.50541665740*x);
R0+=0.00000000199*cost(1.83524172935+3436.59165391760*x);
R0+=0.00000000199*cost(6.00292619279+4427.39591298580*x);
R0+=0.00000000153*cost(3.46447669590+22324.90505670940*x);
R0+=0.00000000171*cost(3.52256446633+5621.77561290760*x);
R0+=0.00000000165*cost(3.32970937124+1272.68102562720*x);
R0+=0.00000000149*cost(0.13370088791+36.02786667740*x);
R0+=0.00000000149*cost(1.23280447264+4193.80880845180*x);
R0+=0.00000000156*cost(0.13018524921+11925.27409260060*x);
R0+=0.00000000146*cost(1.24102730441+3372.58473251660*x);
R0+=0.00000000154*cost(5.63537863362+3185.25933756840*x);
R0+=0.00000000197*cost(3.23364188440+3774.32416457660*x);
R0+=0.00000000180*cost(3.47485722477+8564.30634650200*x);
R0+=0.00000000185*cost(2.18248214016+802.36392244620*x);
R0+=0.00000000145*cost(2.62035460481+3368.01398279660*x);
R0+=0.00000000180*cost(6.01236697222+6691.86151874940*x);
R0+=0.00000000148*cost(2.51710178830+3262.86188271590*x);
R0+=0.00000000151*cost(4.17118896078+16894.51039961060*x);
R0+=0.00000000185*cost(3.03939668350+3354.83952070140*x);
R0+=0.00000000143*cost(3.37267915445+3468.56395973440*x);
R0+=0.00000000160*cost(2.16705959730+0.98032106820*x);
R0+=0.00000000190*cost(1.63240538938+2324.94940881560*x);
R0+=0.00000000140*cost(1.27592043896+6549.68289171320*x);
R0+=0.00000000186*cost(1.44849264278+1015.66301788420*x);
R0+=0.00000000141*cost(4.19208049402+5813.29118932200*x);
R0+=0.00000000153*cost(5.97405255778+3568.08855948880*x);
R0+=0.00000000136*cost(0.45455359025+3193.80074017620*x);
R0+=0.00000000188*cost(0.98977442882+2538.24850425360*x);
R0+=0.00000000157*cost(3.32117477144+3181.66890891660*x);
R0+=0.00000000164*cost(1.67705754742+2751.54759969160*x);
R0+=0.00000000134*cost(5.26327877742+13212.88650966460*x);
R0+=0.00000000184*cost(0.73082474043+369.69981594040*x);
R0+=0.00000000145*cost(5.54086212771+3152.68727893721*x);
R0+=0.00000000139*cost(3.30464120245+6151.51663465280*x);
R0+=0.00000000132*cost(0.96753793729+3487.42411322340*x);
R0+=0.00000000148*cost(1.55321724063+7696.88787128380*x);
R0+=0.00000000140*cost(5.39000757800+2945.98654164060*x);
R0+=0.00000000155*cost(4.35207037526+4005.36847182980*x);
R0+=0.00000000142*cost(5.13441372991+1641.33321019660*x);
R0+=0.00000000131*cost(2.48606821423+1353.39052800780*x);
R0+=0.00000000131*cost(2.18754536881+1765.76662541760*x);
R0+=0.00000000133*cost(3.01300582040+3283.71405176420*x);
R0+=0.00000000177*cost(2.37558492362+11346.77862063940*x);
R0+=0.00000000145*cost(0.79525636457+2281.24775016280*x);
R0+=0.00000000133*cost(5.96263652624+34513.26307268280*x);
R0+=0.00000000165*cost(1.32559153826+6510.55198278040*x);
R0+=0.00000000132*cost(4.31118469609+1971.95217385480*x);
R0+=0.00000000176*cost(3.17539133688+6701.58017279840*x);
R0+=0.00000000140*cost(1.18723558164+1461.05405194640*x);
R0+=0.00000000128*cost(6.07261046225+3362.46325602620*x);
R0+=0.00000000139*cost(5.33541181199+6151.55114195720*x);
R0+=0.00000000143*cost(1.04060603784+3351.65812696370*x);
R0+=0.00000000138*cost(1.96009952022+2014.62345478880*x);
R0+=0.00000000127*cost(2.12310260285+2917.53735417280*x);
R0+=0.00000000142*cost(0.29094317859+3212.66089366520*x);
R0+=0.00000000128*cost(0.49974456440+10264.56588407340*x);
R0+=0.00000000125*cost(1.62548810323+10191.41746323240*x);
R0+=0.00000000128*cost(3.55358985291+3223.29255847960*x);
R0+=0.00000000140*cost(5.87379732521+6382.09845913040*x);
R0+=0.00000000129*cost(2.90428606882+6812.76681508600*x);
R0+=0.00000000127*cost(4.03101399507+10448.43547097540*x);
R0+=0.00000000128*cost(3.23265469000+4576.68808702280*x);
R0+=0.00000000124*cost(2.02283056331+6724.94376570460*x);
R0+=0.00000000134*cost(0.19295362623+3130.83644961080*x);
R0+=0.00000000145*cost(5.04767049759+2281.21324285840*x);
R0+=0.00000000143*cost(4.45744983982+7100.70949727480*x);
R0+=0.00000000133*cost(5.00404182123+11883.58313273480*x);
R0+=0.00000000124*cost(0.73925895836+1485.98012106520*x);
R0+=0.00000000123*cost(0.47283015475+3347.29609057390*x);
R0+=0.00000000137*cost(5.73370922615+5244.04923920100*x);
R0+=0.00000000152*cost(5.01464455460+3358.42494881780*x);
R0+=0.00000000122*cost(1.37003015612+3370.04193523580*x);
R0+=0.00000000143*cost(1.95740753086+2921.68802779920*x);
R0+=0.00000000123*cost(3.94139290312+4957.08687808040*x);
R0+=0.00000000130*cost(0.90844304292+3427.92063123960*x);
R0+=0.00000000135*cost(3.56996218538+3229.42578441220*x);
R0+=0.00000000143*cost(5.30225767870+14128.24277124560*x);
R0+=0.00000000134*cost(2.47836558803+7167.19690618920*x);
R0+=0.00000000150*cost(5.89116199733+966.97087743560*x);
R0+=0.00000000123*cost(3.58787674774+3318.76159737340*x);
R0+=0.00000000153*cost(0.37199746202+6533.14612897330*x);
R0+=0.00000000145*cost(1.73326841661+6637.50594109460*x);
R0+=0.00000000133*cost(3.27553306809+11876.46958573400*x);
R0+=0.00000000119*cost(5.15087396729+15636.56665630900*x);
R0+=0.00000000117*cost(3.70999224131+3343.15522398060*x);
R0+=0.00000000115*cost(5.99541570797+11986.67590695340*x);
R0+=0.00000000152*cost(5.66662339960+6530.17718355670*x);
R0+=0.00000000123*cost(0.05231448642+9801.42463766060*x);
R0+=0.00000000130*cost(1.42377926040+16063.16484718500*x);
R0+=0.00000000120*cost(4.19579234337+604.84974070480*x);
R0+=0.00000000126*cost(1.38788085609+169.58018313300*x);
R0+=0.00000000122*cost(0.18785107006+18849.22754997420*x);
R0+=0.00000000113*cost(4.67731144918+24491.42579258340*x);
R0+=0.00000000122*cost(1.21803689218+3067.93946934820*x);
R0+=0.00000000118*cost(3.92389195187+2963.23881878400*x);
R0+=0.00000000137*cost(0.80076862963+3123.79021291280*x);
R0+=0.00000000124*cost(0.77274469912+12465.53441274220*x);
R0+=0.00000000132*cost(4.73888023892+2267.00340250900*x);
R0+=0.00000000122*cost(3.66231014052+8756.26980147300*x);
R0+=0.00000000113*cost(3.74955221887+21393.54196985760*x);
R0+=0.00000000153*cost(5.00596002145+15906.76412668260*x);
R0+=0.00000000109*cost(1.46394078440+2854.64037391020*x);
R0+=0.00000000125*cost(6.00744459186+1442.26120876020*x);
R0+=0.00000000140*cost(0.64532646558+13532.02988993220*x);
R0+=0.00000000108*cost(2.11691804278+43.71891230500*x);
R0+=0.00000000130*cost(1.43185911960+3370.10424500320*x);
R0+=0.00000000133*cost(2.31239626151+9072.66167112960*x);
R0+=0.00000000107*cost(5.68864833782+4878.85286267780*x);
R0+=0.00000000116*cost(3.91262234002+11904.91877320180*x);
R0+=0.00000000106*cost(1.99989592271+3497.01314720220*x);
R0+=0.00000000106*cost(5.79020088316+1.48447270830*x);
R0+=0.00000000105*cost(1.79751699456+3517.30615683360*x);
R0+=0.00000000130*cost(0.80396347034+3397.51080163540*x);
R0+=0.00000000107*cost(5.29449090921+10.63666534980*x);
R0+=0.00000000137*cost(0.47037516401+13575.74880223720*x);
R0+=0.00000000104*cost(5.03145022037+1751.52227776380*x);
R0+=0.00000000146*cost(2.57659804831+3308.64012088300*x);
R0+=0.00000000103*cost(3.29589452622+4379.63903749020*x);
R0+=0.00000000104*cost(0.77903634693+1751.55678506820*x);
R0+=0.00000000118*cost(4.11892224522+10927.29397676420*x);
R0+=0.00000000106*cost(2.25714927822+13207.02930736500*x);
R0+=0.00000000126*cost(1.10289326962+6680.79497027290*x);
R0+=0.00000000105*cost(1.41449747957+10081.21114201300*x);
R0+=0.00000000110*cost(6.16072219971+3338.06962941900*x);
R0+=0.00000000113*cost(0.61947991056+13421.82356871280*x);
R0+=0.00000000139*cost(2.21345603147+1954.71715036360*x);
R0+=0.00000000102*cost(3.81767069895+6670.17915313570*x);
R0+=0.00000000101*cost(3.44583422545+1505.28780909299*x);
R0+=0.00000000105*cost(2.46134952447+5525.86369599260*x);
R0+=0.00000000119*cost(5.64454862995+8425.71814811760*x);
R0+=0.00000000101*cost(1.87446179141+9161.52735134660*x);
R0+=0.00000000111*cost(5.46183253107+7214.43893684320*x);
R0+=0.00000000123*cost(0.14056284625+16489.76303806100*x);
R0+=0.00000000128*cost(0.00452525697+2185.25126929280*x);
R0+=0.00000000106*cost(6.20225179330+3717.98603461560*x);
R0+=0.00000000099*cost(1.70554147455+1655.56030419820*x);
R0+=0.00000000100*cost(1.76373681853+3002.36972771680*x);
R0+=0.00000000101*cost(0.55693458655+3337.15661865360*x);
R0+=0.00000000101*cost(0.56441794685+30774.50164257480*x);
R0+=0.00000000098*cost(1.93983799659+5562.46906129680*x);
R0+=0.00000000130*cost(5.65255471249+2735.76268599500*x);
R0+=0.00000000125*cost(6.18575288406+9698.33186344200*x);
R0+=0.00000000100*cost(2.35767934317+3337.07205469860*x);
R0+=0.00000000100*cost(3.76317527562+3344.15279870100*x);
R0+=0.00000000105*cost(5.33897491215+5096.08411137890*x);
R0+=0.00000000103*cost(1.24189801298+1385.89527633620*x);
R0+=0.00000000101*cost(1.42727612221+37455.72649597440*x);
R0+=0.00000000096*cost(2.55328478399+4466.48176580340*x);
R0+=0.00000000097*cost(5.86779127410+5220.17080145320*x);
R0+=0.00000000101*cost(2.61513508379+16858.41522263039*x);
R0+=0.00000000107*cost(4.23943588615+8823.86715152580*x);
R0+=0.00000000100*cost(4.38845221965+3337.10656200300*x);
R0+=0.00000000100*cost(1.73240240188+3344.11829139661*x);
R0+=0.00000000101*cost(3.51764169063+4694.00295470760*x);
R0+=0.00000000096*cost(3.16895015703+12825.64519470380*x);
R0+=0.00000000101*cost(6.24060604565+2942.53073359440*x);
R0+=0.00000000103*cost(1.09500325425+12089.76868117200*x);
R0+=0.00000000106*cost(5.57931664756+39048.32250960720*x);
R0+=0.00000000126*cost(3.40521738550+6681.65473652630*x);
R0+=0.00000000105*cost(2.52404371984+1755.06264976500*x);
R0+=0.00000000115*cost(6.10031030713+3145.64104223920*x);
R0+=0.00000000092*cost(5.06385191401+5085.10572141780*x);
R0+=0.00000000097*cost(1.11670836674+3341.79306935190*x);
R0+=0.00000000092*cost(5.83209800268+6682.70932610790*x);
R0+=0.00000000121*cost(2.39411154886+18208.34994259200*x);
R0+=0.00000000110*cost(2.51677822824+1045.15483618760*x);
R0+=0.00000000091*cost(1.07173725022+927.83996850280*x);
R0+=0.00000000096*cost(3.60155667418+13363.43002786740*x);
R0+=0.00000000097*cost(5.34224904711+7636.46637799920*x);
R0+=0.00000000094*cost(1.20811080231+9495.66943335380*x);
R0+=0.00000000090*cost(4.17568982529+0.06731030280*x);
R0+=0.00000000097*cost(3.20862890174+5298.33750655300*x);
R0+=0.00000000092*cost(3.20029831258+4403.51747523800*x);
R0+=0.00000000090*cost(3.79900428724+685.04405422600*x);
R0+=0.00000000101*cost(2.12778329280+10050.28646756720*x);
R0+=0.00000000098*cost(3.89390262307+2373.64154926420*x);
R0+=0.00000000090*cost(4.49046504054+6453.74872061060*x);
R0+=0.00000000096*cost(5.13129666936+7792.86709850160*x);
R0+=0.00000000089*cost(4.51228904794+10037.08975128440*x);
R0+=0.00000000098*cost(0.65689906709+2810.98877190800*x);
R0+=0.00000000114*cost(4.15908543927+9090.47419324760*x);
R0+=0.00000000094*cost(4.78960145866+35707.71008290740*x);
R0+=0.00000000087*cost(6.26525215858+34554.81386366760*x);
R0+=0.00000000087*cost(1.50181194995+9983.70424446160*x);
R0+=0.00000000087*cost(1.43790822626+9488.62319665580*x);
R0+=0.00000000090*cost(2.79573736864+47477.56377607380*x);
R0+=0.00000000094*cost(5.68919291448+6106.88005506480*x);
R0+=0.00000000087*cost(0.74049208991+41990.78593289880*x);
R0+=0.00000000101*cost(0.99308133443+6614.73744448520*x);
R0+=0.00000000115*cost(3.49732055752+4.50343941720*x);
R0+=0.00000000086*cost(0.18628425275+216.82221378700*x);
R0+=0.00000000099*cost(1.06539589813+2810.85415130240*x);
R0+=0.00000000087*cost(3.02856210899+7218.02936549500*x);
R0+=0.00000000085*cost(4.58476007089+1699.27921650320*x);
R0+=0.00000000088*cost(4.47996444588+21957.68072774700*x);
R0+=0.00000000106*cost(6.12011880730+4819.47900076420*x);
R0+=0.00000000089*cost(3.88600719587+12199.97500239140*x);
R0+=0.00000000097*cost(2.70091698598+3339.43178404770*x);
R0+=0.00000000118*cost(1.02739527200+34115.11406927460*x);
R0+=0.00000000101*cost(0.36591831115+2942.39611298880*x);
R0+=0.00000000084*cost(5.66081869654+1169.58825140860*x);
R0+=0.00000000086*cost(1.91214909013+55516.41870984820*x);
R0+=0.00000000084*cost(4.30909434949+4150.08989614680*x);
R0+=0.00000000094*cost(1.36645151323+9093.99731159660*x);
R0+=0.00000000097*cost(2.26544245706+13361.46938573100*x);
R0+=0.00000000099*cost(1.16054562056+128.01884333740*x);
R0+=0.00000000094*cost(1.10573952457+4591.44262300060*x);
R0+=0.00000000092*cost(0.74386387542+4845.90023579280*x);
R0+=0.00000000101*cost(1.51570299040+7807.09419250320*x);
R0+=0.00000000096*cost(1.02187746571+2899.78714182220*x);
R0+=0.00000000086*cost(0.66787658068+2957.73314812880*x);
R0+=0.00000000087*cost(3.49676189640+4061.75165790600*x);
R0+=0.00000000095*cost(3.35452781355+661.23292678100*x);
R0+=0.00000000087*cost(0.04840436087+23546.75362303080*x);
R0+=0.00000000114*cost(2.83270741566+394.62588505920*x);
R0+=0.00000000081*cost(3.44420073782+148.07872442630*x);
R0+=0.00000000081*cost(1.27062968985+4893.07995667940*x);
R0+=0.00000000083*cost(5.48462687348+4349.16189758320*x);
R0+=0.00000000105*cost(3.47842036130+3413.90955255880*x);
R0+=0.00000000084*cost(4.33209852801+51449.32426327820*x);
R0+=0.00000000093*cost(1.59775582035+5088.21980485270*x);
R0+=0.00000000088*cost(3.29950478012+2655.50106217100*x);
R0+=0.00000000081*cost(1.65543714666+78263.70942472259*x);
R0+=0.00000000086*cost(1.19342535692+4029.24690957760*x);
R0+=0.00000000079*cost(4.41964678009+151.04766984290*x);
R0+=0.00000000084*cost(1.96289182788+14867.73751589219*x);
R0+=0.00000000091*cost(5.76229906142+2544.33167353560*x);
R0+=0.00000000086*cost(3.78659802914+1481.40937134520*x);
R0+=0.00000000082*cost(2.85633413428+14164.81362924540*x);
R0+=0.00000000078*cost(4.29426812598+187.92514776260*x);
R0+=0.00000000078*cost(5.38566529072+2655.56837247380*x);
R0+=0.00000000084*cost(2.15121245434+3311.12060839640*x);
R0+=0.00000000078*cost(2.01651247942+9124.92198604240*x);
R0+=0.00000000083*cost(4.28280129037+74923.09699802278*x);
R0+=0.00000000077*cost(1.45903147715+2544.38173018620*x);
R0+=0.00000000081*cost(3.62204400197+12306.59089495900*x);
R0+=0.00000000100*cost(1.33498371324+9278.84721956680*x);
R0+=0.00000000089*cost(2.62080312892+24341.52831745660*x);
R0+=0.00000000098*cost(3.78877505378+3198.43379966360*x);
R0+=0.00000000081*cost(4.34306418828+10177.19036923080*x);
R0+=0.00000000080*cost(5.80054348103+2751.01515718000*x);
R0+=0.00000000092*cost(2.80228448795+3707.83675566220*x);
R0+=0.00000000082*cost(2.45812896240+9815.65173166220*x);
R0+=0.00000000076*cost(3.03616461584+9993.38809263160*x);
R0+=0.00000000076*cost(3.92674885488+2910.08208256070*x);
R0+=0.00000000076*cost(3.20004040720+7733.49323658800*x);
R0+=0.00000000098*cost(3.28574616663+3289.33208883739*x);
R0+=0.00000000077*cost(2.05948930010+12928.73796892240*x);
R0+=0.00000000075*cost(0.85784191736+28638.90558114660*x);
R0+=0.00000000078*cost(0.29690749181+10654.62101941260*x);
R0+=0.00000000101*cost(0.72388999452+48827.43118573260*x);
R0+=0.00000000085*cost(5.19438010130+2146.14816282300*x);
R0+=0.00000000083*cost(4.42475849926+2060.81785407180*x);
R0+=0.00000000075*cost(5.19097428778+1055.44977692610*x);
R0+=0.00000000096*cost(6.24132708357+11.04570026390*x);
R0+=0.00000000074*cost(3.37882325472+8006.16619393960*x);
R0+=0.00000000101*cost(0.95332927487+8186.51266249260*x);
R0+=0.00000000092*cost(0.96173005100+151.89728108520*x);
R0+=0.00000000074*cost(2.22716630210+272.67295735160*x);
R0+=0.00000000092*cost(5.56705883046+27873.58901026800*x);
R0+=0.00000000091*cost(3.73152787182+2544.29716623120*x);
R0+=0.00000000084*cost(0.41493230617+4296.90158267040*x);
R0+=0.00000000074*cost(5.09669613096+9755.23023837760*x);
R0+=0.00000000078*cost(1.79565224435+3564.95722240170*x);
R0+=0.00000000075*cost(4.58345774133+9153.90361602180*x);
R0+=0.00000000074*cost(3.88658218247+25298.29315444680*x);
R0+=0.00000000085*cost(5.31472029744+4716.38622654560*x);
R0+=0.00000000074*cost(1.46907693289+11527.12508919240*x);
R0+=0.00000000101*cost(2.94847804254+12032.93761653920*x);
R0+=0.00000000072*cost(0.24413748615+1324.94134054000*x);
R0+=0.00000000078*cost(0.17721609024+3391.89276456221*x);
R0+=0.00000000073*cost(1.65072742864+5452.26274007740*x);
R0+=0.00000000073*cost(4.91730083470+10787.63034454580*x);
R0+=0.00000000073*cost(3.28285909319+8830.91338822380*x);
R0+=0.00000000081*cost(5.46340742050+3856.07629779280*x);
R0+=0.00000000073*cost(4.61913155968+3288.35211178700*x);
R0+=0.00000000096*cost(5.71767221046+206.70073729660*x);
R0+=0.00000000080*cost(4.47918417138+12299.54465826100*x);
R0+=0.00000000071*cost(4.98130328330+12942.96506292400*x);
R0+=0.00000000073*cost(2.86057567032+4960.60999642940*x);
R0+=0.00000000072*cost(5.14120362338+4665.55376723980*x);
R0+=0.00000000076*cost(0.00928867041+6534.41316687600*x);
R0+=0.00000000090*cost(5.38224594245+2125.81009707640*x);
R0+=0.00000000085*cost(0.94196641948+2146.18267012740*x);
R0+=0.00000000096*cost(0.68069708134+10006.58480891440*x);
R0+=0.00000000073*cost(1.06048379839+3866.78027344540*x);
R0+=0.00000000072*cost(0.84342376295+3334.54651107000*x);
R0+=0.00000000091*cost(5.12701600437+3392.87274161260*x);
R0+=0.00000000076*cost(5.96038992872+3482.79105373600*x);
R0+=0.00000000090*cost(1.46230169383+5092.16921176800*x);
R0+=0.00000000071*cost(1.16745785331+1574.84580128220*x);
R0+=0.00000000072*cost(3.86137692169+16762.43599541260*x);
R0+=0.00000000070*cost(0.07310763691+12839.87228870540*x);
R0+=0.00000000073*cost(0.11725123446+10507.80933288900*x);
R0+=0.00000000081*cost(5.86817748181+3495.96551583120*x);
R0+=0.00000000071*cost(2.07963275673+1063.31408345230*x);
R0+=0.00000000068*cost(3.30993028662+4106.40549114620*x);
R0+=0.00000000069*cost(0.33467954461+5.52292430740*x);
R0+=0.00000000068*cost(1.56404561711+2398.55036473080*x);
R0+=0.00000000090*cost(2.61953849393+3346.67834232960*x);
R0+=0.00000000068*cost(1.06108185791+191.38095580880*x);
R0+=0.00000000077*cost(0.87794040199+2917.94638908690*x);
R0+=0.00000000067*cost(0.29712068423+12012.58229714040*x);
R0+=0.00000000067*cost(2.55451787747+11567.19126307820*x);
R0+=0.00000000083*cost(1.82578570364+3511.28529731900*x);
R0+=0.00000000068*cost(2.68247854175+20213.25474333179*x);
R0+=0.00000000086*cost(2.79273636804+367.22432896240*x);
R0+=0.00000000086*cost(0.81171860574+209.77597708900*x);
R0+=0.00000000067*cost(5.28035928877+8966.38750317330*x);
R0+=0.00000000067*cost(0.20258020424+27433.88921587499*x);
R0+=0.00000000071*cost(2.76410148218+15650.79375031060*x);
R0+=0.00000000090*cost(0.71593793107+3451.79906898740*x);
R0+=0.00000000067*cost(6.18148420146+3966.28261901220*x);
R0+=0.00000000074*cost(3.61959120765+7064.10413197060*x);
R0+=0.00000000068*cost(2.69550405031+12725.45343477500*x);
R0+=0.00000000074*cost(1.24854309783+8027.56914470940*x);
R0+=0.00000000084*cost(2.47006028699+3738.74417645580*x);
R0+=0.00000000077*cost(5.89874180572+4307.58330413540*x);
R0+=0.00000000067*cost(0.33285041428+19645.52555679060*x);
R0+=0.00000000083*cost(3.79134493696+2472.67876262220*x);
R0+=0.00000000064*cost(0.43216125634+1994.26813539000*x);
R0+=0.00000000071*cost(0.65707804543+860.30992875280*x);
R0+=0.00000000064*cost(0.98960038205+3376.17516116840*x);
R0+=0.00000000070*cost(0.96227192685+8428.83223155250*x);
R0+=0.00000000066*cost(0.65425879867+8219.46528937760*x);
R0+=0.00000000070*cost(4.36060455306+8436.69653807870*x);
R0+=0.00000000084*cost(4.50083253887+3738.77868376020*x);
R0+=0.00000000073*cost(5.69670871544+14687.39104733920*x);
R0+=0.00000000071*cost(0.36334330253+2619.47319549360*x);
R0+=0.00000000080*cost(5.85771861744+7747.72033058960*x);
R0+=0.00000000068*cost(3.06409889136+8446.99147881720*x);
R0+=0.00000000066*cost(1.07137364271+1987.22189869200*x);
R0+=0.00000000061*cost(3.71171429905+1055.85881184020*x);
R0+=0.00000000079*cost(0.06487001849+6286.59896834040*x);
R0+=0.00000000075*cost(1.54177744365+1059.39918384140*x);
R0+=0.00000000061*cost(1.47350010728+1685.05212250160*x);
R0+=0.00000000061*cost(0.46897959303+1727.66109366820*x);
R0+=0.00000000064*cost(2.11869877898+3305.04969223120*x);
R0+=0.00000000060*cost(1.17940250396+97670.38771289718*x);
R0+=0.00000000060*cost(5.13953821352+1898.33396428740*x);
R0+=0.00000000064*cost(4.04058406722+3945.46216740460*x);
R0+=0.00000000063*cost(5.20562384814+24606.13555322000*x);
R0+=0.00000000061*cost(0.55428968913+7082.89697515680*x);
R0+=0.00000000075*cost(4.81208819076+27299.24421193320*x);
R0+=0.00000000059*cost(1.75511446129+12082.65513417120*x);
R0+=0.00000000061*cost(5.88333855610+6901.63749583840*x);
R0+=0.00000000074*cost(3.46408580786+14556.89671702380*x);
R0+=0.00000000074*cost(4.40649822049+9360.60435331840*x);
R0+=0.00000000058*cost(4.22827613192+4531.53631857540*x);
R0+=0.00000000080*cost(2.14103357856+7917.30051372260*x);
R0+=0.00000000075*cost(1.85618011420+52566.19261584059*x);
R0+=0.00000000075*cost(5.15830659680+45884.96776244100*x);
R0+=0.00000000068*cost(2.06915254754+8958.52319664710*x);
R0+=0.00000000056*cost(3.77847713307+299.12639426920*x);
R0+=0.00000000062*cost(2.25564130818+9758.75335672660*x);
R0+=0.00000000059*cost(2.68657637673+6283.05859633920*x);
R0+=0.00000000056*cost(5.54148283448+13286.18363552360*x);
R0+=0.00000000056*cost(3.89200811600+8962.38803960740*x);
R0+=0.00000000063*cost(2.07254352069+7593.79509706520*x);
R0+=0.00000000061*cost(4.31994402891+4709.27267954480*x);
R0+=0.00000000075*cost(5.79419108898+1059.36467653700*x);
R0+=0.00000000056*cost(0.18569912415+7768.00833968560*x);
R0+=0.00000000059*cost(5.49627068572+7322.10246078180*x);
R0+=0.00000000064*cost(3.95992112220+3050.12694723020*x);
R0+=0.00000000055*cost(2.19506741266+7.04623669800*x);
R0+=0.00000000057*cost(4.05252695300+3930.20969621960*x);
R0+=0.00000000075*cost(3.99788100837+5483.25472482600*x);
R0+=0.00000000060*cost(4.61703903739+6990.50317605540*x);
R0+=0.00000000073*cost(4.20362525534+21150.81336588360*x);
R0+=0.00000000066*cost(2.82009591985+8771.00708379860*x);
R0+=0.00000000054*cost(0.38782719267+360.11078196160*x);
R0+=0.00000000059*cost(4.71734799803+6283.09310364360*x);
R0+=0.00000000068*cost(5.74655335863+987.74627292800*x);

double R1=0;
R1+=0.01107433340*cost(2.03250524950+3340.61242669980*x);
R1+=0.00103175886*cost(2.37071845682+6681.22485339960*x);
R1+=0.00012877200;
R1+=0.00010815880*cost(2.70888093803+10021.83728009940*x);
R1+=0.00001194550*cost(3.04702182503+13362.44970679920*x);
R1+=0.00000438579*cost(2.88835072628+2281.23049651060*x);
R1+=0.00000395698*cost(3.42324611291+3344.13554504880*x);
R1+=0.00000182572*cost(1.58428644001+2544.31441988340*x);
R1+=0.00000135850*cost(3.38507017993+16703.06213349900*x);
R1+=0.00000128204*cost(0.62991220570+1059.38193018920*x);
R1+=0.00000127068*cost(1.95389775740+796.29800681640*x);
R1+=0.00000118443*cost(2.99761345074+2146.16541647520*x);
R1+=0.00000128362*cost(6.04343360441+3337.08930835080*x);
R1+=0.00000087537*cost(3.42052758979+398.14900340820*x);
R1+=0.00000083026*cost(3.85574986653+3738.76143010800*x);
R1+=0.00000075598*cost(4.45101839349+6151.53388830500*x);
R1+=0.00000071999*cost(2.76442180680+529.69096509460*x);
R1+=0.00000066542*cost(2.54892602695+1751.53953141600*x);
R1+=0.00000054314*cost(0.67750943459+8962.45534991020*x);
R1+=0.00000051035*cost(3.72585409207+6684.74797174860*x);
R1+=0.00000066430*cost(4.40597549957+1748.01641306700*x);
R1+=0.00000047863*cost(2.28527896843+2914.01423582380*x);
R1+=0.00000049428*cost(5.72959428364+3340.59517304760*x);
R1+=0.00000049424*cost(1.47717922226+3340.62968035200*x);
R1+=0.00000057518*cost(0.54354327916+1194.44701022460*x);
R1+=0.00000048318*cost(2.58061691301+3149.16416058820*x);
R1+=0.00000036384*cost(6.02728752344+3185.19202726560*x);
R1+=0.00000037176*cost(5.81439911546+1349.86740965880*x);
R1+=0.00000036036*cost(5.89508336048+3333.49887969900*x);
R1+=0.00000031115*cost(0.97832506960+191.44826611160*x);
R1+=0.00000038953*cost(2.31900090554+4136.91043351620*x);
R1+=0.00000027244*cost(5.41367977087+1592.59601363280*x);
R1+=0.00000024300*cost(3.75843924498+155.42039943420*x);
R1+=0.00000022804*cost(1.74830773908+5088.62883976680*x);
R1+=0.00000022324*cost(0.93932040730+951.71840625060*x);
R1+=0.00000021708*cost(3.83571581352+6283.07584999140*x);
R1+=0.00000021304*cost(0.78049229782+1589.07289528380*x);
R1+=0.00000021631*cost(4.56895741061+3532.06069281140*x);
R1+=0.00000017956*cost(4.21930481803+3870.30339179440*x);
R1+=0.00000018237*cost(0.41328624131+5486.77784317500*x);
R1+=0.00000016251*cost(3.80760134974+3340.54511639700*x);
R1+=0.00000016803*cost(5.54857987615+3097.88382272579*x);
R1+=0.00000016850*cost(4.53690440252+4292.33083295040*x);
R1+=0.00000015755*cost(4.75736730681+9492.14631500480*x);
R1+=0.00000015746*cost(3.72356090283+20043.67456019880*x);
R1+=0.00000020428*cost(3.13540712557+4690.47983635860*x);
R1+=0.00000014699*cost(5.95325006816+3894.18182954220*x);
R1+=0.00000016251*cost(3.39910907599+3340.67973700260*x);
R1+=0.00000014259*cost(3.99897353022+1990.74501704100*x);
R1+=0.00000016528*cost(0.96752074938+4399.99435688900*x);
R1+=0.00000013010*cost(5.14230107067+6677.70173505060*x);
R1+=0.00000012492*cost(1.03211063742+3341.59274776800*x);
R1+=0.00000016463*cost(3.53882915214+2700.71514038580*x);
R1+=0.00000016171*cost(2.34870953554+553.56940284240*x);
R1+=0.00000013169*cost(0.41461716663+5614.72937620960*x);
R1+=0.00000011272*cost(1.02375627844+12303.06777661000*x);
R1+=0.00000012408*cost(6.23142869816+5628.95647021120*x);
R1+=0.00000012747*cost(0.69046314049+3723.50895892300*x);
R1+=0.00000011827*cost(6.25283898676+2274.11694950980*x);
R1+=0.00000010384*cost(1.23257236014+426.59819087600*x);
R1+=0.00000011208*cost(1.31750963435+3496.03282613400*x);
R1+=0.00000010345*cost(0.90062464690+4535.05943692440*x);
R1+=0.00000012215*cost(4.22316056098+7079.37385680780*x);
R1+=0.00000009765*cost(3.45310940204+382.89653222320*x);
R1+=0.00000008586*cost(1.16471901139+2787.04302385740*x);
R1+=0.00000007879*cost(5.73808861790+2288.34404351140*x);
R1+=0.00000009195*cost(1.81689739851+6681.24210705180*x);
R1+=0.00000007751*cost(4.15046998466+6041.32756708560*x);
R1+=0.00000009195*cost(6.06945250657+6681.20759974740*x);
R1+=0.00000009026*cost(2.58210941053+2388.89402044920*x);
R1+=0.00000006771*cost(0.23987737854+11773.37681151540*x);
R1+=0.00000007087*cost(3.51414944377+8031.09226305840*x);
R1+=0.00000009159*cost(3.90158590550+3553.91152213780*x);
R1+=0.00000006702*cost(4.25572879119+242.72860397400*x);
R1+=0.00000007232*cost(3.70287400141+2818.03500860600*x);
R1+=0.00000006546*cost(0.04353472459+2957.71589447660*x);
R1+=0.00000008781*cost(2.19735028572+1221.84856632140*x);
R1+=0.00000006540*cost(2.11834687923+8429.24126646660*x);
R1+=0.00000006836*cost(4.04512263654+10025.36039844840*x);
R1+=0.00000007280*cost(4.26943100715+2803.80791460440*x);
R1+=0.00000007676*cost(1.00782250264+8432.76438481560*x);
R1+=0.00000005732*cost(3.13956241764+213.29909543800*x);
R1+=0.00000005344*cost(3.78220670098+5092.15195811580*x);
R1+=0.00000005991*cost(2.96408254428+6489.77658728800*x);
R1+=0.00000005132*cost(3.98288453952+7.11354700080*x);
R1+=0.00000006261*cost(1.90346469972+5621.84292321040*x);
R1+=0.00000005241*cost(2.67093795050+7477.52286021600*x);
R1+=0.00000006261*cost(1.60056695152+3347.72597370060*x);
R1+=0.00000006526*cost(2.76281601349+3339.63210563160*x);
R1+=0.00000004591*cost(1.81986278078+2810.92146160520*x);
R1+=0.00000005460*cost(4.60874445963+3583.34103067380*x);
R1+=0.00000004733*cost(0.90560026340+5099.26550511660*x);
R1+=0.00000005486*cost(4.91408093456+7632.94325965020*x);
R1+=0.00000004004*cost(4.14067157211+9623.68827669120*x);
R1+=0.00000003837*cost(0.03343295627+7234.79425624200*x);
R1+=0.00000003621*cost(5.76532393672+4933.20844033260*x);
R1+=0.00000003747*cost(0.08778985966+6525.80445396540*x);
R1+=0.00000003016*cost(3.73838855125+6681.29216370240*x);
R1+=0.00000003975*cost(4.91288592965+2942.46342329160*x);
R1+=0.00000003911*cost(0.67451768877+3127.31333126180*x);
R1+=0.00000003923*cost(3.07703531632+3.52311834900*x);
R1+=0.00000003944*cost(0.53974754515+5884.92684658320*x);
R1+=0.00000002901*cost(4.66281989264+7210.91581849420*x);
R1+=0.00000002803*cost(1.00530177454+7064.12138562280*x);
R1+=0.00000003153*cost(4.54673175664+2487.41604494780*x);
R1+=0.00000002784*cost(0.05495331967+639.89728631400*x);
R1+=0.00000002759*cost(5.17099857257+5828.02847164760*x);
R1+=0.00000003017*cost(4.14668877243+6681.15754309680*x);
R1+=0.00000002999*cost(0.82918667275+5085.03841111500*x);
R1+=0.00000002677*cost(0.69427974692+2699.73481931760*x);
R1+=0.00000003023*cost(2.59489020298+2906.90068882300*x);
R1+=0.00000002596*cost(1.08693013783+4929.68532198360*x);
R1+=0.00000003126*cost(1.00027692782+2118.76386037840*x);
R1+=0.00000002598*cost(5.01195749912+10018.31416175040*x);
R1+=0.00000002606*cost(5.34420770679+10973.55568635000*x);
R1+=0.00000002779*cost(3.98358744953+6467.92575796160*x);
R1+=0.00000002460*cost(1.52653571249+6836.64525283380*x);
R1+=0.00000002382*cost(3.93610586965+11371.70468975820*x);
R1+=0.00000002590*cost(5.08892664109+12832.75874170460*x);
R1+=0.00000002201*cost(0.18880589605+9595.23908922340*x);
R1+=0.00000002128*cost(5.69450469171+3191.04922956520*x);
R1+=0.00000002065*cost(3.54133174600+1066.49547719000*x);
R1+=0.00000001868*cost(5.01592531810+3475.67750673520*x);
R1+=0.00000002081*cost(1.30274459220+7740.60678358880*x);
R1+=0.00000001830*cost(5.68365327697+3319.83703120740*x);
R1+=0.00000002022*cost(6.16092328060+1744.42598441520*x);
R1+=0.00000001708*cost(2.21675931288+2921.12778282460*x);
R1+=0.00000001836*cost(6.16477009621+8425.65083781480*x);
R1+=0.00000002060*cost(6.24041853265+6674.11130639880*x);
R1+=0.00000001735*cost(4.58243571826+10419.98628350760*x);
R1+=0.00000001852*cost(1.36883022935+15643.68020330980*x);
R1+=0.00000001689*cost(1.92829590736+3767.21061757580*x);
R1+=0.00000001954*cost(0.46215988899+10575.40668294180*x);
R1+=0.00000001800*cost(2.30913343660+3355.86489788480*x);
R1+=0.00000001444*cost(2.15042616899+10021.85453375160*x);
R1+=0.00000001760*cost(5.87267582299+3320.25710730100*x);
R1+=0.00000001845*cost(4.06123235448+23384.28698689860*x);
R1+=0.00000001423*cost(4.65085713203+4562.46099302120*x);
R1+=0.00000001410*cost(1.50438410845+3325.35995551480*x);
R1+=0.00000001444*cost(0.11969993808+10021.82002644720*x);
R1+=0.00000001443*cost(0.55828572929+15113.98923821520*x);
R1+=0.00000001334*cost(1.25483731308+7875.67186362420*x);
R1+=0.00000001442*cost(1.38958943728+6682.20517446780*x);
R1+=0.00000001606*cost(4.34241260905+5331.35744374080*x);
R1+=0.00000001377*cost(0.14791683820+1758.65307841680*x);
R1+=0.00000001282*cost(5.78533014319+14584.29827312060*x);
R1+=0.00000001281*cost(1.35125896423+10404.73381232260*x);
R1+=0.00000001471*cost(0.34649469321+8969.56889691100*x);
R1+=0.00000001245*cost(6.02681709446+3264.34635542420*x);
R1+=0.00000001234*cost(1.88341938354+10177.25767953360*x);
R1+=0.00000001552*cost(5.92727420332+8439.87793181640*x);
R1+=0.00000001182*cost(4.18100226016+3360.96774609859*x);
R1+=0.00000001333*cost(1.86551437099+692.15760122680*x);
R1+=0.00000001189*cost(0.89892514263+13916.01910964160*x);
R1+=0.00000001192*cost(4.30473818946+6894.52394883760*x);
R1+=0.00000001145*cost(0.15197504252+3134.42687826260*x);
R1+=0.00000001299*cost(1.44631688592+6254.62666252360*x);
R1+=0.00000001494*cost(1.54417907271+3361.38782219220*x);
R1+=0.00000001054*cost(0.67591855339+3344.20285535160*x);
R1+=0.00000001210*cost(0.85117132607+3120.19978426100*x);
R1+=0.00000001061*cost(0.13258232364+522.57741809380*x);
R1+=0.00000001003*cost(1.28021784912+4569.57454002200*x);
R1+=0.00000001012*cost(5.77497169905+14314.16811304980*x);
R1+=0.00000001169*cost(2.99767730172+6247.51311552280*x);
R1+=0.00000001062*cost(0.25467691252+3337.02199804800*x);
R1+=0.00000001032*cost(5.69833683620+536.80451209540*x);
R1+=0.00000001082*cost(2.58016159997+6261.74020952440*x);
R1+=0.00000000867*cost(1.50283829131+6127.65545055720*x);
R1+=0.00000000953*cost(2.92377030638+5729.50644714900*x);
R1+=0.00000000887*cost(5.28743574972+10213.28554621100*x);
R1+=0.00000001108*cost(2.84339171890+640.87760738220*x);
R1+=0.00000000861*cost(3.21491381593+3914.95722503460*x);
R1+=0.00000001069*cost(0.49400181869+11243.68584642080*x);
R1+=0.00000000800*cost(4.64154002129+6144.42034130420*x);
R1+=0.00000000799*cost(3.33215212691+9830.38901398780*x);
R1+=0.00000001046*cost(4.05907877700+6158.64743530580*x);
R1+=0.00000000743*cost(4.93337997290+3230.40610548040*x);
R1+=0.00000000740*cost(3.01511102229+10818.13528691580*x);
R1+=0.00000000716*cost(2.52567242762+5202.35827933520*x);
R1+=0.00000000705*cost(4.39344403231+9808.53818466140*x);
R1+=0.00000000786*cost(1.72357089999+3178.14579056760*x);
R1+=0.00000000719*cost(0.38924465445+6298.32832117640*x);
R1+=0.00000000717*cost(6.23927283856+3369.06161416760*x);
R1+=0.00000000704*cost(1.96763488855+6688.33840040040*x);
R1+=0.00000000882*cost(2.10339285493+2301.58581590939*x);
R1+=0.00000000913*cost(2.30662326829+13517.87010623340*x);
R1+=0.00000000914*cost(4.36610748804+13365.97282514820*x);
R1+=0.00000000659*cost(3.40905557071+1648.44675719740*x);
R1+=0.00000000828*cost(2.13305589137+7903.07341972100*x);
R1+=0.00000000652*cost(5.97050449428+574.34479833480*x);
R1+=0.00000000688*cost(4.02232587894+1052.26838318840*x);
R1+=0.00000000709*cost(2.24658423912+9225.53927328300*x);
R1+=0.00000000590*cost(0.67418318613+8955.34180290940*x);
R1+=0.00000000604*cost(2.73550395152+16858.48253293320*x);
R1+=0.00000000785*cost(3.58704322751+2693.60159338500*x);
R1+=0.00000000570*cost(4.11146135269+6034.21402008480*x);
R1+=0.00000000624*cost(4.45415856101+12964.30070339100*x);
R1+=0.00000000563*cost(3.72383942144+13119.72110282519*x);
R1+=0.00000000547*cost(3.04142188931+2707.82868738660*x);
R1+=0.00000000536*cost(4.65546776421+135.06508003540*x);
R1+=0.00000000680*cost(3.62640859214+6048.44111408640*x);
R1+=0.00000000535*cost(3.32503801413+9779.10867612540*x);
R1+=0.00000000615*cost(0.31792697641+7910.18696672180*x);
R1+=0.00000000506*cost(1.24339056369+4555.34744602040*x);
R1+=0.00000000633*cost(1.32124830132+2648.45482547300*x);
R1+=0.00000000671*cost(2.88173567087+3316.73398895200*x);
R1+=0.00000000570*cost(4.94522781693+6923.95345737360*x);
R1+=0.00000000489*cost(0.48479532469+12935.85151592320*x);
R1+=0.00000000490*cost(1.57712746955+162.46663613220*x);
R1+=0.00000000492*cost(4.08592823251+10021.90459040220*x);
R1+=0.00000000468*cost(4.50628939729+2384.32327072920*x);
R1+=0.00000000462*cost(1.30653882308+17256.63153634140*x);
R1+=0.00000000444*cost(5.20556841675+13358.92658845020*x);
R1+=0.00000000511*cost(5.29436707935+853.19638175200*x);
R1+=0.00000000458*cost(5.52316111365+6438.49624942560*x);
R1+=0.00000000443*cost(4.37626774329+12168.00269657460*x);
R1+=0.00000000429*cost(4.06329082027+149.56319713460*x);
R1+=0.00000000502*cost(6.12188881856+8273.82086703240*x);
R1+=0.00000000420*cost(3.51990468754+9168.64089834740*x);
R1+=0.00000000452*cost(0.15931716927+7895.95987272020*x);
R1+=0.00000000401*cost(0.93276882765+433.71173787680*x);
R1+=0.00000000491*cost(4.49372643902+10021.76996979660*x);
R1+=0.00000000390*cost(1.26790524143+5459.37628707820*x);
R1+=0.00000000460*cost(3.56765356005+1596.18644228460*x);
R1+=0.00000000514*cost(4.14617297678+16460.33352952499*x);
R1+=0.00000000510*cost(2.12338136542+3335.08950239240*x);
R1+=0.00000000365*cost(0.84035244694+3364.49086444760*x);
R1+=0.00000000444*cost(0.42154996651+9866.41688066520*x);
R1+=0.00000000380*cost(2.74315160117+3344.49376205780*x);
R1+=0.00000000355*cost(2.20831807719+5518.75014899180*x);
R1+=0.00000000374*cost(0.93920520997+3863.18984479360*x);
R1+=0.00000000380*cost(0.60825828556+3980.50971301380*x);
R1+=0.00000000366*cost(1.45297694305+1039.02661079040*x);
R1+=0.00000000458*cost(5.01867719021+10551.52824519400*x);
R1+=0.00000000352*cost(5.59661824792+16062.18452611680*x);
R1+=0.00000000361*cost(5.43698827477+11236.57229942000*x);
R1+=0.00000000323*cost(3.25474887566+3116.26763099790*x);
R1+=0.00000000396*cost(5.43635200834+16173.37116840440*x);
R1+=0.00000000316*cost(5.10862851689+17395.21973472580*x);
R1+=0.00000000325*cost(4.59103320065+19800.94595622480*x);
R1+=0.00000000320*cost(0.10022132590+1692.16566950240*x);
R1+=0.00000000313*cost(4.76509182263+3304.58456002240*x);
R1+=0.00000000329*cost(3.51515201342+1903.43681250120*x);
R1+=0.00000000361*cost(1.40179572820+8270.29774868340*x);
R1+=0.00000000380*cost(1.11278812152+3503.07906283200*x);
R1+=0.00000000309*cost(1.63585786252+11081.21921028860*x);
R1+=0.00000000304*cost(6.27804875103+2391.43681773000*x);
R1+=0.00000000336*cost(2.95777936427+6680.24453233140*x);
R1+=0.00000000299*cost(0.48751113813+3347.65866339780*x);
R1+=0.00000000327*cost(3.19951479738+3981.49003408200*x);
R1+=0.00000000298*cost(4.26967988388+13936.79450513400*x);
R1+=0.00000000309*cost(5.05775078180+12721.57209941700*x);
R1+=0.00000000310*cost(6.10243075443+17924.91069982040*x);
R1+=0.00000000290*cost(4.52880846817+5724.93569742900*x);
R1+=0.00000000279*cost(4.30091602167+3607.21946842160*x);
R1+=0.00000000293*cost(1.90646493379+6702.00024889200*x);
R1+=0.00000000375*cost(5.37146136739+3376.64029337720*x);
R1+=0.00000000268*cost(4.93796347898+13760.59871020740*x);
R1+=0.00000000269*cost(5.63342755549+4032.77002792660*x);
R1+=0.00000000361*cost(4.70448724123+9380.95967271720*x);
R1+=0.00000000285*cost(4.37639190605+6040.34724601740*x);
R1+=0.00000000305*cost(3.60878132297+7255.56965173440*x);
R1+=0.00000000265*cost(5.82002998533+1214.73501932060*x);
R1+=0.00000000246*cost(3.48844723382+3237.51965248120*x);
R1+=0.00000000339*cost(6.05128485092+6660.44945790720*x);
R1+=0.00000000325*cost(5.12798981834+11250.79939342160*x);
R1+=0.00000000243*cost(0.48346700024+13362.43245314700*x);
R1+=0.00000000246*cost(4.41923388458+3546.79797513700*x);
R1+=0.00000000239*cost(3.73073204843+76.26607127560*x);
R1+=0.00000000239*cost(6.27709788173+1964.83862685400*x);
R1+=0.00000000242*cost(2.51411096474+13362.46696045140*x);
R1+=0.00000000238*cost(4.61745673345+17277.40693183380*x);
R1+=0.00000000232*cost(3.13987850882+20199.09495963300*x);
R1+=0.00000000245*cost(3.88310965561+4407.10790388980*x);
R1+=0.00000000242*cost(3.07232693388+12566.15169998280*x);
R1+=0.00000000277*cost(3.88618268628+10596.18207843420*x);
R1+=0.00000000277*cost(6.14459469980+19402.79695281660*x);
R1+=0.00000000222*cost(2.20253799065+7107.82304427560*x);
R1+=0.00000000218*cost(1.37621606096+3415.39402526710*x);
R1+=0.00000000297*cost(3.78408680173+2766.26762836500*x);
R1+=0.00000000264*cost(5.35345322905+6816.28993343500*x);
R1+=0.00000000213*cost(1.10915354432+19004.64794940840*x);
R1+=0.00000000213*cost(4.60032427636+3973.39616601300*x);
R1+=0.00000000230*cost(4.39356021431+26724.89941359840*x);
R1+=0.00000000202*cost(0.60981942427+6677.63442474780*x);
R1+=0.00000000268*cost(5.05058237041+9381.93999378540*x);
R1+=0.00000000199*cost(1.34402137469+8329.67161059700*x);
R1+=0.00000000198*cost(5.08527311506+5820.91492464680*x);
R1+=0.00000000201*cost(0.05002970566+11780.49035851620*x);
R1+=0.00000000199*cost(2.66187512344+6696.47732458460*x);
R1+=0.00000000227*cost(1.69939961119+18984.29263000960*x);
R1+=0.00000000217*cost(4.71565260831+8671.96987044060*x);
R1+=0.00000000199*cost(0.66532566162+15664.03552270859*x);
R1+=0.00000000201*cost(3.90133282111+266.60704172180*x);
R1+=0.00000000242*cost(0.76562027191+3281.23856478620*x);
R1+=0.00000000254*cost(6.07712146530+14054.60730802600*x);
R1+=0.00000000193*cost(6.08798590746+8982.81066930900*x);
R1+=0.00000000202*cost(1.12506176909+6684.81528205140*x);
R1+=0.00000000212*cost(0.41763591084+5732.04924442980*x);
R1+=0.00000000191*cost(0.63315794517+3017.10701004240*x);
R1+=0.00000000184*cost(5.68898048651+5642.19824260920*x);
R1+=0.00000000180*cost(4.60366258431+10235.13637553740*x);
R1+=0.00000000198*cost(1.01742381306+3336.73109134180*x);
R1+=0.00000000207*cost(0.80702499658+3877.41693879520*x);
R1+=0.00000000202*cost(1.61753574776+11216.28429032400*x);
R1+=0.00000000177*cost(0.20305783491+22743.40937951640*x);
R1+=0.00000000181*cost(6.17864681592+4885.96640967860*x);
R1+=0.00000000228*cost(0.90779655425+18454.60166491500*x);
R1+=0.00000000165*cost(3.97299091423+20.35531939880*x);
R1+=0.00000000206*cost(3.58770221682+3205.54734666440*x);
R1+=0.00000000185*cost(2.77088436060+220.41264243880*x);
R1+=0.00000000163*cost(0.00569068383+1437.17561419860*x);
R1+=0.00000000185*cost(6.23128875160+6660.86953400080*x);
R1+=0.00000000164*cost(4.64548469502+3253.30422216000*x);
R1+=0.00000000210*cost(4.85590304986+5618.31980486140*x);
R1+=0.00000000226*cost(1.76563729092+5625.36604155940*x);
R1+=0.00000000163*cost(0.67931390118+12310.18132361080*x);
R1+=0.00000000211*cost(1.51278040364+4039.88357492740*x);
R1+=0.00000000177*cost(2.14779710666+3346.13535100720*x);
R1+=0.00000000154*cost(3.33525296567+9070.11887384880*x);
R1+=0.00000000178*cost(1.65162116131+10713.99488132620*x);
R1+=0.00000000156*cost(6.12783235584+103.09277421860*x);
R1+=0.00000000155*cost(3.51854579269+7373.38245462640*x);
R1+=0.00000000157*cost(4.91614155659+15508.61512327440*x);
R1+=0.00000000191*cost(1.74459210202+10022.81760116760*x);
R1+=0.00000000178*cost(3.53665589741+533.21408344360*x);
R1+=0.00000000154*cost(2.64640687885+3333.56619000180*x);
R1+=0.00000000162*cost(1.27235392680+5415.65737477320*x);
R1+=0.00000000144*cost(1.30886254982+6460.81221096080*x);
R1+=0.00000000173*cost(3.76291627342+3561.02506913860*x);
R1+=0.00000000144*cost(0.86629692094+7380.49600162720*x);
R1+=0.00000000150*cost(0.23529641094+1228.96211332220*x);
R1+=0.00000000144*cost(0.12285484149+647.01083331480*x);
R1+=0.00000000160*cost(0.24157324936+11614.43329373220*x);
R1+=0.00000000146*cost(4.76067886088+16706.58525184800*x);
R1+=0.00000000188*cost(2.96688973732+2178.13772229200*x);
R1+=0.00000000175*cost(1.66915420767+22345.26037610820*x);
R1+=0.00000000141*cost(1.75571255457+3657.00429635640*x);
R1+=0.00000000145*cost(0.71777671857+6784.31762761820*x);
R1+=0.00000000138*cost(2.74151377335+6546.15977336420*x);
R1+=0.00000000139*cost(4.12056692213+3351.24909204960*x);
R1+=0.00000000152*cost(4.88528890547+110.20632121940*x);
R1+=0.00000000134*cost(0.86682710306+3603.69635007260*x);
R1+=0.00000000170*cost(5.54401695608+3265.83082813250*x);
R1+=0.00000000165*cost(2.74557093704+4672.66731424060*x);
R1+=0.00000000129*cost(0.94520493983+419.48464387520*x);
R1+=0.00000000167*cost(3.43007767272+1581.95934828300*x);
R1+=0.00000000136*cost(3.68877945956+13171.00144068760*x);
R1+=0.00000000160*cost(0.68321924763+6475.03930496240*x);
R1+=0.00000000129*cost(4.46548223743+9499.25986200560*x);
R1+=0.00000000144*cost(1.88085102951+9468.26787725700*x);
R1+=0.00000000149*cost(3.49118810274+14158.74771361560*x);
R1+=0.00000000138*cost(1.92770959208+15.25247118500*x);
R1+=0.00000000172*cost(0.23189971635+12323.42309600880*x);
R1+=0.00000000121*cost(1.75813513715+4379.63903749020*x);
R1+=0.00000000120*cost(6.04299490267+6606.44325483230*x);
R1+=0.00000000134*cost(1.98845453946+8965.97846825920*x);
R1+=0.00000000118*cost(0.22641710036+11766.26326451460*x);
R1+=0.00000000122*cost(2.92219895926+21947.11137270000*x);
R1+=0.00000000147*cost(5.86576524955+3169.93955608060*x);
R1+=0.00000000121*cost(5.75886629308+19513.98359510420*x);
R1+=0.00000000119*cost(3.93419985914+4936.79886898440*x);
R1+=0.00000000123*cost(4.65853055862+13149.15061136120*x);
R1+=0.00000000151*cost(4.38870879458+13362.51701710200*x);
R1+=0.00000000134*cost(4.49208622602+2480.30249794700*x);
R1+=0.00000000115*cost(5.78268772131+12722.55242048520*x);
R1+=0.00000000126*cost(4.43971496486+3568.08855948880*x);
R1+=0.00000000114*cost(0.36704570747+3384.33133900480*x);
R1+=0.00000000117*cost(0.67607782416+13207.02930736500*x);
R1+=0.00000000124*cost(5.80386208894+10721.10842832700*x);
R1+=0.00000000115*cost(0.23672592056+224.34479570190*x);
R1+=0.00000000110*cost(0.26402316132+3077.52850332700*x);
R1+=0.00000000112*cost(3.50979462224+1375.77379984580*x);
R1+=0.00000000108*cost(5.30086016687+10264.56588407340*x);
R1+=0.00000000146*cost(2.36972522432+4989.05918389720*x);
R1+=0.00000000143*cost(0.92798026058+5401.43028077160*x);
R1+=0.00000000111*cost(2.47771615302+18606.49894600020*x);
R1+=0.00000000124*cost(1.13870545502+2807.39834325620*x);
R1+=0.00000000105*cost(5.87122793977+4193.80880845180*x);
R1+=0.00000000115*cost(3.01754571849+1118.75579210280*x);
R1+=0.00000000107*cost(2.03274473347+25685.87280280800*x);
R1+=0.00000000107*cost(4.82345245872+13362.38239649640*x);
R1+=0.00000000105*cost(1.21018340855+8584.66166590080*x);
R1+=0.00000000104*cost(5.07527834174+23141.55838292460*x);
R1+=0.00000000100*cost(4.08698733114+3511.28529731900*x);
R1+=0.00000000105*cost(1.13833234280+1162.47470440780*x);
R1+=0.00000000102*cost(2.55243872323+664.75604513000*x);
R1+=0.00000000138*cost(3.04361079523+3329.97576135000*x);
R1+=0.00000000130*cost(3.04769575195+3341.03250279340*x);
R1+=0.00000000117*cost(2.97177407391+9602.35263622420*x);
R1+=0.00000000098*cost(4.54292546461+3362.46325602620*x);
R1+=0.00000000097*cost(2.21618504638+10042.61267559180*x);
R1+=0.00000000100*cost(5.45541648580+3024.22055704320*x);
R1+=0.00000000097*cost(1.55448890675+8799.98871377800*x);
R1+=0.00000000107*cost(5.15001764390+956.28915597060*x);
R1+=0.00000000100*cost(1.80839732601+6665.97238221460*x);
R1+=0.00000000104*cost(0.04641040148+10001.06188460700*x);
R1+=0.00000000097*cost(0.30502193916+10014.72373309860*x);
R1+=0.00000000125*cost(3.71144870102+3873.82651014340*x);
R1+=0.00000000102*cost(5.38933965862+13892.14067189380*x);
R1+=0.00000000108*cost(4.33438895790+3490.17562383440*x);
R1+=0.00000000095*cost(2.32591017464+10028.95082710020*x);
R1+=0.00000000113*cost(1.74323945160+11610.91017538320*x);
R1+=0.00000000119*cost(4.94578003013+3443.70520091840*x);
R1+=0.00000000096*cost(1.63239207663+11925.27409260060*x);
R1+=0.00000000124*cost(0.82697196609+9638.94074787620*x);
R1+=0.00000000101*cost(1.51065535085+1062.90504853820*x);
R1+=0.00000000107*cost(4.36653716080+6531.66165626500*x);
R1+=0.00000000090*cost(2.01534774170+22324.90505670940*x);
R1+=0.00000000094*cost(4.85202869277+14047.49376102520*x);
R1+=0.00000000089*cost(1.23714034226+20809.46762464520*x);
R1+=0.00000000095*cost(5.69916785631+6717.25272007700*x);
R1+=0.00000000095*cost(2.15038299943+8013.27974094040*x);
R1+=0.00000000111*cost(3.91313035726+3311.18291816379*x);
R1+=0.00000000089*cost(1.37925538521+74.78159856730*x);
R1+=0.00000000094*cost(3.24872875047+6657.34641565180*x);
R1+=0.00000000089*cost(0.70324117212+23.87843774780*x);
R1+=0.00000000087*cost(0.40376031248+2221.85663459700*x);
R1+=0.00000000092*cost(3.33165786190+2540.79130153440*x);
R1+=0.00000000120*cost(3.09344469205+6685.10618875760*x);
R1+=0.00000000087*cost(4.92694309070+1505.28780909299*x);
R1+=0.00000000091*cost(1.66121998822+24150.08005134500*x);
R1+=0.00000000090*cost(5.47687082598+16699.53901514999*x);
R1+=0.00000000119*cost(2.53709230647+3312.16323923200*x);
R1+=0.00000000118*cost(5.56523997231+2814.44457995420*x);
R1+=0.00000000093*cost(1.61394240489+3341.04230982650*x);
R1+=0.00000000084*cost(1.19439840758+3450.81874791920*x);
R1+=0.00000000085*cost(4.95060410388+7314.00859271280*x);
R1+=0.00000000084*cost(3.92244493446+170.67287061920*x);
R1+=0.00000000096*cost(5.49205832489+3427.92063123960*x);
R1+=0.00000000106*cost(1.61703818023+3774.32416457660*x);
R1+=0.00000000101*cost(6.18535119914+5511.63660199100*x);
R1+=0.00000000081*cost(3.16562241132+52175.80628314840*x);
R1+=0.00000000093*cost(5.15512549422+3451.79906898740*x);
R1+=0.00000000108*cost(0.33314004399+6709.67404086740*x);
R1+=0.00000000078*cost(2.38080208142+13553.89797291080*x);
R1+=0.00000000085*cost(1.18588430640+6705.10329114740*x);
R1+=0.00000000098*cost(3.24856024758+25287.72379939980*x);
R1+=0.00000000080*cost(2.54327778068+6675.70192909220*x);
R1+=0.00000000078*cost(4.70533248161+24889.57479599160*x);
R1+=0.00000000095*cost(1.59916172961+4271.97551355160*x);
R1+=0.00000000076*cost(0.90799171644+2675.85638156980*x);
R1+=0.00000000091*cost(3.80728044706+2125.87740737920*x);
R1+=0.00000000093*cost(5.59480359619+3340.18254357310*x);
R1+=0.00000000095*cost(2.06299921822+6518.75821726740*x);
R1+=0.00000000100*cost(6.02550501045+3313.21087060300*x);
R1+=0.00000000075*cost(6.16095890090+3370.04193523580*x);
R1+=0.00000000077*cost(4.92444879515+3229.42578441220*x);
R1+=0.00000000090*cost(4.55063359845+6701.58017279840*x);
R1+=0.00000000078*cost(2.01202524407+14421.83163698840*x);
R1+=0.00000000079*cost(5.92142974185+6155.05700665400*x);
R1+=0.00000000101*cost(2.07923317336+15265.88651930040*x);
R1+=0.00000000082*cost(6.04078010866+3760.09707057500*x);
R1+=0.00000000073*cost(3.01106366205+206.18554843720*x);
R1+=0.00000000078*cost(1.71095661489+3399.98628861340*x);
R1+=0.00000000073*cost(3.32824316241+9588.12554222260*x);
R1+=0.00000000076*cost(1.74030672711+6756.00645196690*x);
R1+=0.00000000073*cost(1.44980946324+5408.54382777240*x);
R1+=0.00000000077*cost(5.64501410813+3209.07046501340*x);
R1+=0.00000000080*cost(5.70272305344+10156.90236013480*x);
R1+=0.00000000075*cost(3.83222347813+39048.32250960720*x);
R1+=0.00000000072*cost(0.82629826575+7366.26890762560*x);
R1+=0.00000000083*cost(4.71804515025+14061.72085502680*x);
R1+=0.00000000072*cost(4.35767091893+21548.96236929180*x);
R1+=0.00000000086*cost(1.50107043029+5989.06725217280*x);
R1+=0.00000000073*cost(3.77377582806+28628.33622609960*x);
R1+=0.00000000082*cost(0.78740181090+16276.46394262300*x);
R1+=0.00000000070*cost(2.69225539304+3296.89351439480*x);
R1+=0.00000000069*cost(1.01941228196+12295.95422960920*x);
R1+=0.00000000081*cost(4.64227979982+6947.83189512140*x);
R1+=0.00000000094*cost(0.74502278458+5244.04923920100*x);
R1+=0.00000000067*cost(4.47328871650+20206.14119633100*x);
R1+=0.00000000091*cost(2.95968633697+3326.38533269820*x);
R1+=0.00000000076*cost(2.86128350856+8542.97070603500*x);
R1+=0.00000000065*cost(1.31079130285+23546.75362303080*x);
R1+=0.00000000065*cost(3.31422850411+6414.61781167780*x);
R1+=0.00000000064*cost(3.98415414793+3368.01398279660*x);
R1+=0.00000000065*cost(4.15810281695+3340.19235060619*x);
R1+=0.00000000071*cost(3.82044323862+6578.13207918100*x);
R1+=0.00000000080*cost(1.02128994578+7321.12213971360*x);
R1+=0.00000000064*cost(1.07965886113+6944.30877677240*x);
R1+=0.00000000064*cost(1.20215520018+38.13303563780*x);
R1+=0.00000000070*cost(5.11166911478+9485.03276800400*x);
R1+=0.00000000067*cost(2.22216014849+4845.90023579280*x);
R1+=0.00000000083*cost(1.86067842148+931.36308685180*x);
R1+=0.00000000063*cost(0.45029141698+6418.14093002680*x);
R1+=0.00000000062*cost(5.68207205878+4459.36821880260*x);
R1+=0.00000000062*cost(0.62454636835+6688.27109009760*x);
R1+=0.00000000076*cost(0.41820625869+5032.77809620220*x);
R1+=0.00000000062*cost(5.72811519809+2008.55753915900*x);
R1+=0.00000000060*cost(1.98790201827+12199.97500239140*x);
R1+=0.00000000078*cost(2.18035217615+3232.94890276120*x);
R1+=0.00000000060*cost(1.08971396071+10124.93005431800*x);
R1+=0.00000000072*cost(4.08555524166+3416.87849797540*x);
R1+=0.00000000061*cost(2.49066420507+4005.36847182980*x);
R1+=0.00000000059*cost(2.93755144370+9886.77220006400*x);
R1+=0.00000000069*cost(1.02371083242+6621.85099148600*x);
R1+=0.00000000061*cost(4.57446273568+2277.70737816160*x);
R1+=0.00000000059*cost(4.74745481720+16865.52876963120*x);
R1+=0.00000000069*cost(3.62576981720+15906.76412668260*x);
R1+=0.00000000058*cost(4.15993379336+1854.63230563460*x);
R1+=0.00000000060*cost(4.92798256747+3391.89276456221*x);
R1+=0.00000000070*cost(4.51699340219+16304.91313009080*x);
R1+=0.00000000056*cost(3.59354639280+7322.10246078180*x);
R1+=0.00000000068*cost(0.81217091970+16703.04487984680*x);
R1+=0.00000000056*cost(3.19997567622+4140.43355186520*x);
R1+=0.00000000058*cost(1.73479637157+2409.24933984800*x);
R1+=0.00000000054*cost(5.54310937490+2604.73591316800*x);
R1+=0.00000000059*cost(2.02922256380+45486.81875903279*x);
R1+=0.00000000063*cost(5.29505507594+17101.21113690720*x);
R1+=0.00000000054*cost(4.88230660750+48300.16010269000*x);
R1+=0.00000000071*cost(4.84381041200+3289.33208883739*x);
R1+=0.00000000054*cost(1.76917054114+3510.19260983280*x);
R1+=0.00000000063*cost(2.80175814276+16894.51039961060*x);
R1+=0.00000000058*cost(0.91631357427+10018.24685144760*x);
R1+=0.00000000054*cost(1.06826755543+8948.22825590860*x);
R1+=0.00000000072*cost(1.36121375974+10025.42770875120*x);
R1+=0.00000000061*cost(0.92427393171+17468.85519794540*x);
R1+=0.00000000068*cost(2.84271358352+16703.07938715119*x);
R1+=0.00000000053*cost(3.42679182927+14867.73751589219*x);
R1+=0.00000000054*cost(0.41070672545+18451.07854656599*x);
R1+=0.00000000060*cost(5.86922287544+7447.01791784600*x);
R1+=0.00000000051*cost(1.64684042106+3472.15438838620*x);
R1+=0.00000000057*cost(6.13250399703+17085.95866572220*x);
R1+=0.00000000053*cost(4.16969434701+6106.88005506480*x);
R1+=0.00000000050*cost(3.17196717347+2111.65031337760*x);
R1+=0.00000000055*cost(5.72607545560+10706.88133432540*x);
R1+=0.00000000062*cost(0.57333106196+3171.03224356680*x);
R1+=0.00000000053*cost(1.29007833025+6652.77566593180*x);
R1+=0.00000000050*cost(2.96441858632+10037.08975128440*x);
R1+=0.00000000065*cost(5.11165617529+3113.13629391080*x);
R1+=0.00000000053*cost(4.87447079015+1485.98012106520*x);
R1+=0.00000000050*cost(2.52848298042+10448.43547097540*x);
R1+=0.00000000059*cost(1.69623653028+4025.65648092580*x);
R1+=0.00000000047*cost(5.15559748285+12012.58229714040*x);
R1+=0.00000000049*cost(1.19473362353+3448.27595063840*x);
R1+=0.00000000063*cost(1.01191427607+11769.85369316640*x);
R1+=0.00000000064*cost(3.86219786087+18208.34994259200*x);
R1+=0.00000000059*cost(2.96261275062+14071.43950907579*x);
R1+=0.00000000049*cost(1.41657179779+2938.94030494260*x);
R1+=0.00000000048*cost(2.95878690387+11527.12508919240*x);
R1+=0.00000000052*cost(0.01971915447+8226.57883637840*x);
R1+=0.00000000045*cost(5.07966377852+3318.76159737340*x);
R1+=0.00000000043*cost(1.23879381294+7218.02936549500*x);
R1+=0.00000000058*cost(5.58121433163+6643.09181776180*x);
R1+=0.00000000048*cost(5.02446939402+6645.19698672220*x);
R1+=0.00000000043*cost(0.69492704598+20995.39296644940*x);
R1+=0.00000000044*cost(4.02272101657+9389.05354078620*x);
R1+=0.00000000055*cost(4.38138154697+1478.86657406440*x);
R1+=0.00000000051*cost(4.24292455428+792.77488846740*x);
R1+=0.00000000042*cost(2.74826708762+14577.18472611980*x);
R1+=0.00000000044*cost(4.18397905503+8535.85715903420*x);
R1+=0.00000000047*cost(1.33588473182+632.78373931320*x);
R1+=0.00000000042*cost(5.05676915852+3397.51080163540*x);
R1+=0.00000000042*cost(0.28204510006+10001.48196070061*x);
R1+=0.00000000042*cost(0.75310918544+6357.71943674220*x);
R1+=0.00000000042*cost(4.94532732982+18052.92954315780*x);
R1+=0.00000000052*cost(4.09912687749+5835.14201864840*x);
R1+=0.00000000054*cost(2.46533302314+8186.51266249260*x);
R1+=0.00000000043*cost(4.77713978044+32124.36905223359*x);
R1+=0.00000000053*cost(6.08293348275+3377.21779200400*x);
R1+=0.00000000041*cost(2.51168269556+4186.69526145100*x);
R1+=0.00000000041*cost(1.24482327948+3212.59358336240*x);
R1+=0.00000000041*cost(5.42003026893+685.04405422600*x);
R1+=0.00000000041*cost(5.04768364997+6571.01853218020*x);
R1+=0.00000000042*cost(2.08904552145+13363.43002786740*x);
R1+=0.00000000048*cost(4.82888746454+1835.32461760680*x);
R1+=0.00000000043*cost(4.17203713456+43340.65334255760*x);
R1+=0.00000000046*cost(0.81640935106+45884.96776244100*x);
R1+=0.00000000042*cost(2.26773068307+12729.66596748600*x);
R1+=0.00000000039*cost(5.85791936573+846.08283475120*x);
R1+=0.00000000043*cost(2.90976420757+6872.67311951120*x);
R1+=0.00000000045*cost(1.98725045807+1861.74585263540*x);
R1+=0.00000000045*cost(0.50053853542+14128.24277124560*x);
R1+=0.00000000046*cost(2.86512929328+38650.17350619900*x);
R1+=0.00000000038*cost(3.65846461938+29698.28751133580*x);
R1+=0.00000000039*cost(4.57679716458+6901.63749583840*x);
R1+=0.00000000039*cost(3.85504465583+9945.57120882380*x);
R1+=0.00000000040*cost(0.06127203284+9947.05568153210*x);
R1+=0.00000000043*cost(5.28854105201+3274.12501778540*x);
R1+=0.00000000047*cost(6.25707790441+24606.13555322000*x);
R1+=0.00000000037*cost(5.02115296017+11128.97608578420*x);
R1+=0.00000000039*cost(1.71421919870+7696.88787128380*x);
R1+=0.00000000037*cost(4.34652985120+3283.71405176420*x);
R1+=0.00000000037*cost(0.05572748092+21150.81336588360*x);
R1+=0.00000000042*cost(4.97872041460+13575.74880223720*x);
R1+=0.00000000050*cost(4.24170332288+7747.72033058960*x);
R1+=0.00000000037*cost(4.07496312186+8646.06348025360*x);
R1+=0.00000000038*cost(0.44080908793+24491.42579258340*x);
R1+=0.00000000036*cost(1.73681874925+3468.63127003720*x);
R1+=0.00000000041*cost(5.69294900686+26087.90314157420*x);
R1+=0.00000000036*cost(1.80256389689+8756.26980147300*x);
R1+=0.00000000036*cost(3.37374689465+48429.28218232440*x);
R1+=0.00000000035*cost(0.10555289345+8742.04270747140*x);
R1+=0.00000000041*cost(4.26832466355+21000.91589075680*x);
R1+=0.00000000038*cost(0.73199792046+26084.02180621620*x);

double R2=0;
R2+=0.00044242247*cost(0.47930603943+3340.61242669980*x);
R2+=0.00008138042*cost(0.86998398093+6681.22485339960*x);
R2+=0.00001274915*cost(1.22594050809+10021.83728009940*x);
R2+=0.00000187387*cost(1.57298991982+13362.44970679920*x);
R2+=0.00000040744*cost(1.97080175060+3344.13554504880*x);
R2-=0.00000052396;
R2+=0.00000026616*cost(1.91665615762+16703.06213349900*x);
R2+=0.00000017825*cost(4.43499505333+2281.23049651060*x);
R2+=0.00000011713*cost(4.52510453730+3185.19202726560*x);
R2+=0.00000010209*cost(5.39143469548+1059.38193018920*x);
R2+=0.00000009950*cost(0.41870577185+796.29800681640*x);
R2+=0.00000009237*cost(4.53579272961+2146.16541647520*x);
R2+=0.00000007299*cost(3.14218509183+2544.31441988340*x);
R2+=0.00000007217*cost(2.29300859074+6684.74797174860*x);
R2+=0.00000006808*cost(5.26702580055+155.42039943420*x);
R2+=0.00000006528*cost(2.30781369329+3738.76143010800*x);
R2+=0.00000007785*cost(5.93369079547+1748.01641306700*x);
R2+=0.00000005840*cost(1.05191350362+1349.86740965880*x);
R2+=0.00000006749*cost(5.30194395749+1194.44701022460*x);
R2+=0.00000004695*cost(0.76880586144+3097.88382272579*x);
R2+=0.00000005391*cost(1.00223256041+3149.16416058820*x);
R2+=0.00000004406*cost(2.45556303355+951.71840625060*x);
R2+=0.00000004286*cost(3.89643520638+1592.59601363280*x);
R2+=0.00000003514*cost(1.85168391963+398.14900340820*x);
R2+=0.00000003699*cost(2.26043707772+20043.67456019880*x);
R2+=0.00000003377*cost(3.81683532672+1751.53953141600*x);
R2+=0.00000004585*cost(0.80787441740+4136.91043351620*x);
R2+=0.00000003201*cost(2.11657635165+5614.72937620960*x);
R2+=0.00000003622*cost(1.32395191387+3333.49887969900*x);
R2+=0.00000002916*cost(1.19337460559+529.69096509460*x);
R2+=0.00000002979*cost(2.86481008776+6151.53388830500*x);
R2+=0.00000003057*cost(4.55276793064+5628.95647021120*x);
R2+=0.00000002906*cost(1.20295377623+3894.18182954220*x);
R2+=0.00000003850*cost(3.86055626689+553.56940284240*x);
R2+=0.00000002820*cost(2.48683324916+1990.74501704100*x);
R2+=0.00000002657*cost(6.07411629964+4292.33083295040*x);
R2+=0.00000002700*cost(2.92139773350+3496.03282613400*x);
R2+=0.00000002395*cost(5.94175921617+2787.04302385740*x);
R2+=0.00000002264*cost(2.56219866409+191.44826611160*x);
R2+=0.00000002167*cost(5.36812435483+8962.45534991020*x);
R2+=0.00000002149*cost(2.74950075397+242.72860397400*x);
R2+=0.00000002217*cost(1.85265984462+3337.08930835080*x);
R2+=0.00000001996*cost(5.76429928131+3341.59274776800*x);
R2+=0.00000001999*cost(3.82349238481+2914.01423582380*x);
R2+=0.00000001835*cost(5.68592723044+1589.07289528380*x);
R2+=0.00000001812*cost(3.32042068028+5088.62883976680*x);
R2+=0.00000002413*cost(4.68291336853+4690.47983635860*x);
R2+=0.00000001970*cost(4.17480610904+3340.59517304760*x);
R2+=0.00000001970*cost(6.20643855008+3340.62968035200*x);
R2+=0.00000001627*cost(5.67733051452+4535.05943692440*x);
R2+=0.00000002160*cost(1.07452599834+2388.89402044920*x);
R2+=0.00000001964*cost(3.10805316088+3583.34103067380*x);
R2+=0.00000001985*cost(5.75850351840+4399.99435688900*x);
R2+=0.00000001507*cost(4.95936409838+382.89653222320*x);
R2+=0.00000001278*cost(4.82232889938+2957.71589447660*x);
R2+=0.00000001475*cost(2.22707926559+3723.50895892300*x);
R2+=0.00000001196*cost(3.26724458920+9492.14631500480*x);
R2+=0.00000001349*cost(4.87573224485+6525.80445396540*x);
R2+=0.00000001433*cost(2.69734916443+7079.37385680780*x);
R2+=0.00000001224*cost(2.62012336714+10025.36039844840*x);
R2+=0.00000001404*cost(5.19056026479+2700.71514038580*x);
R2+=0.00000001202*cost(0.93472783088+2810.92146160520*x);
R2+=0.00000000869*cost(5.81340811635+12303.06777661000*x);
R2+=0.00000000867*cost(2.20046640409+2699.73481931760*x);
R2+=0.00000000830*cost(2.01484544773+5092.15195811580*x);
R2+=0.00000000855*cost(5.96220147975+426.59819087600*x);
R2+=0.00000000848*cost(2.26407047301+6283.07584999140*x);
R2+=0.00000000917*cost(1.40295785881+6489.77658728800*x);
R2+=0.00000000833*cost(1.17384197174+7477.52286021600*x);
R2+=0.00000001041*cost(6.27171470048+3347.72597370060*x);
R2+=0.00000000965*cost(3.39855816541+5621.84292321040*x);
R2+=0.00000000722*cost(4.26304776331+4933.20844033260*x);
R2+=0.00000000706*cost(2.34131594714+7.11354700080*x);
R2+=0.00000000768*cost(2.06208352904+5486.77784317500*x);
R2+=0.00000000953*cost(2.11123497948+3870.30339179440*x);
R2+=0.00000000844*cost(2.23931963240+3553.91152213780*x);
R2+=0.00000000646*cost(2.24669034469+3340.54511639700*x);
R2+=0.00000000653*cost(3.99043329363+6677.70173505060*x);
R2+=0.00000000714*cost(0.29739480601+6681.24210705180*x);
R2+=0.00000000828*cost(0.22863617670+3532.06069281140*x);
R2+=0.00000000612*cost(1.55388376751+7234.79425624200*x);
R2+=0.00000000714*cost(4.54969883976+6681.20759974740*x);
R2+=0.00000000586*cost(3.30118433303+1221.84856632140*x);
R2+=0.00000000646*cost(1.83853693231+3340.67973700260*x);
R2+=0.00000000560*cost(5.05848353328+8031.09226305840*x);
R2+=0.00000000651*cost(0.15897472160+7632.94325965020*x);
R2+=0.00000000488*cost(3.08086378649+6836.64525283380*x);
R2+=0.00000000534*cost(4.25727954634+3339.63210563160*x);
R2+=0.00000000504*cost(2.59990772815+23384.28698689860*x);
R2+=0.00000000372*cost(6.27186983164+2487.41604494780*x);
R2+=0.00000000343*cost(4.71059403854+639.89728631400*x);
R2+=0.00000000449*cost(1.34123846614+640.87760738220*x);
R2+=0.00000000342*cost(5.96338023755+4929.68532198360*x);
R2+=0.00000000329*cost(2.65955258770+9623.68827669120*x);
R2+=0.00000000352*cost(6.09567212646+7740.60678358880*x);
R2+=0.00000000326*cost(6.05498346093+2118.76386037840*x);
R2+=0.00000000403*cost(4.96465831103+8969.56889691100*x);
R2+=0.00000000402*cost(2.84624835384+5331.35744374080*x);
R2+=0.00000000319*cost(1.44545457475+5729.50644714900*x);
R2+=0.00000000303*cost(0.01918776551+6127.65545055720*x);
R2+=0.00000000297*cost(5.74070606294+6041.32756708560*x);
R2+=0.00000000297*cost(3.06763224975+10419.98628350760*x);
R2+=0.00000000282*cost(6.04069352017+7875.67186362420*x);
R2+=0.00000000278*cost(5.11654962157+11773.37681151540*x);
R2+=0.00000000259*cost(2.89786343627+7210.91581849420*x);
R2+=0.00000000273*cost(3.83181794308+8429.24126646660*x);
R2+=0.00000000256*cost(1.08862226474+2288.34404351140*x);
R2+=0.00000000288*cost(6.13572687680+6682.20517446780*x);
R2+=0.00000000302*cost(3.61490647715+12832.75874170460*x);
R2+=0.00000000235*cost(2.21413387615+6681.29216370240*x);
R2+=0.00000000317*cost(3.60634897209+2301.58581590939*x);
R2+=0.00000000289*cost(5.08223311018+2274.11694950980*x);
R2+=0.00000000254*cost(0.36603904729+3767.21061757580*x);
R2+=0.00000000235*cost(2.62434481550+6681.15754309680*x);
R2+=0.00000000226*cost(3.45305949713+6923.95345737360*x);
R2+=0.00000000205*cost(3.88943452829+10018.31416175040*x);
R2+=0.00000000206*cost(3.44453113177+10177.25767953360*x);
R2+=0.00000000210*cost(0.57926734389+10973.55568635000*x);
R2+=0.00000000194*cost(1.57870686859+10818.13528691580*x);
R2+=0.00000000190*cost(2.42312911773+8955.34180290940*x);
R2+=0.00000000194*cost(2.45887376159+7064.12138562280*x);
R2+=0.00000000193*cost(0.58793888724+5828.02847164760*x);
R2+=0.00000000183*cost(1.68247271963+213.29909543800*x);
R2+=0.00000000236*cost(1.98863774162+10575.40668294180*x);
R2+=0.00000000245*cost(2.17761779228+4562.46099302120*x);
R2+=0.00000000177*cost(0.66379705293+10021.85453375160*x);
R2+=0.00000000176*cost(4.91607557961+10021.82002644720*x);
R2+=0.00000000217*cost(2.93968443649+13365.97282514820*x);
R2+=0.00000000167*cost(4.74764434327+3914.95722503460*x);
R2+=0.00000000213*cost(0.15734917857+2942.46342329160*x);
R2+=0.00000000155*cost(1.78776991092+9830.38901398780*x);
R2+=0.00000000180*cost(5.21088564787+9866.41688066520*x);
R2+=0.00000000161*cost(5.17683861380+6298.32832117640*x);
R2+=0.00000000159*cost(2.68980684850+6894.52394883760*x);
R2+=0.00000000149*cost(6.26524493469+1039.02661079040*x);
R2+=0.00000000147*cost(0.36939961702+6688.33840040040*x);
R2+=0.00000000151*cost(1.22272892290+574.34479833480*x);
R2+=0.00000000137*cost(2.09492296067+1066.49547719000*x);
R2+=0.00000000165*cost(6.15952050903+15643.68020330980*x);
R2+=0.00000000163*cost(4.66507592292+8273.82086703240*x);
R2+=0.00000000124*cost(0.67855210339+6438.49624942560*x);
R2+=0.00000000128*cost(1.69206367749+3981.49003408200*x);
R2+=0.00000000116*cost(2.78191248964+3360.96774609859*x);
R2+=0.00000000128*cost(0.84461423001+3355.86489788480*x);
R2+=0.00000000124*cost(1.63253732557+6674.11130639880*x);
R2+=0.00000000120*cost(0.31762150109+3127.31333126180*x);
R2+=0.00000000129*cost(2.26678583645+6467.92575796160*x);
R2+=0.00000000104*cost(0.07355376701+3325.35995551480*x);
R2+=0.00000000130*cost(4.41777190830+3320.25710730100*x);
R2+=0.00000000095*cost(1.31957248342+7903.07341972100*x);
R2+=0.00000000114*cost(0.65681602343+3178.14579056760*x);
R2+=0.00000000092*cost(4.98392367746+9779.10867612540*x);
R2+=0.00000000101*cost(4.10670787374+536.80451209540*x);
R2+=0.00000000106*cost(5.41622566807+15113.98923821520*x);
R2+=0.00000000096*cost(3.52561014696+3475.67750673520*x);
R2+=0.00000000101*cost(2.91169549546+692.15760122680*x);
R2+=0.00000000093*cost(3.21464368291+8671.96987044060*x);
R2+=0.00000000087*cost(5.24375873119+13119.72110282519*x);
R2+=0.00000000106*cost(3.76804681559+13517.87010623340*x);
R2+=0.00000000089*cost(5.73652101746+11371.70468975820*x);
R2+=0.00000000104*cost(5.90078964406+8432.76438481560*x);
R2+=0.00000000099*cost(3.61425346453+853.19638175200*x);
R2+=0.00000000078*cost(0.95802015551+3191.04922956520*x);
R2+=0.00000000089*cost(2.50872076312+1052.26838318840*x);
R2+=0.00000000078*cost(2.98115354616+26724.89941359840*x);
R2+=0.00000000079*cost(5.91514993930+6040.34724601740*x);
R2+=0.00000000090*cost(3.00950470302+12964.30070339100*x);
R2+=0.00000000075*cost(1.31512531841+17924.91069982040*x);
R2+=0.00000000073*cost(5.01153593776+1903.43681250120*x);
R2+=0.00000000075*cost(2.57969241717+10021.90459040220*x);
R2+=0.00000000073*cost(4.09954161905+3319.83703120740*x);
R2+=0.00000000070*cost(5.37678396256+12310.18132361080*x);
R2+=0.00000000071*cost(0.98422998240+13362.46696045140*x);
R2+=0.00000000068*cost(4.69140248943+522.57741809380*x);
R2+=0.00000000068*cost(3.24217441291+16706.58525184800*x);
R2+=0.00000000069*cost(2.53964193741+5884.92684658320*x);
R2+=0.00000000070*cost(2.38237948321+13916.01910964160*x);
R2+=0.00000000066*cost(3.48443797546+13760.59871020740*x);
R2+=0.00000000068*cost(5.27435069681+3980.50971301380*x);
R2+=0.00000000076*cost(0.12288413214+11216.28429032400*x);
R2+=0.00000000073*cost(3.94785759909+16173.37116840440*x);
R2+=0.00000000062*cost(0.15518975647+11081.21921028860*x);
R2+=0.00000000074*cost(2.99926779692+10021.76996979660*x);
R2+=0.00000000080*cost(6.18812323827+9380.95967271720*x);
R2+=0.00000000064*cost(3.99294283669+13358.92658845020*x);
R2+=0.00000000061*cost(2.56817782412+149.56319713460*x);
R2+=0.00000000059*cost(3.80850908229+10264.56588407340*x);
R2+=0.00000000060*cost(4.79879360562+1437.17561419860*x);
R2+=0.00000000068*cost(2.07515658228+1596.18644228460*x);
R2+=0.00000000060*cost(2.26503107747+28628.33622609960*x);
R2+=0.00000000058*cost(6.10782258899+5459.37628707820*x);
R2+=0.00000000063*cost(0.24407077742+18984.29263000960*x);
R2+=0.00000000058*cost(5.22738430747+13362.43245314700*x);
R2+=0.00000000056*cost(1.88708253797+9070.11887384880*x);
R2+=0.00000000055*cost(5.72587156499+433.71173787680*x);
R2+=0.00000000056*cost(1.18238857561+6696.47732458460*x);
R2+=0.00000000062*cost(3.98214740104+3427.92063123960*x);
R2+=0.00000000056*cost(5.37129176649+5099.26550511660*x);
R2+=0.00000000057*cost(0.86204712032+5642.19824260920*x);
R2+=0.00000000055*cost(1.31787605222+8982.81066930900*x);
R2+=0.00000000056*cost(5.49808236951+24093.27678917520*x);
R2+=0.00000000054*cost(3.77562154746+10213.28554621100*x);
R2+=0.00000000054*cost(2.36294643031+33716.96506586640*x);
R2+=0.00000000063*cost(3.53402427573+3205.54734666440*x);
R2+=0.00000000066*cost(6.25810929981+8270.29774868340*x);
R2+=0.00000000067*cost(0.58592813080+3335.08950239240*x);
R2+=0.00000000055*cost(4.74995645767+6660.86953400080*x);
R2+=0.00000000053*cost(0.31930032532+12721.57209941700*x);
R2+=0.00000000069*cost(2.42905593362+6158.64743530580*x);
R2+=0.00000000055*cost(5.03192783121+7255.56965173440*x);
R2+=0.00000000051*cost(5.45351947711+13207.02930736500*x);
R2+=0.00000000050*cost(0.23368526162+4379.63903749020*x);
R2+=0.00000000053*cost(2.12826344020+13171.00144068760*x);
R2+=0.00000000049*cost(2.35512151368+4032.77002792660*x);
R2+=0.00000000049*cost(2.81773050890+9808.53818466140*x);
R2+=0.00000000067*cost(2.26295786556+2766.26762836500*x);
R2+=0.00000000049*cost(0.72597680486+10028.95082710020*x);
R2+=0.00000000050*cost(6.10119450350+3253.30422216000*x);
R2+=0.00000000059*cost(0.27861398526+9225.53927328300*x);
R2+=0.00000000053*cost(1.27330874549+3344.49376205780*x);
R2+=0.00000000049*cost(2.91499389416+10404.73381232260*x);
R2+=0.00000000047*cost(0.48598973231+17395.21973472580*x);
R2+=0.00000000049*cost(3.40240207389+3304.58456002240*x);
R2+=0.00000000060*cost(3.40554368741+10551.52824519400*x);
R2+=0.00000000050*cost(1.83471955355+30376.35263916660*x);
R2+=0.00000000046*cost(3.04980996832+6144.42034130420*x);
R2+=0.00000000049*cost(0.33200904496+6702.00024889200*x);
R2+=0.00000000053*cost(0.35820094732+9468.26787725700*x);
R2+=0.00000000050*cost(0.15378507249+2648.45482547300*x);
R2+=0.00000000044*cost(0.79762157297+7107.82304427560*x);
R2+=0.00000000050*cost(2.41332661328+4407.10790388980*x);
R2+=0.00000000054*cost(0.21682940856+10022.81760116760*x);
R2+=0.00000000044*cost(5.78502737591+3364.49086444760*x);
R2+=0.00000000044*cost(0.75508636274+16062.18452611680*x);
R2+=0.00000000043*cost(3.10581037685+10235.13637553740*x);
R2+=0.00000000044*cost(5.21252098878+7373.38245462640*x);
R2+=0.00000000058*cost(4.51680312444+6660.44945790720*x);
R2+=0.00000000043*cost(0.15523355839+1505.28780909299*x);
R2+=0.00000000055*cost(5.93371026829+8439.87793181640*x);
R2+=0.00000000042*cost(5.40417232308+3344.20285535160*x);
R2+=0.00000000056*cost(3.87534582911+6816.28993343500*x);
R2+=0.00000000049*cost(5.57153056447+17468.85519794540*x);
R2+=0.00000000046*cost(3.07783299049+12722.55242048520*x);
R2+=0.00000000045*cost(1.49303542795+6247.51311552280*x);
R2+=0.00000000055*cost(6.26098836404+3361.38782219220*x);
R2+=0.00000000042*cost(4.74455545491+3369.06161416760*x);
R2+=0.00000000040*cost(1.58676666294+2818.03500860600*x);
R2+=0.00000000043*cost(4.97295184315+3337.02199804800*x);
R2+=0.00000000055*cost(3.80215638520+3376.64029337720*x);
R2+=0.00000000047*cost(1.97367775421+1581.95934828300*x);
R2+=0.00000000045*cost(2.03598705348+5244.04923920100*x);
R2+=0.00000000049*cost(4.43182954044+9595.23908922340*x);
R2+=0.00000000043*cost(0.38914582094+6665.97238221460*x);
R2+=0.00000000040*cost(1.06953099245+23695.12778576700*x);
R2+=0.00000000038*cost(0.59996214864+10713.99488132620*x);
R2+=0.00000000039*cost(3.79055778605+33318.81606245820*x);
R2+=0.00000000041*cost(5.54542347834+3863.18984479360*x);
R2+=0.00000000037*cost(5.27208151144+20752.66436247540*x);
R2+=0.00000000039*cost(3.15412760412+14469.58851248400*x);
R2+=0.00000000041*cost(0.55705920174+3346.13535100720*x);
R2+=0.00000000048*cost(1.42210748234+3316.73398895200*x);
R2+=0.00000000049*cost(5.44942247991+9638.94074787620*x);
R2+=0.00000000038*cost(2.11846271943+15664.03552270859*x);
R2+=0.00000000035*cost(5.30782933148+6677.63442474780*x);
R2+=0.00000000036*cost(2.68151450016+8584.66166590080*x);
R2+=0.00000000046*cost(3.09450395763+6701.58017279840*x);
R2+=0.00000000038*cost(1.81885395671+14158.74771361560*x);
R2+=0.00000000037*cost(5.80483071722+6684.81528205140*x);
R2+=0.00000000047*cost(2.60317702777+162.46663613220*x);
R2+=0.00000000038*cost(2.22559377525+3503.07906283200*x);
R2+=0.00000000035*cost(0.84358942718+6518.75821726740*x);
R2+=0.00000000033*cost(4.92302322062+23141.55838292460*x);
R2+=0.00000000043*cost(0.95148893985+34115.11406927460*x);
R2+=0.00000000046*cost(4.99457196207+9381.93999378540*x);
R2+=0.00000000043*cost(1.73832102244+12323.42309600880*x);
R2+=0.00000000032*cost(2.92741580696+9499.25986200560*x);
R2+=0.00000000043*cost(1.50296327105+27035.74021246680*x);
R2+=0.00000000033*cost(5.41731109688+20597.24396304120*x);
R2+=0.00000000032*cost(4.13881058425+31570.79964939120*x);
R2+=0.00000000040*cost(5.84463069180+16460.33352952499*x);
R2+=0.00000000035*cost(5.50083743557+8425.65083781480*x);
R2+=0.00000000038*cost(5.91991985929+3336.73109134180*x);
R2+=0.00000000030*cost(5.09155042811+5085.03841111500*x);
R2+=0.00000000031*cost(4.27211180916+36659.42848915800*x);
R2+=0.00000000030*cost(4.87389489592+1692.16566950240*x);
R2+=0.00000000030*cost(3.75494646937+4845.90023579280*x);
R2+=0.00000000034*cost(3.71030605417+8827.39026987480*x);
R2+=0.00000000030*cost(0.01599456850+11243.68584642080*x);
R2+=0.00000000029*cost(2.66198696023+12295.95422960920*x);
R2+=0.00000000028*cost(3.12114207206+11925.27409260060*x);
R2+=0.00000000036*cost(1.16568750904+18052.92954315780*x);
R2+=0.00000000032*cost(1.72704226918+12566.15169998280*x);
R2+=0.00000000028*cost(2.80254457895+3607.21946842160*x);
R2+=0.00000000032*cost(4.04390839531+6680.24453233140*x);
R2+=0.00000000027*cost(2.53565904393+19004.64794940840*x);
R2+=0.00000000036*cost(3.33518515689+29978.20363575840*x);
R2+=0.00000000028*cost(0.58104982217+20354.51535906720*x);
R2+=0.00000000029*cost(5.85207825749+31172.65064598300*x);
R2+=0.00000000026*cost(2.22598820379+3.52311834900*x);
R2+=0.00000000033*cost(5.15903548241+10596.18207843420*x);
R2+=0.00000000028*cost(1.89792803028+3333.56619000180*x);
R2+=0.00000000027*cost(2.25129832716+76.26607127560*x);
R2+=0.00000000026*cost(4.32703172263+17085.95866572220*x);
R2+=0.00000000026*cost(5.12847780702+11766.26326451460*x);
R2+=0.00000000028*cost(0.80926596905+20735.83216142559*x);
R2+=0.00000000026*cost(5.06814803493+17412.05193577560*x);
R2+=0.00000000024*cost(4.47399155600+3134.42687826260*x);
R2+=0.00000000024*cost(4.35557152695+14584.29827312060*x);
R2+=0.00000000027*cost(4.98717355201+3877.41693879520*x);
R2+=0.00000000025*cost(5.63712701265+14054.60730802600*x);
R2+=0.00000000024*cost(4.12573657295+4193.80880845180*x);
R2+=0.00000000025*cost(1.40880282063+8186.51266249260*x);
R2+=0.00000000024*cost(4.96463811748+26087.90314157420*x);

double R3=0;
R3+=0.00001113107*cost(5.14987350142+3340.61242669980*x);
R3+=0.00000424446*cost(5.61343766478+6681.22485339960*x);
R3+=0.00000100044*cost(5.99726827028+10021.83728009940*x);
R3+=0.00000019606*cost(0.07633062094+13362.44970679920*x);
R3+=0.00000003477*cost(0.42951907576+16703.06213349900*x);
R3-=0.00000004693;
R3+=0.00000002869*cost(0.44711842697+3344.13554504880*x);
R3+=0.00000002428*cost(3.02115527957+3185.19202726560*x);
R3+=0.00000000688*cost(0.80693359444+6684.74797174860*x);
R3+=0.00000000540*cost(3.86836515672+1059.38193018920*x);
R3+=0.00000000577*cost(0.77853275120+20043.67456019880*x);
R3+=0.00000000468*cost(4.52450786544+3496.03282613400*x);
R3+=0.00000000487*cost(1.60862391345+3583.34103067380*x);
R3+=0.00000000362*cost(4.42397903418+2787.04302385740*x);
R3+=0.00000000397*cost(5.71967986581+3149.16416058820*x);
R3+=0.00000000299*cost(0.75640033535+3738.76143010800*x);
R3+=0.00000000350*cost(5.55691984889+4136.91043351620*x);
R3+=0.00000000314*cost(3.37632898783+6525.80445396540*x);
R3+=0.00000000233*cost(2.13965262306+3097.88382272579*x);
R3+=0.00000000212*cost(4.20487494011+3341.59274776800*x);
R3+=0.00000000214*cost(0.56779556947+155.42039943420*x);
R3+=0.00000000201*cost(2.35284464564+1592.59601363280*x);
R3+=0.00000000204*cost(0.96723315302+1990.74501704100*x);
R3+=0.00000000230*cost(5.82959057146+2388.89402044920*x);
R3+=0.00000000160*cost(4.14974194757+4535.05943692440*x);
R3+=0.00000000156*cost(5.13345210285+796.29800681640*x);
R3+=0.00000000146*cost(3.29541339704+2957.71589447660*x);
R3+=0.00000000156*cost(1.13805508457+10025.36039844840*x);
R3+=0.00000000159*cost(3.76174286126+1194.44701022460*x);
R3+=0.00000000136*cost(5.58293924642+3894.18182954220*x);
R3+=0.00000000145*cost(3.02112488974+3337.08930835080*x);
R3+=0.00000000146*cost(4.25359617225+4399.99435688900*x);
R3+=0.00000000100*cost(4.26740096115+1589.07289528380*x);
R3+=0.00000000091*cost(6.12108227231+6489.77658728800*x);
R3+=0.00000000101*cost(1.17242141914+7079.37385680780*x);
R3+=0.00000000098*cost(1.12613498307+23384.28698689860*x);
R3+=0.00000000075*cost(6.02182689533+529.69096509460*x);
R3+=0.00000000078*cost(5.93418069229+7477.52286021600*x);
R3+=0.00000000068*cost(1.70775041911+9492.14631500480*x);
R3+=0.00000000070*cost(3.67253155189+8962.45534991020*x);
R3+=0.00000000062*cost(4.14954627063+4292.33083295040*x);
R3+=0.00000000067*cost(0.15092246550+3870.30339179440*x);
R3+=0.00000000066*cost(1.12578506413+6151.53388830500*x);
R3+=0.00000000062*cost(1.93984222091+6923.95345737360*x);
R3+=0.00000000060*cost(4.30641513096+12303.06777661000*x);
R3+=0.00000000074*cost(4.72156358149+3347.72597370060*x);
R3+=0.00000000055*cost(2.75742802464+4933.20844033260*x);
R3+=0.00000000053*cost(4.77894621871+6127.65545055720*x);
R3+=0.00000000050*cost(2.57807944338+3340.59517304760*x);
R3+=0.00000000048*cost(3.72532068729+9866.41688066520*x);
R3+=0.00000000042*cost(6.15391373101+7234.79425624200*x);
R3+=0.00000000043*cost(3.43955584179+5486.77784317500*x);
R3+=0.00000000050*cost(4.60885064189+3340.62968035200*x);
R3+=0.00000000044*cost(4.47943289816+426.59819087600*x);
R3+=0.00000000045*cost(6.24485207500+2274.11694950980*x);
R3+=0.00000000040*cost(0.73805316471+7.11354700080*x);
R3+=0.00000000038*cost(1.06497784748+9623.68827669120*x);
R3+=0.00000000041*cost(4.60954640493+6682.20517446780*x);
R3+=0.00000000038*cost(4.60963924082+7740.60678358880*x);
R3+=0.00000000036*cost(3.15129246169+639.89728631400*x);
R3+=0.00000000037*cost(6.14629970622+5729.50644714900*x);
R3+=0.00000000040*cost(1.47395544850+13365.97282514820*x);
R3+=0.00000000035*cost(2.60772245492+4690.47983635860*x);
R3+=0.00000000035*cost(2.45077931900+2288.34404351140*x);
R3+=0.00000000034*cost(4.50544497582+7875.67186362420*x);
R3+=0.00000000042*cost(2.11383330882+12832.75874170460*x);
R3+=0.00000000033*cost(3.97655860802+191.44826611160*x);
R3+=0.00000000032*cost(4.06047154083+3532.06069281140*x);
R3+=0.00000000034*cost(5.06671994554+6681.24210705180*x);
R3+=0.00000000042*cost(4.67024017441+15643.68020330980*x);
R3+=0.00000000036*cost(0.29140871479+3723.50895892300*x);
R3+=0.00000000033*cost(4.52588149629+4929.68532198360*x);
R3+=0.00000000034*cost(2.74499072890+6677.70173505060*x);
R3+=0.00000000030*cost(1.57743012295+10419.98628350760*x);
R3+=0.00000000040*cost(1.31713176335+5331.35744374080*x);
R3+=0.00000000034*cost(3.03490000148+6681.20759974740*x);
R3+=0.00000000031*cost(1.25306164576+242.72860397400*x);
R3+=0.00000000029*cost(5.44118048011+10021.85453375160*x);
R3+=0.00000000029*cost(3.41037097794+10021.82002644720*x);
R3+=0.00000000028*cost(4.81855060968+6836.64525283380*x);
R3+=0.00000000028*cost(0.72745302325+6283.07584999140*x);
R3+=0.00000000030*cost(3.06267495632+2281.23049651060*x);
R3+=0.00000000027*cost(0.62535799761+6681.29216370240*x);
R3+=0.00000000030*cost(3.56389476096+8969.56889691100*x);
R3+=0.00000000032*cost(5.31078691958+553.56940284240*x);
R3+=0.00000000033*cost(2.00753799963+5884.92684658320*x);
R3+=0.00000000027*cost(1.18001479303+8955.34180290940*x);
R3+=0.00000000025*cost(2.94122791628+2544.31441988340*x);
R3+=0.00000000025*cost(0.17808889827+9830.38901398780*x);
R3+=0.00000000031*cost(5.73384204593+3339.63210563160*x);
R3+=0.00000000028*cost(3.70436008855+6298.32832117640*x);
R3+=0.00000000024*cost(0.07739730466+10818.13528691580*x);
R3+=0.00000000027*cost(1.03401737006+6681.15754309680*x);
R3+=0.00000000024*cost(0.09987383242+382.89653222320*x);
R3+=0.00000000027*cost(0.60053652251+3553.91152213780*x);
R3+=0.00000000027*cost(4.97107900859+3767.21061757580*x);
R3+=0.00000000024*cost(3.36621347824+8031.09226305840*x);
R3+=0.00000000026*cost(4.80509833364+7632.94325965020*x);
R3+=0.00000000022*cost(1.43966107077+26724.89941359840*x);
R3+=0.00000000020*cost(0.36901153144+398.14900340820*x);
R3+=0.00000000019*cost(1.00325306041+7064.12138562280*x);
R3+=0.00000000020*cost(0.19821371186+6674.11130639880*x);
R3+=0.00000000018*cost(1.07169297658+7210.91581849420*x);
R3+=0.00000000021*cost(2.69512140340+10018.31416175040*x);
R3+=0.00000000023*cost(3.25670295081+5621.84292321040*x);
R3+=0.00000000018*cost(0.24542781929+3981.49003408200*x);
R3+=0.00000000018*cost(5.14428605713+6688.33840040040*x);
R3+=0.00000000020*cost(0.97539014916+6894.52394883760*x);
R3+=0.00000000024*cost(4.42156401638+1748.01641306700*x);
R3+=0.00000000016*cost(0.65389503440+3340.54511639700*x);
R3+=0.00000000016*cost(5.28427106012+3333.49887969900*x);

double R4=0;
R4+=0.00000019552*cost(3.58211650473+3340.61242669980*x);
R4+=0.00000016323*cost(4.05116076923+6681.22485339960*x);
R4+=0.00000005848*cost(4.46383962094+10021.83728009940*x);
R4+=0.00000001532*cost(4.84374321619+13362.44970679920*x);
R4+=0.00000000375*cost(1.50962233608+3185.19202726560*x);
R4+=0.00000000339*cost(5.20684967613+16703.06213349900*x);
R4+=0.00000000151*cost(5.16472931648+3344.13554504880*x);
R4+=0.00000000125*cost(2.19233532803+3496.03282613400*x);
R4+=0.00000000148;
R4+=0.00000000087*cost(0.10275067375+3583.34103067380*x);
R4+=0.00000000070*cost(5.55303619365+20043.67456019880*x);
R4+=0.00000000048*cost(2.91797786512+2787.04302385740*x);
R4+=0.00000000049*cost(5.57038514830+6684.74797174860*x);
R4+=0.00000000057*cost(1.86867280743+6525.80445396540*x);
R4+=0.00000000034*cost(3.63370917313+3097.88382272579*x);
R4+=0.00000000021*cost(2.30677637991+1059.38193018920*x);
R4+=0.00000000021*cost(4.03682122005+4136.91043351620*x);
R4+=0.00000000018*cost(4.17438755890+3149.16416058820*x);
R4+=0.00000000013*cost(1.97805475719+155.42039943420*x);
R4+=0.00000000017*cost(5.94856414690+10025.36039844840*x);
R4+=0.00000000012*cost(0.51097435253+6923.95345737360*x);
R4+=0.00000000012*cost(3.27945299261+6127.65545055720*x);
R4+=0.00000000013*cost(2.22938285522+9866.41688066520*x);
R4+=0.00000000016*cost(2.64206771227+4399.99435688900*x);
R4+=0.00000000013*cost(2.75813969974+6836.64525283380*x);
R4+=0.00000000013*cost(4.51988349676+6489.77658728800*x);
R4+=0.00000000014*cost(0.76591550754+3894.18182954220*x);
R4+=0.00000000011*cost(5.47381242145+3738.76143010800*x);

double R5=0;
R5+=0.00000000476*cost(2.47617204701+6681.22485339960*x);
R5+=0.00000000268*cost(2.91510547706+10021.83728009940*x);
R5+=0.00000000115*cost(1.76888962311+3340.61242669980*x);
R5+=0.00000000096*cost(3.31378377179+13362.44970679920*x);
R5+=0.00000000048*cost(6.27457828287+3185.19202726560*x);
R5+=0.00000000027*cost(3.69380877066+16703.06213349900*x);
R5+=0.00000000013*cost(3.72005807206+3496.03282613400*x);
R5+=0.00000000012*cost(4.88179002689+3583.34103067380*x);
R5-=0.00000000012;

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
	
return (R0+R1*x+R2*x2+R3*x3+R4*x4+R5*x5); //END MARS
}

//Heliocentric longitude of Jupiter
double Ljupiter(double x)
{
double L0=0;
L0+=0.59954691495;
L0+=0.09695898711*cost(5.06191793105+529.69096509460*x);
L0+=0.00573610145*cost(1.44406205976+7.11354700080*x);
L0+=0.00306389180*cost(5.41734729976+1059.38193018920*x);
L0+=0.00097178280*cost(4.14264708819+632.78373931320*x);
L0+=0.00072903096*cost(3.64042909255+522.57741809380*x);
L0+=0.00064263986*cost(3.41145185203+103.09277421860*x);
L0+=0.00039806051*cost(2.29376744855+419.48464387520*x);
L0+=0.00038857780*cost(1.27231724860+316.39186965660*x);
L0+=0.00027964622*cost(1.78454589485+536.80451209540*x);
L0+=0.00013589738*cost(5.77481031590+1589.07289528380*x);
L0+=0.00008246362*cost(3.58227961655+206.18554843720*x);
L0+=0.00008768686*cost(3.63000324417+949.17560896980*x);
L0+=0.00007368057*cost(5.08101125612+735.87651353180*x);
L0+=0.00006263171*cost(0.02497643742+213.29909543800*x);
L0+=0.00006114050*cost(4.51319531666+1162.47470440780*x);
L0+=0.00004905419*cost(1.32084631684+110.20632121940*x);
L0+=0.00005305283*cost(1.30671236848+14.22709400160*x);
L0+=0.00005305457*cost(4.18625053495+1052.26838318840*x);
L0+=0.00004647249*cost(4.69958109497+3.93215326310*x);
L0+=0.00003045009*cost(4.31675960318+426.59819087600*x);
L0+=0.00002610001*cost(1.56667594850+846.08283475120*x);
L0+=0.00002028191*cost(1.06376547379+3.18139373770*x);
L0+=0.00001764768*cost(2.14148077766+1066.49547719000*x);
L0+=0.00001722983*cost(3.88036008872+1265.56747862640*x);
L0+=0.00001920959*cost(0.97168928755+639.89728631400*x);
L0+=0.00001633217*cost(3.58201089758+515.46387109300*x);
L0+=0.00001431997*cost(4.29683690269+625.67019231240*x);
L0+=0.00000973278*cost(4.09764957065+95.97922721780*x);
L0+=0.00000884439*cost(2.43701426123+412.37109687440*x);
L0+=0.00000732875*cost(6.08534113239+838.96928775040*x);
L0+=0.00000731072*cost(3.80591233956+1581.95934828300*x);
L0+=0.00000691928*cost(6.13368222939+2118.76386037840*x);
L0+=0.00000709190*cost(1.29272573658+742.99006053260*x);
L0+=0.00000614464*cost(4.10853496756+1478.86657406440*x);
L0+=0.00000495224*cost(3.75567461379+323.50541665740*x);
L0+=0.00000581902*cost(4.53967717552+309.27832265580*x);
L0+=0.00000375657*cost(4.70299124833+1368.66025284500*x);
L0+=0.00000389864*cost(4.89716105852+1692.16566950240*x);
L0+=0.00000341006*cost(5.71452525783+533.62311835770*x);
L0+=0.00000330458*cost(4.74049819491+0.04818410980*x);
L0+=0.00000440854*cost(2.95818460943+454.90936652730*x);
L0+=0.00000417266*cost(1.03554430161+2.44768055480*x);
L0+=0.00000244170*cost(5.22020878900+728.76296653100*x);
L0+=0.00000261540*cost(1.87652461032+0.96320784650*x);
L0+=0.00000256568*cost(3.72410724159+199.07200143640*x);
L0+=0.00000261009*cost(0.82047246448+380.12776796000*x);
L0+=0.00000220382*cost(1.65115015995+543.91805909620*x);
L0+=0.00000201996*cost(1.80684574186+1375.77379984580*x);
L0+=0.00000207327*cost(1.85461666594+525.75881183150*x);
L0+=0.00000197046*cost(5.29252149016+1155.36115740700*x);
L0+=0.00000235141*cost(1.22693908124+909.81873305460*x);
L0+=0.00000174809*cost(5.90973505276+956.28915597060*x);
L0+=0.00000149368*cost(4.37745104275+1685.05212250160*x);
L0+=0.00000175184*cost(3.22634903433+1898.35121793960*x);
L0+=0.00000175191*cost(3.72966554761+942.06206196900*x);
L0+=0.00000157909*cost(4.36483921766+1795.25844372100*x);
L0+=0.00000137871*cost(1.31797920785+1169.58825140860*x);
L0+=0.00000117495*cost(2.50022140890+1596.18644228460*x);
L0+=0.00000150502*cost(3.90625022622+74.78159856730*x);
L0+=0.00000116757*cost(3.38920921041+0.52126486180*x);
L0+=0.00000105895*cost(4.55439798236+526.50957135690*x);
L0+=0.00000130531*cost(4.16867945489+1045.15483618760*x);
L0+=0.00000141445*cost(3.13568357861+491.55792945680*x);
L0+=0.00000099511*cost(1.42117395747+532.87235883230*x);
L0+=0.00000096137*cost(1.18156870005+117.31986822020*x);
L0+=0.00000091758*cost(0.85756633461+1272.68102562720*x);
L0+=0.00000087695*cost(1.21738140813+453.42489381900*x);
L0+=0.00000068507*cost(2.35242959478+2.92076130680*x);
L0+=0.00000066098*cost(5.34386149468+1471.75302706360*x);
L0+=0.00000077401*cost(4.42676337124+39.35687591520*x);
L0+=0.00000072006*cost(4.23834923691+2111.65031337760*x);
L0+=0.00000063406*cost(4.97665525033+0.75075952540*x);
L0+=0.00000059427*cost(4.11130498612+2001.44399215820*x);
L0+=0.00000062481*cost(0.51211384012+220.41264243880*x);
L0+=0.00000066532*cost(2.98864358135+2214.74308759620*x);
L0+=0.00000060194*cost(4.12628179571+4.19278569400*x);
L0+=0.00000056012*cost(1.15493222602+21.34064100240*x);
L0+=0.00000052854*cost(0.91207215543+10.29494073850*x);
L0+=0.00000070297*cost(5.14180555282+835.03713448730*x);
L0+=0.00000051916*cost(4.10048180020+1258.45393162560*x);
L0+=0.00000046442*cost(4.66531163524+5.62907429250*x);
L0+=0.00000058190*cost(5.86646380344+5753.38488489680*x);
L0+=0.00000040103*cost(4.68801114087+0.16005869440*x);
L0+=0.00000046654*cost(4.79394835282+305.34616939270*x);
L0+=0.00000039298*cost(4.25448423697+853.19638175200*x);
L0+=0.00000046042*cost(5.10983515150+4.66586644600*x);
L0+=0.00000054459*cost(1.57072704127+983.11585891360*x);
L0+=0.00000038920*cost(6.07592905580+518.64526483070*x);
L0+=0.00000038450*cost(2.43836870888+433.71173787680*x);
L0+=0.00000046800*cost(3.54640538283+5.41662597140*x);
L0+=0.00000041830*cost(4.67982493646+302.16477565500*x);
L0+=0.00000035920*cost(2.45088036239+430.53034413910*x);
L0+=0.00000037888*cost(0.21127448431+2648.45482547300*x);
L0+=0.00000039190*cost(1.71835571629+11.04570026390*x);
L0+=0.00000037567*cost(6.19481310233+831.85574074960*x);
L0+=0.00000035828*cost(4.61459907698+2008.55753915900*x);
L0+=0.00000043402*cost(0.14992289081+528.20649238630*x);
L0+=0.00000031598*cost(5.14073450755+1788.14489672020*x);
L0+=0.00000029849*cost(5.34441117167+2221.85663459700*x);
L0+=0.00000032811*cost(5.28907118836+88.86568021700*x);
L0+=0.00000027686*cost(1.85227036207+0.21244832110*x);
L0+=0.00000025820*cost(3.85920882494+2317.83586181480*x);
L0+=0.00000024705*cost(2.63495214991+114.13847448250*x);
L0+=0.00000033844*cost(1.00563073268+9683.59458111640*x);
L0+=0.00000024266*cost(3.82355417268+1574.84580128220*x);
L0+=0.00000027111*cost(2.80845435102+18.15924726470*x);
L0+=0.00000026837*cost(1.77586123775+532.13864564940*x);
L0+=0.00000026064*cost(2.74361318804+2531.13495725280*x);
L0+=0.00000030765*cost(0.42330537728+1.48447270830*x);
L0+=0.00000030476*cost(3.66677894407+508.35032409220*x);
L0+=0.00000023282*cost(3.24372142416+984.60033162190*x);
L0+=0.00000019445*cost(0.52370214471+14.97785352700*x);
L0+=0.00000019332*cost(4.86314494382+1361.54670584420*x);
L0+=0.00000022910*cost(3.84914895064+2428.04218303420*x);
L0+=0.00000021617*cost(6.01696940024+1063.31408345230*x);
L0+=0.00000020155*cost(5.59582008789+527.24328453980*x);
L0+=0.00000023732*cost(2.52766031921+494.26624244250*x);
L0+=0.00000020189*cost(1.01560227681+628.85158605010*x);
L0+=0.00000015994*cost(5.09003530653+529.73914920440*x);
L0+=0.00000016134*cost(5.27095037302+142.44965013380*x);
L0+=0.00000020697*cost(4.03443281612+355.74874557180*x);
L0+=0.00000021479*cost(1.28668134295+35.42472265210*x);
L0+=0.00000014964*cost(4.86039684390+2104.53676637680*x);
L0+=0.00000017242*cost(1.59187913206+1439.50969814920*x);
L0+=0.00000015994*cost(1.89222417794+529.64278098480*x);
L0+=0.00000017958*cost(4.30178016003+6.15033915430*x);
L0+=0.00000013279*cost(2.18943981644+1055.44977692610*x);
L0+=0.00000014148*cost(2.71597731671+0.26063243090*x);
L0+=0.00000014689*cost(0.87944553412+99.16062095550*x);
L0+=0.00000014202*cost(2.41335693735+530.65417294110*x);
L0+=0.00000015320*cost(6.07703092728+149.56319713460*x);
L0+=0.00000015832*cost(4.11682440678+636.71589257630*x);
L0+=0.00000012398*cost(2.61042299578+405.25754987360*x);
L0+=0.00000016199*cost(2.77035044582+760.25553592000*x);
L0+=0.00000013665*cost(3.56039678310+217.23124870110*x);
L0+=0.00000015261*cost(2.81824770887+621.73803904930*x);
L0+=0.00000014681*cost(6.26423732742+569.04784100980*x);
L0+=0.00000012529*cost(1.39077179081+7.06536289100*x);
L0+=0.00000011677*cost(3.60447374272+2634.22773147140*x);
L0+=0.00000011603*cost(4.60461756191+7.16173111060*x);
L0+=0.00000012152*cost(0.24540531919+1485.98012106520*x);
L0+=0.00000011347*cost(2.00818458261+1073.60902419080*x);
L0+=0.00000011242*cost(2.48000947870+423.41679713830*x);
L0+=0.00000010942*cost(5.03602448252+458.84151979040*x);
L0+=0.00000011117*cost(4.04973271023+519.39602435610*x);
L0+=0.00000012256*cost(4.30153222783+604.47256366190*x);
L0+=0.00000013149*cost(2.72189077702+1364.72809958190*x);
L0+=0.00000010604*cost(3.11518747072+1.27202438720*x);
L0+=0.00000009874*cost(1.70200068743+1699.27921650320*x);
L0+=0.00000010851*cost(5.08554552028+2324.94940881560*x);
L0+=0.00000010692*cost(2.51401681528+2847.52682690940*x);
L0+=0.00000012640*cost(4.75572797691+528.72775724810*x);
L0+=0.00000010084*cost(4.05599810206+38.13303563780*x);
L0+=0.00000011536*cost(2.35034215745+643.82943957710*x);
L0+=0.00000010247*cost(3.63479911496+2744.43405269080*x);
L0+=0.00000010105*cost(3.65845333837+107.02492748170*x);
L0+=0.00000010121*cost(1.31482648275+1905.46476494040*x);
L0+=0.00000009341*cost(5.92176693887+1148.24761040620*x);
L0+=0.00000008796*cost(2.77421822809+6.59228213900*x);
L0+=0.00000008420*cost(4.52537756809+1677.93857550080*x);
L0+=0.00000010128*cost(2.09034472544+511.53171782990*x);
L0+=0.00000008272*cost(2.98682673354+540.73666535850*x);
L0+=0.00000009753*cost(1.22438911827+32.24332891440*x);
L0+=0.00000010630*cost(2.07777800288+92.04707395470*x);
L0+=0.00000007850*cost(0.98996894618+408.43894361130*x);
L0+=0.00000008811*cost(3.46911754939+1021.24889455140*x);
L0+=0.00000007946*cost(2.86682926070+2125.87740737920*x);
L0+=0.00000008575*cost(5.29590411702+415.55249061210*x);
L0+=0.00000007841*cost(6.08025056721+70.84944530420*x);
L0+=0.00000007706*cost(1.69832954219+8.07675484730*x);
L0+=0.00000007265*cost(4.65503563919+629.60234557550*x);
L0+=0.00000007164*cost(4.93400217968+1056.20053645150*x);
L0+=0.00000007247*cost(4.61607677560+2420.92863603340*x);
L0+=0.00000007753*cost(2.12871653382+33.94024994380*x);
L0+=0.00000006645*cost(0.45647460873+635.96513305090*x);
L0+=0.00000009377*cost(4.03158388202+2810.92146160520*x);
L0+=0.00000008263*cost(1.23558676139+1802.37199072180*x);
L0+=0.00000006341*cost(0.07278001580+202.25339517410*x);
L0+=0.00000006383*cost(3.54310669809+1891.23767093880*x);
L0+=0.00000007902*cost(2.32510002614+230.56457082540*x);
L0+=0.00000006214*cost(4.54560345237+2.70831298570*x);
L0+=0.00000007347*cost(1.24457237337+24.37902238820*x);
L0+=0.00000007451*cost(3.02719199239+330.61896365820*x);
L0+=0.00000006220*cost(1.77687561489+1062.56332392690*x);
L0+=0.00000005674*cost(5.14132196367+746.92221379570*x);
L0+=0.00000005855*cost(5.42130172896+28.31117565130*x);
L0+=0.00000005629*cost(3.24348217277+529.16970023280*x);
L0+=0.00000007652*cost(0.52813391052+672.14061522840*x);
L0+=0.00000005456*cost(3.34716871364+2950.61960112800*x);
L0+=0.00000007127*cost(1.43497795005+6.21977512350*x);
L0+=0.00000005388*cost(4.90175095580+69.15252427480*x);
L0+=0.00000005618*cost(4.97903783721+2641.34127847220*x);
L0+=0.00000005844*cost(2.95364118152+490.33408917940*x);
L0+=0.00000004943*cost(5.37597740579+721.64941953020*x);
L0+=0.00000005062*cost(4.84282906467+31.01948863700*x);
L0+=0.00000005163*cost(5.07410777073+67.66805156650*x);
L0+=0.00000004739*cost(6.10248862834+106.27416795630*x);
L0+=0.00000004879*cost(0.07095292379+78.71375183040*x);
L0+=0.00000004854*cost(5.63875661096+1.69692102940*x);
L0+=0.00000005629*cost(3.73871604865+530.21222995640*x);
L0+=0.00000004471*cost(4.49152882547+505.31194270640*x);
L0+=0.00000004313*cost(4.79369370451+535.10759106600*x);
L0+=0.00000004280*cost(0.54783823710+1.43628859850*x);
L0+=0.00000004453*cost(0.50551854591+524.06189080210*x);
L0+=0.00000004936*cost(4.82992988255+422.66603761290*x);
L0+=0.00000004701*cost(3.41634869046+3060.82592234740*x);
L0+=0.00000004261*cost(2.67044686458+561.93429400900*x);
L0+=0.00000004156*cost(4.00660658688+99.91138048090*x);
L0+=0.00000004561*cost(2.29650164054+3163.91869656600*x);
L0+=0.00000004414*cost(5.67224020329+1464.63948006280*x);
L0+=0.00000005345*cost(0.31513851830+1289.94650101460*x);
L0+=0.00000005269*cost(3.89116469022+191.95845443560*x);
L0+=0.00000003855*cost(4.28942301453+1994.33044515740*x);
L0+=0.00000004210*cost(5.32763589447+2538.24850425360*x);
L0+=0.00000003949*cost(4.56507101172+1382.88734684660*x);
L0+=0.00000003885*cost(1.56778786810+647.01083331480*x);
L0+=0.00000004227*cost(5.51697599030+5223.69391980220*x);
L0+=0.00000004129*cost(2.81119457666+416.30325013750*x);
L0+=0.00000003663*cost(4.35187510477+2737.32050569000*x);
L0+=0.00000003566*cost(5.48243943375+750.10360753340*x);
L0+=0.00000004330*cost(0.84941756640+531.17543780290*x);
L0+=0.00000004093*cost(0.19980340452+525.02509864860*x);
L0+=0.00000004022*cost(1.92293311337+1512.80682400820*x);
L0+=0.00000003400*cost(6.00302355875+1.22384027740*x);
L0+=0.00000003496*cost(0.31252921473+597.35901666110*x);
L0+=0.00000003299*cost(4.27596694481+526.77020378780*x);
L0+=0.00000003226*cost(2.90455264496+963.40270297140*x);
L0+=0.00000003150*cost(3.81061764181+280.96714700450*x);
L0+=0.00000004129*cost(4.74946631331+0.89377187730*x);
L0+=0.00000003840*cost(1.91064405186+378.64329525170*x);
L0+=0.00000003057*cost(1.65589659685+528.94020556920*x);
L0+=0.00000003011*cost(1.59276337369+224.34479570190*x);
L0+=0.00000003196*cost(5.86588452873+4.14460158420*x);
L0+=0.00000003628*cost(0.07930225897+558.00214074590*x);
L0+=0.00000002932*cost(0.41424445089+7.86430652620*x);
L0+=0.00000003316*cost(2.70211697795+532.61172640140*x);
L0+=0.00000002925*cost(4.47580363425+533.88375078860*x);
L0+=0.00000003690*cost(0.39897023849+685.47393735270*x);
L0+=0.00000003223*cost(2.45833032883+960.22130923370*x);
L0+=0.00000003059*cost(5.32616140812+530.44172462000*x);
L0+=0.00000003383*cost(4.42170370028+312.45971639350*x);
L0+=0.00000003320*cost(2.71417812514+495.75071515080*x);
L0+=0.00000002697*cost(5.23146633437+739.80866679490*x);
L0+=0.00000003590*cost(2.30999595873+908.33426034630*x);
L0+=0.00000003677*cost(5.07337955976+73.29712585900*x);
L0+=0.00000002618*cost(3.09118499149+3267.01147078460*x);
L0+=0.00000002796*cost(2.98942316119+483.22054217860*x);
L0+=0.00000003398*cost(3.29598270278+911.30320576290*x);
L0+=0.00000003352*cost(1.44391979336+593.42686339800*x);
L0+=0.00000002563*cost(3.35080110279+2207.62954059540*x);
L0+=0.00000002553*cost(0.36892288645+1048.33622992530*x);
L0+=0.00000002620*cost(3.82769874340+520.12973753900*x);
L0+=0.00000003356*cost(1.08315053878+46.47042291600*x);
L0+=0.00000003035*cost(5.52230028113+618.55664531160*x);
L0+=0.00000003397*cost(3.83084746522+210.11770170030*x);
L0+=0.00000002497*cost(0.47917884538+945.24345570670*x);
L0+=0.00000002341*cost(5.87941292649+2751.54759969160*x);
L0+=0.00000002656*cost(0.49713061045+1057.89745748090*x);
L0+=0.00000002581*cost(0.03759881914+1.64453140270*x);
L0+=0.00000002900*cost(2.50019054587+525.49817940060*x);
L0+=0.00000003153*cost(2.30900986177+457.61767951300*x);
L0+=0.00000002201*cost(3.94367109739+31.49256938900*x);
L0+=0.00000002381*cost(6.19252134885+327.43756992050*x);
L0+=0.00000002458*cost(0.65614291954+9153.90361602180*x);
L0+=0.00000002111*cost(5.61905648764+16.46232623530*x);
L0+=0.00000002130*cost(3.75880734109+724.83081326790*x);
L0+=0.00000002406*cost(2.29315649755+195.13984817330*x);
L0+=0.00000002166*cost(5.43262641046+534.35683154060*x);
L0+=0.00000002057*cost(1.49875151278+551.03160609700*x);
L0+=0.00000002676*cost(5.06374981112+456.39383923560*x);
L0+=0.00000002078*cost(5.28920097886+76.26607127560*x);
L0+=0.00000002261*cost(5.38117230692+1781.03134971940*x);
L0+=0.00000002356*cost(0.67392574097+227.52618943960*x);
L0+=0.00000002240*cost(3.18006978517+3377.21779200400*x);
L0+=0.00000002183*cost(3.08384250950+524.27433912320*x);
L0+=0.00000002119*cost(2.70107659927+387.24131496080*x);
L0+=0.00000002056*cost(4.82779196994+2957.73314812880*x);
L0+=0.00000002116*cost(6.20263841494+209.36694217490*x);
L0+=0.00000002712*cost(3.18157754631+1474.67378837040*x);
L0+=0.00000002127*cost(1.24424012514+539.98590583310*x);
L0+=0.00000002424*cost(3.57595925853+953.10776223290*x);
L0+=0.00000001947*cost(1.94468082546+529.53090640020*x);
L0+=0.00000001896*cost(4.01406242800+2310.72231481400*x);
L0+=0.00000001935*cost(4.10051493950+3053.71237534660*x);
L0+=0.00000002056*cost(6.27074148550+245.54242435240*x);
L0+=0.00000002108*cost(3.22886474225+252.65597135320*x);
L0+=0.00000002596*cost(2.77467278614+177.87437278590*x);
L0+=0.00000001919*cost(3.14834694111+381.61224066830*x);
L0+=0.00000002217*cost(1.92368906925+535.91074021810*x);
L0+=0.00000001947*cost(5.03751780002+529.85102378900*x);
L0+=0.00000002025*cost(4.82814272957+17.26547538740*x);
L0+=0.00000001945*cost(2.10611582568+3480.31056622260*x);
L0+=0.00000001899*cost(0.05104263891+560.71045373160*x);
L0+=0.00000002221*cost(0.58365090630+3178.14579056760*x);
L0+=0.00000002271*cost(1.67360565619+731.94436026870*x);
L0+=0.00000001706*cost(5.40277333462+20.44686912510*x);
L0+=0.00000002295*cost(4.20863103004+1038.04128918680*x);
L0+=0.00000002218*cost(3.65982280555+282.45161971280*x);
L0+=0.00000002181*cost(4.87369503022+535.32003938710*x);
L0+=0.00000001745*cost(1.34021867874+25.12978191360*x);
L0+=0.00000001601*cost(3.92730015840+17.52610781830*x);
L0+=0.00000001651*cost(0.63598292839+17.40848773930*x);
L0+=0.00000001826*cost(0.31592311031+124.43341522100*x);
L0+=0.00000002041*cost(0.15617294873+598.84348936940*x);
L0+=0.00000001494*cost(3.81418025130+319.57326339430*x);
L0+=0.00000001551*cost(5.25201528605+437.64389113990*x);
L0+=0.00000001852*cost(2.36130812462+37.87240320690*x);
L0+=0.00000001466*cost(1.72926380881+59.80374504030*x);
L0+=0.00000001417*cost(5.82273267086+81.75213321620*x);
L0+=0.00000001430*cost(1.17528806260+440.82528487760*x);
L0+=0.00000001906*cost(4.06896022692+1819.63746610920*x);
L0+=0.00000001397*cost(0.26383366743+50.40257617910*x);
L0+=0.00000001756*cost(2.32977483716+938.12990870590*x);
L0+=0.00000001487*cost(2.24866746540+10.03430830760*x);
L0+=0.00000001368*cost(3.56691602771+1514.29129671650*x);
L0+=0.00000001400*cost(4.84502200703+295.05122865420*x);
L0+=0.00000001344*cost(2.20177702122+529.90341341570*x);
L0+=0.00000001464*cost(1.42648716568+1158.54255114470*x);
L0+=0.00000001341*cost(1.15693423225+2435.15573003500*x);
L0+=0.00000001786*cost(5.44716330146+2854.64037391020*x);
L0+=0.00000001677*cost(6.22875777048+833.55266177900*x);
L0+=0.00000001471*cost(4.80574535807+696.51963761660*x);
L0+=0.00000001436*cost(1.45810957330+537.76771994190*x);
L0+=0.00000001657*cost(0.02890651793+138.51749687070*x);
L0+=0.00000001300*cost(3.14074420421+547.85021235930*x);
L0+=0.00000001343*cost(6.14827138025+988.53248488500*x);
L0+=0.00000001344*cost(4.78042160426+529.47851677350*x);
L0+=0.00000001234*cost(2.83294330979+3583.40334044120*x);
L0+=0.00000001651*cost(2.12056447005+1061.82961074400*x);
L0+=0.00000001479*cost(0.24646493075+1593.00504854690*x);
L0+=0.00000001413*cost(3.07444632745+6283.07584999140*x);
L0+=0.00000001246*cost(5.94882321661+1056.93424963440*x);
L0+=0.00000001225*cost(1.95642397635+1969.20066324380*x);
L0+=0.00000001388*cost(2.87749576073+1023.95720753710*x);
L0+=0.00000001263*cost(3.46181945031+40.84134862350*x);
L0+=0.00000001325*cost(4.15429781246+916.93228005540*x);
L0+=0.00000001477*cost(5.26691818477+810.65811209910*x);
L0+=0.00000001165*cost(4.65528125418+944.98282327580*x);
L0+=0.00000001137*cost(2.48561382158+2.00573757010*x);
L0+=0.00000001118*cost(3.80747957482+7.00167241620*x);
L0+=0.00000001138*cost(5.11611532241+885.43971066640*x);
L0+=0.00000001131*cost(1.54599459004+775.23338944700*x);
L0+=0.00000001477*cost(4.69742954455+630.33605875840*x);
L0+=0.00000001252*cost(1.34316620527+739.05790726950*x);
L0+=0.00000001273*cost(5.19070939905+2097.42321937600*x);
L0+=0.00000001446*cost(5.54999644374+43.28902917830*x);
L0+=0.00000001344*cost(4.75897665313+1166.40685767090*x);
L0+=0.00000001101*cost(4.56997613488+3274.12501778540*x);
L0+=0.00000001376*cost(3.60998729004+415.29185818120*x);
L0+=0.00000001437*cost(6.22410093972+155.78297225810*x);
L0+=0.00000001167*cost(4.09497264272+203.00415469950*x);
L0+=0.00000001237*cost(4.41132627005+292.01284726840*x);
L0+=0.00000001077*cost(2.57045229823+25.27279426550*x);
L0+=0.00000001341*cost(0.49262296655+635.23141986800*x);
L0+=0.00000001209*cost(3.36289125536+521.61421024730*x);
L0+=0.00000001030*cost(1.81822316284+465.95506679120*x);
L0+=0.00000001002*cost(3.21720955284+2524.02141025200*x);
L0+=0.00000001338*cost(1.26054917773+902.70518605380*x);
L0+=0.00000001037*cost(3.87858871885+3370.10424500320*x);
L0+=0.00000001224*cost(0.09219976028+824.74219374880*x);
L0+=0.00000001255*cost(3.04675952762+447.79581952650*x);
L0+=0.00000000991*cost(4.16587903812+632.83192342300*x);
L0+=0.00000000975*cost(3.80216680539+2627.11418447060*x);
L0+=0.00000001061*cost(5.60184374277+732.69511979410*x);
L0+=0.00000001049*cost(2.94931080683+3693.60966166060*x);
L0+=0.00000000984*cost(0.98260254313+632.73555520340*x);
L0+=0.00000001050*cost(2.20935815967+7.22542158540*x);
L0+=0.00000000996*cost(5.41921062583+1059.43011429900*x);
L0+=0.00000000961*cost(0.87315283361+544.66881862160*x);
L0+=0.00000001175*cost(3.09093466406+1894.41906467650*x);
L0+=0.00000001049*cost(5.81616384906+26.82670294300*x);
L0+=0.00000001161*cost(0.01274801567+850.01498801430*x);
L0+=0.00000001109*cost(3.63294273717+306.83064210100*x);
L0+=0.00000001077*cost(0.95716576092+608.40471692500*x);
L0+=0.00000001288*cost(4.23019288942+1215.16490244730*x);
L0+=0.00000001060*cost(3.85856787901+631.82053146670*x);
L0+=0.00000001251*cost(6.15889818604+462.02291352810*x);
L0+=0.00000001165*cost(3.50653563773+8.59801970910*x);
L0+=0.00000000933*cost(4.62559759882+1049.08698945070*x);
L0+=0.00000001035*cost(1.30805283339+633.74694715970*x);
L0+=0.00000001238*cost(2.21195391602+25558.21217647960*x);
L0+=0.00000001240*cost(2.27960685992+6.90109867970*x);
L0+=0.00000000942*cost(4.14526324371+945.99421523210*x);
L0+=0.00000000927*cost(6.10893117637+514.71311156760*x);
L0+=0.00000000914*cost(6.17656044376+952.35700270750*x);
L0+=0.00000000893*cost(4.27448748055+0.63313944640*x);
L0+=0.00000001045*cost(1.64682770236+565.11568774670*x);
L0+=0.00000000903*cost(1.94250156640+3796.70243587920*x);
L0+=0.00000001162*cost(5.51229668479+2.96894541660*x);
L0+=0.00000000901*cost(3.03568112112+460.53844081980*x);
L0+=0.00000000903*cost(2.24012822393+523.54062594030*x);
L0+=0.00000001060*cost(5.28027224466+3171.03224356680*x);
L0+=0.00000001064*cost(0.99330150801+320.32402291970*x);
L0+=0.00000000970*cost(4.56607888439+429.04587143080*x);
L0+=0.00000001071*cost(4.33203090957+610.69233878540*x);
L0+=0.00000000865*cost(0.21831429230+1098.73880610440*x);
L0+=0.00000000865*cost(2.82123742108+1060.34513803570*x);
L0+=0.00000000882*cost(4.80076824948+384.05992122310*x);
L0+=0.00000000959*cost(5.45468005818+451.94042111070*x);
L0+=0.00000001042*cost(5.79270325150+303.86169668440*x);
L0+=0.00000000784*cost(1.85150700827+313.21047591890*x);
L0+=0.00000001083*cost(1.40526460812+72.07328558160*x);
L0+=0.00000000782*cost(3.03559242565+5.84152261360*x);
L0+=0.00000000854*cost(1.22236205478+611.44309831080*x);
L0+=0.00000000996*cost(2.22139794743+1059.33374607940*x);
L0+=0.00000000719*cost(4.92550252164+421.93232443000*x);
L0+=0.00000000953*cost(3.98347050083+836.52160719560*x);
L0+=0.00000000822*cost(4.49679856387+10213.28554621100*x);
L0+=0.00000000707*cost(2.16473400319+2228.97018159780*x);
L0+=0.00000000715*cost(4.62515255534+385.54439393140*x);
L0+=0.00000000737*cost(4.63776694324+1134.16352875650*x);
L0+=0.00000000730*cost(1.87179326186+153.49535039770*x);
L0+=0.00000000709*cost(2.93132115910+417.03696332040*x);
L0+=0.00000000926*cost(1.77006317007+2332.06295581640*x);
L0+=0.00000000864*cost(3.03246275970+1041.22268292450*x);
L0+=0.00000000708*cost(6.01601101389+395.10562148700*x);
L0+=0.00000000935*cost(6.01864676296+173.94221952280*x);
L0+=0.00000000695*cost(1.39408383356+432.01481684740*x);
L0+=0.00000000687*cost(3.06548397586+529.95159752550*x);
L0+=0.00000000677*cost(3.58357527210+244.31858407500*x);
L0+=0.00000000850*cost(5.46114025921+41.05379694460*x);
L0+=0.00000000817*cost(4.65315342412+535.84130424890*x);
L0+=0.00000000652*cost(0.44173759183+1201.83158032300*x);
L0+=0.00000000711*cost(0.96283289310+373.01422095920*x);
L0+=0.00000000665*cost(1.03244633471+623.22251175760*x);
L0+=0.00000000643*cost(5.05335060049+522.62560220360*x);
L0+=0.00000000639*cost(4.22718483639+25.86349509650*x);
L0+=0.00000000718*cost(5.07576900710+1058.41872234270*x);
L0+=0.00000000664*cost(2.43728454444+1585.14074202070*x);
L0+=0.00000000833*cost(1.49468440213+563.63121503840*x);
L0+=0.00000000760*cost(4.34849823663+100.64509366380*x);
L0+=0.00000000633*cost(4.31796718640+3590.51688744200*x);
L0+=0.00000000629*cost(6.23431126402+679.25416222920*x);
L0+=0.00000000617*cost(2.68075016456+3899.79521009780*x);
L0+=0.00000000646*cost(2.88581188015+13.49338081870*x);
L0+=0.00000000768*cost(3.18498076120+1151.42900414390*x);
L0+=0.00000000731*cost(5.86653168561+501.37978944330*x);
L0+=0.00000000652*cost(0.82865771780+2015.67108615980*x);
L0+=0.00000000796*cost(5.36663489938+420.96911658350*x);
L0+=0.00000000647*cost(4.74965662438+567.82400073240*x);
L0+=0.00000000845*cost(1.69406147722+1744.85586754190*x);
L0+=0.00000000802*cost(5.79824707751+981.63138620530*x);
L0+=0.00000000764*cost(5.05232933368+827.92358748650*x);
L0+=0.00000000604*cost(5.11265182908+1159.29331067010*x);
L0+=0.00000000682*cost(3.68248136835+2281.23049651060*x);
L0+=0.00000000740*cost(0.74512356954+1261.63532536330*x);
L0+=0.00000000666*cost(2.06624389616+27.08733537390*x);
L0+=0.00000000652*cost(4.92932795958+2413.81508903260*x);
L0+=0.00000000559*cost(0.17558868481+63.73589830340*x);
L0+=0.00000000577*cost(3.82752312276+1550.93985964600*x);
L0+=0.00000000727*cost(1.05835550856+490.07345674850*x);
L0+=0.00000000574*cost(3.61492119092+3686.49611465980*x);
L0+=0.00000000732*cost(5.93179840659+42.53826965290*x);
L0+=0.00000000606*cost(2.71411884300+1173.52040467170*x);
L0+=0.00000000633*cost(4.21720828607+166.82867252200*x);
L0+=0.00000000687*cost(3.91671464962+529.43033266370*x);
L0+=0.00000000570*cost(2.73551750122+4010.00153131720*x);
L0+=0.00000000552*cost(2.36967119362+1603.29998928540*x);
L0+=0.00000000600*cost(1.82659364395+522.52923398400*x);
L0+=0.00000000558*cost(5.09099246601+1354.43315884340*x);
L0+=0.00000000519*cost(6.11952999304+366.79444583570*x);
L0+=0.00000000719*cost(0.85722557905+362.86229257260*x);
L0+=0.00000000518*cost(2.03954064144+418.52143602870*x);
L0+=0.00000000515*cost(3.51750445111+528.41894070740*x);
L0+=0.00000000515*cost(3.47930063838+103.14095832840*x);
L0+=0.00000000550*cost(5.77676837730+420.44785172170*x);
L0+=0.00000000702*cost(3.67952126446+1279.79457262800*x);
L0+=0.00000000550*cost(0.61451088395+104.05598206510*x);
L0+=0.00000000495*cost(2.41738205536+179.35884549420*x);
L0+=0.00000000513*cost(0.29823688044+103.04459010880*x);
L0+=0.00000000537*cost(5.47946238724+771.30123618390*x);
L0+=0.00000000507*cost(3.08777345288+1357.61455258110*x);
L0+=0.00000000495*cost(4.95362659160+536.85269620520*x);
L0+=0.00000000681*cost(4.56294416261+112.65400177420*x);
L0+=0.00000000500*cost(3.15631977489+1070.42763045310*x);
L0+=0.00000000484*cost(0.79038835602+28.45418800320*x);
L0+=0.00000000529*cost(5.46978501034+419.43645976540*x);
L0+=0.00000000597*cost(4.98058295172+1251.34038462480*x);
L0+=0.00000000492*cost(3.96066546484+1269.49963188950*x);
L0+=0.00000000482*cost(3.60167662490+2943.50605412720*x);
L0+=0.00000000630*cost(6.16496640092+105.54045477340*x);
L0+=0.00000000480*cost(0.86786400621+35.21227433100*x);
L0+=0.00000000516*cost(5.97528782923+3067.93946934820*x);
L0+=0.00000000586*cost(5.48467997697+56.62235130260*x);
L0+=0.00000000502*cost(1.43671788959+469.88722005430*x);
L0+=0.00000000473*cost(2.28007170041+2042.49778910280*x);
L0+=0.00000000565*cost(1.90952569252+107.28555991260*x);
L0+=0.00000000452*cost(3.13938145287+934.94851496820*x);
L0+=0.00000000605*cost(1.65413715574+761.74000862830*x);
L0+=0.00000000443*cost(5.46282223686+135.33610313300*x);
L0+=0.00000000580*cost(2.06327501551+493.04240216510*x);
L0+=0.00000000540*cost(1.73777995970+536.75632798560*x);
L0+=0.00000000432*cost(0.27167052107+93.53154666300*x);
L0+=0.00000000515*cost(3.46469417437+530.96298948180*x);
L0+=0.00000000440*cost(5.28884782489+497.44763618020*x);
L0+=0.00000000487*cost(5.78767525063+12036.46073488820*x);
L0+=0.00000000452*cost(2.57855172248+1254.52177836250*x);
L0+=0.00000000427*cost(3.21032629463+2840.41327990860*x);
L0+=0.00000000414*cost(1.54298025443+115.62294719080*x);
L0+=0.00000000424*cost(0.12699448931+1268.74887236410*x);
L0+=0.00000000411*cost(3.12424023238+536.28324723360*x);
L0+=0.00000000452*cost(1.00194596383+113.38771495710*x);
L0+=0.00000000419*cost(0.81834479225+1165.65609814550*x);
L0+=0.00000000490*cost(4.72785081986+277.03499374140*x);
L0+=0.00000000434*cost(0.36146539146+1304.92435454160*x);
L0+=0.00000000401*cost(5.70326543719+1127.04998175570*x);
L0+=0.00000000461*cost(3.26462894820+102.12956637210*x);
L0+=0.00000000533*cost(2.54951615753+141.22580985640*x);
L0+=0.00000000413*cost(4.38801694479+6151.53388830500*x);
L0+=0.00000000415*cost(1.68861617902+391.17346822390*x);
L0+=0.00000000385*cost(1.69092319074+4113.09430553580*x);
L0+=0.00000000450*cost(5.49339192735+602.98809095360*x);
L0+=0.00000000499*cost(3.80738617353+81.00137369080*x);
L0+=0.00000000454*cost(0.10952919733+600.54041039880*x);
L0+=0.00000000377*cost(6.25375060718+913.75088631770*x);
L0+=0.00000000453*cost(3.86104865567+758.77106321170*x);
L0+=0.00000000401*cost(4.44475618337+990.22940591440*x);
L0+=0.00000000407*cost(5.13442416563+3487.42411322340*x);
L0+=0.00000000435*cost(3.76103358490+523.09868295560*x);
L0+=0.00000000425*cost(3.22287851959+2655.56837247380*x);
L0+=0.00000000365*cost(5.16456645463+4694.00295470760*x);
L0+=0.00000000454*cost(1.63325197950+976.00231191280*x);
L0+=0.00000000406*cost(2.72102389267+1438.02522544090*x);
L0+=0.00000000349*cost(3.59598366422+1058.86066532740*x);
L0+=0.00000000354*cost(0.62136331420+498.67147645760*x);
L0+=0.00000000383*cost(5.09229089574+539.25219265020*x);
L0+=0.00000000380*cost(3.92653231573+561.18353448360*x);
L0+=0.00000000339*cost(4.12175871949+3906.90875709860*x);
L0+=0.00000000458*cost(3.42556794767+121.25202148330*x);
L0+=0.00000000427*cost(3.61285264910+860.30992875280*x);
L0+=0.00000000424*cost(4.72757252331+1366.21257229020*x);
L0+=0.00000000328*cost(4.55286002816+1696.09782276550*x);
L0+=0.00000000324*cost(4.23685005210+642.34496686880*x);
L0+=0.00000000395*cost(3.26282558955+484.44438245600*x);
L0+=0.00000000330*cost(6.05223507989+215.74677599280*x);
L0+=0.00000000318*cost(2.02072800070+2964.84669512960*x);
L0+=0.00000000417*cost(0.20173093597+842.90144101350*x);
L0+=0.00000000408*cost(0.45800247268+1578.02719501990*x);
L0+=0.00000000342*cost(6.15347077985+1371.84164658270*x);
L0+=0.00000000310*cost(1.97259286255+754.03576079650*x);
L0+=0.00000000340*cost(2.77813018312+3.52311834900*x);
L0+=0.00000000333*cost(2.91352254678+576.16138801060*x);
L0+=0.00000000324*cost(0.32544817254+586.31331639720*x);
L0+=0.00000000302*cost(2.08708848849+526.98265210890*x);
L0+=0.00000000363*cost(4.70567113230+2730.20695868920*x);
L0+=0.00000000300*cost(0.94464473068+1432.39615114840*x);
L0+=0.00000000352*cost(5.75013621801+806.72595883600*x);
L0+=0.00000000296*cost(3.97807312133+2043.98226181110*x);
L0+=0.00000000295*cost(2.35257797599+4216.18707975440*x);
L0+=0.00000000309*cost(2.49768755925+4326.39340097380*x);
L0+=0.00000000306*cost(3.35876843257+2424.11002977110*x);
L0+=0.00000000300*cost(4.94288858368+1379.70595310890*x);
L0+=0.00000000336*cost(4.49193455535+1585.89150154610*x);
L0+=0.00000000402*cost(2.04684001796+842.15068148810*x);
L0+=0.00000000312*cost(4.59043534747+188.92007304980*x);
L0+=0.00000000346*cost(5.19792097706+523.47118997110*x);
L0+=0.00000000380*cost(1.67961600066+36.64856292950*x);
L0+=0.00000000338*cost(1.32014513725+148.07872442630*x);
L0+=0.00000000391*cost(4.82224015188+1012.91150727320*x);
L0+=0.00000000285*cost(3.43655052437+1053.96530421780*x);
L0+=0.00000000332*cost(2.02575636311+1091.62525910360*x);
L0+=0.00000000282*cost(5.78865321890+1064.04779663520*x);
L0+=0.00000000282*cost(0.39153852422+207.67002114550*x);
L0+=0.00000000280*cost(3.80196391678+298.23262239190*x);
L0+=0.00000000387*cost(6.26819309990+1141.13406340540*x);
L0+=0.00000000349*cost(4.09121908199+1059.90319505100*x);
L0+=0.00000000320*cost(0.39871942000+2122.69601364150*x);
L0+=0.00000000327*cost(4.76503823073+134.58534360760*x);
L0+=0.00000000283*cost(3.90409016441+127.47179660680*x);
L0+=0.00000000301*cost(4.30291951219+299.12639426920*x);
L0+=0.00000000322*cost(2.48251052680+1065.60170531270*x);
L0+=0.00000000297*cost(2.40814103509+1591.52057583860*x);
L0+=0.00000000286*cost(5.85849626574+172.24529849340*x);
L0+=0.00000000285*cost(4.55845472479+1446.62324515000*x);
L0+=0.00000000270*cost(4.08342186112+1578.77795454530*x);
L0+=0.00000000362*cost(1.06148806683+181.80652604900*x);
L0+=0.00000000335*cost(4.51094500655+2349.32843120380*x);
L0+=0.00000000347*cost(0.62281394535+1542.60247236780*x);
L0+=0.00000000275*cost(3.38473403113+4002.88798431640*x);
L0+=0.00000000255*cost(1.52357936497+1688.23351623930*x);
L0+=0.00000000276*cost(4.32192160071+1912.57831194120*x);
L0+=0.00000000253*cost(2.40482338279+97.67614824720*x);
L0+=0.00000000248*cost(4.45058246237+1688.98427576470*x);
L0+=0.00000000300*cost(3.07435583442+1902.28337120270*x);
L0+=0.00000000257*cost(4.79180478086+1670.82502850000*x);
L0+=0.00000000319*cost(1.34244222683+1288.46202830630*x);
L0+=0.00000000245*cost(4.01852686769+1567.73225428140*x);
L0+=0.00000000278*cost(0.25406312148+874.39401040250*x);
L0+=0.00000000324*cost(5.57824969423+1670.07426897460*x);
L0+=0.00000000300*cost(4.67161812947+1329.30337692980*x);
L0+=0.00000000241*cost(0.01789818312+1586.62521472900*x);
L0+=0.00000000295*cost(5.86996114913+2804.23779773110*x);
L0+=0.00000000317*cost(3.17967272487+1020.02505427400*x);
L0+=0.00000000238*cost(4.97765946754+351.81659230870*x);
L0+=0.00000000302*cost(1.20236375616+232.04904353370*x);
L0+=0.00000000301*cost(5.53432687957+2274.54683263650*x);
L0+=0.00000000286*cost(2.41008592059+2545.36205125440*x);
L0+=0.00000000294*cost(2.01783542485+313.94418910180*x);
L0+=0.00000000292*cost(2.12690999284+1592.25428902150*x);
L0+=0.00000000250*cost(2.31712163679+632.26247445140*x);
L0+=0.00000000238*cost(5.06557054569+3803.81598288000*x);
L0+=0.00000000226*cost(0.05916712753+1518.22344997960*x);
L0+=0.00000000235*cost(0.16574304942+137.03302416240*x);
L0+=0.00000000298*cost(2.99720233431+1467.82087380050*x);
L0+=0.00000000286*cost(5.08357076653+774.00954916960*x);
L0+=0.00000000246*cost(2.81685822336+633.30500417500*x);
L0+=0.00000000269*cost(4.93023426152+151.04766984290*x);
L0+=0.00000000228*cost(6.13118739321+3281.23856478620*x);
L0+=0.00000000228*cost(1.22066024988+700.45179087970*x);
L0+=0.00000000239*cost(0.71695698501+1276.61317889030*x);
L0+=0.00000000289*cost(6.08263862565+3384.33133900480*x);
L0+=0.00000000218*cost(2.90308501961+85.82729883120*x);
L0+=0.00000000283*cost(6.28058228271+71.81265315070*x);
L0+=0.00000000271*cost(6.01605074549+170.76082578510*x);
L0+=0.00000000221*cost(0.99914179141+1053.75285589670*x);
L0+=0.00000000218*cost(1.50681393471+1087.69310584050*x);
L0+=0.00000000223*cost(3.39126063354+3259.89792378380*x);
L0+=0.00000000229*cost(1.19373202707+1060.86640289750*x);
L0+=0.00000000264*cost(3.93467945263+1363.24362687360*x);
L0+=0.00000000228*cost(5.04188376116+1064.79855616060*x);
L0+=0.00000000295*cost(2.15253086390+6386.16862421000*x);
L0+=0.00000000214*cost(3.85961180377+4223.30062675520*x);
L0+=0.00000000218*cost(0.79681703388+1909.39691820350*x);
L0+=0.00000000212*cost(4.11706418218+269.92144674060*x);
L0+=0.00000000264*cost(5.81676406517+77.96299230500*x);
L0+=0.00000000256*cost(5.65978708108+799.61241183520*x);
L0+=0.00000000242*cost(6.25078283449+1621.31622419820*x);
L0+=0.00000000235*cost(2.20668997852+1570.91364801910*x);
L0+=0.00000000212*cost(2.88214546012+1674.00642223770*x);
L0+=0.00000000206*cost(1.59586787037+4429.48617519240*x);
L0+=0.00000000208*cost(2.31366614282+878.32616366560*x);
L0+=0.00000000213*cost(0.30373338388+8624.21265092720*x);
L0+=0.00000000223*cost(4.88419887133+1035.00290780100*x);
L0+=0.00000000279*cost(3.65173543621+84.93352695390*x);
L0+=0.00000000210*cost(4.08825553401+203.73786788240*x);
L0+=0.00000000214*cost(4.63498396475+812.14258480740*x);
L0+=0.00000000258*cost(1.73501688450+1887.30551767570*x);
L0+=0.00000000210*cost(4.51798082710+1262.38608488870*x);
L0+=0.00000000252*cost(5.69246905091+104.57724692690*x);
L0+=0.00000000205*cost(4.62946016431+1056.46116888240*x);
L0+=0.00000000263*cost(3.04951219565+1493.09366806600*x);
L0+=0.00000000222*cost(5.54424082649+5216.58037280140*x);
L0+=0.00000000244*cost(0.91026645686+3707.83675566220*x);
L0+=0.00000000204*cost(0.90117975859+1408.01712876020*x);
L0+=0.00000000225*cost(1.23997048012+3340.61242669980*x);
L0+=0.00000000258*cost(2.35906183505+2861.75392091100*x);
L0+=0.00000000267*cost(3.27705002283+5120.60114558360*x);
L0+=0.00000000214*cost(0.66988779149+9146.79006902100*x);
L0+=0.00000000235*cost(4.93761209111+1443.44185141230*x);
L0+=0.00000000194*cost(1.60798828275+102.57150935680*x);
L0+=0.00000000215*cost(0.97603524747+479.28838891550*x);
L0+=0.00000000205*cost(5.23642605904+4649.89881763120*x);
L0+=0.00000000257*cost(4.70227260707+9050.81084180320*x);
L0+=0.00000000228*cost(6.23410921116+64.95973858080*x);
L0+=0.00000000180*cost(4.21309134581+143.93412284210*x);
L0+=0.00000000180*cost(4.82870451226+1063.57471588320*x);
L0+=0.00000000180*cost(5.06126965624+52.69019803950*x);
L0+=0.00000000226*cost(0.55334952097+554.06998748280*x);
L0+=0.00000000209*cost(5.67975843693+48.75804477640*x);
L0+=0.00000000186*cost(3.66368928017+108.72184851110*x);
L0+=0.00000000190*cost(2.00852986549+1058.63117066380*x);
L0+=0.00000000183*cost(3.17358464220+140.96517742550*x);
L0+=0.00000000198*cost(5.49816579454+4333.50694797460*x);
L0+=0.00000000240*cost(6.06602357868+1821.12193881750*x);
L0+=0.00000000172*cost(3.04802064781+54.33472944220*x);
L0+=0.00000000170*cost(4.66520291204+1372.59240610810*x);
L0+=0.00000000173*cost(4.72884056307+77204.32749453338*x);
L0+=0.00000000174*cost(0.85370421252+1587.58842257550*x);
L0+=0.00000000215*cost(0.68219980704+1054.71606374320*x);
L0+=0.00000000170*cost(1.52204803308+5591.96087960020*x);
L0+=0.00000000200*cost(1.60275092073+6681.22485339960*x);
L0+=0.00000000193*cost(2.13003479280+103.61403908040*x);
L0+=0.00000000231*cost(4.69962389031+1966.23171782720*x);
L0+=0.00000000179*cost(5.57395905447+1457.52593306200*x);
L0+=0.00000000205*cost(3.65507571128+906.84978763800*x);
L0+=0.00000000181*cost(4.52272934666+24498.83024629040*x);
L0+=0.00000000223*cost(0.11650319998+67.88049988760*x);
L0+=0.00000000172*cost(5.68083885227+1884.12412393800*x);
L0+=0.00000000219*cost(0.60964963735+2729.45619916380*x);
L0+=0.00000000164*cost(1.06675279755+594.65070367540*x);
L0+=0.00000000176*cost(2.36848603898+977.48678462110*x);
L0+=0.00000000170*cost(2.43036684800+4532.57894941100*x);
L0+=0.00000000191*cost(3.64255924842+1440.99417085750*x);
L0+=0.00000000207*cost(0.49276008455+71.60020482960*x);
L0+=0.00000000157*cost(4.26888100582+5069.38346150640*x);
L0+=0.00000000157*cost(5.14847227422+451.72797278960*x);
L0+=0.00000000158*cost(5.00063628575+650.94298657790*x);
L0+=0.00000000159*cost(5.37530499642+20426.57109242200*x);
L0+=0.00000000218*cost(0.27875408082+175.16605980020*x);
L0+=0.00000000155*cost(0.83696849428+1474.93442080130*x);
L0+=0.00000000154*cost(2.62839957291+683.18631549230*x);
L0+=0.00000000171*cost(1.79511736017+1123.11782849260*x);
L0+=0.00000000188*cost(5.24747110812+25565.32572348040*x);
L0+=0.00000000168*cost(4.14907553818+946.72792841500*x);
L0+=0.00000000203*cost(2.83699715530+1489.91227432830*x);
L0+=0.00000000173*cost(4.34546063838+3046.59882834580*x);
L0+=0.00000000190*cost(5.67865607835+1060.13268971460*x);
L0+=0.00000000201*cost(2.38524182920+419.53282798500*x);
L0+=0.00000000152*cost(5.89088685790+208.63322899200*x);
L0+=0.00000000206*cost(4.46933127349+2654.67460059650*x);
L0+=0.00000000156*cost(2.37819796438+2758.66114669240*x);
L0+=0.00000000203*cost(0.70565514297+498.19839570560*x);
L0+=0.00000000205*cost(3.05468636546+1062.30269149600*x);
L0+=0.00000000174*cost(3.50824761708+2004.36475346500*x);
L0+=0.00000000148*cost(4.73961194393+1799.19059698410*x);
L0+=0.00000000188*cost(3.62315953725+3156.80514956520*x);
L0+=0.00000000183*cost(2.35011338194+25551.09862947879*x);
L0+=0.00000000162*cost(1.58053710589+628.59095361920*x);
L0+=0.00000000162*cost(3.99983876824+1482.79872732750*x);
L0+=0.00000000181*cost(2.85489861839+1055.18914449520*x);
L0+=0.00000000151*cost(3.43198157222+629.86297800640*x);
L0+=0.00000000157*cost(3.15195826490+1025.44168024540*x);
L0+=0.00000000194*cost(5.13049187783+1818.15299340090*x);
L0+=0.00000000193*cost(1.92287052164+1140.38330388000*x);
L0+=0.00000000137*cost(4.22335221970+1049.82070263360*x);
L0+=0.00000000167*cost(2.85163087563+5746.27133789600*x);
L0+=0.00000000167*cost(5.73970282991+5760.49843189760*x);
L0+=0.00000000138*cost(2.23519776527+1176.70179840940*x);
L0+=0.00000000151*cost(4.89507270899+532.39927808030*x);
L0+=0.00000000147*cost(2.65931838448+987.30864460760*x);
L0+=0.00000000135*cost(0.12836417770+991.71387862270*x);
L0+=0.00000000166*cost(3.12682515439+580.09354127370*x);
L0+=0.00000000118*cost(5.98810576300+531.38788612400*x);
L0+=0.00000000135*cost(5.26601313643+1065.01100448170*x);
L0+=0.00000000138*cost(3.18511244397+707.56533788050*x);
L0+=0.00000000122*cost(1.34377059565+446.31134681820*x);
L0+=0.00000000120*cost(2.29717714347+1059.22187149480*x);
L0+=0.00000000121*cost(0.58145552537+5621.84292321040*x);
L0+=0.00000000103*cost(4.75645235023+1226.21060271120*x);
L0+=0.00000000104*cost(6.08481630139+528.25467649610*x);
L0+=0.00000000119*cost(1.06475523307+527.99404406520*x);
L0+=0.00000000104*cost(0.89730746841+531.12725369310*x);
L0+=0.00000000120*cost(5.39001411803+1059.54198888360*x);
L0+=0.00000000104*cost(0.44849170648+1128.53445446400*x);
L0+=0.00000000117*cost(5.42449214711+986.08480433020*x);
L0+=0.00000000101*cost(5.09893554462+530.58473697190*x);
L0+=0.00000000102*cost(0.26948040239+450.97721326420*x);
L0+=0.00000000107*cost(1.58724086516+1069.67687092770*x);
L0+=0.00000000086*cost(2.28711702506+2498.89162833840*x);
L0+=0.00000000101*cost(1.88318822518+528.79719321730*x);
L0+=0.00000000086*cost(1.37568728263+970.51624997220*x);
L0+=0.00000000083*cost(0.06930748288+530.91480537200*x);
L0+=0.00000000085*cost(3.22094000094+1553.64817263170*x);
L0+=0.00000000083*cost(0.62963097974+528.46712481720*x);
L0+=0.00000000083*cost(4.16314675511+849.26422848890*x);
L0+=0.00000000079*cost(3.46688102340+1077.54117745390*x);
L0+=0.00000000097*cost(0.87886975916+9690.70812811720*x);
L0+=0.00000000097*cost(4.27398311206+9676.48103411560*x);
L0+=0.00000000101*cost(0.29639798579+857.12853501510*x);
L0+=0.00000000083*cost(2.55427333923+1059.59437851030*x);
L0+=0.00000000078*cost(0.06461496210+521.82665856840*x);
L0+=0.00000000078*cost(0.76677000862+525.54636351040*x);
L0+=0.00000000096*cost(0.33631035749+1090.40141882620*x);
L0+=0.00000000098*cost(1.42815294497+757.21715453420*x);
L0+=0.00000000077*cost(0.85066773729+537.55527162080*x);
L0+=0.00000000084*cost(5.04765104413+1160.02702385300*x);
L0+=0.00000000076*cost(3.62264327413+782.34693644780*x);
L0+=0.00000000085*cost(1.86831145784+25028.52121138500*x);
L0+=0.00000000079*cost(2.90602202890+2114.83170711530*x);

double L1=0;
L1+=529.93480757497;
L1+=0.00489741194*cost(4.22066689928+529.69096509460*x);
L1+=0.00228918538*cost(6.02647464016+7.11354700080*x);
L1+=0.00027655380*cost(4.57265956824+1059.38193018920*x);
L1+=0.00020720943*cost(5.45938936295+522.57741809380*x);
L1+=0.00012105732*cost(0.16985765041+536.80451209540*x);
L1+=0.00006068051*cost(4.42419502005+103.09277421860*x);
L1+=0.00005433924*cost(3.98478382565+419.48464387520*x);
L1+=0.00004237795*cost(5.89009351271+14.22709400160*x);
L1+=0.00002211854*cost(5.26771446618+206.18554843720*x);
L1+=0.00001295769*cost(5.55132765087+3.18139373770*x);
L1+=0.00001745919*cost(4.92669378486+1589.07289528380*x);
L1+=0.00001163411*cost(0.51450895328+3.93215326310*x);
L1+=0.00001007216*cost(0.46478398551+735.87651353180*x);
L1+=0.00001173129*cost(5.85647304350+1052.26838318840*x);
L1+=0.00000847678*cost(5.75805850450+110.20632121940*x);
L1+=0.00000827329*cost(4.80312015734+213.29909543800*x);
L1+=0.00001003574*cost(3.15040301822+426.59819087600*x);
L1+=0.00001098735*cost(5.30704981594+515.46387109300*x);
L1+=0.00000816397*cost(0.58643054886+1066.49547719000*x);
L1+=0.00000725447*cost(5.51827471473+639.89728631400*x);
L1+=0.00000567845*cost(5.98867049451+625.67019231240*x);
L1+=0.00000474181*cost(4.13245269168+412.37109687440*x);
L1+=0.00000412930*cost(5.73652891261+95.97922721780*x);
L1+=0.00000335817*cost(3.73248749046+1162.47470440780*x);
L1+=0.00000345249*cost(4.24159565410+632.78373931320*x);
L1+=0.00000234066*cost(6.24302226646+309.27832265580*x);
L1+=0.00000194784*cost(2.21879010911+323.50541665740*x);
L1+=0.00000234340*cost(4.03469970332+949.17560896980*x);
L1+=0.00000183938*cost(6.27963588822+543.91805909620*x);
L1+=0.00000198525*cost(1.50458442825+838.96928775040*x);
L1+=0.00000186899*cost(6.08620565908+742.99006053260*x);
L1+=0.00000171380*cost(5.41655983845+199.07200143640*x);
L1+=0.00000130771*cost(0.62643377351+728.76296653100*x);
L1+=0.00000107575*cost(4.49282760117+956.28915597060*x);
L1+=0.00000115393*cost(0.68019050174+846.08283475120*x);
L1+=0.00000115047*cost(5.28641699144+2118.76386037840*x);
L1+=0.00000066824*cost(5.73365126533+21.34064100240*x);
L1+=0.00000069618*cost(5.97263450278+532.87235883230*x);
L1+=0.00000064850*cost(6.08803490288+1581.95934828300*x);
L1+=0.00000079686*cost(5.82412400273+1045.15483618760*x);
L1+=0.00000057939*cost(0.99453087342+1596.18644228460*x);
L1+=0.00000065635*cost(0.12924191430+526.50957135690*x);
L1+=0.00000058509*cost(0.58626971028+1155.36115740700*x);
L1+=0.00000056600*cost(1.41198438841+533.62311835770*x);
L1+=0.00000071643*cost(5.34162650321+942.06206196900*x);
L1+=0.00000057368*cost(5.96851304799+1169.58825140860*x);
L1+=0.00000054935*cost(5.42806383723+10.29494073850*x);
L1+=0.00000052016*cost(0.22981299129+1368.66025284500*x);
L1+=0.00000052309*cost(5.72661448388+117.31986822020*x);
L1+=0.00000050418*cost(6.08075147811+525.75881183150*x);
L1+=0.00000047418*cost(3.62611843241+1478.86657406440*x);
L1+=0.00000039888*cost(4.16158013600+1692.16566950240*x);
L1+=0.00000046678*cost(0.51144073175+1265.56747862640*x);
L1+=0.00000032827*cost(5.03596689455+220.41264243880*x);
L1+=0.00000033558*cost(0.09913904872+302.16477565500*x);
L1+=0.00000029379*cost(3.35927241533+4.66586644600*x);
L1+=0.00000029307*cost(0.75907909735+88.86568021700*x);
L1+=0.00000032449*cost(5.37492530697+508.35032409220*x);
L1+=0.00000029483*cost(5.42208897099+1272.68102562720*x);
L1+=0.00000021802*cost(6.15054054070+1685.05212250160*x);
L1+=0.00000025195*cost(1.60723063387+831.85574074960*x);
L1+=0.00000021133*cost(5.86346824200+1258.45393162560*x);
L1+=0.00000019747*cost(2.17205957814+316.39186965660*x);
L1+=0.00000017871*cost(0.82841413516+433.71173787680*x);
L1+=0.00000017703*cost(5.95527049039+5.41662597140*x);
L1+=0.00000017230*cost(2.76395560958+853.19638175200*x);
L1+=0.00000017453*cost(0.70749901224+1471.75302706360*x);
L1+=0.00000017508*cost(0.49799925173+1375.77379984580*x);
L1+=0.00000014368*cost(0.91459831140+18.15924726470*x);
L1+=0.00000014107*cost(0.63031082833+2.92076130680*x);
L1+=0.00000011559*cost(4.30379009964+405.25754987360*x);
L1+=0.00000011728*cost(1.76426582357+380.12776796000*x);
L1+=0.00000011054*cost(5.56735602213+1574.84580128220*x);
L1+=0.00000010425*cost(0.31355034390+1361.54670584420*x);
L1+=0.00000009804*cost(5.90363777277+519.39602435610*x);
L1+=0.00000009805*cost(0.38648727979+1073.60902419080*x);
L1+=0.00000009285*cost(3.21842287530+1795.25844372100*x);
L1+=0.00000008864*cost(0.53776257958+1788.14489672020*x);
L1+=0.00000008370*cost(5.88484552222+2001.44399215820*x);
L1+=0.00000008148*cost(5.10162311410+1485.98012106520*x);
L1+=0.00000007658*cost(5.64890060131+2648.45482547300*x);
L1+=0.00000006690*cost(2.41093459420+4.19278569400*x);
L1+=0.00000005840*cost(4.22347896053+2008.55753915900*x);
L1+=0.00000007256*cost(6.19384525651+11.04570026390*x);
L1+=0.00000006266*cost(1.36137786945+1148.24761040620*x);
L1+=0.00000005141*cost(5.23083932012+628.85158605010*x);
L1+=0.00000005140*cost(2.92955981951+518.64526483070*x);
L1+=0.00000004765*cost(0.16838181862+629.60234557550*x);
L1+=0.00000004603*cost(0.78529559911+721.64941953020*x);
L1+=0.00000004575*cost(6.24794935732+1677.93857550080*x);
L1+=0.00000004537*cost(4.95096707833+635.96513305090*x);
L1+=0.00000004518*cost(2.06523915453+453.42489381900*x);
L1+=0.00000004414*cost(0.15381186059+1699.27921650320*x);
L1+=0.00000005593*cost(5.57489981207+191.95845443560*x);
L1+=0.00000005403*cost(1.46004886198+330.61896365820*x);
L1+=0.00000004285*cost(0.23949868127+2104.53676637680*x);
L1+=0.00000004223*cost(1.44087555881+2125.87740737920*x);
L1+=0.00000004101*cost(6.19274358942+636.71589257630*x);
L1+=0.00000004432*cost(4.35811524051+423.41679713830*x);
L1+=0.00000004132*cost(0.50170694173+1056.20053645150*x);
L1+=0.00000004398*cost(4.14280286969+511.53171782990*x);
L1+=0.00000005406*cost(4.40429493698+2221.85663459700*x);
L1+=0.00000004467*cost(0.08534650684+1062.56332392690*x);
L1+=0.00000003569*cost(5.66540477010+2317.83586181480*x);
L1+=0.00000004007*cost(2.54845549248+74.78159856730*x);
L1+=0.00000003515*cost(0.25495124831+1055.44977692610*x);
L1+=0.00000003687*cost(2.93378008847+32.24332891440*x);
L1+=0.00000002883*cost(5.72793010505+99.91138048090*x);
L1+=0.00000002969*cost(5.50054720569+107.02492748170*x);
L1+=0.00000002720*cost(1.25222590925+540.73666535850*x);
L1+=0.00000002808*cost(3.30714813896+0.75075952540*x);
L1+=0.00000002768*cost(1.61339487804+1063.31408345230*x);
L1+=0.00000002666*cost(4.28662288102+106.27416795630*x);
L1+=0.00000002704*cost(3.03615556153+422.66603761290*x);
L1+=0.00000003290*cost(5.89081682150+1802.37199072180*x);
L1+=0.00000002578*cost(3.60390367979+750.10360753340*x);
L1+=0.00000002661*cost(0.35249312659+1898.35121793960*x);
L1+=0.00000002486*cost(5.28950877719+1891.23767093880*x);
L1+=0.00000002936*cost(1.09052029450+1464.63948006280*x);
L1+=0.00000003190*cost(4.60740643547+416.30325013750*x);
L1+=0.00000002390*cost(6.01779736611+551.03160609700*x);
L1+=0.00000002214*cost(5.24450923180+621.73803904930*x);
L1+=0.00000002319*cost(5.82920300130+305.34616939270*x);
L1+=0.00000002089*cost(5.99310370434+1994.33044515740*x);
L1+=0.00000002042*cost(0.75008788531+142.44965013380*x);
L1+=0.00000002121*cost(0.01537599023+2420.92863603340*x);
L1+=0.00000002114*cost(6.25308371567+647.01083331480*x);
L1+=0.00000002020*cost(4.17560390841+569.04784100980*x);
L1+=0.00000002109*cost(5.18682321403+227.52618943960*x);
L1+=0.00000002283*cost(5.80043809222+539.98590583310*x);
L1+=0.00000001977*cost(3.99197009651+24.37902238820*x);
L1+=0.00000001960*cost(1.35288793079+963.40270297140*x);
L1+=0.00000001903*cost(2.78349628184+2428.04218303420*x);
L1+=0.00000001915*cost(4.22134509685+2324.94940881560*x);
L1+=0.00000001971*cost(5.88715684267+217.23124870110*x);
L1+=0.00000001917*cost(3.03728154374+1382.88734684660*x);
L1+=0.00000002026*cost(3.08606488714+408.43894361130*x);
L1+=0.00000001834*cost(5.61474110217+430.53034413910*x);
L1+=0.00000001838*cost(1.25467410218+81.75213321620*x);
L1+=0.00000002460*cost(4.63268678998+1905.46476494040*x);
L1+=0.00000001820*cost(5.97497926120+114.13847448250*x);
L1+=0.00000002043*cost(4.34047514845+70.84944530420*x);
L1+=0.00000001959*cost(4.03116026306+92.04707395470*x);
L1+=0.00000001768*cost(0.33097462499+35.42472265210*x);
L1+=0.00000002334*cost(5.87042638470+1038.04128918680*x);
L1+=0.00000001835*cost(4.81326127892+124.43341522100*x);
L1+=0.00000002269*cost(1.02549350754+618.55664531160*x);
L1+=0.00000001919*cost(5.01297395549+99.16062095550*x);
L1+=0.00000001923*cost(0.28688549585+31.01948863700*x);
L1+=0.00000001878*cost(5.69299116574+210.11770170030*x);
L1+=0.00000001679*cost(0.25635730278+295.05122865420*x);
L1+=0.00000001656*cost(5.46039280732+2634.22773147140*x);
L1+=0.00000001675*cost(6.15609073315+643.82943957710*x);
L1+=0.00000001953*cost(5.09846435548+17.40848773930*x);
L1+=0.00000001539*cost(2.75316078346+415.55249061210*x);
L1+=0.00000001467*cost(0.54812675158+458.84151979040*x);
L1+=0.00000001482*cost(3.76736278426+534.35683154060*x);
L1+=0.00000001446*cost(3.15802770791+25.12978191360*x);
L1+=0.00000001667*cost(0.26406950755+835.03713448730*x);
L1+=0.00000001472*cost(0.83054329617+28.31117565130*x);
L1+=0.00000001655*cost(0.88908548504+1781.03134971940*x);
L1+=0.00000001294*cost(5.76241191046+440.82528487760*x);
L1+=0.00000001348*cost(2.49823510924+984.60033162190*x);
L1+=0.00000001352*cost(5.10869562455+149.56319713460*x);
L1+=0.00000001344*cost(0.01942249067+2214.74308759620*x);
L1+=0.00000001188*cost(2.24279457878+31.49256938900*x);
L1+=0.00000001166*cost(0.80686346228+739.80866679490*x);
L1+=0.00000001322*cost(4.25691184168+2538.24850425360*x);
L1+=0.00000001094*cost(6.02985819406+2737.32050569000*x);
L1+=0.00000001112*cost(4.38204360670+561.93429400900*x);
L1+=0.00000001346*cost(3.20575848870+525.02509864860*x);
L1+=0.00000001056*cost(5.76507115032+2310.72231481400*x);
L1+=0.00000001159*cost(0.46189564970+67.66805156650*x);
L1+=0.00000001027*cost(0.20709586018+7.86430652620*x);
L1+=0.00000001143*cost(5.56626418636+46.47042291600*x);
L1+=0.00000001012*cost(0.54293005597+532.13864564940*x);
L1+=0.00000000978*cost(5.13939194101+2207.62954059540*x);
L1+=0.00000000993*cost(2.03698185233+319.57326339430*x);
L1+=0.00000001035*cost(2.90231353535+611.44309831080*x);
L1+=0.00000001021*cost(4.75651217048+527.24328453980*x);
L1+=0.00000001308*cost(1.78809336431+824.74219374880*x);
L1+=0.00000000964*cost(2.82269601958+2111.65031337760*x);
L1+=0.00000000896*cost(2.54505998806+2744.43405269080*x);
L1+=0.00000000890*cost(5.41036782817+28.45418800320*x);
L1+=0.00000000906*cost(0.76565238554+1439.50969814920*x);
L1+=0.00000000985*cost(0.88687623770+5760.49843189760*x);
L1+=0.00000000983*cost(1.42102343372+5746.27133789600*x);
L1+=0.00000000892*cost(5.87250060663+203.00415469950*x);
L1+=0.00000000942*cost(2.31049430734+9690.70812811720*x);
L1+=0.00000000941*cost(2.84331157527+9676.48103411560*x);
L1+=0.00000000867*cost(0.81020362547+524.27433912320*x);
L1+=0.00000000829*cost(2.35178495412+312.45971639350*x);
L1+=0.00000000912*cost(2.80494184378+6.21977512350*x);
L1+=0.00000000809*cost(1.05148218513+529.64278098480*x);
L1+=0.00000000779*cost(4.80009242059+945.24345570670*x);
L1+=0.00000000878*cost(5.76532521399+1.64453140270*x);
L1+=0.00000000953*cost(4.30945738629+209.36694217490*x);
L1+=0.00000000772*cost(5.25607113566+2950.61960112800*x);
L1+=0.00000000745*cost(0.03810558502+535.10759106600*x);
L1+=0.00000000744*cost(0.58381523987+25.27279426550*x);
L1+=0.00000000734*cost(0.20800485100+1049.08698945070*x);
L1+=0.00000000747*cost(2.71772840871+38.13303563780*x);
L1+=0.00000000728*cost(5.97210358938+945.99421523210*x);
L1+=0.00000000769*cost(4.51394016967+952.35700270750*x);
L1+=0.00000000710*cost(0.38016353553+69.15252427480*x);
L1+=0.00000000760*cost(3.07033779824+39.35687591520*x);
L1+=0.00000000802*cost(1.14191463412+532.61172640140*x);
L1+=0.00000000704*cost(1.25447308120+547.85021235930*x);
L1+=0.00000000721*cost(0.73855379162+2228.97018159780*x);
L1+=0.00000000794*cost(4.25051539085+2641.34127847220*x);
L1+=0.00000000795*cost(3.20588363820+604.47256366190*x);
L1+=0.00000000818*cost(1.05229815343+909.81873305460*x);
L1+=0.00000000724*cost(5.68281830264+953.10776223290*x);
L1+=0.00000000836*cost(0.60410469174+2097.42321937600*x);
L1+=0.00000000669*cost(5.75757140051+2015.67108615980*x);
L1+=0.00000000682*cost(1.19994890339+387.24131496080*x);
L1+=0.00000000640*cost(3.91546675664+528.72775724810*x);
L1+=0.00000000809*cost(4.24929331276+529.73914920440*x);
L1+=0.00000000819*cost(4.91540072376+2751.54759969160*x);
L1+=0.00000000692*cost(2.51162384766+916.93228005540*x);
L1+=0.00000000784*cost(4.23651511312+195.13984817330*x);
L1+=0.00000000762*cost(1.12201139619+732.69511979410*x);
L1+=0.00000000617*cost(5.80920925081+739.05790726950*x);
L1+=0.00000000727*cost(4.24401822698+760.25553592000*x);
L1+=0.00000000591*cost(3.26075006572+202.25339517410*x);
L1+=0.00000000552*cost(5.83533550039+526.77020378780*x);
L1+=0.00000000640*cost(1.38530872949+530.65417294110*x);
L1+=0.00000000577*cost(6.09100925678+2531.13495725280*x);
L1+=0.00000000620*cost(3.01917904435+902.70518605380*x);
L1+=0.00000000722*cost(5.18171159557+1.48447270830*x);
L1+=0.00000000540*cost(3.78809230820+2957.73314812880*x);
L1+=0.00000000523*cost(3.63882376000+437.64389113990*x);
L1+=0.00000000527*cost(5.80796427555+3053.71237534660*x);
L1+=0.00000000488*cost(4.99103190309+483.22054217860*x);
L1+=0.00000000557*cost(4.11381202161+2854.64037391020*x);
L1+=0.00000000492*cost(0.76371083106+1603.29998928540*x);
L1+=0.00000000487*cost(5.55383951779+2627.11418447060*x);
L1+=0.00000000487*cost(5.86510858429+724.83081326790*x);
L1+=0.00000000453*cost(0.61375011101+1159.29331067010*x);
L1+=0.00000000450*cost(2.28121042355+3060.82592234740*x);
L1+=0.00000000515*cost(4.78126059280+447.79581952650*x);
L1+=0.00000000449*cost(4.70231576312+934.94851496820*x);
L1+=0.00000000450*cost(1.91049508739+597.35901666110*x);
L1+=0.00000000438*cost(6.01178917646+3178.14579056760*x);
L1+=0.00000000494*cost(0.53844942275+1354.43315884340*x);
L1+=0.00000000501*cost(5.51752195462+2435.15573003500*x);
L1+=0.00000000432*cost(3.64903264921+313.21047591890*x);
L1+=0.00000000435*cost(3.02449828967+533.88375078860*x);
L1+=0.00000000426*cost(5.07945534339+2524.02141025200*x);
L1+=0.00000000491*cost(3.59286364200+230.56457082540*x);
L1+=0.00000000547*cost(0.34432090949+1251.34038462480*x);
L1+=0.00000000503*cost(1.57454509207+454.90936652730*x);
L1+=0.00000000486*cost(4.39351469958+462.02291352810*x);
L1+=0.00000000524*cost(2.03003740296+1279.79457262800*x);
L1+=0.00000000388*cost(5.58318013074+731.94436026870*x);
L1+=0.00000000449*cost(1.11025492739+56.62235130260*x);
L1+=0.00000000398*cost(5.19943284273+3267.01147078460*x);
L1+=0.00000000416*cost(1.70821917336+245.54242435240*x);
L1+=0.00000000379*cost(1.80234948769+2655.56837247380*x);
L1+=0.00000000355*cost(1.65214516751+78.71375183040*x);
L1+=0.00000000404*cost(1.72647262603+1141.13406340540*x);
L1+=0.00000000335*cost(6.01254286794+960.22130923370*x);
L1+=0.00000000331*cost(1.74086938716+490.33408917940*x);
L1+=0.00000000401*cost(0.30034336462+2332.06295581640*x);
L1+=0.00000000336*cost(2.64385574909+1021.24889455140*x);
L1+=0.00000000389*cost(0.31259289221+2413.81508903260*x);
L1+=0.00000000314*cost(5.73833529708+1158.54255114470*x);
L1+=0.00000000313*cost(4.74363791106+938.12990870590*x);
L1+=0.00000000333*cost(0.80112437148+1585.14074202070*x);
L1+=0.00000000323*cost(3.52656245280+3274.12501778540*x);
L1+=0.00000000395*cost(1.73181407631+1593.00504854690*x);
L1+=0.00000000302*cost(4.64184749164+1261.63532536330*x);
L1+=0.00000000325*cost(0.54991590409+43.28902917830*x);
L1+=0.00000000293*cost(0.97977818746+1585.89150154610*x);
L1+=0.00000000341*cost(2.80833606944+1514.29129671650*x);
L1+=0.00000000304*cost(6.12522825214+1262.38608488870*x);
L1+=0.00000000286*cost(2.89800423081+530.21222995640*x);
L1+=0.00000000387*cost(0.46648572639+1592.25428902150*x);
L1+=0.00000000285*cost(4.56394598052+1268.74887236410*x);
L1+=0.00000000310*cost(4.69102289591+76.26607127560*x);
L1+=0.00000000278*cost(5.49867187248+280.96714700450*x);
L1+=0.00000000358*cost(5.45926487831+113.38771495710*x);
L1+=0.00000000283*cost(1.09230506350+1061.82961074400*x);
L1+=0.00000000326*cost(0.60265259639+827.92358748650*x);
L1+=0.00000000284*cost(5.36580034539+1165.65609814550*x);
L1+=0.00000000281*cost(5.54635461050+3370.10424500320*x);
L1+=0.00000000269*cost(3.92616563946+42.53826965290*x);
L1+=0.00000000275*cost(2.58465453365+373.01422095920*x);
L1+=0.00000000357*cost(1.39391983207+1493.09366806600*x);
L1+=0.00000000258*cost(5.96670694140+1269.49963188950*x);
L1+=0.00000000259*cost(2.56026216784+9146.79006902100*x);
L1+=0.00000000281*cost(2.74823090198+4694.00295470760*x);
L1+=0.00000000281*cost(3.01324655940+320.32402291970*x);
L1+=0.00000000272*cost(4.18504958920+8624.21265092720*x);
L1+=0.00000000245*cost(1.24462798353+252.65597135320*x);
L1+=0.00000000244*cost(2.02892764690+3377.21779200400*x);
L1+=0.00000000324*cost(1.84851618413+1289.94650101460*x);
L1+=0.00000000221*cost(6.22167997496+3281.23856478620*x);
L1+=0.00000000238*cost(3.93371505401+3171.03224356680*x);
L1+=0.00000000226*cost(5.94296271326+224.34479570190*x);
L1+=0.00000000213*cost(3.68264234750+1048.33622992530*x);
L1+=0.00000000216*cost(5.82941334164+1567.73225428140*x);
L1+=0.00000000295*cost(4.70194747095+3067.93946934820*x);
L1+=0.00000000206*cost(4.98184230959+1357.61455258110*x);
L1+=0.00000000202*cost(1.32439444045+4326.39340097380*x);
L1+=0.00000000227*cost(0.78540105705+59.80374504030*x);
L1+=0.00000000237*cost(5.56926897693+2943.50605412720*x);
L1+=0.00000000207*cost(0.07907015398+5223.69391980220*x);
L1+=0.00000000199*cost(3.30501818656+4120.20785253660*x);
L1+=0.00000000194*cost(5.95526916809+84.93352695390*x);
L1+=0.00000000266*cost(1.58032565718+983.11585891360*x);
L1+=0.00000000198*cost(4.31078641704+4017.11507831800*x);
L1+=0.00000000198*cost(0.30166351366+1166.40685767090*x);
L1+=0.00000000188*cost(0.90738705875+135.33610313300*x);
L1+=0.00000000186*cost(0.69289672485+92.79783348010*x);
L1+=0.00000000182*cost(1.18931462257+1512.80682400820*x);
L1+=0.00000000191*cost(1.04146023518+1884.12412393800*x);
L1+=0.00000000174*cost(6.13734594396+3597.63043444280*x);
L1+=0.00000000189*cost(0.35191512844+1372.59240610810*x);
L1+=0.00000000172*cost(4.35250972697+1578.02719501990*x);
L1+=0.00000000173*cost(2.30241719278+1176.70179840940*x);
L1+=0.00000000220*cost(1.06991056825+2200.51599359460*x);
L1+=0.00000000186*cost(4.90511103807+3583.40334044120*x);
L1+=0.00000000189*cost(0.24160744024+1670.82502850000*x);
L1+=0.00000000206*cost(0.01485146863+2730.20695868920*x);
L1+=0.00000000174*cost(1.83997277029+746.92221379570*x);
L1+=0.00000000225*cost(3.13108099660+630.33605875840*x);
L1+=0.00000000206*cost(5.22730929781+3995.77443731560*x);
L1+=0.00000000169*cost(2.57956682688+9161.01716302260*x);
L1+=0.00000000165*cost(1.51795928301+4010.00153131720*x);
L1+=0.00000000181*cost(2.05055200822+842.90144101350*x);
L1+=0.00000000181*cost(5.96554625357+1578.77795454530*x);
L1+=0.00000000166*cost(1.55114863100+1070.42763045310*x);
L1+=0.00000000157*cost(5.87839958880+3914.02230409940*x);
L1+=0.00000000160*cost(0.43729819176+2545.36205125440*x);
L1+=0.00000000168*cost(5.73975661792+2847.52682690940*x);
L1+=0.00000000157*cost(2.25764581068+850.01498801430*x);
L1+=0.00000000187*cost(0.64918748618+842.15068148810*x);
L1+=0.00000000180*cost(1.88055488803+685.47393735270*x);
L1+=0.00000000153*cost(4.15259684562+4333.50694797460*x);
L1+=0.00000000154*cost(3.65536637158+77734.01845962799*x);
L1+=0.00000000151*cost(3.17795437121+3590.51688744200*x);
L1+=0.00000000155*cost(3.87623547990+327.43756992050*x);
L1+=0.00000000171*cost(3.33647878498+1912.57831194120*x);
L1+=0.00000000188*cost(4.53005359421+1041.22268292450*x);
L1+=0.00000000134*cost(4.09921613445+530.44172462000*x);
L1+=0.00000000123*cost(4.79543460218+1098.73880610440*x);
L1+=0.00000000161*cost(2.02006564218+860.30992875280*x);
L1+=0.00000000143*cost(2.40197278329+529.16970023280*x);
L1+=0.00000000115*cost(1.55831212007+9153.90361602180*x);
L1+=0.00000000106*cost(5.94313244357+1057.89745748090*x);
L1+=0.00000000119*cost(5.10578428676+1056.93424963440*x);
L1+=0.00000000100*cost(5.74974781049+501.23677709140*x);
L1+=0.00000000094*cost(1.40134175492+1059.33374607940*x);
L1+=0.00000000098*cost(3.79115318281+497.44763618020*x);
L1+=0.00000000090*cost(4.09610113044+1064.04779663520*x);
L1+=0.00000000102*cost(1.10442899544+1969.20066324380*x);
L1+=0.00000000087*cost(0.58218477838+1173.52040467170*x);
L1+=0.00000000109*cost(3.83745968299+525.49817940060*x);
L1+=0.00000000094*cost(4.59915291355+1059.43011429900*x);
L1+=0.00000000118*cost(6.11701561559+1069.67687092770*x);
L1+=0.00000000107*cost(5.40509332689+679.25416222920*x);
L1+=0.00000000089*cost(5.90037690244+757.21715453420*x);
L1+=0.00000000078*cost(6.06217863109+970.51624997220*x);
L1+=0.00000000080*cost(5.45470236239+3163.91869656600*x);
L1+=0.00000000072*cost(5.65789862232+1151.42900414390*x);
L1+=0.00000000080*cost(0.04539720100+1080.72257119160*x);
L1+=0.00000000075*cost(4.26526686574+1058.41872234270*x);

double L2=0;
L2+=0.00047233598*cost(4.32148323554+7.11354700080*x);
L2+=0.00030629053*cost(2.93021440216+529.69096509460*x);
L2+=0.00038965550;
L2+=0.00003189317*cost(1.05504615595+522.57741809380*x);
L2+=0.00002723358*cost(3.41411526638+1059.38193018920*x);
L2+=0.00002729292*cost(4.84545481351+536.80451209540*x);
L2+=0.00001721069*cost(4.18734385158+14.22709400160*x);
L2+=0.00000383258*cost(5.76790714387+419.48464387520*x);
L2+=0.00000367498*cost(6.05509120409+103.09277421860*x);
L2+=0.00000377524*cost(0.76048964872+515.46387109300*x);
L2+=0.00000337386*cost(3.78644384244+3.18139373770*x);
L2+=0.00000308200*cost(0.69356654052+206.18554843720*x);
L2+=0.00000218408*cost(3.81389191353+1589.07289528380*x);
L2+=0.00000198883*cost(5.33996443444+1066.49547719000*x);
L2+=0.00000197445*cost(2.48356402053+3.93215326310*x);
L2+=0.00000146230*cost(3.81373196838+639.89728631400*x);
L2+=0.00000155862*cost(1.40642426467+1052.26838318840*x);
L2+=0.00000129570*cost(5.83738872525+412.37109687440*x);
L2+=0.00000141932*cost(1.63435169016+426.59819087600*x);
L2+=0.00000117327*cost(1.41435462588+625.67019231240*x);
L2+=0.00000096733*cost(4.03383427887+110.20632121940*x);
L2+=0.00000090823*cost(1.10630629042+95.97922721780*x);
L2+=0.00000078769*cost(4.63726131329+543.91805909620*x);
L2+=0.00000072392*cost(2.21716670026+735.87651353180*x);
L2+=0.00000087292*cost(2.52235174825+632.78373931320*x);
L2+=0.00000056910*cost(3.12292059854+213.29909543800*x);
L2+=0.00000048622*cost(1.67283791618+309.27832265580*x);
L2+=0.00000058475*cost(0.83216317444+199.07200143640*x);
L2+=0.00000040150*cost(4.02485444740+21.34064100240*x);
L2+=0.00000039784*cost(0.62416945827+323.50541665740*x);
L2+=0.00000035718*cost(2.32581247002+728.76296653100*x);
L2+=0.00000025620*cost(2.51240623862+1162.47470440780*x);
L2+=0.00000029255*cost(3.60838327799+10.29494073850*x);
L2+=0.00000023591*cost(3.00532139306+956.28915597060*x);
L2+=0.00000027814*cost(3.23992013743+838.96928775040*x);
L2+=0.00000025993*cost(4.50118298290+742.99006053260*x);
L2+=0.00000025194*cost(1.21868110687+1045.15483618760*x);
L2+=0.00000019458*cost(4.29028644674+532.87235883230*x);
L2+=0.00000017660*cost(0.80953941560+508.35032409220*x);
L2+=0.00000015355*cost(5.81037986941+1596.18644228460*x);
L2+=0.00000017058*cost(4.20001977723+2118.76386037840*x);
L2+=0.00000017040*cost(1.83402146640+526.50957135690*x);
L2+=0.00000014661*cost(3.99989622586+117.31986822020*x);
L2+=0.00000013639*cost(1.80336677963+302.16477565500*x);
L2+=0.00000013230*cost(2.51856643603+88.86568021700*x);
L2+=0.00000012756*cost(4.36856232414+1169.58825140860*x);
L2+=0.00000015292*cost(0.68174165476+942.06206196900*x);
L2+=0.00000010986*cost(4.43586634639+525.75881183150*x);
L2+=0.00000013920*cost(5.95169568482+316.39186965660*x);
L2+=0.00000009437*cost(2.17684563456+1155.36115740700*x);
L2+=0.00000008812*cost(3.29452783338+220.41264243880*x);
L2+=0.00000007823*cost(5.75672228354+846.08283475120*x);
L2+=0.00000007549*cost(2.70955516779+533.62311835770*x);
L2+=0.00000009681*cost(1.71563161051+1581.95934828300*x);
L2+=0.00000008690*cost(3.31924493607+831.85574074960*x);
L2+=0.00000006285*cost(0.49939863541+949.17560896980*x);
L2+=0.00000006685*cost(2.17560093281+1265.56747862640*x);
L2+=0.00000005381*cost(6.00510875948+405.25754987360*x);
L2+=0.00000004676*cost(1.40846192799+1258.45393162560*x);
L2+=0.00000004421*cost(3.02360159274+1692.16566950240*x);
L2+=0.00000004403*cost(5.47737266160+433.71173787680*x);
L2+=0.00000004286*cost(5.07139951645+1073.60902419080*x);
L2+=0.00000004201*cost(5.28560721767+18.15924726470*x);
L2+=0.00000003933*cost(1.26665387164+853.19638175200*x);
L2+=0.00000005351*cost(3.65320121089+1272.68102562720*x);
L2+=0.00000004392*cost(2.27325303667+1368.66025284500*x);
L2+=0.00000003482*cost(1.53983001273+519.39602435610*x);
L2+=0.00000002745*cost(2.09685315627+1478.86657406440*x);
L2+=0.00000002737*cost(1.06017230524+1574.84580128220*x);
L2+=0.00000002897*cost(2.05128453665+1361.54670584420*x);
L2+=0.00000003075*cost(0.99085727534+191.95845443560*x);
L2+=0.00000002462*cost(2.37173605635+1471.75302706360*x);
L2+=0.00000002203*cost(2.47960567714+721.64941953020*x);
L2+=0.00000002096*cost(3.71482580504+1485.98012106520*x);
L2+=0.00000001984*cost(1.88475229557+1685.05212250160*x);
L2+=0.00000002274*cost(3.03360234351+1148.24761040620*x);
L2+=0.00000002041*cost(6.17114556019+330.61896365820*x);
L2+=0.00000001451*cost(4.72055072637+32.24332891440*x);
L2+=0.00000001454*cost(5.14703918585+1375.77379984580*x);
L2+=0.00000001447*cost(3.18833439444+635.96513305090*x);
L2+=0.00000001403*cost(4.26712075104+551.03160609700*x);
L2+=0.00000001420*cost(1.99288040133+629.60234557550*x);
L2+=0.00000001269*cost(0.03300387779+2125.87740737920*x);
L2+=0.00000001276*cost(2.26356919237+1788.14489672020*x);
L2+=0.00000001189*cost(1.70223550488+1677.93857550080*x);
L2+=0.00000001182*cost(2.18142313946+1795.25844372100*x);
L2+=0.00000001366*cost(1.27629917215+1038.04128918680*x);
L2+=0.00000001306*cost(4.76302079847+1062.56332392690*x);
L2+=0.00000001109*cost(2.97787130235+81.75213321620*x);
L2+=0.00000001027*cost(1.99236027398+295.05122865420*x);
L2+=0.00000001349*cost(4.01621534182+539.98590583310*x);
L2+=0.00000001025*cost(3.75336759986+28.45418800320*x);
L2+=0.00000000977*cost(3.01355125761+124.43341522100*x);
L2+=0.00000001290*cost(4.62594234857+2648.45482547300*x);
L2+=0.00000001065*cost(5.06153058155+1699.27921650320*x);
L2+=0.00000000965*cost(1.17716405513+99.91138048090*x);
L2+=0.00000001021*cost(1.90712102660+750.10360753340*x);
L2+=0.00000000923*cost(3.53450109212+227.52618943960*x);
L2+=0.00000001059*cost(0.13532061468+416.30325013750*x);
L2+=0.00000000836*cost(2.07492422755+1056.20053645150*x);
L2+=0.00000000889*cost(1.75177808106+1898.35121793960*x);
L2+=0.00000000772*cost(2.89217715561+2008.55753915900*x);
L2+=0.00000001014*cost(2.80847772922+1464.63948006280*x);
L2+=0.00000000820*cost(1.99735697577+2111.65031337760*x);
L2+=0.00000000787*cost(4.91912237671+1055.44977692610*x);
L2+=0.00000000743*cost(2.65209650690+106.27416795630*x);
L2+=0.00000000705*cost(0.08006443278+963.40270297140*x);
L2+=0.00000000724*cost(3.29664246938+628.85158605010*x);
L2+=0.00000000791*cost(1.64655202110+2001.44399215820*x);
L2+=0.00000000822*cost(2.74067639972+618.55664531160*x);
L2+=0.00000000761*cost(1.26393500358+1382.88734684660*x);
L2+=0.00000000650*cost(1.19590511216+422.66603761290*x);
L2+=0.00000000677*cost(1.88476058357+2104.53676637680*x);
L2+=0.00000000681*cost(5.47481665606+5760.49843189760*x);
L2+=0.00000000681*cost(3.11621209674+5746.27133789600*x);
L2+=0.00000000644*cost(4.68385640894+611.44309831080*x);
L2+=0.00000000752*cost(3.03497138894+2221.85663459700*x);
L2+=0.00000000641*cost(1.86274530783+636.71589257630*x);
L2+=0.00000000614*cost(3.07677356670+380.12776796000*x);
L2+=0.00000000635*cost(4.53916684689+9676.48103411560*x);
L2+=0.00000000635*cost(0.61458805483+9690.70812811720*x);
L2+=0.00000000822*cost(6.25170365084+423.41679713830*x);
L2+=0.00000000762*cost(4.32362906505+1802.37199072180*x);
L2+=0.00000000582*cost(0.84137872868+1891.23767093880*x);
L2+=0.00000000558*cost(3.96171840325+440.82528487760*x);
L2+=0.00000000624*cost(2.83657771014+1905.46476494040*x);
L2+=0.00000000711*cost(3.43538032357+824.74219374880*x);
L2+=0.00000000517*cost(1.10660016329+107.02492748170*x);
L2+=0.00000000535*cost(1.55761050176+1994.33044515740*x);
L2+=0.00000000501*cost(4.44389802599+647.01083331480*x);
L2+=0.00000000414*cost(5.37130370397+2228.97018159780*x);
L2+=0.00000000533*cost(2.54756313371+1781.03134971940*x);
L2+=0.00000000393*cost(1.26351262287+210.11770170030*x);
L2+=0.00000000433*cost(2.90103969634+1063.31408345230*x);
L2+=0.00000000384*cost(1.36194621083+203.00415469950*x);
L2+=0.00000000440*cost(1.46934545869+2214.74308759620*x);
L2+=0.00000000424*cost(4.98974282486+3178.14579056760*x);
L2+=0.00000000338*cost(2.72210106345+2324.94940881560*x);
L2+=0.00000000332*cost(0.37505564414+2655.56837247380*x);
L2+=0.00000000318*cost(6.11024720065+934.94851496820*x);
L2+=0.00000000405*cost(3.51005860013+2751.54759969160*x);
L2+=0.00000000388*cost(5.00609647265+2015.67108615980*x);
L2+=0.00000000424*cost(4.29668654117+5753.38488489680*x);
L2+=0.00000000328*cost(2.35571531981+1251.34038462480*x);
L2+=0.00000000316*cost(0.16949503062+1279.79457262800*x);
L2+=0.00000000345*cost(2.89328206121+2957.73314812880*x);
L2+=0.00000000303*cost(1.63964826684+2428.04218303420*x);
L2+=0.00000000328*cost(3.36132375845+1141.13406340540*x);
L2+=0.00000000294*cost(2.48947693371+2641.34127847220*x);
L2+=0.00000000350*cost(1.50537240918+2317.83586181480*x);
L2+=0.00000000287*cost(1.69638214958+2420.92863603340*x);
L2+=0.00000000272*cost(0.27466529753+319.57326339430*x);
L2+=0.00000000303*cost(2.43034117616+70.84944530420*x);
L2+=0.00000000251*cost(0.43544711316+3259.89792378380*x);
L2+=0.00000000224*cost(4.49752269293+5223.69391980220*x);
L2+=0.00000000272*cost(2.98590404673+1457.52593306200*x);
L2+=0.00000000228*cost(5.47896916415+1603.29998928540*x);
L2+=0.00000000288*cost(2.30146999217+2854.64037391020*x);
L2+=0.00000000207*cost(5.94297320087+9153.90361602180*x);
L2+=0.00000000243*cost(1.58604251447+2744.43405269080*x);
L2+=0.00000000228*cost(1.28182702946+2310.72231481400*x);
L2+=0.00000000224*cost(1.28623905132+3060.82592234740*x);
L2+=0.00000000222*cost(0.63265553397+3163.91869656600*x);
L2+=0.00000000242*cost(2.52382905368+3274.12501778540*x);
L2+=0.00000000188*cost(6.00513627145+92.04707395470*x);
L2+=0.00000000239*cost(1.93897157244+2413.81508903260*x);
L2+=0.00000000214*cost(1.14529237568+2531.13495725280*x);
L2+=0.00000000200*cost(3.42280996072+99.16062095550*x);
L2+=0.00000000179*cost(0.53892926207+2207.62954059540*x);
L2+=0.00000000177*cost(5.56545270243+2332.06295581640*x);
L2+=0.00000000172*cost(1.38604067808+945.99421523210*x);
L2+=0.00000000203*cost(0.41899069603+2840.41327990860*x);
L2+=0.00000000231*cost(2.26353330460+2097.42321937600*x);
L2+=0.00000000228*cost(3.82701076821+113.38771495710*x);
L2+=0.00000000165*cost(4.08776703733+6283.07584999140*x);
L2+=0.00000000202*cost(3.30429764992+3067.93946934820*x);
L2+=0.00000000224*cost(3.69285208525+2435.15573003500*x);
L2+=0.00000000214*cost(2.55756944911+2538.24850425360*x);
L2+=0.00000000203*cost(2.24205059922+67.66805156650*x);
L2+=0.00000000152*cost(5.48122906518+10213.28554621100*x);
L2+=0.00000000191*cost(2.68685722531+1773.91780271860*x);
L2+=0.00000000189*cost(2.95184620359+732.69511979410*x);
L2+=0.00000000149*cost(1.98737542735+1049.08698945070*x);
L2+=0.00000000163*cost(1.24084734609+3053.71237534660*x);
L2+=0.00000000171*cost(2.34210749987+1354.43315884340*x);
L2+=0.00000000112*cost(5.77407285790+547.85021235930*x);
L2+=0.00000000124*cost(0.14001204498+860.30992875280*x);
L2+=0.00000000086*cost(1.26924601636+511.53171782990*x);
L2+=0.00000000114*cost(5.15982838070+1592.25428902150*x);
L2+=0.00000000091*cost(1.48896790758+1567.73225428140*x);
L2+=0.00000000086*cost(4.34444949905+1069.67687092770*x);

double L3=0;
L3+=0.00006501665*cost(2.59862880482+7.11354700080*x);
L3+=0.00001356524*cost(1.34635886411+529.69096509460*x);
L3+=0.00000470716*cost(2.47503977883+14.22709400160*x);
L3+=0.00000416960*cost(3.24451243214+536.80451209540*x);
L3+=0.00000352851*cost(2.97360159003+522.57741809380*x);
L3+=0.00000154880*cost(2.07565585817+1059.38193018920*x);
L3+=0.00000086771*cost(2.51431584316+515.46387109300*x);
L3+=0.00000033538*cost(3.82633794497+1066.49547719000*x);
L3+=0.00000044378;
L3+=0.00000022644*cost(2.98231326774+543.91805909620*x);
L3+=0.00000023737*cost(1.27667172313+412.37109687440*x);
L3+=0.00000028457*cost(2.44754756058+206.18554843720*x);
L3+=0.00000019798*cost(2.10099934005+639.89728631400*x);
L3+=0.00000019740*cost(1.40255938973+419.48464387520*x);
L3+=0.00000018768*cost(1.59368403500+103.09277421860*x);
L3+=0.00000017033*cost(2.30214681202+21.34064100240*x);
L3+=0.00000016774*cost(2.59821460673+1589.07289528380*x);
L3+=0.00000016214*cost(3.14521117299+625.67019231240*x);
L3+=0.00000016055*cost(3.36030126297+1052.26838318840*x);
L3+=0.00000013392*cost(2.75973892202+95.97922721780*x);
L3+=0.00000013234*cost(2.53862244340+199.07200143640*x);
L3+=0.00000012611*cost(6.26578110400+426.59819087600*x);
L3+=0.00000008637*cost(2.26563256289+110.20632121940*x);
L3+=0.00000006725*cost(3.42566433316+309.27832265580*x);
L3+=0.00000008701*cost(1.76334960737+10.29494073850*x);
L3+=0.00000006527*cost(4.03869562907+728.76296653100*x);
L3+=0.00000005368*cost(5.25196153539+323.50541665740*x);
L3+=0.00000005675*cost(2.52096417685+508.35032409220*x);
L3+=0.00000005399*cost(2.91184687105+1045.15483618760*x);
L3+=0.00000003996*cost(4.30290261177+88.86568021700*x);
L3+=0.00000003857*cost(3.52381361552+302.16477565500*x);
L3+=0.00000003774*cost(4.09125315146+735.87651353180*x);
L3+=0.00000003269*cost(1.43175991274+956.28915597060*x);
L3+=0.00000002783*cost(4.35817507670+1596.18644228460*x);
L3+=0.00000002661*cost(1.25276590759+213.29909543800*x);
L3+=0.00000002553*cost(2.23785673285+117.31986822020*x);
L3+=0.00000002371*cost(2.89662409244+742.99006053260*x);
L3+=0.00000002656*cost(5.01505839848+838.96928775040*x);
L3+=0.00000001948*cost(2.77248294666+1169.58825140860*x);
L3+=0.00000002279*cost(2.35581871230+942.06206196900*x);
L3+=0.00000001474*cost(1.61011468581+220.41264243880*x);
L3+=0.00000001457*cost(3.09381959396+2118.76386037840*x);
L3+=0.00000001937*cost(5.01388256693+831.85574074960*x);
L3+=0.00000001585*cost(1.40097680805+405.25754987360*x);
L3+=0.00000001257*cost(3.97811260358+1155.36115740700*x);
L3+=0.00000001227*cost(3.45959919972+1073.60902419080*x);
L3+=0.00000000986*cost(3.39209446167+532.87235883230*x);
L3+=0.00000000942*cost(2.70200385825+191.95845443560*x);
L3+=0.00000000828*cost(1.48348768286+632.78373931320*x);
L3+=0.00000000797*cost(1.10706688850+1162.47470440780*x);
L3+=0.00000000822*cost(3.30295824153+1258.45393162560*x);
L3+=0.00000000710*cost(5.89798771980+853.19638175200*x);
L3+=0.00000000766*cost(3.66351539483+1581.95934828300*x);
L3+=0.00000000722*cost(3.74673245797+433.71173787680*x);
L3+=0.00000000663*cost(2.93063953915+1574.84580128220*x);
L3+=0.00000000658*cost(3.52797311863+525.75881183150*x);
L3+=0.00000000609*cost(4.14881313523+721.64941953020*x);
L3+=0.00000000598*cost(4.69454609357+81.75213321620*x);
L3+=0.00000000668*cost(1.96442971289+1272.68102562720*x);
L3+=0.00000000515*cost(1.57251270902+949.17560896980*x);
L3+=0.00000000658*cost(2.02329201466+526.50957135690*x);
L3+=0.00000000517*cost(4.35827478516+1368.66025284500*x);
L3+=0.00000000510*cost(4.95846155301+1148.24761040620*x);
L3+=0.00000000507*cost(4.31396370095+330.61896365820*x);
L3+=0.00000000567*cost(2.27813343743+551.03160609700*x);
L3+=0.00000000480*cost(3.86758235988+1361.54670584420*x);
L3+=0.00000000383*cost(0.24287136454+611.44309831080*x);
L3+=0.00000000434*cost(2.95461755540+1038.04128918680*x);
L3+=0.00000000377*cost(1.42957648215+124.43341522100*x);
L3+=0.00000000391*cost(4.07770324592+1471.75302706360*x);
L3+=0.00000000385*cost(4.70295179800+519.39602435610*x);
L3+=0.00000000428*cost(2.22472522305+539.98590583310*x);
L3+=0.00000000343*cost(4.83463725823+2125.87740737920*x);
L3+=0.00000000394*cost(4.52891996323+1464.63948006280*x);
L3+=0.00000000305*cost(2.02797683648+1485.98012106520*x);
L3+=0.00000000283*cost(0.97461612169+1905.46476494040*x);
L3+=0.00000000276*cost(3.83552772064+1062.56332392690*x);
L3+=0.00000000351*cost(2.06334334462+533.62311835770*x);
L3+=0.00000000304*cost(3.93228052293+1685.05212250160*x);
L3+=0.00000000322*cost(3.54763044791+846.08283475120*x);
L3+=0.00000000345*cost(4.18332148409+1788.14489672020*x);
L3+=0.00000000253*cost(3.12703531516+1994.33044515740*x);
L3+=0.00000000257*cost(1.05361498985+1478.86657406440*x);
L3+=0.00000000232*cost(1.69999081817+1692.16566950240*x);
L3+=0.00000000225*cost(2.51624149780+1891.23767093880*x);
L3+=0.00000000217*cost(4.58512911216+963.40270297140*x);
L3+=0.00000000277*cost(3.63353707701+1677.93857550080*x);
L3+=0.00000000242*cost(2.90163762388+2310.72231481400*x);
L3+=0.00000000211*cost(3.96419403991+295.05122865420*x);
L3+=0.00000000199*cost(5.17046500750+618.55664531160*x);
L3+=0.00000000256*cost(4.19052619061+1781.03134971940*x);
L3+=0.00000000192*cost(0.81556540966+2221.85663459700*x);
L3+=0.00000000187*cost(3.49895198981+2648.45482547300*x);
L3+=0.00000000208*cost(4.11838429822+2097.42321937600*x);
L3+=0.00000000183*cost(3.30680692414+1699.27921650320*x);
L3+=0.00000000231*cost(2.54516792766+1375.77379984580*x);
L3+=0.00000000189*cost(5.74277274755+2627.11418447060*x);
L3+=0.00000000214*cost(5.48031974537+1354.43315884340*x);
L3+=0.00000000220*cost(3.87471989410+2104.53676637680*x);
L3+=0.00000000171*cost(6.10827209399+1382.88734684660*x);
L3+=0.00000000184*cost(5.98415847544+750.10360753340*x);
L3+=0.00000000171*cost(5.25744961028+824.74219374880*x);
L3+=0.00000000151*cost(4.30799091626+2001.44399215820*x);
L3+=0.00000000140*cost(4.27089466070+1265.56747862640*x);
L3+=0.00000000097*cost(4.67188056608+647.01083331480*x);
L3+=0.00000000088*cost(2.43775210355+440.82528487760*x);
L3+=0.00000000075*cost(3.93105183253+1055.44977692610*x);
L3+=0.00000000079*cost(1.88533153220+934.94851496820*x);
L3+=0.00000000077*cost(3.80503143236+1603.29998928540*x);

double L4=0;
L4+=0.00000669483*cost(0.85282421090+7.11354700080*x);
L4+=0.00000099961*cost(0.74258947751+14.22709400160*x);
L4-=0.00000114019;
L4+=0.00000050024*cost(1.65346208248+536.80451209540*x);
L4+=0.00000043585*cost(5.82026386621+529.69096509460*x);
L4+=0.00000031813*cost(4.85829986650+522.57741809380*x);
L4+=0.00000014742*cost(4.29061635784+515.46387109300*x);
L4+=0.00000008899*cost(0.71478520741+1059.38193018920*x);
L4+=0.00000004957*cost(1.29502259434+543.91805909620*x);
L4+=0.00000004484*cost(2.31715516627+1066.49547719000*x);
L4+=0.00000004251*cost(0.48326797501+21.34064100240*x);
L4+=0.00000003100*cost(3.00245542678+412.37109687440*x);
L4+=0.00000002055*cost(0.39858940218+639.89728631400*x);
L4+=0.00000001762*cost(4.90536207307+625.67019231240*x);
L4+=0.00000001902*cost(4.25925620271+199.07200143640*x);
L4+=0.00000001695*cost(4.26147580803+206.18554843720*x);
L4+=0.00000001375*cost(5.25546955667+1052.26838318840*x);
L4+=0.00000001203*cost(4.71614633845+95.97922721780*x);
L4+=0.00000001086*cost(1.28604571172+1589.07289528380*x);
L4+=0.00000000982*cost(4.77990073662+1045.15483618760*x);
L4+=0.00000000935*cost(6.05847062188+88.86568021700*x);
L4+=0.00000000916*cost(5.77537499431+728.76296653100*x);
L4+=0.00000000890*cost(4.55299189579+426.59819087600*x);
L4+=0.00000000784*cost(3.40161567950+419.48464387520*x);
L4+=0.00000000768*cost(3.54672049322+103.09277421860*x);
L4+=0.00000000670*cost(0.52223307700+110.20632121940*x);
L4+=0.00000000415*cost(5.22809480633+302.16477565500*x);
L4+=0.00000000393*cost(6.24184621807+956.28915597060*x);
L4+=0.00000000381*cost(5.25466966040+309.27832265580*x);
L4+=0.00000000421*cost(0.59561318533+117.31986822020*x);
L4+=0.00000000346*cost(4.78348312106+508.35032409220*x);
L4+=0.00000000319*cost(3.47979828725+323.50541665740*x);
L4+=0.00000000331*cost(2.95893485883+1596.18644228460*x);
L4+=0.00000000295*cost(4.32713459459+942.06206196900*x);
L4+=0.00000000319*cost(0.47990052824+831.85574074960*x);
L4+=0.00000000251*cost(1.79898001222+1073.60902419080*x);
L4+=0.00000000212*cost(0.43917684084+220.41264243880*x);
L4+=0.00000000188*cost(1.12654974776+1169.58825140860*x);
L4+=0.00000000188*cost(2.16135407548+1361.54670584420*x);
L4+=0.00000000180*cost(3.43266428069+1148.24761040620*x);
L4+=0.00000000164*cost(1.92864127211+2118.76386037840*x);
L4+=0.00000000157*cost(3.02963907392+1272.68102562720*x);
L4+=0.00000000093*cost(5.60436000012+1581.95934828300*x);
L4+=0.00000000085*cost(5.02317256200+1155.36115740700*x);
L4+=0.00000000075*cost(3.13198879608+632.78373931320*x);

double L5=0;
L5+=0.00000049577*cost(5.25658966184+7.11354700080*x);
L5+=0.00000015761*cost(5.25126837478+14.22709400160*x);
L5+=0.00000004343*cost(0.01461869263+536.80451209540*x);
L5+=0.00000001526*cost(1.09739911439+522.57741809380*x);
L5+=0.00000000728*cost(5.85949047619+543.91805909620*x);
L5+=0.00000000694*cost(0.87382487754+515.46387109300*x);
L5-=0.00000000845;
L5+=0.00000000456*cost(0.81521692852+1066.49547719000*x);
L5+=0.00000000293*cost(5.62909357048+1059.38193018920*x);
L5+=0.00000000090*cost(0.21178119710+529.69096509460*x);

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
double rtd=180/3.141592653589793;

return rtd*trunc2(L0+L1*x+L2*x2+L3*x3+L4*x4+L5*x5); //END JUPITER
}


//Heliocentric latitude of Jupiter
double Bjupiter(double x)
{
double  Bx0=0;
 Bx0+=0.02268615703*cost(3.55852606718+529.69096509460*x);
 Bx0+=0.00109971634*cost(3.90809347389+1059.38193018920*x);
 Bx0+=0.00110090358;
 Bx0+=0.00008101427*cost(3.60509573368+522.57741809380*x);
 Bx0+=0.00006043996*cost(4.25883108794+1589.07289528380*x);
 Bx0+=0.00006437782*cost(0.30627121409+536.80451209540*x);
 Bx0+=0.00001106880*cost(2.98534421928+1162.47470440780*x);
 Bx0+=0.00000941651*cost(2.93619072405+1052.26838318840*x);
 Bx0+=0.00000894088*cost(1.75447429921+7.11354700080*x);
 Bx0+=0.00000767280*cost(2.15473594060+632.78373931320*x);
 Bx0+=0.00000944328*cost(1.67522288396+426.59819087600*x);
 Bx0+=0.00000684220*cost(3.67808770098+213.29909543800*x);
 Bx0+=0.00000629223*cost(0.64343282328+1066.49547719000*x);
 Bx0+=0.00000835861*cost(5.17881973234+103.09277421860*x);
 Bx0+=0.00000531670*cost(2.70305954352+110.20632121940*x);
 Bx0+=0.00000558524*cost(0.01354830508+846.08283475120*x);
 Bx0+=0.00000464449*cost(1.17337249185+949.17560896980*x);
 Bx0+=0.00000431072*cost(2.60825000494+419.48464387520*x);
 Bx0+=0.00000351433*cost(4.61062990714+2118.76386037840*x);
 Bx0+=0.00000123148*cost(3.34968181384+1692.16566950240*x);
 Bx0+=0.00000115038*cost(5.04892295442+316.39186965660*x);
 Bx0+=0.00000132160*cost(4.77816990670+742.99006053260*x);
 Bx0+=0.00000103402*cost(2.31878999565+1478.86657406440*x);
 Bx0+=0.00000116379*cost(1.38688232033+323.50541665740*x);
 Bx0+=0.00000102420*cost(3.15293785436+1581.95934828300*x);
 Bx0+=0.00000103762*cost(3.70103838110+515.46387109300*x);
 Bx0+=0.00000078650*cost(3.98318653238+1265.56747862640*x);
 Bx0+=0.00000069935*cost(2.56006216424+956.28915597060*x);
 Bx0+=0.00000055597*cost(0.37500753017+1375.77379984580*x);
 Bx0+=0.00000051986*cost(0.99007119033+1596.18644228460*x);
 Bx0+=0.00000055194*cost(0.40176412035+525.75881183150*x);
 Bx0+=0.00000063456*cost(4.50073574333+735.87651353180*x);
 Bx0+=0.00000049691*cost(0.18649893085+543.91805909620*x);
 Bx0+=0.00000048831*cost(3.57260550671+533.62311835770*x);
 Bx0+=0.00000028353*cost(1.53532744749+625.67019231240*x);
 Bx0+=0.00000029209*cost(5.43145863011+206.18554843720*x);
 Bx0+=0.00000023255*cost(5.95197992848+838.96928775040*x);
 Bx0+=0.00000022841*cost(6.19262787685+532.87235883230*x);
 Bx0+=0.00000023202*cost(4.06473368575+526.50957135690*x);
 Bx0+=0.00000024436*cost(6.10947656959+1169.58825140860*x);
 Bx0+=0.00000021116*cost(4.96322972735+2648.45482547300*x);
 Bx0+=0.00000017879*cost(3.08704395969+1795.25844372100*x);
 Bx0+=0.00000016234*cost(4.83515727869+1368.66025284500*x);
 Bx0+=0.00000021314*cost(2.69476951059+1045.15483618760*x);
 Bx0+=0.00000015740*cost(1.15130330106+942.06206196900*x);
 Bx0+=0.00000017325*cost(1.61550009206+14.22709400160*x);
 Bx0+=0.00000013396*cost(2.30539585502+853.19638175200*x);
 Bx0+=0.00000011904*cost(3.09811974536+2111.65031337760*x);
 Bx0+=0.00000011734*cost(2.83006431723+2008.55753915900*x);
 Bx0+=0.00000011291*cost(0.98957560201+433.71173787680*x);
 Bx0+=0.00000011830*cost(4.76527836803+309.27832265580*x);
 Bx0+=0.00000010702*cost(3.70181397065+2221.85663459700*x);
 Bx0+=0.00000010815*cost(5.81958878617+1272.68102562720*x);
 Bx0+=0.00000013505*cost(3.28126975760+1155.36115740700*x);
 Bx0+=0.00000010179*cost(2.58691128827+117.31986822020*x);
 Bx0+=0.00000010632*cost(5.23487936086+95.97922721780*x);
 Bx0+=0.00000008771*cost(0.40456546655+220.41264243880*x);
 Bx0+=0.00000007439*cost(2.94638292086+412.37109687440*x);
 Bx0+=0.00000006151*cost(2.69100382247+380.12776796000*x);
 Bx0+=0.00000005028*cost(0.72750312028+1055.44977692610*x);
 Bx0+=0.00000004939*cost(0.73756716762+1905.46476494040*x);
 Bx0+=0.00000005421*cost(4.08612438558+1685.05212250160*x);
 Bx0+=0.00000005936*cost(4.32059910537+1063.31408345230*x);
 Bx0+=0.00000004737*cost(4.09303016850+527.24328453980*x);
 Bx0+=0.00000004010*cost(0.51530008355+1073.60902419080*x);
 Bx0+=0.00000004709*cost(1.84067645204+984.60033162190*x);
 Bx0+=0.00000003974*cost(1.33608029246+2125.87740737920*x);
 Bx0+=0.00000003762*cost(3.58647039394+529.73914920440*x);
 Bx0+=0.00000004731*cost(6.16377350841+532.13864564940*x);
 Bx0+=0.00000004666*cost(5.88762905802+639.89728631400*x);
 Bx0+=0.00000003763*cost(0.38865925413+529.64278098480*x);
 Bx0+=0.00000003409*cost(4.05398247269+1898.35121793960*x);
 Bx0+=0.00000003457*cost(3.43865563497+1485.98012106520*x);
 Bx0+=0.00000004229*cost(2.23767157901+74.78159856730*x);
 Bx0+=0.00000003091*cost(0.16470256025+1699.27921650320*x);
 Bx0+=0.00000002975*cost(0.72268908074+530.65417294110*x);
 Bx0+=0.00000003162*cost(1.25048416420+330.61896365820*x);
 Bx0+=0.00000002727*cost(4.37679213321+149.56319713460*x);
 Bx0+=0.00000002837*cost(0.05987107395+1439.50969814920*x);
 Bx0+=0.00000002983*cost(3.25251207220+528.72775724810*x);
 Bx0+=0.00000002232*cost(0.26149880534+1062.56332392690*x);
 Bx0+=0.00000002464*cost(1.16913304420+453.42489381900*x);
 Bx0+=0.00000002596*cost(3.30510149086+2324.94940881560*x);
 Bx0+=0.00000001988*cost(2.85269577619+1574.84580128220*x);
 Bx0+=0.00000002527*cost(5.94458202950+909.81873305460*x);
 Bx0+=0.00000002269*cost(1.30379329597+3.93215326310*x);
 Bx0+=0.00000001742*cost(4.49909767044+1258.45393162560*x);
 Bx0+=0.00000001714*cost(4.12945878208+2001.44399215820*x);
 Bx0+=0.00000002029*cost(3.97938086639+1056.20053645150*x);
 Bx0+=0.00000001667*cost(0.36037092553+10213.28554621100*x);
 Bx0+=0.00000001579*cost(6.11640144795+1802.37199072180*x);
 Bx0+=0.00000001393*cost(3.69324470827+2214.74308759620*x);
 Bx0+=0.00000001604*cost(1.98841031703+38.13303563780*x);
 Bx0+=0.00000001325*cost(1.74025919863+529.16970023280*x);
 Bx0+=0.00000001451*cost(2.39804501178+2428.04218303420*x);
 Bx0+=0.00000001594*cost(2.07556780757+1021.24889455140*x);
 Bx0+=0.00000001320*cost(1.33770977126+618.55664531160*x);
 Bx0+=0.00000001346*cost(3.27591492540+2641.34127847220*x);
 Bx0+=0.00000001230*cost(0.19552728220+305.34616939270*x);
 Bx0+=0.00000001223*cost(2.86681556337+1382.88734684660*x);
 Bx0+=0.00000001324*cost(2.23549334986+530.21222995640*x);
 Bx0+=0.00000001056*cost(3.80579750957+76.26607127560*x);
 Bx0+=0.00000001050*cost(4.68011652614+1788.14489672020*x);
 Bx0+=0.00000001226*cost(5.34003255221+3178.14579056760*x);
 Bx0+=0.00000001009*cost(3.19608028376+2538.24850425360*x);
 Bx0+=0.00000001266*cost(3.04704446731+604.47256366190*x);
 Bx0+=0.00000000954*cost(3.86932544808+728.76296653100*x);
 Bx0+=0.00000001124*cost(1.59560367480+3.18139373770*x);
 Bx0+=0.00000000978*cost(0.25223689838+983.11585891360*x);
 Bx0+=0.00000000948*cost(0.21552742733+750.10360753340*x);
 Bx0+=0.00000000946*cost(3.93927748120+508.35032409220*x);
 Bx0+=0.00000000920*cost(1.14672086939+963.40270297140*x);
 Bx0+=0.00000000817*cost(5.93809619876+831.85574074960*x);
 Bx0+=0.00000000770*cost(2.96062737592+526.77020378780*x);
 Bx0+=0.00000001017*cost(5.55711112145+199.07200143640*x);
 Bx0+=0.00000000761*cost(1.38163787157+532.61172640140*x);
 Bx0+=0.00000000726*cost(3.98337964395+2317.83586181480*x);
 Bx0+=0.00000000862*cost(0.87975657414+490.33408917940*x);
 Bx0+=0.00000000868*cost(3.44331872364+569.04784100980*x);
 Bx0+=0.00000000711*cost(4.11107052823+2751.54759969160*x);
 Bx0+=0.00000000708*cost(0.33555577415+528.94020556920*x);
 Bx0+=0.00000000708*cost(4.00539820601+530.44172462000*x);
 Bx0+=0.00000000656*cost(4.39568451439+519.39602435610*x);
 Bx0+=0.00000000801*cost(4.03984430862+1364.72809958190*x);
 Bx0+=0.00000000679*cost(1.18645749024+525.49817940060*x);
 Bx0+=0.00000000645*cost(5.10510349996+1361.54670584420*x);
 Bx0+=0.00000000668*cost(3.15607509055+533.88375078860*x);
 Bx0+=0.00000000663*cost(0.73722024843+5223.69391980220*x);
 Bx0+=0.00000000663*cost(1.57092786811+6283.07584999140*x);
 Bx0+=0.00000000543*cost(0.26376529935+227.52618943960*x);
 Bx0+=0.00000000525*cost(6.22318693939+539.98590583310*x);
 Bx0+=0.00000000513*cost(4.98337900151+302.16477565500*x);
 Bx0+=0.00000000544*cost(2.22227019273+2744.43405269080*x);
 Bx0+=0.00000000532*cost(2.62425372687+99.16062095550*x);
 Bx0+=0.00000000602*cost(1.56074089013+454.90936652730*x);
 Bx0+=0.00000000518*cost(0.26343805959+551.03160609700*x);
 Bx0+=0.00000000516*cost(1.09376390349+934.94851496820*x);
 Bx0+=0.00000000659*cost(0.62560671589+1512.80682400820*x);
 Bx0+=0.00000000524*cost(0.64710955846+524.06189080210*x);
 Bx0+=0.00000000516*cost(3.69478866795+535.32003938710*x);
 Bx0+=0.00000000491*cost(3.63039940597+2531.13495725280*x);
 Bx0+=0.00000000570*cost(0.61976758791+540.73666535850*x);
 Bx0+=0.00000000496*cost(2.19398015038+1514.29129671650*x);
 Bx0+=0.00000000532*cost(0.20040217534+525.02509864860*x);
 Bx0+=0.00000000493*cost(0.39160693598+224.34479570190*x);
 Bx0+=0.00000000449*cost(0.62392433691+529.53090640020*x);
 Bx0+=0.00000000449*cost(3.71676131146+529.85102378900*x);
 Bx0+=0.00000000450*cost(5.02467015031+1048.33622992530*x);
 Bx0+=0.00000000428*cost(5.44804660290+11.04570026390*x);
 Bx0+=0.00000000499*cost(4.13924061941+534.35683154060*x);
 Bx0+=0.00000000528*cost(1.76471074936+524.27433912320*x);
 Bx0+=0.00000000454*cost(4.53321742354+1056.93424963440*x);
 Bx0+=0.00000000520*cost(2.57406093768+535.10759106600*x);
 Bx0+=0.00000000398*cost(1.40345870113+960.22130923370*x);
 Bx0+=0.00000000457*cost(4.17708652827+2104.53676637680*x);
 Bx0+=0.00000000505*cost(5.36536256321+1057.89745748090*x);
 Bx0+=0.00000000535*cost(4.80455380313+1593.00504854690*x);
 Bx0+=0.00000000415*cost(0.96548127237+2435.15573003500*x);
 Bx0+=0.00000000519*cost(0.54543519483+1061.82961074400*x);
 Bx0+=0.00000000359*cost(4.02704454075+1059.43011429900*x);
 Bx0+=0.00000000356*cost(2.66818105522+835.03713448730*x);
 Bx0+=0.00000000443*cost(5.27513700376+1.48447270830*x);
 Bx0+=0.00000000358*cost(5.94423960514+440.82528487760*x);
 Bx0+=0.00000000471*cost(6.05791940453+1471.75302706360*x);
 Bx0+=0.00000000386*cost(2.15984900214+9153.90361602180*x);
 Bx0+=0.00000000424*cost(2.70929670030+1038.04128918680*x);
 Bx0+=0.00000000359*cost(0.82922836987+1059.33374607940*x);
 Bx0+=0.00000000310*cost(0.88102053266+529.90341341570*x);
 Bx0+=0.00000000310*cost(3.45966511571+529.47851677350*x);
 Bx0+=0.00000000300*cost(3.70331799503+2634.22773147140*x);
 Bx0+=0.00000000292*cost(2.63594456361+415.55249061210*x);
 Bx0+=0.00000000279*cost(1.60669121578+643.82943957710*x);
 Bx0+=0.00000000291*cost(5.83134071820+1148.24761040620*x);
 Bx0+=0.00000000370*cost(5.71572992274+531.17543780290*x);
 Bx0+=0.00000000268*cost(5.39275891813+1891.23767093880*x);
 Bx0+=0.00000000275*cost(3.34108666036+518.64526483070*x);
 Bx0+=0.00000000269*cost(1.06051406954+1585.14074202070*x);
 Bx0+=0.00000000306*cost(2.50289017370+511.53171782990*x);
 Bx0+=0.00000000295*cost(1.84394223501+547.85021235930*x);
 Bx0+=0.00000000254*cost(2.98312992496+1134.16352875650*x);
 Bx0+=0.00000000289*cost(1.86070918711+21.34064100240*x);
 Bx0+=0.00000000265*cost(4.93075479744+679.25416222920*x);
 Bx0+=0.00000000250*cost(0.42860925124+1969.20066324380*x);
 Bx0+=0.00000000308*cost(2.67237933272+2957.73314812880*x);
 Bx0+=0.00000000313*cost(4.88085697819+528.20649238630*x);
 Bx0+=0.00000000222*cost(4.78828764413+514.71311156760*x);
 Bx0+=0.00000000221*cost(4.32763468981+1677.93857550080*x);
 Bx0+=0.00000000217*cost(3.46278526461+2950.61960112800*x);
 Bx0+=0.00000000216*cost(0.52207667980+2228.97018159780*x);
 Bx0+=0.00000000214*cost(5.83569926578+544.66881862160*x);
 Bx0+=0.00000000283*cost(2.88709716090+35.42472265210*x);
 Bx0+=0.00000000272*cost(1.65708415457+3060.82592234740*x);
 Bx0+=0.00000000234*cost(1.68821537711+2655.56837247380*x);
 Bx0+=0.00000000205*cost(3.36186888290+2847.52682690940*x);
 Bx0+=0.00000000264*cost(3.62722625694+2420.92863603340*x);
 Bx0+=0.00000000191*cost(4.26821147044+430.53034413910*x);
 Bx0+=0.00000000179*cost(3.91470663005+3340.61242669980*x);
 Bx0+=0.00000000180*cost(0.04531671003+387.24131496080*x);
 Bx0+=0.00000000241*cost(4.03927631611+494.26624244250*x);
 Bx0+=0.00000000176*cost(4.26298906325+672.14061522840*x);
 Bx0+=0.00000000187*cost(2.72587420586+299.12639426920*x);
 Bx0+=0.00000000234*cost(1.34474827450+173.94221952280*x);
 Bx0+=0.00000000171*cost(0.85473611718+1603.29998928540*x);
 Bx0+=0.00000000224*cost(0.33130232434+565.11568774670*x);
 Bx0+=0.00000000200*cost(1.27632489123+39.35687591520*x);
 Bx0+=0.00000000170*cost(4.96479470273+1464.63948006280*x);
 Bx0+=0.00000000211*cost(1.00937080256+523.54062594030*x);
 Bx0+=0.00000000210*cost(3.75793720248+2854.64037391020*x);
 Bx0+=0.00000000162*cost(5.87784787295+3480.31056622260*x);
 Bx0+=0.00000000163*cost(4.62850343495+2015.67108615980*x);
 Bx0+=0.00000000191*cost(3.33159283750+535.84130424890*x);
 Bx0+=0.00000000151*cost(1.17096741034+1060.34513803570*x);
 Bx0+=0.00000000160*cost(1.81852636004+312.45971639350*x);
 Bx0+=0.00000000158*cost(2.59595816107+529.43033266370*x);
 Bx0+=0.00000000158*cost(1.74472748730+529.95159752550*x);
 Bx0+=0.00000000173*cost(3.62399350412+230.56457082540*x);
 Bx0+=0.00000000142*cost(0.70435921398+522.52923398400*x);
 Bx0+=0.00000000144*cost(5.35763122430+107.02492748170*x);
 Bx0+=0.00000000144*cost(6.13954848857+1158.54255114470*x);
 Bx0+=0.00000000178*cost(0.27566275049+3906.90875709860*x);
 Bx0+=0.00000000126*cost(5.14832919826+2207.62954059540*x);
 Bx0+=0.00000000126*cost(3.41994798109+2.44768055480*x);
 Bx0+=0.00000000127*cost(0.39825164051+70.84944530420*x);
 Bx0+=0.00000000123*cost(4.77865550523+2524.02141025200*x);
 Bx0+=0.00000000123*cost(0.46184813516+647.01083331480*x);
 Bx0+=0.00000000144*cost(3.60261852727+1058.41872234270*x);
 Bx0+=0.00000000158*cost(3.76231915252+92.04707395470*x);
 Bx0+=0.00000000119*cost(4.08266911415+1585.89150154610*x);
 Bx0+=0.00000000125*cost(2.35496721797+3163.91869656600*x);
 Bx0+=0.00000000122*cost(3.21027426317+3377.21779200400*x);
 Bx0+=0.00000000121*cost(3.39770381916+18.15924726470*x);
 Bx0+=0.00000000131*cost(1.67926417552+1289.94650101460*x);
 Bx0+=0.00000000115*cost(2.35735471566+1550.93985964600*x);
 Bx0+=0.00000000126*cost(2.40833814513+106.27416795630*x);
 Bx0+=0.00000000131*cost(1.37610474529+1023.95720753710*x);
 Bx0+=0.00000000121*cost(1.60252617273+10.29494073850*x);
 Bx0+=0.00000000121*cost(0.61420823557+1592.25428902150*x);
 Bx0+=0.00000000135*cost(3.60177675518+124.43341522100*x);
 Bx0+=0.00000000137*cost(2.41724947062+3274.12501778540*x);
 Bx0+=0.00000000129*cost(0.09702914345+2332.06295581640*x);
 Bx0+=0.00000000093*cost(4.88949890397+1098.73880610440*x);
 Bx0+=0.00000000106*cost(5.18592950792+2281.23049651060*x);
 Bx0+=0.00000000114*cost(2.96523316419+1166.40685767090*x);
 Bx0+=0.00000000092*cost(1.65166124027+860.30992875280*x);
 Bx0+=0.00000000102*cost(3.64093193142+3171.03224356680*x);
 Bx0+=0.00000000103*cost(1.63066232967+1894.41906467650*x);
 Bx0+=0.00000000080*cost(0.38766601876+4694.00295470760*x);
 Bx0+=0.00000000074*cost(3.86865238736+3067.93946934820*x);
 Bx0+=0.00000000095*cost(1.66362447044+1151.42900414390*x);

double B1=0;
B1+=0.00177351787*cost(5.70166488486+529.69096509460*x);
B1+=0.00003230171*cost(5.77941619340+1059.38193018920*x);
B1+=0.00003081364*cost(5.47464296527+522.57741809380*x);
B1+=0.00002211914*cost(4.73477480209+536.80451209540*x);
B1-=0.00001694232;
B1+=0.00000346445*cost(4.74595174109+1052.26838318840*x);
B1+=0.00000234264*cost(5.18856099929+1066.49547719000*x);
B1+=0.00000196154*cost(6.18554286642+7.11354700080*x);
B1+=0.00000150468*cost(3.92721226087+1589.07289528380*x);
B1+=0.00000114128*cost(3.43897271830+632.78373931320*x);
B1+=0.00000096667*cost(2.91426304090+949.17560896980*x);
B1+=0.00000076599*cost(2.50522188662+103.09277421860*x);
B1+=0.00000081671*cost(5.07666097497+1162.47470440780*x);
B1+=0.00000076572*cost(0.61288981445+419.48464387520*x);
B1+=0.00000073875*cost(5.49958292155+515.46387109300*x);
B1+=0.00000049915*cost(3.94799616572+735.87651353180*x);
B1+=0.00000060544*cost(5.44740084359+213.29909543800*x);
B1+=0.00000036561*cost(4.69828392839+543.91805909620*x);
B1+=0.00000046032*cost(0.53850360901+110.20632121940*x);
B1+=0.00000045123*cost(1.89516645239+846.08283475120*x);
B1+=0.00000036019*cost(6.10952578764+316.39186965660*x);
B1+=0.00000031975*cost(4.92452714629+1581.95934828300*x);
B1+=0.00000021015*cost(5.62957731410+1596.18644228460*x);
B1+=0.00000023156*cost(5.84829490183+323.50541665740*x);
B1+=0.00000024719*cost(3.94107395247+2118.76386037840*x);
B1+=0.00000017274*cost(5.65310656429+533.62311835770*x);
B1+=0.00000016521*cost(5.89840100621+526.50957135690*x);
B1+=0.00000016698*cost(5.66663034948+1265.56747862640*x);
B1+=0.00000015815*cost(4.43314786393+1045.15483618760*x);
B1+=0.00000013398*cost(4.30179033605+532.87235883230*x);
B1+=0.00000011744*cost(1.80990486955+956.28915597060*x);
B1+=0.00000011925*cost(4.30094564154+525.75881183150*x);
B1+=0.00000009514*cost(2.02589667166+206.18554843720*x);
B1+=0.00000010542*cost(6.15533910933+14.22709400160*x);
B1+=0.00000008414*cost(3.92910450340+1478.86657406440*x);
B1+=0.00000008099*cost(4.20152809071+1169.58825140860*x);
B1+=0.00000007712*cost(2.99160389601+942.06206196900*x);
B1+=0.00000008825*cost(1.55897920307+426.59819087600*x);
B1+=0.00000008884*cost(4.87430124264+1155.36115740700*x);
B1+=0.00000007793*cost(3.84684930196+625.67019231240*x);
B1+=0.00000005646*cost(3.40915964493+639.89728631400*x);
B1+=0.00000004615*cost(0.83374662294+117.31986822020*x);
B1+=0.00000004020*cost(5.50502127885+433.71173787680*x);
B1+=0.00000003704*cost(0.90226777963+95.97922721780*x);
B1+=0.00000003859*cost(0.69640284662+853.19638175200*x);
B1+=0.00000003091*cost(5.09115860882+1073.60902419080*x);
B1+=0.00000003360*cost(5.10133284081+1692.16566950240*x);
B1+=0.00000002892*cost(4.90418916660+220.41264243880*x);
B1+=0.00000002772*cost(5.09066125724+2111.65031337760*x);
B1+=0.00000002425*cost(3.74438653232+742.99006053260*x);
B1+=0.00000002558*cost(5.46955948791+1795.25844372100*x);
B1+=0.00000002466*cost(4.22278355430+2648.45482547300*x);
B1+=0.00000001968*cost(0.57192251841+309.27832265580*x);
B1+=0.00000001794*cost(4.60765219417+1272.68102562720*x);
B1+=0.00000001822*cost(1.98842964323+1375.77379984580*x);
B1+=0.00000001703*cost(6.12660562937+2125.87740737920*x);
B1+=0.00000002011*cost(5.00936865256+412.37109687440*x);
B1+=0.00000001645*cost(0.08830372958+1063.31408345230*x);
B1+=0.00000001875*cost(5.81006158403+330.61896365820*x);
B1+=0.00000001741*cost(4.58650290431+1574.84580128220*x);
B1+=0.00000001529*cost(5.81660291389+1258.45393162560*x);
B1+=0.00000001916*cost(0.85150399517+1368.66025284500*x);
B1+=0.00000001614*cost(4.36839107221+728.76296653100*x);
B1+=0.00000001510*cost(2.79374165455+1485.98012106520*x);
B1+=0.00000001333*cost(4.84260898693+1062.56332392690*x);
B1+=0.00000001359*cost(5.16511980864+838.96928775040*x);
B1+=0.00000001165*cost(5.66275740881+508.35032409220*x);
B1+=0.00000001092*cost(4.68797557406+1699.27921650320*x);
B1+=0.00000001438*cost(5.78105679279+1056.20053645150*x);
B1+=0.00000001083*cost(3.99886917926+1471.75302706360*x);
B1+=0.00000001002*cost(4.79949608524+1055.44977692610*x);
B1+=0.00000000749*cost(6.14400862030+519.39602435610*x);
B1+=0.00000000657*cost(5.63765568876+1898.35121793960*x);
B1+=0.00000000702*cost(5.04126574492+1685.05212250160*x);
B1+=0.00000000607*cost(3.15707515246+618.55664531160*x);
B1+=0.00000000587*cost(1.37658820775+199.07200143640*x);
B1+=0.00000000552*cost(4.80657729450+551.03160609700*x);
B1+=0.00000000494*cost(4.43417307482+539.98590583310*x);
B1+=0.00000000517*cost(0.05161181997+3.18139373770*x);
B1+=0.00000000469*cost(3.81715950042+2008.55753915900*x);
B1+=0.00000000415*cost(1.34693184108+1382.88734684660*x);
B1+=0.00000000382*cost(4.86764073919+227.52618943960*x);
B1+=0.00000000473*cost(1.72405831407+532.13864564940*x);
B1+=0.00000000458*cost(4.44604993015+1038.04128918680*x);
B1+=0.00000000376*cost(2.23190744786+529.64278098480*x);
B1+=0.00000000451*cost(3.75869883836+984.60033162190*x);
B1+=0.00000000376*cost(5.42971857629+529.73914920440*x);
B1+=0.00000000389*cost(1.92698506631+525.02509864860*x);
B1+=0.00000000364*cost(3.35456685746+2221.85663459700*x);
B1+=0.00000000476*cost(5.93625415892+527.24328453980*x);
B1+=0.00000000383*cost(6.12255867339+149.56319713460*x);
B1+=0.00000000301*cost(4.09378934049+440.82528487760*x);
B1+=0.00000000310*cost(5.58150418981+2428.04218303420*x);
B1+=0.00000000282*cost(4.85996662231+1788.14489672020*x);
B1+=0.00000000298*cost(5.09589374634+528.72775724810*x);
B1+=0.00000000340*cost(4.56537070220+750.10360753340*x);
B1+=0.00000000272*cost(2.35346960340+534.35683154060*x);
B1+=0.00000000360*cost(3.91050161665+74.78159856730*x);
B1+=0.00000000299*cost(1.43093538841+909.81873305460*x);
B1+=0.00000000297*cost(2.56584512211+530.65417294110*x);
B1+=0.00000000235*cost(4.81644489422+535.10759106600*x);
B1+=0.00000000306*cost(0.68420442848+380.12776796000*x);
B1+=0.00000000236*cost(4.63162956792+526.77020378780*x);
B1+=0.00000000270*cost(0.18549916939+21.34064100240*x);
B1+=0.00000000288*cost(4.26655874393+1802.37199072180*x);
B1+=0.00000000196*cost(5.35950443033+2214.74308759620*x);
B1+=0.00000000190*cost(4.54615193260+2104.53676637680*x);
B1+=0.00000000193*cost(4.35426216497+511.53171782990*x);
B1+=0.00000000178*cost(4.51895208036+3178.14579056760*x);
B1+=0.00000000194*cost(0.57050756837+1361.54670584420*x);
B1+=0.00000000200*cost(1.48040474749+302.16477565500*x);
B1+=0.00000000168*cost(5.40141749419+524.27433912320*x);
B1+=0.00000000152*cost(0.68077486546+1905.46476494040*x);
B1+=0.00000000149*cost(1.06678990744+831.85574074960*x);
B1+=0.00000000182*cost(3.62401009613+38.13303563780*x);
B1+=0.00000000176*cost(5.64331384323+963.40270297140*x);
B1+=0.00000000184*cost(4.48850356629+604.47256366190*x);
B1+=0.00000000133*cost(5.45026366125+2641.34127847220*x);
B1+=0.00000000143*cost(2.21577268292+1439.50969814920*x);
B1+=0.00000000130*cost(4.88155705493+2531.13495725280*x);
B1+=0.00000000129*cost(6.15206333598+547.85021235930*x);
B1+=0.00000000133*cost(5.43193972385+1603.29998928540*x);
B1+=0.00000000133*cost(3.49297492409+529.16970023280*x);
B1+=0.00000000132*cost(3.98820790955+530.21222995640*x);
B1+=0.00000000118*cost(5.38352943814+1891.23767093880*x);
B1+=0.00000000133*cost(5.65694269884+76.26607127560*x);
B1+=0.00000000145*cost(2.94976686191+454.90936652730*x);
B1+=0.00000000115*cost(3.29206553804+3.93215326310*x);
B1+=0.00000000102*cost(4.48856749557+2001.44399215820*x);
B1+=0.00000000106*cost(6.08434275898+10.29494073850*x);
B1+=0.00000000093*cost(5.84737771840+2324.94940881560*x);
B1+=0.00000000101*cost(0.15815934254+2655.56837247380*x);
B1+=0.00000000115*cost(3.59221021604+2015.67108615980*x);
B1+=0.00000000103*cost(4.70399583323+305.34616939270*x);
B1+=0.00000000084*cost(0.44180206332+1593.00504854690*x);
B1+=0.00000000092*cost(2.44863388631+490.33408917940*x);
B1+=0.00000000087*cost(6.23817512863+6283.07584999140*x);
B1+=0.00000000095*cost(3.30154605532+2317.83586181480*x);
B1+=0.00000000072*cost(1.90578907085+528.94020556920*x);
B1+=0.00000000072*cost(5.57619428876+530.44172462000*x);
B1+=0.00000000078*cost(5.97323507836+1585.89150154610*x);

double B2=0;
B2+=0.00008094051*cost(1.46322843658+529.69096509460*x);
B2+=0.00000742415*cost(0.95691639003+522.57741809380*x);
B2-=0.00000813244;
B2+=0.00000398951*cost(2.89888666447+536.80451209540*x);
B2+=0.00000342226*cost(1.44683789727+1059.38193018920*x);
B2+=0.00000073948*cost(0.40724675866+1052.26838318840*x);
B2+=0.00000046151*cost(3.48036895772+1066.49547719000*x);
B2+=0.00000029314*cost(0.99088831805+515.46387109300*x);
B2+=0.00000029717*cost(1.92504171329+1589.07289528380*x);
B2+=0.00000022753*cost(4.27124052435+7.11354700080*x);
B2+=0.00000013916*cost(2.92242387338+543.91805909620*x);
B2+=0.00000012067*cost(5.22168932482+632.78373931320*x);
B2+=0.00000010703*cost(4.88024222475+949.17560896980*x);
B2+=0.00000006078*cost(6.21089108431+1045.15483618760*x);
B2+=0.00000005935*cost(0.52977760072+1581.95934828300*x);
B2+=0.00000005037*cost(1.43444929374+526.50957135690*x);
B2+=0.00000004564*cost(0.91811732585+1162.47470440780*x);
B2+=0.00000004547*cost(4.01953745202+1596.18644228460*x);
B2+=0.00000005098*cost(6.03169795231+735.87651353180*x);
B2+=0.00000003593*cost(4.54080164408+110.20632121940*x);
B2+=0.00000003443*cost(1.38618954572+533.62311835770*x);
B2+=0.00000003277*cost(4.39650286553+14.22709400160*x);
B2+=0.00000003407*cost(0.42275631534+419.48464387520*x);
B2+=0.00000002904*cost(2.06041641723+316.39186965660*x);
B2+=0.00000002541*cost(3.98323842017+323.50541665740*x);
B2+=0.00000003113*cost(2.48079280193+2118.76386037840*x);
B2+=0.00000003061*cost(2.39880866911+532.87235883230*x);
B2+=0.00000002155*cost(4.77990637140+942.06206196900*x);
B2+=0.00000002143*cost(3.88727338786+426.59819087600*x);
B2+=0.00000002252*cost(0.37196434120+1155.36115740700*x);
B2+=0.00000002019*cost(3.89985000464+846.08283475120*x);
B2+=0.00000001857*cost(1.19658907851+103.09277421860*x);
B2+=0.00000001683*cost(1.42264195434+1265.56747862640*x);
B2+=0.00000002313*cost(0.87671613055+213.29909543800*x);
B2+=0.00000001443*cost(2.38565505909+1169.58825140860*x);
B2+=0.00000001823*cost(5.80106463776+625.67019231240*x);
B2+=0.00000001728*cost(2.24114678267+525.75881183150*x);
B2+=0.00000001198*cost(0.03252059731+956.28915597060*x);
B2+=0.00000001138*cost(3.46420904745+1073.60902419080*x);
B2+=0.00000001086*cost(5.35279146700+117.31986822020*x);
B2+=0.00000000840*cost(2.89946334223+95.97922721780*x);
B2+=0.00000000746*cost(5.53017890231+1478.86657406440*x);
B2+=0.00000000944*cost(4.05587053500+206.18554843720*x);
B2+=0.00000000758*cost(3.74770617289+433.71173787680*x);
B2+=0.00000000673*cost(1.26396626349+508.35032409220*x);
B2+=0.00000000889*cost(6.07878453176+728.76296653100*x);
B2+=0.00000000600*cost(1.82954494089+639.89728631400*x);
B2+=0.00000000589*cost(1.23625943417+1258.45393162560*x);
B2+=0.00000000619*cost(0.67923057477+838.96928775040*x);
B2+=0.00000000566*cost(5.36336098734+742.99006053260*x);
B2+=0.00000000648*cost(5.32990375008+853.19638175200*x);
B2+=0.00000000553*cost(3.15511946637+220.41264243880*x);
B2+=0.00000000432*cost(1.03719283016+1692.16566950240*x);
B2+=0.00000000435*cost(1.65056479007+519.39602435610*x);
B2+=0.00000000430*cost(1.41830384501+412.37109687440*x);
B2+=0.00000000431*cost(2.20986254651+1368.66025284500*x);
B2+=0.00000000415*cost(4.35372561905+330.61896365820*x);
B2+=0.00000000438*cost(0.16552277290+1574.84580128220*x);
B2+=0.00000000312*cost(4.50639455819+2125.87740737920*x);
B2+=0.00000000280*cost(3.01441283033+551.03160609700*x);
B2+=0.00000000309*cost(0.67399908949+2111.65031337760*x);
B2+=0.00000000301*cost(3.06868080871+1062.56332392690*x);
B2+=0.00000000236*cost(1.94696842200+1485.98012106520*x);
B2+=0.00000000235*cost(3.41850395941+199.07200143640*x);
B2+=0.00000000246*cost(2.61803442505+309.27832265580*x);
B2+=0.00000000238*cost(2.56643737684+539.98590583310*x);
B2+=0.00000000248*cost(2.96997778167+2648.45482547300*x);
B2+=0.00000000209*cost(5.82481690851+1471.75302706360*x);
B2+=0.00000000205*cost(1.20202002469+1056.20053645150*x);
B2+=0.00000000188*cost(0.97113663101+1685.05212250160*x);
B2+=0.00000000137*cost(2.91203499563+1699.27921650320*x);
B2+=0.00000000131*cost(1.79274504072+1063.31408345230*x);
B2+=0.00000000161*cost(1.05926568614+1795.25844372100*x);
B2+=0.00000000112*cost(2.62660288825+440.82528487760*x);
B2+=0.00000000110*cost(3.56263668146+227.52618943960*x);
B2+=0.00000000114*cost(6.13907482464+1038.04128918680*x);
B2+=0.00000000103*cost(4.64287101040+3.18139373770*x);
B2+=0.00000000123*cost(4.81268110532+21.34064100240*x);
B2+=0.00000000102*cost(4.27603827970+1375.77379984580*x);
B2+=0.00000000089*cost(1.22926014128+1898.35121793960*x);
B2+=0.00000000080*cost(0.62129648755+831.85574074960*x);

double B3=0;
B3+=0.00000251624*cost(3.38087923084+529.69096509460*x);
B3+=0.00000121738*cost(2.73311837200+522.57741809380*x);
B3+=0.00000048694*cost(1.03689996685+536.80451209540*x);
B3+=0.00000010988*cost(2.31463561347+1052.26838318840*x);
B3+=0.00000008067*cost(2.76729757621+515.46387109300*x);
B3+=0.00000006205*cost(1.78115827370+1066.49547719000*x);
B3+=0.00000007287*cost(4.25268318975+1059.38193018920*x);
B3+=0.00000003627*cost(1.13028917221+543.91805909620*x);
B3-=0.00000002798;
B3+=0.00000001898*cost(2.28934054087+7.11354700080*x);
B3+=0.00000001643*cost(1.77507208483+1045.15483618760*x);
B3+=0.00000000945*cost(0.45261136388+632.78373931320*x);
B3+=0.00000000758*cost(0.30577920142+949.17560896980*x);
B3+=0.00000000731*cost(2.63748223583+14.22709400160*x);
B3+=0.00000000876*cost(0.32927768725+1589.07289528380*x);
B3+=0.00000000678*cost(2.36909615348+1581.95934828300*x);
B3+=0.00000000623*cost(2.48056213600+1596.18644228460*x);
B3+=0.00000000736*cost(1.52532370632+735.87651353180*x);
B3+=0.00000000499*cost(3.67985494258+419.48464387520*x);
B3+=0.00000000454*cost(0.26977404624+942.06206196900*x);
B3+=0.00000000453*cost(3.18232334886+526.50957135690*x);
B3+=0.00000000409*cost(2.88147337106+110.20632121940*x);
B3+=0.00000000347*cost(5.76244285870+103.09277421860*x);
B3+=0.00000000310*cost(2.98017326384+508.35032409220*x);
B3+=0.00000000321*cost(4.40642025933+532.87235883230*x);
B3+=0.00000000300*cost(1.66936571536+625.67019231240*x);
B3+=0.00000000295*cost(1.75924202728+1073.60902419080*x);
B3+=0.00000000282*cost(3.11087801399+533.62311835770*x);
B3+=0.00000000263*cost(0.55255030187+426.59819087600*x);
B3+=0.00000000208*cost(2.17540496886+1155.36115740700*x);
B3+=0.00000000183*cost(4.34670868038+525.75881183150*x);
B3+=0.00000000180*cost(6.07777744541+639.89728631400*x);
B3+=0.00000000159*cost(2.60843864402+1162.47470440780*x);
B3+=0.00000000117*cost(4.70141431381+95.97922721780*x);
B3+=0.00000000107*cost(5.48942805114+433.71173787680*x);
B3+=0.00000000105*cost(3.75192101775+316.39186965660*x);
B3+=0.00000000130*cost(1.37897716939+323.50541665740*x);
B3+=0.00000000094*cost(3.05797832024+1265.56747862640*x);
B3+=0.00000000114*cost(3.75170981478+117.31986822020*x);
B3+=0.00000000095*cost(0.54905691533+1169.58825140860*x);
B3+=0.00000000088*cost(3.26874502411+213.29909543800*x);
B3+=0.00000000098*cost(2.00704668688+1574.84580128220*x);

double B4=0;
B4+=0.00000015050*cost(4.52956999637+522.57741809380*x);
B4+=0.00000005370*cost(4.47427159142+529.69096509460*x);
B4+=0.00000004456*cost(5.43908581047+536.80451209540*x);
B4+=0.00000003422;
B4+=0.00000001833*cost(4.51807036227+515.46387109300*x);
B4+=0.00000001322*cost(4.20117611581+1052.26838318840*x);
B4+=0.00000000755*cost(5.59451554966+543.91805909620*x);
B4+=0.00000000512*cost(0.05803177475+1066.49547719000*x);
B4+=0.00000000282*cost(3.66807771223+1059.38193018920*x);
B4+=0.00000000147*cost(3.56490986181+1045.15483618760*x);
B4+=0.00000000142*cost(5.69936472988+7.11354700080*x);
B4+=0.00000000112*cost(1.16718383135+14.22709400160*x);

double B5=0;
B5+=0.00000001445*cost(0.09198554072+522.57741809380*x);
B5+=0.00000000368*cost(0.00874408003+515.46387109300*x);
B5+=0.00000000304*cost(3.27902945138+536.80451209540*x);
B5+=0.00000000129*cost(0.33959775247+529.69096509460*x);
B5+=0.00000000095*cost(1.29305954542+543.91805909620*x);

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
double rtd=180/3.141592653589793;

return rtd*( Bx0+B1*x+B2*x2+B3*x3+B4*x4+B5*x5); //END Jupiter
}

//Distance Jupiter-Sun [AU]
double Rjupiter(double x)
{
double R0=0;
R0+=5.20887429471;
R0+=0.25209327020*cost(3.49108640015+529.69096509460*x);
R0+=0.00610599902*cost(3.84115365602+1059.38193018920*x);
R0+=0.00282029465*cost(2.57419879933+632.78373931320*x);
R0+=0.00187647391*cost(2.07590380082+522.57741809380*x);
R0+=0.00086792941*cost(0.71001090609+419.48464387520*x);
R0+=0.00072062869*cost(0.21465694745+536.80451209540*x);
R0+=0.00065517227*cost(5.97995850843+316.39186965660*x);
R0+=0.00029134620*cost(1.67759243710+103.09277421860*x);
R0+=0.00030135275*cost(2.16132058449+949.17560896980*x);
R0+=0.00023453209*cost(3.54023147303+735.87651353180*x);
R0+=0.00022283710*cost(4.19362773546+1589.07289528380*x);
R0+=0.00023947340*cost(0.27457854894+7.11354700080*x);
R0+=0.00013032600*cost(2.96043055741+1162.47470440780*x);
R0+=0.00009703346*cost(1.90669572402+206.18554843720*x);
R0+=0.00012749004*cost(2.71550102862+1052.26838318840*x);
R0+=0.00009161431*cost(4.41352618935+213.29909543800*x);
R0+=0.00007894539*cost(2.47907551404+426.59819087600*x);
R0+=0.00007057978*cost(2.18184753111+1265.56747862640*x);
R0+=0.00006137755*cost(6.26417542514+846.08283475120*x);
R0+=0.00005477093*cost(5.65729325169+639.89728631400*x);
R0+=0.00003502519*cost(0.56531297394+1066.49547719000*x);
R0+=0.00004136890*cost(2.72219979684+625.67019231240*x);
R0+=0.00004170012*cost(2.01605033912+515.46387109300*x);
R0+=0.00002499966*cost(4.55182055941+838.96928775040*x);
R0+=0.00002616955*cost(2.00993967129+1581.95934828300*x);
R0+=0.00001911876*cost(0.85621927419+412.37109687440*x);
R0+=0.00002127644*cost(6.12751461750+742.99006053260*x);
R0+=0.00001610549*cost(3.08867789275+1368.66025284500*x);
R0+=0.00001479484*cost(2.68026191372+1478.86657406440*x);
R0+=0.00001230708*cost(1.89042979701+323.50541665740*x);
R0+=0.00001216810*cost(1.80171561024+110.20632121940*x);
R0+=0.00000961072*cost(4.54876989805+2118.76386037840*x);
R0+=0.00000885708*cost(4.14785948471+533.62311835770*x);
R0+=0.00000776700*cost(3.67696954690+728.76296653100*x);
R0+=0.00000998579*cost(2.87208940110+309.27832265580*x);
R0+=0.00001014959*cost(1.38673237666+454.90936652730*x);
R0+=0.00000727162*cost(3.98824686402+1155.36115740700*x);
R0+=0.00000655289*cost(2.79065604219+1685.05212250160*x);
R0+=0.00000821465*cost(1.59342534396+1898.35121793960*x);
R0+=0.00000620798*cost(4.82284338962+956.28915597060*x);
R0+=0.00000653981*cost(3.38150775269+1692.16566950240*x);
R0+=0.00000812036*cost(5.94091899141+909.81873305460*x);
R0+=0.00000562120*cost(0.08095987241+543.91805909620*x);
R0+=0.00000542221*cost(0.28360266386+525.75881183150*x);
R0+=0.00000457859*cost(0.12722694510+1375.77379984580*x);
R0+=0.00000614784*cost(2.27624915604+942.06206196900*x);
R0+=0.00000435805*cost(2.60272129748+95.97922721780*x);
R0+=0.00000496066*cost(5.53005947761+380.12776796000*x);
R0+=0.00000469965*cost(2.81896276101+1795.25844372100*x);
R0+=0.00000445003*cost(0.14623567024+14.22709400160*x);
R0+=0.00000290869*cost(3.89339143564+1471.75302706360*x);
R0+=0.00000276627*cost(2.52238450687+2001.44399215820*x);
R0+=0.00000275084*cost(2.98863518924+526.50957135690*x);
R0+=0.00000293875*cost(2.04938438861+199.07200143640*x);
R0+=0.00000290985*cost(6.03131226226+1169.58825140860*x);
R0+=0.00000338342*cost(2.79873192583+1045.15483618760*x);
R0+=0.00000257482*cost(6.13395478303+532.87235883230*x);
R0+=0.00000319013*cost(1.34803130803+2214.74308759620*x);
R0+=0.00000309352*cost(5.36855804945+1272.68102562720*x);
R0+=0.00000345804*cost(1.56404293688+491.55792945680*x);
R0+=0.00000303364*cost(1.15407454372+5753.38488489680*x);
R0+=0.00000192325*cost(0.91996333387+1596.18644228460*x);
R0+=0.00000215398*cost(2.63572815848+2111.65031337760*x);
R0+=0.00000200738*cost(2.37259566683+1258.45393162560*x);
R0+=0.00000239036*cost(3.57397189838+835.03713448730*x);
R0+=0.00000197073*cost(5.92859096863+453.42489381900*x);
R0+=0.00000139440*cost(3.63960322318+1788.14489672020*x);
R0+=0.00000191373*cost(6.28251311870+983.11585891360*x);
R0+=0.00000176551*cost(2.57669991654+9683.59458111640*x);
R0+=0.00000123567*cost(2.26158186345+2317.83586181480*x);
R0+=0.00000128176*cost(4.66585907670+831.85574074960*x);
R0+=0.00000112430*cost(0.85604150812+433.71173787680*x);
R0+=0.00000128817*cost(1.10567106595+2531.13495725280*x);
R0+=0.00000099390*cost(4.50312054049+518.64526483070*x);
R0+=0.00000093870*cost(2.72553879990+853.19638175200*x);
R0+=0.00000106481*cost(5.81462222290+220.41264243880*x);
R0+=0.00000120188*cost(2.95156363556+3.93215326310*x);
R0+=0.00000104002*cost(2.22221906187+74.78159856730*x);
R0+=0.00000081655*cost(3.23481337678+1361.54670584420*x);
R0+=0.00000112513*cost(4.86216964016+528.20649238630*x);
R0+=0.00000079539*cost(0.88542246830+430.53034413910*x);
R0+=0.00000085801*cost(2.11458386763+1574.84580128220*x);
R0+=0.00000085685*cost(2.33823884827+2428.04218303420*x);
R0+=0.00000068311*cost(3.35727048905+2104.53676637680*x);
R0+=0.00000069570*cost(3.04164697156+302.16477565500*x);
R0+=0.00000069775*cost(3.22402404312+305.34616939270*x);
R0+=0.00000069570*cost(0.20494979941+532.13864564940*x);
R0+=0.00000056991*cost(2.00204191909+2634.22773147140*x);
R0+=0.00000077062*cost(2.09816000231+508.35032409220*x);
R0+=0.00000056716*cost(3.91743976711+2221.85663459700*x);
R0+=0.00000058325*cost(5.72360355252+628.85158605010*x);
R0+=0.00000052485*cost(4.02485010492+527.24328453980*x);
R0+=0.00000063645*cost(1.09973563964+1364.72809958190*x);
R0+=0.00000053607*cost(0.87425992614+2847.52682690940*x);
R0+=0.00000059598*cost(0.95822471775+494.26624244250*x);
R0+=0.00000057960*cost(3.45779497978+2008.55753915900*x);
R0+=0.00000041512*cost(3.51955526735+529.73914920440*x);
R0+=0.00000044666*cost(1.62313786651+984.60033162190*x);
R0+=0.00000044883*cost(4.90091959557+2648.45482547300*x);
R0+=0.00000053206*cost(1.19800364308+760.25553592000*x);
R0+=0.00000044393*cost(4.42623747662+1063.31408345230*x);
R0+=0.00000037566*cost(2.93021095213+1677.93857550080*x);
R0+=0.00000041516*cost(0.32174409278+529.64278098480*x);
R0+=0.00000042855*cost(0.03093594081+1439.50969814920*x);
R0+=0.00000045963*cost(2.54342106514+636.71589257630*x);
R0+=0.00000040181*cost(4.39381642864+1148.24761040620*x);
R0+=0.00000038770*cost(4.31675565025+149.56319713460*x);
R0+=0.00000040348*cost(2.10140891053+2744.43405269080*x);
R0+=0.00000048851*cost(5.60297777544+2810.92146160520*x);
R0+=0.00000037085*cost(5.07828164301+1905.46476494040*x);
R0+=0.00000043875*cost(1.24536971083+621.73803904930*x);
R0+=0.00000034005*cost(3.09360167248+2420.92863603340*x);
R0+=0.00000036782*cost(0.84232174637+530.65417294110*x);
R0+=0.00000031139*cost(5.35811251334+1485.98012106520*x);
R0+=0.00000039295*cost(4.70800489067+569.04784100980*x);
R0+=0.00000039700*cost(2.46163878814+355.74874557180*x);
R0+=0.00000031527*cost(6.19284070863+3.18139373770*x);
R0+=0.00000028399*cost(2.48456666067+519.39602435610*x);
R0+=0.00000032432*cost(2.73281750275+604.47256366190*x);
R0+=0.00000027119*cost(3.92341697086+2324.94940881560*x);
R0+=0.00000026753*cost(1.74975198417+2950.61960112800*x);
R0+=0.00000028986*cost(1.83535862643+1891.23767093880*x);
R0+=0.00000026493*cost(0.60380196895+1055.44977692610*x);
R0+=0.00000033525*cost(0.76068430639+643.82943957710*x);
R0+=0.00000026568*cost(1.03594610835+405.25754987360*x);
R0+=0.00000025534*cost(3.46320665375+458.84151979040*x);
R0+=0.00000024421*cost(0.88181836930+423.41679713830*x);
R0+=0.00000032949*cost(3.18597137308+528.72775724810*x);
R0+=0.00000022456*cost(0.43129919683+1073.60902419080*x);
R0+=0.00000021599*cost(1.41820425091+540.73666535850*x);
R0+=0.00000025673*cost(0.52358194760+511.53171782990*x);
R0+=0.00000021115*cost(3.08023522766+629.60234557550*x);
R0+=0.00000022713*cost(0.65234613144+3163.91869656600*x);
R0+=0.00000019189*cost(5.16589014963+635.96513305090*x);
R0+=0.00000026042*cost(1.33629471285+330.61896365820*x);
R0+=0.00000018263*cost(3.59973446951+746.92221379570*x);
R0+=0.00000018210*cost(2.66819439927+1994.33044515740*x);
R0+=0.00000019724*cost(4.13552133321+1464.63948006280*x);
R0+=0.00000019480*cost(1.85656428109+3060.82592234740*x);
R0+=0.00000023927*cost(4.99826361784+1289.94650101460*x);
R0+=0.00000021886*cost(5.91718683551+1802.37199072180*x);
R0+=0.00000017482*cost(2.82161612542+2737.32050569000*x);
R0+=0.00000016608*cost(5.67394889755+408.43894361130*x);
R0+=0.00000022892*cost(5.26731352093+672.14061522840*x);
R0+=0.00000018349*cost(1.89869734949+1021.24889455140*x);
R0+=0.00000019123*cost(3.65882402977+415.55249061210*x);
R0+=0.00000015735*cost(3.34772676006+1056.20053645150*x);
R0+=0.00000016373*cost(0.18094878053+1699.27921650320*x);
R0+=0.00000018899*cost(3.69120638874+88.86568021700*x);
R0+=0.00000018655*cost(1.97327300097+38.13303563780*x);
R0+=0.00000015542*cost(3.82204881010+721.64941953020*x);
R0+=0.00000016780*cost(1.90976657921+217.23124870110*x);
R0+=0.00000015313*cost(1.05907174619+114.13847448250*x);
R0+=0.00000015190*cost(1.32317039042+117.31986822020*x);
R0+=0.00000015080*cost(3.74469077216+2641.34127847220*x);
R0+=0.00000019836*cost(2.73184571324+39.35687591520*x);
R0+=0.00000014708*cost(1.67270454473+529.16970023280*x);
R0+=0.00000014036*cost(3.54305270022+142.44965013380*x);
R0+=0.00000012931*cost(1.48829749349+3267.01147078460*x);
R0+=0.00000014924*cost(1.32546085940+490.33408917940*x);
R0+=0.00000014753*cost(4.64530618027+6283.07584999140*x);
R0+=0.00000014672*cost(0.80451954754+5223.69391980220*x);
R0+=0.00000012085*cost(3.67072510553+750.10360753340*x);
R0+=0.00000011954*cost(2.97127390765+505.31194270640*x);
R0+=0.00000014650*cost(2.16792930250+530.21222995640*x);
R0+=0.00000011869*cost(1.66551754962+2207.62954059540*x);
R0+=0.00000012273*cost(0.20690014405+1062.56332392690*x);
R0+=0.00000011460*cost(1.11906683214+561.93429400900*x);
R0+=0.00000011083*cost(3.22049096074+535.10759106600*x);
R0+=0.00000011567*cost(5.22625628971+524.06189080210*x);
R0+=0.00000011161*cost(3.82945634036+76.26607127560*x);
R0+=0.00000010918*cost(1.27796962818+2125.87740737920*x);
R0+=0.00000012685*cost(3.96848605476+2538.24850425360*x);
R0+=0.00000011230*cost(3.23092119889+422.66603761290*x);
R0+=0.00000012645*cost(0.73670428580+908.33426034630*x);
R0+=0.00000011330*cost(5.56127247007+531.17543780290*x);
R0+=0.00000009509*cost(5.00507284204+597.35901666110*x);
R0+=0.00000010291*cost(3.84159025239+1781.03134971940*x);
R0+=0.00000010762*cost(4.91380719453+525.02509864860*x);
R0+=0.00000011786*cost(5.11863653538+685.47393735270*x);
R0+=0.00000011980*cost(1.72470898635+911.30320576290*x);
R0+=0.00000008937*cost(2.40338241992+2310.72231481400*x);
R0+=0.00000009253*cost(2.57670338148+3053.71237534660*x);
R0+=0.00000009488*cost(2.95089828501+1382.88734684660*x);
R0+=0.00000009889*cost(0.43758517388+3480.31056622260*x);
R0+=0.00000008781*cost(3.66562388594+739.80866679490*x);
R0+=0.00000008664*cost(2.70398612383+526.77020378780*x);
R0+=0.00000009505*cost(1.61249870019+3377.21779200400*x);
R0+=0.00000011540*cost(1.59520481029+1474.67378837040*x);
R0+=0.00000009533*cost(0.35468711552+1512.80682400820*x);
R0+=0.00000009980*cost(4.80984684596+558.00214074590*x);
R0+=0.00000009014*cost(1.21458362718+416.30325013750*x);
R0+=0.00000007969*cost(0.08480602718+528.94020556920*x);
R0+=0.00000008668*cost(5.29060005706+945.24345570670*x);
R0+=0.00000007851*cost(1.46751861875+963.40270297140*x);
R0+=0.00000008611*cost(1.13232641062+532.61172640140*x);
R0+=0.00000007838*cost(6.26933498027+647.01083331480*x);
R0+=0.00000007581*cost(2.90608705954+533.88375078860*x);
R0+=0.00000008583*cost(6.06634530166+10213.28554621100*x);
R0+=0.00000010198*cost(2.48743123636+1819.63746610920*x);
R0+=0.00000008536*cost(2.22700701790+9153.90361602180*x);
R0+=0.00000009759*cost(6.15593336218+593.42686339800*x);
R0+=0.00000007968*cost(3.75535355212+530.44172462000*x);
R0+=0.00000007142*cost(3.58836120327+2957.73314812880*x);
R0+=0.00000007122*cost(0.11970048938+224.34479570190*x);
R0+=0.00000008731*cost(0.75302913970+960.22130923370*x);
R0+=0.00000007063*cost(2.16793037690+724.83081326790*x);
R0+=0.00000007263*cost(2.29499675875+520.12973753900*x);
R0+=0.00000006418*cost(1.25058991868+3583.40334044120*x);
R0+=0.00000008270*cost(1.24806288317+495.75071515080*x);
R0+=0.00000006483*cost(4.74567772640+202.25339517410*x);
R0+=0.00000007197*cost(3.84169279666+618.55664531160*x);
R0+=0.00000008146*cost(0.73147060302+230.56457082540*x);
R0+=0.00000006165*cost(5.50124418381+11.04570026390*x);
R0+=0.00000007946*cost(2.07754951174+953.10776223290*x);
R0+=0.00000007675*cost(0.92400307662+525.49817940060*x);
R0+=0.00000006210*cost(1.45641362115+483.22054217860*x);
R0+=0.00000007359*cost(0.31355650764+378.64329525170*x);
R0+=0.00000006707*cost(2.92071167098+1038.04128918680*x);
R0+=0.00000007143*cost(0.18218134889+731.94436026870*x);
R0+=0.00000007309*cost(6.27084533477+21.34064100240*x);
R0+=0.00000006135*cost(2.67651237303+312.45971639350*x);
R0+=0.00000005558*cost(3.83419160288+534.35683154060*x);
R0+=0.00000005344*cost(5.25294750019+1048.33622992530*x);
R0+=0.00000007504*cost(0.74281415471+457.61767951300*x);
R0+=0.00000005335*cost(6.23059924424+551.03160609700*x);
R0+=0.00000005613*cost(1.51210605952+524.27433912320*x);
R0+=0.00000005284*cost(2.18579185671+280.96714700450*x);
R0+=0.00000005475*cost(5.95864753605+539.98590583310*x);
R0+=0.00000005056*cost(0.37387972537+529.53090640020*x);
R0+=0.00000006202*cost(5.53813122743+2.44768055480*x);
R0+=0.00000005490*cost(5.97692444199+227.52618943960*x);
R0+=0.00000006266*cost(0.76632858238+938.12990870590*x);
R0+=0.00000005750*cost(2.13496323512+191.95845443560*x);
R0+=0.00000005218*cost(4.69335266854+560.71045373160*x);
R0+=0.00000005480*cost(5.21157595558+1057.89745748090*x);
R0+=0.00000005738*cost(0.34249718209+535.91074021810*x);
R0+=0.00000004816*cost(1.51326236835+2524.02141025200*x);
R0+=0.00000005056*cost(3.46671669992+529.85102378900*x);
R0+=0.00000004710*cost(2.27813830550+3370.10424500320*x);
R0+=0.00000005228*cost(3.61776977584+2097.42321937600*x);
R0+=0.00000004878*cost(1.39829798223+3693.60966166060*x);
R0+=0.00000005727*cost(4.80120381106+598.84348936940*x);
R0+=0.00000005707*cost(3.94177950323+2854.64037391020*x);
R0+=0.00000004988*cost(4.87244187719+1.48447270830*x);
R0+=0.00000005424*cost(3.53268613904+456.39383923560*x);
R0+=0.00000004288*cost(4.84438067847+70.84944530420*x);
R0+=0.00000005944*cost(3.79180483544+25558.21217647960*x);
R0+=0.00000004195*cost(2.09136830994+2627.11418447060*x);
R0+=0.00000004582*cost(5.61707254513+2435.15573003500*x);
R0+=0.00000004268*cost(6.20250525415+775.23338944700*x);
R0+=0.00000004521*cost(0.20049967962+92.04707395470*x);
R0+=0.00000005405*cost(4.66492781581+833.55266177900*x);
R0+=0.00000005607*cost(3.30226645638+535.32003938710*x);
R0+=0.00000004171*cost(3.14873010832+944.98282327580*x);
R0+=0.00000004108*cost(5.84489743779+440.82528487760*x);
R0+=0.00000004367*cost(4.68363584557+327.43756992050*x);
R0+=0.00000004033*cost(3.30883782817+3274.12501778540*x);
R0+=0.00000004292*cost(0.20604269202+3796.70243587920*x);
R0+=0.00000004270*cost(0.98941708997+387.24131496080*x);
R0+=0.00000004259*cost(3.21120589971+696.51963761660*x);
R0+=0.00000004673*cost(1.96606729969+107.02492748170*x);
R0+=0.00000004031*cost(4.62854606236+2751.54759969160*x);
R0+=0.00000005115*cost(2.66416451377+1215.16490244730*x);
R0+=0.00000004181*cost(4.74527698816+988.53248488500*x);
R0+=0.00000004374*cost(1.50010561403+1894.41906467650*x);
R0+=0.00000003803*cost(3.59911687954+437.64389113990*x);
R0+=0.00000003761*cost(3.96903199782+732.69511979410*x);
R0+=0.00000003620*cost(1.57847427805+381.61224066830*x);
R0+=0.00000003490*cost(0.63097592112+529.90341341570*x);
R0+=0.00000004019*cost(2.57664165720+916.93228005540*x);
R0+=0.00000004133*cost(4.78417930217+824.74219374880*x);
R0+=0.00000004411*cost(3.13179382423+630.33605875840*x);
R0+=0.00000004099*cost(3.63702212253+810.65811209910*x);
R0+=0.00000003704*cost(6.17243801274+537.76771994190*x);
R0+=0.00000004124*cost(2.14248285449+210.11770170030*x);
R0+=0.00000003490*cost(3.20962050417+529.47851677350*x);
R0+=0.00000003281*cost(1.53106243317+547.85021235930*x);
R0+=0.00000003554*cost(6.03787799174+739.05790726950*x);
R0+=0.00000004101*cost(6.00406226999+902.70518605380*x);
R0+=0.00000003267*cost(3.49354065789+1166.40685767090*x);
R0+=0.00000003286*cost(2.55966870530+945.99421523210*x);
R0+=0.00000004041*cost(4.78735413707+850.01498801430*x);
R0+=0.00000004304*cost(0.11406117717+1744.85586754190*x);
R0+=0.00000004043*cost(5.20417093600+635.23141986800*x);
R0+=0.00000003115*cost(4.61986265585+952.35700270750*x);
R0+=0.00000003016*cost(0.95126220905+3899.79521009780*x);
R0+=0.00000003017*cost(2.59699501992+632.83192342300*x);
R0+=0.00000003219*cost(1.83594791142+18.15924726470*x);
R0+=0.00000003203*cost(6.12597544496+10.29494073850*x);
R0+=0.00000003220*cost(6.14213423140+1158.54255114470*x);
R0+=0.00000003000*cost(5.69509924353+632.73555520340*x);
R0+=0.00000003226*cost(5.59910267099+608.40471692500*x);
R0+=0.00000003118*cost(5.64998934505+99.16062095550*x);
R0+=0.00000003745*cost(2.08111521615+282.45161971280*x);
R0+=0.00000002837*cost(4.60175594220+245.54242435240*x);
R0+=0.00000003093*cost(6.02049413961+633.74694715970*x);
R0+=0.00000003120*cost(2.29047945342+631.82053146670*x);
R0+=0.00000002662*cost(3.69016679729+885.43971066640*x);
R0+=0.00000003150*cost(1.79784999553+521.61421024730*x);
R0+=0.00000002822*cost(3.14927418161+295.05122865420*x);
R0+=0.00000002615*cost(0.20732170653+35.42472265210*x);
R0+=0.00000002971*cost(1.28795094653+1023.95720753710*x);
R0+=0.00000002571*cost(2.01817133502+1514.29129671650*x);
R0+=0.00000002592*cost(0.48790221200+195.13984817330*x);
R0+=0.00000003263*cost(2.38820607343+836.52160719560*x);
R0+=0.00000002501*cost(0.21653750027+465.95506679120*x);
R0+=0.00000002451*cost(5.58559489768+544.66881862160*x);
R0+=0.00000002535*cost(1.44414086617+460.53844081980*x);
R0+=0.00000002666*cost(3.30350145485+2413.81508903260*x);
R0+=0.00000002412*cost(4.36756580310+1056.93424963440*x);
R0+=0.00000002452*cost(4.53818816565+514.71311156760*x);
R0+=0.00000003239*cost(1.17022488774+177.87437278590*x);
R0+=0.00000003218*cost(0.60551913257+1061.82961074400*x);
R0+=0.00000002408*cost(0.65423523810+523.54062594030*x);
R0+=0.00000002299*cost(2.15247752560+319.57326339430*x);
R0+=0.00000002791*cost(2.71505085086+610.69233878540*x);
R0+=0.00000002729*cost(1.77685979153+252.65597135320*x);
R0+=0.00000002666*cost(3.77750458842+3171.03224356680*x);
R0+=0.00000002303*cost(0.36676453766+1969.20066324380*x);
R0+=0.00000002664*cost(0.09674841214+565.11568774670*x);
R0+=0.00000002312*cost(2.07210502831+3686.49611465980*x);
R0+=0.00000002680*cost(4.94445888050+1593.00504854690*x);
R0+=0.00000002193*cost(0.55645982205+2228.97018159780*x);
R0+=0.00000002526*cost(1.07528597373+12036.46073488820*x);
R0+=0.00000002778*cost(1.48379350517+447.79581952650*x);
R0+=0.00000002235*cost(5.95475282699+6151.53388830500*x);
R0+=0.00000002759*cost(4.63976153480+462.02291352810*x);
R0+=0.00000002175*cost(4.53588570240+501.37978944330*x);
R0+=0.00000002323*cost(5.93670041006+611.44309831080*x);
R0+=0.00000002384*cost(2.81746622971+3340.61242669980*x);
R0+=0.00000002087*cost(3.10716079675+1049.08698945070*x);
R0+=0.00000001994*cost(2.02500860064+1058.86066532740*x);
R0+=0.00000002199*cost(2.20937490997+1269.49963188950*x);
R0+=0.00000002705*cost(1.97665276677+415.29185818120*x);
R0+=0.00000002787*cost(1.31053438756+1041.22268292450*x);
R0+=0.00000002003*cost(4.66904374443+679.25416222920*x);
R0+=0.00000001962*cost(1.82999730674+2943.50605412720*x);
R0+=0.00000002289*cost(2.96480800939+69.15252427480*x);
R0+=0.00000002192*cost(4.47837196209+209.36694217490*x);
R0+=0.00000002020*cost(0.04621364490+4113.09430553580*x);
R0+=0.00000002082*cost(1.11203059170+4010.00153131720*x);
R0+=0.00000001991*cost(3.20108648275+3590.51688744200*x);
R0+=0.00000001900*cost(3.32227077969+421.93232443000*x);
R0+=0.00000002193*cost(2.82218305362+292.01284726840*x);
R0+=0.00000002288*cost(1.94695631885+1279.79457262800*x);
R0+=0.00000001843*cost(5.23293634337+14.97785352700*x);
R0+=0.00000001932*cost(5.46684252030+2281.23049651060*x);
R0+=0.00000002177*cost(2.93031976617+429.04587143080*x);
R0+=0.00000002125*cost(0.06224847826+24.37902238820*x);
R0+=0.00000002464*cost(5.39581078430+1261.63532536330*x);
R0+=0.00000001938*cost(3.79908004671+1059.43011429900*x);
R0+=0.00000002029*cost(3.95461157815+771.30123618390*x);
R0+=0.00000001841*cost(4.74905354737+78.71375183040*x);
R0+=0.00000001922*cost(2.21862085389+99.91138048090*x);
R0+=0.00000001836*cost(5.75449805175+623.22251175760*x);
R0+=0.00000002145*cost(3.87052575546+451.94042111070*x);
R0+=0.00000001782*cost(0.40860352236+754.03576079650*x);
R0+=0.00000001784*cost(1.49468287576+529.95159752550*x);
R0+=0.00000001842*cost(3.49726261337+1354.43315884340*x);
R0+=0.00000001748*cost(3.48730020953+522.62560220360*x);
R0+=0.00000001816*cost(1.24334711210+417.03696332040*x);
R0+=0.00000001752*cost(1.15500390019+1060.34513803570*x);
R0+=0.00000001729*cost(2.69831073799+642.34496686880*x);
R0+=0.00000001985*cost(1.99916658759+934.94851496820*x);
R0+=0.00000001828*cost(5.44095029767+1201.83158032300*x);
R0+=0.00000002158*cost(3.45672748590+827.92358748650*x);
R0+=0.00000001959*cost(1.06033047373+33.94024994380*x);
R0+=0.00000001751*cost(3.13572498964+384.05992122310*x);
R0+=0.00000001781*cost(5.02895146997+1098.73880610440*x);
R0+=0.00000002074*cost(3.18582065441+1366.21257229020*x);
R0+=0.00000001757*cost(5.02778552877+586.31331639720*x);
R0+=0.00000002045*cost(3.08816627459+535.84130424890*x);
R0+=0.00000002273*cost(5.17998505813+3178.14579056760*x);
R0+=0.00000001617*cost(3.16674916201+67.66805156650*x);
R0+=0.00000001627*cost(6.10603469594+432.01481684740*x);
R0+=0.00000001930*cost(1.63968957659+5.41662597140*x);
R0+=0.00000001741*cost(0.99408274736+1254.52177836250*x);
R0+=0.00000001607*cost(5.65498642076+1165.65609814550*x);
R0+=0.00000001676*cost(3.06138410273+1134.16352875650*x);
R0+=0.00000001821*cost(3.05183555090+567.82400073240*x);
R0+=0.00000001677*cost(3.09175084930+1251.34038462480*x);
R0+=0.00000001994*cost(2.52023134712+1059.90319505100*x);
R0+=0.00000002204*cost(6.15376698510+563.63121503840*x);
R0+=0.00000001692*cost(4.19142612803+106.27416795630*x);
R0+=0.00000001906*cost(5.58417395051+32.24332891440*x);
R0+=0.00000002206*cost(1.75883974012+1151.42900414390*x);
R0+=0.00000001552*cost(3.04262360186+385.54439393140*x);
R0+=0.00000001508*cost(0.42002830727+313.21047591890*x);
R0+=0.00000001494*cost(1.43672345922+2840.41327990860*x);
R0+=0.00000001678*cost(2.17255433434+306.83064210100*x);
R0+=0.00000001511*cost(4.44377608685+395.10562148700*x);
R0+=0.00000001958*cost(0.05215107058+761.74000862830*x);
R0+=0.00000001760*cost(1.27045286501+1173.52040467170*x);
R0+=0.00000001463*cost(6.07810373103+0.96320784650*x);
R0+=0.00000001498*cost(2.79408561759+277.03499374140*x);
R0+=0.00000001636*cost(0.26199351490+522.52923398400*x);
R0+=0.00000001507*cost(0.48961801593+4216.18707975440*x);
R0+=0.00000001530*cost(3.42953827550+1159.29331067010*x);
R0+=0.00000001744*cost(2.39637837261+203.00415469950*x);
R0+=0.00000001569*cost(2.55719070621+4.19278569400*x);
R0+=0.00000001576*cost(3.45039607104+1058.41872234270*x);
R0+=0.00000001466*cost(2.24427539934+1550.93985964600*x);
R0+=0.00000001784*cost(2.34591354953+529.43033266370*x);
R0+=0.00000001939*cost(4.73685428610+3067.93946934820*x);
R0+=0.00000001938*cost(0.60126164334+1059.33374607940*x);
R0+=0.00000001523*cost(2.98744673443+2730.20695868920*x);
R0+=0.00000001834*cost(3.78099298791+420.96911658350*x);
R0+=0.00000001372*cost(3.53997115825+5.62907429250*x);
R0+=0.00000001361*cost(0.45533257707+418.52143602870*x);
R0+=0.00000001833*cost(5.12743628215+1578.02719501990*x);
R0+=0.00000001839*cost(4.24616044210+981.63138620530*x);
R0+=0.00000001567*cost(3.32429870195+532.39927808030*x);
R0+=0.00000001340*cost(1.94668282270+528.41894070740*x);
R0+=0.00000001422*cost(1.83191577465+4002.88798431640*x);
R0+=0.00000001745*cost(5.76913240451+490.07345674850*x);
R0+=0.00000001437*cost(4.19470227783+420.44785172170*x);
R0+=0.00000001419*cost(0.74849005330+632.26247445140*x);
R0+=0.00000001447*cost(5.65611888743+373.01422095920*x);
R0+=0.00000001578*cost(3.90273683089+602.98809095360*x);
R0+=0.00000001385*cost(3.88479835656+419.43645976540*x);
R0+=0.00000001352*cost(0.81697905853+1585.14074202070*x);
R0+=0.00000001399*cost(1.24785452243+633.30500417500*x);
R0+=0.00000001297*cost(5.57914023189+1276.61317889030*x);
R0+=0.00000001491*cost(1.66541781223+2655.56837247380*x);
R0+=0.00000001252*cost(0.72155670765+173.94221952280*x);
R0+=0.00000001658*cost(5.60924662850+362.86229257260*x);
R0+=0.00000001606*cost(3.95301396173+2274.54683263650*x);
R0+=0.00000001213*cost(4.55264289565+366.79444583570*x);
R0+=0.00000001521*cost(0.55773831071+1592.25428902150*x);
R0+=0.00000001220*cost(3.63029788040+497.44763618020*x);
R0+=0.00000001215*cost(4.42854185903+531.38788612400*x);
R0+=0.00000001549*cost(5.73765962068+320.32402291970*x);
R0+=0.00000001480*cost(4.29779032931+303.86169668440*x);
R0+=0.00000001507*cost(2.27998567874+758.77106321170*x);
R0+=0.00000001212*cost(3.38335836048+536.85269620520*x);
R0+=0.00000001245*cost(4.21639959154+4.66586644600*x);
R0+=0.00000001507*cost(3.52136655355+774.00954916960*x);
R0+=0.00000001481*cost(3.06156044618+1585.89150154610*x);
R0+=0.00000001462*cost(2.30628702634+1363.24362687360*x);
R0+=0.00000001180*cost(3.52708055024+1064.79855616060*x);
R0+=0.00000001193*cost(5.88284733845+1060.86640289750*x);
R0+=0.00000001398*cost(4.99456521692+842.90144101350*x);
R0+=0.00000001406*cost(1.53799746944+1020.02505427400*x);
R0+=0.00000001367*cost(4.10254739443+799.61241183520*x);
R0+=0.00000001336*cost(1.89387272380+530.96298948180*x);
R0+=0.00000001238*cost(3.62226383331+3487.42411322340*x);
R0+=0.00000001306*cost(3.39985119727+539.25219265020*x);
R0+=0.00000001156*cost(0.77127511567+1603.29998928540*x);
R0+=0.00000001482*cost(0.48451915093+493.04240216510*x);
R0+=0.00000001247*cost(5.64344659992+479.28838891550*x);
R0+=0.00000001195*cost(2.39909893341+561.18353448360*x);
R0+=0.00000001106*cost(0.89453807282+2.92076130680*x);
R0+=0.00000001227*cost(2.76231244946+299.12639426920*x);
R0+=0.00000001128*cost(4.72319873338+124.43341522100*x);
R0+=0.00000001086*cost(5.66180289525+1053.75285589670*x);
R0+=0.00000001329*cost(0.16664094530+536.75632798560*x);
R0+=0.00000001082*cost(4.51407359350+528.25467649610*x);
R0+=0.00000001105*cost(1.93890691771+244.31858407500*x);
R0+=0.00000001446*cost(0.65096230619+1091.62525910360*x);
R0+=0.00000001071*cost(4.67974963103+521.82665856840*x);
R0+=0.00000001413*cost(4.72936311016+1141.13406340540*x);
R0+=0.00000001086*cost(2.88721124443+1262.38608488870*x);
R0+=0.00000001254*cost(5.74156595137+527.99404406520*x);
R0+=0.00000001082*cost(5.60975006771+531.12725369310*x);
R0+=0.00000001148*cost(3.27410230525+1035.00290780100*x);
R0+=0.00000001224*cost(3.68807537150+81.75213321620*x);
R0+=0.00000001072*cost(0.48068438564+1058.63117066380*x);
R0+=0.00000001036*cost(1.68789163831+1070.42763045310*x);
R0+=0.00000001052*cost(4.72763208332+913.75088631770*x);
R0+=0.00000001166*cost(4.97812626679+450.97721326420*x);
R0+=0.00000001042*cost(2.90894542321+3906.90875709860*x);
R0+=0.00000000997*cost(1.65967703856+3259.89792378380*x);
R0+=0.00000001113*cost(3.06502453809+1482.79872732750*x);
R0+=0.00000000991*cost(0.91568114148+576.16138801060*x);
R0+=0.00000000987*cost(0.91349590742+2332.06295581640*x);
R0+=0.00000001003*cost(6.17381204883+391.17346822390*x);
R0+=0.00000001087*cost(3.19260020877+151.04766984290*x);
R0+=0.00000000987*cost(2.48065918834+1912.57831194120*x);
R0+=0.00000000975*cost(1.55458771092+536.28324723360*x);
R0+=0.00000001193*cost(2.19383228000+523.09868295560*x);
R0+=0.00000000979*cost(3.28693620660+1379.70595310890*x);
R0+=0.00000000963*cost(2.29845109892+1467.82087380050*x);
R0+=0.00000001279*cost(4.73978455573+600.54041039880*x);
R0+=0.00000001269*cost(1.77171706595+5120.60114558360*x);
R0+=0.00000000938*cost(3.13636271584+1372.59240610810*x);
R0+=0.00000000956*cost(0.94045126791+429.77958461370*x);
R0+=0.00000001130*cost(4.87259620358+874.39401040250*x);
R0+=0.00000001044*cost(3.52819283674+530.58473697190*x);
R0+=0.00000001244*cost(0.80634178279+419.53282798500*x);
R0+=0.00000000914*cost(4.34324212455+1127.04998175570*x);
R0+=0.00000001095*cost(3.17513475763+6681.22485339960*x);
R0+=0.00000000926*cost(5.53099018797+537.55527162080*x);
R0+=0.00000001025*cost(6.08315999637+469.88722005430*x);
R0+=0.00000000928*cost(2.64064849636+31.01948863700*x);
R0+=0.00000000887*cost(5.53922649066+498.67147645760*x);
R0+=0.00000001153*cost(5.20213407651+554.06998748280*x);
R0+=0.00000000976*cost(4.26047885490+806.72595883600*x);
R0+=0.00000000871*cost(5.79751110150+594.65070367540*x);
R0+=0.00000001044*cost(0.31244551729+528.79719321730*x);
R0+=0.00000000911*cost(0.94039205468+337.73251065900*x);
R0+=0.00000001197*cost(3.12884590029+1966.23171782720*x);
R0+=0.00000000930*cost(2.88178471518+1056.46116888240*x);
R0+=0.00000001052*cost(1.69484089706+484.44438245600*x);
R0+=0.00000000862*cost(0.67309397482+20426.57109242200*x);
R0+=0.00000001152*cost(1.16751621652+1489.91227432830*x);
R0+=0.00000000847*cost(3.25831322825+1063.57471588320*x);
R0+=0.00000000884*cost(0.71487680084+2042.49778910280*x);
R0+=0.00000000888*cost(5.38714907441+5621.84292321040*x);
R0+=0.00000001137*cost(4.02029739425+1670.07426897460*x);
R0+=0.00000000844*cost(3.31846798590+812.14258480740*x);
R0+=0.00000000860*cost(4.78175008217+530.91480537200*x);
R0+=0.00000000835*cost(3.63117401608+451.72797278960*x);
R0+=0.00000000931*cost(2.27352189963+100.64509366380*x);
R0+=0.00000000939*cost(3.51238251326+523.47118997110*x);
R0+=0.00000000860*cost(5.34207357904+528.46712481720*x);
R0+=0.00000000875*cost(0.87775537110+4326.39340097380*x);
R0+=0.00000000961*cost(5.69327275886+498.19839570560*x);
R0+=0.00000000966*cost(6.25512226434+700.45179087970*x);
R0+=0.00000000842*cost(3.20535945596+1670.82502850000*x);
R0+=0.00000000808*cost(1.09148925587+683.18631549230*x);
R0+=0.00000000810*cost(5.47935192896+525.54636351040*x);
R0+=0.00000000855*cost(6.06969867736+446.31134681820*x);
R0+=0.00000000989*cost(1.55623875216+1493.09366806600*x);
R0+=0.00000000837*cost(1.49510080792+1025.44168024540*x);
R0+=0.00000000974*cost(3.67667471757+25565.32572348040*x);
R0+=0.00000000788*cost(0.51622458293+526.98265210890*x);
R0+=0.00000000820*cost(1.86002542644+629.86297800640*x);
R0+=0.00000000813*cost(0.45441968195+4694.00295470760*x);
R0+=0.00000000953*cost(0.58786779132+627.36711334180*x);
R0+=0.00000000908*cost(2.82093327912+3046.59882834580*x);
R0+=0.00000000912*cost(2.69124310451+946.72792841500*x);
R0+=0.00000000820*cost(4.14947931572+1884.12412393800*x);
R0+=0.00000000948*cost(0.77931728039+25551.09862947879*x);
R0+=0.00000000844*cost(0.00976249584+628.59095361920*x);
R0+=0.00000000910*cost(0.99542530366+5760.49843189760*x);
R0+=0.00000000844*cost(0.22630964490+1123.11782849260*x);
R0+=0.00000000924*cost(4.41952345708+5746.27133789600*x);
R0+=0.00000000967*cost(3.20618313117+9050.81084180320*x);
R0+=0.00000000800*cost(0.10663079153+4532.57894941100*x);
R0+=0.00000000748*cost(3.01376405927+5481.75455838080*x);
R0+=0.00000000752*cost(5.82360472890+701.93626358800*x);
R0+=0.00000000771*cost(0.12101982692+635.70450062000*x);
R0+=0.00000000725*cost(2.81220410314+3597.63043444280*x);
R0+=0.00000000944*cost(0.40327408174+1140.38330388000*x);
R0+=0.00000000726*cost(5.28930472464+1304.92435454160*x);
R0+=0.00000000994*cost(5.16391370100+10316.37832042960*x);
R0+=0.00000000890*cost(4.10819809692+1060.13268971460*x);
R0+=0.00000000962*cost(1.48376004549+1062.30269149600*x);
R0+=0.00000000883*cost(5.26813169286+1542.60247236780*x);
R0+=0.00000000916*cost(6.02908368648+7.86430652620*x);
R0+=0.00000000725*cost(2.18773773010+1176.70179840940*x);
R0+=0.00000000808*cost(5.81725174908+1087.69310584050*x);
R0+=0.00000000757*cost(0.77440414330+977.48678462110*x);
R0+=0.00000000838*cost(3.81585420192+986.08480433020*x);
R0+=0.00000000888*cost(1.89634795578+707.56533788050*x);
R0+=0.00000000854*cost(5.47701506544+2818.03500860600*x);
R0+=0.00000000796*cost(1.08794807212+987.30864460760*x);
R0+=0.00000000856*cost(2.58042139486+2803.80791460440*x);
R0+=0.00000000708*cost(1.09492310353+248.72381809010*x);
R0+=0.00000000811*cost(3.23726191865+121.25202148330*x);
R0+=0.00000000727*cost(1.56150632966+4319.27985397300*x);
R0+=0.00000000687*cost(2.65457835371+1567.73225428140*x);
R0+=0.00000000675*cost(1.78690909614+103.14095832840*x);
R0+=0.00000000853*cost(4.74476428852+951.62328952460*x);
R0+=0.00000000832*cost(5.14362789810+1054.71606374320*x);
R0+=0.00000000846*cost(1.47557828604+898.77303279070*x);
R0+=0.00000000701*cost(1.72139817505+5230.80746680300*x);
R0+=0.00000000863*cost(3.98700238575+686.95841006100*x);
R0+=0.00000000703*cost(2.89202252444+63.73589830340*x);
R0+=0.00000000673*cost(6.11618580510+738.32419408660*x);
R0+=0.00000000806*cost(4.64475158248+533.83556667880*x);
R0+=0.00000000670*cost(2.67625974048+1012.91150727320*x);
R0+=0.00000000668*cost(4.93815253692+5172.47623572500*x);
R0+=0.00000000818*cost(1.41973280302+580.09354127370*x);
R0+=0.00000000652*cost(3.41422919445+650.94298657790*x);
R0+=0.00000000643*cost(2.46566726278+1049.82070263360*x);
R0+=0.00000000859*cost(2.50530106631+782.34693644780*x);
R0+=0.00000000662*cost(4.13533996643+733.42883297700*x);
R0+=0.00000000812*cost(1.30325352179+1055.18914449520*x);
R0+=0.00000000638*cost(4.21760246824+1064.04779663520*x);
R0+=0.00000000637*cost(6.13121700151+4752.99159184980*x);
R0+=0.00000000636*cost(0.83411828974+711.49749114360*x);
R0+=0.00000000642*cost(1.86741704507+1053.96530421780*x);
R0+=0.00000000795*cost(4.54081089118+1457.52593306200*x);
R0+=0.00000000783*cost(4.37652961667+105.54045477340*x);
R0+=0.00000000640*cost(5.44039474349+632.03297978780*x);
R0+=0.00000000651*cost(5.02431301146+528.04643369190*x);
R0+=0.00000000686*cost(0.27079898498+11.77941344680*x);
R0+=0.00000000644*cost(5.36935176134+835.78789401270*x);
R0+=0.00000000639*cost(1.86699974431+6172.86952877200*x);
R0+=0.00000000630*cost(2.86895754523+633.53449883860*x);
R0+=0.00000000826*cost(1.46026926041+2199.76523406920*x);
R0+=0.00000000687*cost(3.81221717134+73.29712585900*x);
R0+=0.00000000697*cost(4.18082589322+1.69692102940*x);
R0+=0.00000000788*cost(0.21278801649+313.94418910180*x);
R0+=0.00000000686*cost(2.51807576494+638.41281360570*x);
R0+=0.00000000847*cost(5.56263749391+4429.48617519240*x);
R0+=0.00000000673*cost(4.87494072856+103.04459010880*x);
R0+=0.00000000663*cost(4.80713895807+991.71387862270*x);
R0+=0.00000000614*cost(3.87231597482+767.36908292080*x);
R0+=0.00000000666*cost(5.71697262323+661.09491496450*x);
R0+=0.00000000681*cost(2.33844767741+501.23677709140*x);
R0+=0.00000000597*cost(3.03921014345+6.95348830640*x);
R0+=0.00000000777*cost(3.08786050361+441.57604440300*x);
R0+=0.00000000588*cost(0.08236113246+4164.31198961300*x);
R0+=0.00000000693*cost(4.66190836234+3384.33133900480*x);
R0+=0.00000000810*cost(1.97701084490+860.30992875280*x);
R0+=0.00000000602*cost(5.56403449542+1587.58842257550*x);
R0+=0.00000000622*cost(6.11554348965+7.06536289100*x);
R0+=0.00000000592*cost(3.29013906024+10103.07922499160*x);
R0+=0.00000000692*cost(6.10931942233+12.74262129330*x);
R0+=0.00000000597*cost(6.13204711801+7.27360569520*x);
R0+=0.00000000594*cost(2.58839673551+849.26422848890*x);
R0+=0.00000000728*cost(2.73732195088+6.15033915430*x);
R0+=0.00000000602*cost(5.28816527514+949.12742486000*x);
R0+=0.00000000568*cost(1.75508433865+1077.54117745390*x);
R0+=0.00000000575*cost(4.50676079721+1230.14275597430*x);
R0+=0.00000000588*cost(0.65827893998+4642.78527063040*x);
R0+=0.00000000561*cost(3.87565914360+135.33610313300*x);
R0+=0.00000000558*cost(3.36094471852+24498.83024629040*x);
R0+=0.00000000557*cost(3.45629457197+19896.88012732740*x);
R0+=0.00000000558*cost(1.17103892689+3576.28979344040*x);
R0+=0.00000000574*cost(5.19235074140+104.05598206510*x);
R0+=0.00000000560*cost(3.57141429379+5333.90024102160*x);
R0+=0.00000000555*cost(0.18349908409+512.42548970720*x);
R0+=0.00000000571*cost(0.83070148820+1570.91364801910*x);
R0+=0.00000000632*cost(3.67893818442+1065.01100448170*x);
R0+=0.00000000744*cost(2.33083237537+620.25356634100*x);
R0+=0.00000000540*cost(5.15775909675+1751.53953141600*x);
R0+=0.00000000592*cost(3.07238123875+1446.62324515000*x);
R0+=0.00000000537*cost(1.52803865425+8094.52168583260*x);
R0+=0.00000000550*cost(5.50701003577+1432.39615114840*x);
R0+=0.00000000546*cost(2.34388967045+949.22379307960*x);
R0+=0.00000000534*cost(3.04076654796+7.16173111060*x);
R0+=0.00000000619*cost(6.07865159203+46.47042291600*x);
R0+=0.00000000562*cost(0.96641974928+1438.02522544090*x);
R0+=0.00000000531*cost(1.06695547390+100.17201291180*x);
R0+=0.00000000599*cost(3.59295739143+1144.31545714310*x);
R0+=0.00000000526*cost(3.51641923371+0.75075952540*x);
R0+=0.00000000564*cost(0.72677136494+1059.22187149480*x);
R0+=0.00000000537*cost(5.72603965787+513.22863885930*x);
R0+=0.00000000630*cost(2.31183143900+2729.45619916380*x);
R0+=0.00000000530*cost(4.99510636441+9264.10993724120*x);
R0+=0.00000000649*cost(0.95666735852+920.86443331850*x);
R0+=0.00000000547*cost(1.18801926149+11506.76976979360*x);
R0+=0.00000000516*cost(3.28562070858+734.91330568530*x);
R0+=0.00000000567*cost(5.13926871155+288.08069400530*x);
R0+=0.00000000538*cost(0.28159637680+153.49535039770*x);
R0+=0.00000000718*cost(0.48326672359+842.15068148810*x);
R0+=0.00000000526*cost(4.39778401928+546.15329132990*x);
R0+=0.00000000695*cost(2.44235086902+657.16276170140*x);
R0+=0.00000000697*cost(4.99042365686+12.53017297220*x);
R0+=0.00000000519*cost(6.27847163164+59.80374504030*x);
R0+=0.00000000504*cost(2.58550284000+5378.66178416220*x);
R0+=0.00000000496*cost(2.43659402827+990.22940591440*x);
R0+=0.00000000617*cost(5.73284985700+745.43774108740*x);
R0+=0.00000000519*cost(3.10157097770+9161.01716302260*x);
R0+=0.00000000654*cost(1.31181453784+878.32616366560*x);
R0+=0.00000000619*cost(3.71554817226+2090.30967237520*x);
R0+=0.00000000500*cost(4.28937439066+5216.58037280140*x);
R0+=0.00000000621*cost(3.98893673383+409.92341631960*x);
R0+=0.00000000685*cost(1.95310431695+3156.80514956520*x);
R0+=0.00000000552*cost(2.81774132958+344.70304530790*x);
R0+=0.00000000551*cost(1.91969778405+113.38771495710*x);
R0+=0.00000000682*cost(0.87321578326+6069.77675455340*x);
R0+=0.00000000651*cost(5.09951064975+531.33549649730*x);
R0+=0.00000000537*cost(3.67357440226+605.95703637020*x);
R0+=0.00000000525*cost(0.74584814988+736.83972137830*x);
R0+=0.00000000505*cost(3.12494814307+1475.68518032670*x);
R0+=0.00000000622*cost(3.00013939606+2349.32843120380*x);
R0+=0.00000000644*cost(3.00156986335+298.23262239190*x);
R0+=0.00000000564*cost(3.81960833949+1059.54198888360*x);
R0+=0.00000000468*cost(3.50348554992+4841.85727206680*x);
R0+=0.00000000491*cost(1.28535573072+247.23934538180*x);
R0+=0.00000000458*cost(0.45056377876+1065.60170531270*x);
R0+=0.00000000543*cost(2.39704308320+9690.70812811720*x);
R0+=0.00000000459*cost(5.29870259698+1474.93442080130*x);
R0+=0.00000000483*cost(3.63649121244+131.40394986990*x);
R0+=0.00000000632*cost(2.75028345792+334.55111692130*x);
R0+=0.00000000483*cost(0.42979609421+735.82832942200*x);
R0+=0.00000000540*cost(0.54791737146+51646.11531805379*x);
R0+=0.00000000531*cost(0.30026207053+912.78767847120*x);
R0+=0.00000000449*cost(3.02583472996+5901.23920225600*x);
R0+=0.00000000544*cost(2.98747240952+4223.30062675520*x);
R0+=0.00000000557*cost(5.83542572008+9676.48103411560*x);
R0+=0.00000000501*cost(0.03408180117+1080.72257119160*x);
R0+=0.00000000517*cost(4.40400852026+2545.36205125440*x);
R0+=0.00000000481*cost(3.63292807076+5584.84733259940*x);
R0+=0.00000000557*cost(6.11443978190+976.00231191280*x);
R0+=0.00000000481*cost(3.41035583659+3803.81598288000*x);
R0+=0.00000000622*cost(2.29597570837+9999.98645077300*x);
R0+=0.00000000454*cost(2.88584538455+1987.21689815660*x);
R0+=0.00000000439*cost(4.83198101064+50.40257617910*x);
R0+=0.00000000475*cost(2.69994471394+491.81856188770*x);
R0+=0.00000000618*cost(0.72471290082+1291.43097372290*x);
R0+=0.00000000503*cost(0.13449993622+2015.67108615980*x);
R0+=0.00000000551*cost(2.13418546604+1440.99417085750*x);
R0+=0.00000000595*cost(3.78181802545+6386.16862421000*x);
R0+=0.00000000434*cost(2.64411689486+748.40668650400*x);
R0+=0.00000000592*cost(0.32587740408+737.36098624010*x);
R0+=0.00000000490*cost(2.37988828800+2225.78878786010*x);
R0+=0.00000000439*cost(1.33582802018+995.64603188580*x);
R0+=0.00000000543*cost(2.05067702505+906.84978763800*x);
R0+=0.00000000466*cost(2.43707405011+3362.99069800240*x);
R0+=0.00000000481*cost(2.32223226419+1357.61455258110*x);
R0+=0.00000000566*cost(0.59740900184+350.33211960040*x);
R0+=0.00000000429*cost(2.46287580628+3914.02230409940*x);
R0+=0.00000000429*cost(1.01299906509+4333.50694797460*x);
R0+=0.00000000425*cost(1.67255823369+148.07872442630*x);
R0+=0.00000000412*cost(3.29630633921+7.32599532190*x);
R0+=0.00000000508*cost(1.16158524676+9.56122755560*x);
R0+=0.00000000524*cost(5.02562926120+1090.40141882620*x);
R0+=0.00000000409*cost(5.80053072411+9146.79006902100*x);
R0+=0.00000000497*cost(0.01579913593+1069.67687092770*x);
R0+=0.00000000548*cost(6.03429743373+9367.20271145980*x);
R0+=0.00000000433*cost(5.93688350840+1688.23351623930*x);
R0+=0.00000000424*cost(4.18150111530+550.13783421970*x);
R0+=0.00000000401*cost(0.11519846139+970.51624997220*x);
R0+=0.00000000503*cost(5.28212300854+668.20846196530*x);
R0+=0.00000000555*cost(1.00328633255+141.22580985640*x);
R0+=0.00000000404*cost(2.48633976473+519.65665678700*x);
R0+=0.00000000441*cost(6.06185501734+25.12978191360*x);
R0+=0.00000000412*cost(5.87495245826+6.90109867970*x);
R0+=0.00000000478*cost(0.71264950607+1094.80665284130*x);
R0+=0.00000000446*cost(2.71248183031+31.49256938900*x);
R0+=0.00000000404*cost(5.49462012486+447.93883187840*x);
R0+=0.00000000391*cost(1.26105612700+8.07675484730*x);
R0+=0.00000000463*cost(1.93535321271+6275.96230299060*x);
R0+=0.00000000507*cost(3.61089992782+546.95644048200*x);
R0+=0.00000000402*cost(5.86200127054+927.83496796740*x);
R0+=0.00000000481*cost(6.21043578332+683.98946464440*x);
R0+=0.00000000483*cost(5.02142924458+857.12853501510*x);
R0+=0.00000000444*cost(0.84873092377+1371.84164658270*x);
R0+=0.00000000391*cost(2.81753436573+5798.14642803740*x);
R0+=0.00000000395*cost(0.22367886581+51116.42435295920*x);
R0+=0.00000000378*cost(6.03765733432+1268.74887236410*x);
R0+=0.00000000471*cost(6.24506463249+946.46729598410*x);
R0+=0.00000000405*cost(0.57785207581+107.28555991260*x);
R0+=0.00000000371*cost(6.15750793727+509.24409596950*x);
R0+=0.00000000370*cost(4.90330687618+1436.54075273260*x);
R0+=0.00000000448*cost(4.76565111029+284.14854074220*x);
R0+=0.00000000474*cost(0.71146352197+2108.46891963990*x);
R0+=0.00000000509*cost(5.53328407404+1128.53445446400*x);

double R1=0;
R1+=0.01271801596*cost(2.64937511122+529.69096509460*x);
R1+=0.00061661771*cost(3.00076251018+1059.38193018920*x);
R1+=0.00053443592*cost(3.89717644226+522.57741809380*x);
R1+=0.00031185167*cost(4.88276663526+536.80451209540*x);
R1+=0.00041390257;
R1+=0.00011847190*cost(2.41329588176+419.48464387520*x);
R1+=0.00009166360*cost(4.75979408587+7.11354700080*x);
R1+=0.00003175763*cost(2.79297987071+103.09277421860*x);
R1+=0.00003203446*cost(5.21083285476+735.87651353180*x);
R1+=0.00003403605*cost(3.34688537997+1589.07289528380*x);
R1+=0.00002600003*cost(3.63435101622+206.18554843720*x);
R1+=0.00002412207*cost(1.46947308304+426.59819087600*x);
R1+=0.00002806064*cost(3.74223693580+515.46387109300*x);
R1+=0.00002676575*cost(4.33052878699+1052.26838318840*x);
R1+=0.00002100507*cost(3.92762682306+639.89728631400*x);
R1+=0.00001646182*cost(5.30953510947+1066.49547719000*x);
R1+=0.00001641257*cost(4.41628669824+625.67019231240*x);
R1+=0.00001049866*cost(3.16113622955+213.29909543800*x);
R1+=0.00001024802*cost(2.55432643018+412.37109687440*x);
R1+=0.00000740996*cost(2.17094630558+1162.47470440780*x);
R1+=0.00000806404*cost(2.67750801380+632.78373931320*x);
R1+=0.00000676928*cost(6.24953479790+838.96928775040*x);
R1+=0.00000468895*cost(4.70973463481+543.91805909620*x);
R1+=0.00000444683*cost(0.40281181402+323.50541665740*x);
R1+=0.00000567076*cost(4.57655414712+742.99006053260*x);
R1+=0.00000415894*cost(5.36836018215+728.76296653100*x);
R1+=0.00000484689*cost(2.46882793186+949.17560896980*x);
R1+=0.00000337555*cost(3.16781951120+956.28915597060*x);
R1+=0.00000401738*cost(4.60528841541+309.27832265580*x);
R1+=0.00000347378*cost(4.68148808722+14.22709400160*x);
R1+=0.00000260753*cost(5.34290306101+846.08283475120*x);
R1+=0.00000220084*cost(4.84210964963+1368.66025284500*x);
R1+=0.00000203217*cost(5.59995425432+1155.36115740700*x);
R1+=0.00000246603*cost(3.92313823537+942.06206196900*x);
R1+=0.00000183504*cost(4.26526769703+95.97922721780*x);
R1+=0.00000180134*cost(4.40165491159+532.87235883230*x);
R1+=0.00000197134*cost(3.70551461394+2118.76386037840*x);
R1+=0.00000196005*cost(3.75877587139+199.07200143640*x);
R1+=0.00000200190*cost(4.43888814441+1045.15483618760*x);
R1+=0.00000170225*cost(4.84647488867+526.50957135690*x);
R1+=0.00000146335*cost(6.12958365535+533.62311835770*x);
R1+=0.00000133483*cost(1.32245735855+110.20632121940*x);
R1+=0.00000132076*cost(4.51187950811+525.75881183150*x);
R1+=0.00000123851*cost(2.04290370696+1478.86657406440*x);
R1+=0.00000121861*cost(4.40581788491+1169.58825140860*x);
R1+=0.00000115313*cost(4.46741278152+1581.95934828300*x);
R1+=0.00000098527*cost(5.72833991647+1596.18644228460*x);
R1+=0.00000091608*cost(4.52965592121+1685.05212250160*x);
R1+=0.00000110638*cost(3.62504147403+1272.68102562720*x);
R1+=0.00000080536*cost(4.11311699583+1258.45393162560*x);
R1+=0.00000079552*cost(2.71898473954+1692.16566950240*x);
R1+=0.00000100164*cost(5.24693885858+1265.56747862640*x);
R1+=0.00000077854*cost(5.56722651753+1471.75302706360*x);
R1+=0.00000085766*cost(0.07906707372+831.85574074960*x);
R1+=0.00000082132*cost(3.80763015979+508.35032409220*x);
R1+=0.00000055319*cost(0.35180851191+316.39186965660*x);
R1+=0.00000052338*cost(5.53074272117+433.71173787680*x);
R1+=0.00000055769*cost(4.75141241141+302.16477565500*x);
R1+=0.00000050597*cost(4.85603161770+1375.77379984580*x);
R1+=0.00000043554*cost(4.94441642712+1361.54670584420*x);
R1+=0.00000042172*cost(1.22404278447+853.19638175200*x);
R1+=0.00000037695*cost(4.26767539209+2001.44399215820*x);
R1+=0.00000049395*cost(4.01422828967+220.41264243880*x);
R1+=0.00000038263*cost(5.33025236797+1788.14489672020*x);
R1+=0.00000035611*cost(1.76205571128+1795.25844372100*x);
R1+=0.00000036296*cost(3.84995284393+1574.84580128220*x);
R1+=0.00000029332*cost(5.16619257786+3.93215326310*x);
R1+=0.00000025180*cost(4.33777727362+519.39602435610*x);
R1+=0.00000024778*cost(2.72907897410+405.25754987360*x);
R1+=0.00000027025*cost(6.09669947903+1148.24761040620*x);
R1+=0.00000022604*cost(0.19173890105+380.12776796000*x);
R1+=0.00000020499*cost(4.32881495378+3.18139373770*x);
R1+=0.00000019925*cost(4.62967500111+1677.93857550080*x);
R1+=0.00000019528*cost(5.10596326232+1073.60902419080*x);
R1+=0.00000018427*cost(3.76522178300+1485.98012106520*x);
R1+=0.00000018869*cost(5.05259402407+2104.53676637680*x);
R1+=0.00000017031*cost(4.01843356903+2317.83586181480*x);
R1+=0.00000016671*cost(5.42931676507+88.86568021700*x);
R1+=0.00000015337*cost(2.92700926091+2008.55753915900*x);
R1+=0.00000014499*cost(3.63339836845+628.85158605010*x);
R1+=0.00000014575*cost(5.50832843322+721.64941953020*x);
R1+=0.00000013728*cost(4.87623389735+629.60234557550*x);
R1+=0.00000018481*cost(6.03032762264+330.61896365820*x);
R1+=0.00000013499*cost(1.38539534821+518.64526483070*x);
R1+=0.00000015740*cost(2.93038271684+1905.46476494040*x);
R1+=0.00000012459*cost(1.58587053146+2111.65031337760*x);
R1+=0.00000012272*cost(3.37671053917+635.96513305090*x);
R1+=0.00000011836*cost(4.08486322993+2648.45482547300*x);
R1+=0.00000011166*cost(4.62623267608+636.71589257630*x);
R1+=0.00000014348*cost(2.74177797727+2221.85663459700*x);
R1+=0.00000011221*cost(3.55311861205+1891.23767093880*x);
R1+=0.00000013121*cost(5.83845065644+1464.63948006280*x);
R1+=0.00000011351*cost(2.57606886230+511.53171782990*x);
R1+=0.00000010487*cost(0.49850799841+453.42489381900*x);
R1+=0.00000009728*cost(4.38837468002+1994.33044515740*x);
R1+=0.00000010131*cost(2.76432756215+423.41679713830*x);
R1+=0.00000008620*cost(5.16374493158+1056.20053645150*x);
R1+=0.00000008952*cost(4.79407952752+2420.92863603340*x);
R1+=0.00000008126*cost(3.72977106954+2634.22773147140*x);
R1+=0.00000008078*cost(1.29246272894+2428.04218303420*x);
R1+=0.00000008867*cost(1.85684753622+750.10360753340*x);
R1+=0.00000008912*cost(4.80973516711+1062.56332392690*x);
R1+=0.00000008552*cost(4.53818617984+21.34064100240*x);
R1+=0.00000009468*cost(4.33472161983+1802.37199072180*x);
R1+=0.00000006904*cost(5.96616555709+540.73666535850*x);
R1+=0.00000007293*cost(4.97763580465+1699.27921650320*x);
R1+=0.00000007083*cost(4.99096728816+1055.44977692610*x);
R1+=0.00000007226*cost(4.97823884383+1898.35121793960*x);
R1+=0.00000006464*cost(1.39173466879+422.66603761290*x);
R1+=0.00000006214*cost(4.46490158256+551.03160609700*x);
R1+=0.00000006794*cost(2.90878831415+2324.94940881560*x);
R1+=0.00000006173*cost(3.65617162985+621.73803904930*x);
R1+=0.00000006243*cost(6.13691919694+2125.87740737920*x);
R1+=0.00000005936*cost(2.58312235120+569.04784100980*x);
R1+=0.00000006504*cost(4.56908431757+1038.04128918680*x);
R1+=0.00000007305*cost(3.02062127734+416.30325013750*x);
R1+=0.00000006598*cost(5.55348005731+1781.03134971940*x);
R1+=0.00000005133*cost(6.21646917980+963.40270297140*x);
R1+=0.00000005876*cost(4.23153077453+539.98590583310*x);
R1+=0.00000005119*cost(0.06942832171+1063.31408345230*x);
R1+=0.00000005460*cost(4.91084384602+835.03713448730*x);
R1+=0.00000004989*cost(1.35153694680+1382.88734684660*x);
R1+=0.00000005224*cost(0.18468411116+117.31986822020*x);
R1+=0.00000006187*cost(3.87193497099+191.95845443560*x);
R1+=0.00000004681*cost(4.61057119508+643.82943957710*x);
R1+=0.00000004627*cost(3.34644534691+2207.62954059540*x);
R1+=0.00000004526*cost(4.07729737127+2310.72231481400*x);
R1+=0.00000004718*cost(4.55578336947+2737.32050569000*x);
R1+=0.00000004471*cost(1.47603161897+408.43894361130*x);
R1+=0.00000004073*cost(1.13014903180+415.55249061210*x);
R1+=0.00000005476*cost(5.63198569698+618.55664531160*x);
R1+=0.00000004034*cost(4.09631702747+430.53034413910*x);
R1+=0.00000004304*cost(4.60536378943+647.01083331480*x);
R1+=0.00000003765*cost(3.42751259825+2950.61960112800*x);
R1+=0.00000004559*cost(4.23723998745+227.52618943960*x);
R1+=0.00000003695*cost(1.03127824978+2744.43405269080*x);
R1+=0.00000003667*cost(4.12268925541+440.82528487760*x);
R1+=0.00000003677*cost(2.19480200527+534.35683154060*x);
R1+=0.00000003818*cost(1.14800596289+74.78159856730*x);
R1+=0.00000004221*cost(2.37721579949+2538.24850425360*x);
R1+=0.00000003488*cost(5.33792561596+458.84151979040*x);
R1+=0.00000003437*cost(4.26164443643+10.29494073850*x);
R1+=0.00000004394*cost(0.18808423412+824.74219374880*x);
R1+=0.00000003339*cost(4.85708402591+295.05122865420*x);
R1+=0.00000003329*cost(5.50043586719+739.80866679490*x);
R1+=0.00000003623*cost(4.64011531952+2214.74308759620*x);
R1+=0.00000003185*cost(2.69708590442+561.93429400900*x);
R1+=0.00000003421*cost(3.38512615384+149.56319713460*x);
R1+=0.00000003442*cost(4.34217280083+305.34616939270*x);
R1+=0.00000003580*cost(5.29481665335+2097.42321937600*x);
R1+=0.00000003401*cost(2.74761862893+2641.34127847220*x);
R1+=0.00000002901*cost(0.91012525424+984.60033162190*x);
R1+=0.00000003566*cost(1.63400343968+525.02509864860*x);
R1+=0.00000002869*cost(1.31799241974+611.44309831080*x);
R1+=0.00000002635*cost(5.25517910535+532.13864564940*x);
R1+=0.00000002683*cost(4.24641945773+3053.71237534660*x);
R1+=0.00000002614*cost(3.17862099921+527.24328453980*x);
R1+=0.00000002251*cost(4.21598247360+739.05790726950*x);
R1+=0.00000002268*cost(5.52248110560+524.27433912320*x);
R1+=0.00000002372*cost(4.19741177512+217.23124870110*x);
R1+=0.00000002623*cost(5.82647427958+732.69511979410*x);
R1+=0.00000002666*cost(3.92538056951+210.11770170030*x);
R1+=0.00000002036*cost(4.84043420813+1049.08698945070*x);
R1+=0.00000002441*cost(2.63840901843+760.25553592000*x);
R1+=0.00000002095*cost(5.76269812349+529.64278098480*x);
R1+=0.00000002021*cost(3.81308146017+2627.11418447060*x);
R1+=0.00000002089*cost(4.18463193132+945.99421523210*x);
R1+=0.00000002305*cost(1.61220665690+604.47256366190*x);
R1+=0.00000001969*cost(5.37427735384+142.44965013380*x);
R1+=0.00000001923*cost(4.75088270631+535.10759106600*x);
R1+=0.00000001955*cost(5.49000238006+1439.50969814920*x);
R1+=0.00000001877*cost(3.26978877187+3267.01147078460*x);
R1+=0.00000002286*cost(2.93885172004+76.26607127560*x);
R1+=0.00000002074*cost(5.85386852879+532.61172640140*x);
R1+=0.00000002121*cost(3.92430797099+2435.15573003500*x);
R1+=0.00000001807*cost(3.17208959472+2524.02141025200*x);
R1+=0.00000001712*cost(4.02986641257+731.94436026870*x);
R1+=0.00000002119*cost(0.41049593984+1279.79457262800*x);
R1+=0.00000001660*cost(2.34370903423+528.72775724810*x);
R1+=0.00000001655*cost(0.78809717175+3060.82592234740*x);
R1+=0.00000001729*cost(4.26127896267+724.83081326790*x);
R1+=0.00000002060*cost(5.04785330873+2413.81508903260*x);
R1+=0.00000002095*cost(2.67732367556+529.73914920440*x);
R1+=0.00000001933*cost(2.49162437046+2957.73314812880*x);
R1+=0.00000001898*cost(2.71948262975+952.35700270750*x);
R1+=0.00000001634*cost(2.98113068812+945.24345570670*x);
R1+=0.00000001582*cost(5.84373095005+547.85021235930*x);
R1+=0.00000001662*cost(0.27359627181+454.90936652730*x);
R1+=0.00000001595*cost(1.18530167095+38.13303563780*x);
R1+=0.00000001550*cost(0.64264572959+312.45971639350*x);
R1+=0.00000001525*cost(4.08789824989+1158.54255114470*x);
R1+=0.00000001542*cost(1.12520322326+1021.24889455140*x);
R1+=0.00000001539*cost(0.37324921979+319.57326339430*x);
R1+=0.00000001628*cost(5.24285773388+1354.43315884340*x);
R1+=0.00000001897*cost(3.79973291113+953.10776223290*x);
R1+=0.00000001440*cost(4.37872256685+3178.14579056760*x);
R1+=0.00000001439*cost(4.26513521887+526.77020378780*x);
R1+=0.00000001557*cost(5.43779802371+81.75213321620*x);
R1+=0.00000001656*cost(6.09667089740+530.65417294110*x);
R1+=0.00000001548*cost(3.48799710267+934.94851496820*x);
R1+=0.00000001772*cost(5.82549274759+909.81873305460*x);
R1+=0.00000001615*cost(1.45018725033+902.70518605380*x);
R1+=0.00000001387*cost(2.52840497309+530.44172462000*x);
R1+=0.00000001574*cost(1.89565809136+437.64389113990*x);
R1+=0.00000001459*cost(3.32546061506+1041.22268292450*x);
R1+=0.00000001377*cost(0.10015418633+490.33408917940*x);
R1+=0.00000001460*cost(4.00706825185+3370.10424500320*x);
R1+=0.00000001605*cost(4.27993020192+2531.13495725280*x);
R1+=0.00000001707*cost(6.28253681644+18.15924726470*x);
R1+=0.00000001802*cost(2.23019296374+2854.64037391020*x);
R1+=0.00000001390*cost(3.76737324192+1165.65609814550*x);
R1+=0.00000001498*cost(0.17285954362+1141.13406340540*x);
R1+=0.00000001401*cost(4.81225317549+1251.34038462480*x);
R1+=0.00000001244*cost(2.83383980283+124.43341522100*x);
R1+=0.00000001320*cost(5.80675430384+387.24131496080*x);
R1+=0.00000001329*cost(0.88314574243+916.93228005540*x);
R1+=0.00000001558*cost(6.17808619637+983.11585891360*x);
R1+=0.00000001243*cost(0.29239666059+597.35901666110*x);
R1+=0.00000001541*cost(3.51095241498+2751.54759969160*x);
R1+=0.00000001482*cost(0.83066678204+529.16970023280*x);
R1+=0.00000001149*cost(3.91142023857+99.91138048090*x);
R1+=0.00000001114*cost(3.53339637290+483.22054217860*x);
R1+=0.00000001195*cost(4.16301075999+203.00415469950*x);
R1+=0.00000001100*cost(1.74769285223+497.44763618020*x);
R1+=0.00000001458*cost(5.19315120878+1592.25428902150*x);
R1+=0.00000001123*cost(1.45270581179+533.88375078860*x);
R1+=0.00000001078*cost(5.23991792940+1159.29331067010*x);
R1+=0.00000001083*cost(3.57026506855+2943.50605412720*x);
R1+=0.00000001072*cost(0.07132659992+1070.42763045310*x);
R1+=0.00000001037*cost(5.48955598976+1585.89150154610*x);
R1+=0.00000001343*cost(0.29600445633+860.30992875280*x);
R1+=0.00000001361*cost(3.46603373194+107.02492748170*x);
R1+=0.00000001061*cost(2.44580706826+1048.33622992530*x);
R1+=0.00000001002*cost(5.55216117410+337.73251065900*x);
R1+=0.00000000981*cost(3.15500987023+70.84944530420*x);
R1+=0.00000001007*cost(4.11504050436+501.23677709140*x);
R1+=0.00000000965*cost(5.63719524421+1603.29998928540*x);
R1+=0.00000001083*cost(4.88373909810+1166.40685767090*x);
R1+=0.00000000953*cost(2.83352026342+3583.40334044120*x);
R1+=0.00000001060*cost(3.18542176646+447.79581952650*x);
R1+=0.00000001136*cost(2.26568590950+525.49817940060*x);
R1+=0.00000001191*cost(2.25249961404+106.27416795630*x);
R1+=0.00000000884*cost(4.69777781327+960.22130923370*x);
R1+=0.00000001165*cost(1.56030440737+630.33605875840*x);
R1+=0.00000000947*cost(0.50856414717+842.90144101350*x);
R1+=0.00000001011*cost(0.30814674949+1593.00504854690*x);
R1+=0.00000000924*cost(2.31939900786+327.43756992050*x);
R1+=0.00000000896*cost(0.22222521202+746.92221379570*x);
R1+=0.00000001078*cost(4.78329116086+2730.20695868920*x);
R1+=0.00000000938*cost(5.42471506763+1585.14074202070*x);
R1+=0.00000000923*cost(4.44469169065+9676.48103411560*x);
R1+=0.00000000894*cost(0.26940821870+2655.56837247380*x);
R1+=0.00000001131*cost(5.46382510304+224.34479570190*x);
R1+=0.00000000808*cost(0.48295590141+3377.21779200400*x);
R1+=0.00000000809*cost(4.14122746067+114.13847448250*x);
R1+=0.00000000864*cost(1.83217006136+4.66586644600*x);
R1+=0.00000001106*cost(2.60444312553+209.36694217490*x);
R1+=0.00000000790*cost(0.11493626208+460.53844081980*x);
R1+=0.00000000799*cost(1.60426497590+5223.69391980220*x);
R1+=0.00000000933*cost(0.30976125598+685.47393735270*x);
R1+=0.00000001053*cost(5.23433104008+842.15068148810*x);
R1+=0.00000000846*cost(3.02878393490+5746.27133789600*x);
R1+=0.00000000799*cost(2.08457026425+77734.01845962799*x);
R1+=0.00000000820*cost(0.99821486743+373.01422095920*x);
R1+=0.00000000892*cost(5.36446426391+827.92358748650*x);
R1+=0.00000000821*cost(3.53889274951+498.67147645760*x);
R1+=0.00000000741*cost(1.32379374647+530.21222995640*x);
R1+=0.00000000790*cost(2.88034567513+938.12990870590*x);
R1+=0.00000000842*cost(3.39449778904+484.44438245600*x);
R1+=0.00000000785*cost(0.57841470897+850.01498801430*x);
R1+=0.00000000759*cost(3.82014112009+6283.07584999140*x);
R1+=0.00000000954*cost(2.94534072982+462.02291352810*x);
R1+=0.00000000767*cost(3.33725133157+99.16062095550*x);
R1+=0.00000000810*cost(4.69425300466+2228.97018159780*x);
R1+=0.00000000700*cost(1.72050221502+775.23338944700*x);
R1+=0.00000000764*cost(4.91747674296+1670.82502850000*x);
R1+=0.00000000724*cost(6.08692841992+2281.23049651060*x);
R1+=0.00000000711*cost(4.82250918143+11.77941344680*x);
R1+=0.00000000692*cost(2.63705354662+6.59228213900*x);
R1+=0.00000000771*cost(3.87410612014+9690.70812811720*x);
R1+=0.00000000906*cost(2.47189948442+3274.12501778540*x);
R1+=0.00000000781*cost(1.25357484582+202.25339517410*x);
R1+=0.00000000757*cost(3.78079814332+2818.03500860600*x);
R1+=0.00000000756*cost(4.28312053897+2803.80791460440*x);
R1+=0.00000000663*cost(5.27704405712+4532.57894941100*x);
R1+=0.00000000759*cost(5.45358686570+9683.59458111640*x);
R1+=0.00000000698*cost(5.43712520216+565.11568774670*x);
R1+=0.00000000709*cost(3.71117647887+3686.49611465980*x);
R1+=0.00000000677*cost(4.27891183416+25028.52121138500*x);
R1+=0.00000000643*cost(1.40239510103+9161.01716302260*x);
R1+=0.00000000656*cost(0.60909845504+835.78789401270*x);
R1+=0.00000000635*cost(5.75373871128+429.77958461370*x);
R1+=0.00000000702*cost(6.10412979847+4635.67172362960*x);
R1+=0.00000000627*cost(3.03666956129+2840.41327990860*x);
R1+=0.00000000802*cost(4.18688054701+5753.38488489680*x);
R1+=0.00000000838*cost(4.51386507097+1069.67687092770*x);
R1+=0.00000000633*cost(4.37183361444+5.41662597140*x);
R1+=0.00000000652*cost(5.79409889124+1061.82961074400*x);
R1+=0.00000000638*cost(2.18896270346+313.21047591890*x);
R1+=0.00000000827*cost(5.94231186039+1457.52593306200*x);
R1+=0.00000000678*cost(2.45013730979+5760.49843189760*x);
R1+=0.00000000814*cost(4.89578791170+1567.73225428140*x);
R1+=0.00000000624*cost(0.61631100566+1176.70179840940*x);
R1+=0.00000000600*cost(3.20918322285+1098.73880610440*x);
R1+=0.00000000717*cost(1.82349064490+3171.03224356680*x);
R1+=0.00000000651*cost(4.14419317491+2847.52682690940*x);
R1+=0.00000000629*cost(1.75272560843+92.04707395470*x);
R1+=0.00000000626*cost(3.53146082217+3067.93946934820*x);
R1+=0.00000000667*cost(4.22974611158+4539.69249641180*x);
R1+=0.00000000565*cost(0.99416346033+1894.41906467650*x);
R1+=0.00000000752*cost(0.46063700150+635.23141986800*x);
R1+=0.00000000622*cost(1.98136818407+25565.32572348040*x);
R1+=0.00000000614*cost(2.48275371627+25551.09862947879*x);
R1+=0.00000000560*cost(1.40733893388+446.31134681820*x);
R1+=0.00000000558*cost(4.37217796469+1057.89745748090*x);
R1+=0.00000000628*cost(4.65037810102+6275.96230299060*x);
R1+=0.00000000659*cost(2.41470950463+195.13984817330*x);
R1+=0.00000000616*cost(2.08837621877+10.03430830760*x);
R1+=0.00000000692*cost(3.13229025530+7.63481186260*x);
R1+=0.00000000685*cost(4.18539472904+46.47042291600*x);
R1+=0.00000000624*cost(0.02693303471+1493.09366806600*x);
R1+=0.00000000594*cost(2.13375704438+121.25202148330*x);
R1+=0.00000000508*cost(2.13584300710+1.69692102940*x);
R1+=0.00000000674*cost(1.47570122611+4694.00295470760*x);
R1+=0.00000000559*cost(4.48852017557+531.17543780290*x);
R1+=0.00000000640*cost(3.10239233469+11.04570026390*x);
R1+=0.00000000496*cost(1.29000001439+927.83496796740*x);
R1+=0.00000000587*cost(3.30651435298+600.54041039880*x);
R1+=0.00000000582*cost(0.44540948860+113.38771495710*x);
R1+=0.00000000492*cost(4.83275232000+9492.14631500480*x);
R1+=0.00000000549*cost(4.34579166146+3046.59882834580*x);
R1+=0.00000000576*cost(1.22846846364+1514.29129671650*x);
R1+=0.00000000593*cost(5.86079640612+524.06189080210*x);
R1+=0.00000000510*cost(2.62557031270+529.85102378900*x);
R1+=0.00000000489*cost(6.26855707323+3693.60966166060*x);
R1+=0.00000000480*cost(0.30754294369+528.94020556920*x);
R1+=0.00000000582*cost(3.51934668795+1056.93424963440*x);
R1+=0.00000000493*cost(5.52699906925+512.28247735530*x);
R1+=0.00000000481*cost(2.99681040149+9153.90361602180*x);
R1+=0.00000000562*cost(3.73437025868+2015.67108615980*x);
R1+=0.00000000458*cost(3.86646994292+11.30633269480*x);
R1+=0.00000000457*cost(1.80238019931+3281.23856478620*x);
R1+=0.00000000453*cost(6.17995938655+1059.33374607940*x);
R1+=0.00000000551*cost(0.13794958618+1912.57831194120*x);
R1+=0.00000000446*cost(5.53828660924+2332.06295581640*x);
R1+=0.00000000444*cost(5.06219342598+7.86430652620*x);
R1+=0.00000000461*cost(0.16951411708+26087.90314157420*x);
R1+=0.00000000439*cost(4.14986379679+1151.42900414390*x);
R1+=0.00000000614*cost(5.42289673768+2090.30967237520*x);
R1+=0.00000000488*cost(3.71681959056+447.93883187840*x);
R1+=0.00000000592*cost(2.91424148255+8624.21265092720*x);
R1+=0.00000000433*cost(2.55336268329+1064.04779663520*x);
R1+=0.00000000449*cost(5.24955106938+10213.28554621100*x);
R1+=0.00000000510*cost(5.81591864532+529.53090640020*x);
R1+=0.00000000435*cost(5.34355963629+560.71045373160*x);
R1+=0.00000000449*cost(0.72330388784+2758.66114669240*x);
R1+=0.00000000430*cost(0.94519103478+6.36278747540*x);
R1+=0.00000000563*cost(6.19175228344+1884.12412393800*x);
R1+=0.00000000443*cost(3.39246520261+1152.17976366930*x);
R1+=0.00000000430*cost(1.28652623263+505.31194270640*x);
R1+=0.00000000422*cost(5.12631540623+944.98282327580*x);
R1+=0.00000000464*cost(2.90444584145+398.14400287280*x);
R1+=0.00000000410*cost(1.24248975309+5069.38346150640*x);
R1+=0.00000000411*cost(2.95117124177+4326.39340097380*x);
R1+=0.00000000418*cost(5.15499986314+1173.52040467170*x);
R1+=0.00000000412*cost(2.98125446330+554.06998748280*x);
R1+=0.00000000403*cost(0.34381388674+32.24332891440*x);
R1+=0.00000000402*cost(5.88926765351+1570.91364801910*x);
R1+=0.00000000505*cost(1.49028912471+3782.47534187760*x);
R1+=0.00000000447*cost(0.03952029309+245.54242435240*x);
R1+=0.00000000453*cost(3.09458004153+1059.43011429900*x);
R1+=0.00000000411*cost(3.21727542472+1475.68518032670*x);
R1+=0.00000000426*cost(3.12237794195+12566.15169998280*x);
R1+=0.00000000434*cost(3.59362426939+3259.89792378380*x);
R1+=0.00000000398*cost(4.91510709622+4120.20785253660*x);
R1+=0.00000000399*cost(4.67075122011+234.63973644040*x);
R1+=0.00000000386*cost(4.81320787761+970.51624997220*x);
R1+=0.00000000427*cost(3.21176085113+977.48678462110*x);
R1+=0.00000000411*cost(4.31566962034+757.21715453420*x);
R1+=0.00000000392*cost(1.86527946688+885.43971066640*x);
R1+=0.00000000416*cost(3.81408093105+3156.80514956520*x);

double R2=0;
R2+=0.00079644833*cost(1.35865896596+529.69096509460*x);
R2+=0.00008251618*cost(5.77773935444+522.57741809380*x);
R2+=0.00007029864*cost(3.27476965833+536.80451209540*x);
R2+=0.00005314006*cost(1.83835109712+1059.38193018920*x);
R2+=0.00001860833*cost(2.97682139367+7.11354700080*x);
R2+=0.00000836267*cost(4.19889881718+419.48464387520*x);
R2+=0.00000964466*cost(5.48031822015+515.46387109300*x);
R2+=0.00000406453*cost(3.78250730354+1066.49547719000*x);
R2+=0.00000426570*cost(2.22753101795+639.89728631400*x);
R2+=0.00000377316*cost(2.24248352873+1589.07289528380*x);
R2-=0.00000497920;
R2+=0.00000339043*cost(6.12690864038+625.67019231240*x);
R2+=0.00000362943*cost(5.36761847267+206.18554843720*x);
R2+=0.00000342048*cost(6.09922969324+1052.26838318840*x);
R2+=0.00000279920*cost(4.26162555827+412.37109687440*x);
R2+=0.00000332578*cost(0.00328961161+426.59819087600*x);
R2+=0.00000229777*cost(0.70530766213+735.87651353180*x);
R2+=0.00000200783*cost(3.06850623368+543.91805909620*x);
R2+=0.00000199807*cost(4.42884165317+103.09277421860*x);
R2+=0.00000257290*cost(0.96295364983+632.78373931320*x);
R2+=0.00000138606*cost(2.93235671606+14.22709400160*x);
R2+=0.00000113535*cost(0.78713911289+728.76296653100*x);
R2+=0.00000086025*cost(5.14434751994+323.50541665740*x);
R2+=0.00000094565*cost(1.70498041073+838.96928775040*x);
R2+=0.00000083469*cost(0.05834873484+309.27832265580*x);
R2+=0.00000075198*cost(1.60495195911+956.28915597060*x);
R2+=0.00000070451*cost(1.50988357484+213.29909543800*x);
R2+=0.00000080328*cost(2.98122361797+742.99006053260*x);
R2+=0.00000056203*cost(0.95534810533+1162.47470440780*x);
R2+=0.00000061649*cost(6.10137889854+1045.15483618760*x);
R2+=0.00000066572*cost(5.47307178077+199.07200143640*x);
R2+=0.00000050057*cost(2.72063162317+532.87235883230*x);
R2+=0.00000051904*cost(5.58435625607+942.06206196900*x);
R2+=0.00000039833*cost(5.94566506227+95.97922721780*x);
R2+=0.00000044548*cost(5.52445621411+508.35032409220*x);
R2+=0.00000044282*cost(0.27118152557+526.50957135690*x);
R2+=0.00000029944*cost(0.93641735919+1155.36115740700*x);
R2+=0.00000028412*cost(2.87835720211+525.75881183150*x);
R2+=0.00000026330*cost(4.26891877269+1596.18644228460*x);
R2+=0.00000027039*cost(2.80607741398+1169.58825140860*x);
R2+=0.00000027477*cost(2.64841266238+2118.76386037840*x);
R2+=0.00000022705*cost(0.17830004133+302.16477565500*x);
R2+=0.00000029347*cost(1.78589692350+831.85574074960*x);
R2+=0.00000019991*cost(0.04328951895+949.17560896980*x);
R2+=0.00000019906*cost(1.16072627347+533.62311835770*x);
R2+=0.00000021714*cost(1.88820231818+1272.68102562720*x);
R2+=0.00000017581*cost(4.14974757919+846.08283475120*x);
R2+=0.00000017085*cost(5.89188996975+1258.45393162560*x);
R2+=0.00000021407*cost(4.35468497204+316.39186965660*x);
R2+=0.00000021295*cost(0.54429472455+1265.56747862640*x);
R2+=0.00000019859*cost(0.06453825800+1581.95934828300*x);
R2+=0.00000017025*cost(0.53383755278+1368.66025284500*x);
R2+=0.00000012804*cost(3.90044242142+433.71173787680*x);
R2+=0.00000013072*cost(0.79468040717+110.20632121940*x);
R2+=0.00000011945*cost(0.40671403646+1361.54670584420*x);
R2+=0.00000011695*cost(4.44394618065+405.25754987360*x);
R2+=0.00000011979*cost(2.22872778682+220.41264243880*x);
R2+=0.00000009633*cost(6.01002272123+853.19638175200*x);
R2+=0.00000010163*cost(0.99504635158+1471.75302706360*x);
R2+=0.00000008977*cost(1.60328709409+1692.16566950240*x);
R2+=0.00000008701*cost(3.52167876799+1073.60902419080*x);
R2+=0.00000008314*cost(5.60169732564+1574.84580128220*x);
R2+=0.00000008958*cost(6.26708748901+519.39602435610*x);
R2+=0.00000007828*cost(0.65241611799+1478.86657406440*x);
R2+=0.00000007833*cost(0.17920601344+1685.05212250160*x);
R2+=0.00000007451*cost(0.88421084942+88.86568021700*x);
R2+=0.00000007320*cost(0.89341249264+721.64941953020*x);
R2+=0.00000009135*cost(1.51210840939+1148.24761040620*x);
R2+=0.00000006110*cost(2.50080005128+3.18139373770*x);
R2+=0.00000007037*cost(4.44127496638+330.61896365820*x);
R2+=0.00000005163*cost(2.79219166952+21.34064100240*x);
R2+=0.00000005079*cost(2.97991736844+1375.77379984580*x);
R2+=0.00000004930*cost(0.04683167622+1677.93857550080*x);
R2+=0.00000004664*cost(2.28007273876+1485.98012106520*x);
R2+=0.00000004692*cost(0.86220230505+3.93215326310*x);
R2+=0.00000005307*cost(0.85008578245+1788.14489672020*x);
R2+=0.00000004239*cost(0.40758287124+629.60234557550*x);
R2+=0.00000004230*cost(1.61046658091+635.96513305090*x);
R2+=0.00000003627*cost(2.71151441113+551.03160609700*x);
R2+=0.00000003314*cost(0.55067236587+1795.25844372100*x);
R2+=0.00000004409*cost(1.28127751050+1464.63948006280*x);
R2+=0.00000003270*cost(1.18744032691+1905.46476494040*x);
R2+=0.00000003226*cost(6.18716071251+1038.04128918680*x);
R2+=0.00000003103*cost(6.22971614425+2001.44399215820*x);
R2+=0.00000003410*cost(2.44624067925+539.98590583310*x);
R2+=0.00000003174*cost(5.54870592599+191.95845443560*x);
R2+=0.00000002590*cost(3.24430559059+1062.56332392690*x);
R2+=0.00000002614*cost(0.55149554149+2104.53676637680*x);
R2+=0.00000002174*cost(5.32613824409+1891.23767093880*x);
R2+=0.00000002659*cost(4.82459974220+416.30325013750*x);
R2+=0.00000002187*cost(1.71707514653+628.85158605010*x);
R2+=0.00000002263*cost(6.19233486371+1994.33044515740*x);
R2+=0.00000002328*cost(4.28236795066+963.40270297140*x);
R2+=0.00000002579*cost(0.03256542251+1898.35121793960*x);
R2+=0.00000002077*cost(3.32602157426+1699.27921650320*x);
R2+=0.00000002529*cost(2.39697505835+227.52618943960*x);
R2+=0.00000002468*cost(0.06551346218+750.10360753340*x);
R2+=0.00000001989*cost(0.29206371261+636.71589257630*x);
R2+=0.00000001927*cost(0.32286661566+295.05122865420*x);
R2+=0.00000001904*cost(3.43534792123+647.01083331480*x);
R2+=0.00000001940*cost(0.29170673525+2111.65031337760*x);
R2+=0.00000001880*cost(3.14403615586+611.44309831080*x);
R2+=0.00000002324*cost(1.94960720763+824.74219374880*x);
R2+=0.00000001854*cost(4.71794950485+2125.87740737920*x);
R2+=0.00000002547*cost(1.23908353090+2221.85663459700*x);
R2+=0.00000001814*cost(1.60250861074+2008.55753915900*x);
R2+=0.00000001611*cost(5.83466560322+422.66603761290*x);
R2+=0.00000001667*cost(2.32455940876+440.82528487760*x);
R2+=0.00000001622*cost(0.36650974375+1056.20053645150*x);
R2+=0.00000001624*cost(2.42139677881+10.29494073850*x);
R2+=0.00000001622*cost(3.51892791175+1055.44977692610*x);
R2+=0.00000001606*cost(5.76205763975+117.31986822020*x);
R2+=0.00000001646*cost(5.88662636573+2317.83586181480*x);
R2+=0.00000002026*cost(4.61781314145+423.41679713830*x);
R2+=0.00000002098*cost(1.04559231028+1781.03134971940*x);
R2+=0.00000001868*cost(1.12487729469+618.55664531160*x);
R2+=0.00000001885*cost(2.78775930564+1802.37199072180*x);
R2+=0.00000001445*cost(0.08308050305+1382.88734684660*x);
R2+=0.00000001797*cost(3.00776822706+2648.45482547300*x);
R2+=0.00000001422*cost(0.17649746278+2420.92863603340*x);
R2+=0.00000001129*cost(1.59030291320+380.12776796000*x);
R2+=0.00000001126*cost(4.19989673600+547.85021235930*x);
R2+=0.00000001186*cost(5.98943062173+2310.72231481400*x);
R2+=0.00000001108*cost(4.22655117757+934.94851496820*x);
R2+=0.00000001259*cost(1.19687222266+1063.31408345230*x);
R2+=0.00000001072*cost(3.86169004168+1603.29998928540*x);
R2+=0.00000000946*cost(5.59968097387+99.91138048090*x);
R2+=0.00000000937*cost(1.03083276760+81.75213321620*x);
R2+=0.00000000938*cost(6.18136092771+945.99421523210*x);
R2+=0.00000000908*cost(2.54355964041+6283.07584999140*x);
R2+=0.00000000874*cost(5.21903196047+2207.62954059540*x);
R2+=0.00000000874*cost(6.01240284465+511.53171782990*x);
R2+=0.00000001188*cost(0.75698357968+2097.42321937600*x);
R2+=0.00000000789*cost(3.91035208173+10213.28554621100*x);
R2+=0.00000001000*cost(1.34667100304+732.69511979410*x);
R2+=0.00000000952*cost(1.55355777420+2324.94940881560*x);
R2+=0.00000000811*cost(5.00475553271+319.57326339430*x);
R2+=0.00000000763*cost(3.98527559630+337.73251065900*x);
R2+=0.00000000880*cost(1.14789972199+952.35700270750*x);
R2+=0.00000000780*cost(4.69463316930+5746.27133789600*x);
R2+=0.00000000910*cost(0.08774541571+2737.32050569000*x);
R2+=0.00000000773*cost(0.77131695762+5760.49843189760*x);
R2+=0.00000000764*cost(6.11686539353+9676.48103411560*x);
R2+=0.00000000758*cost(2.19350719860+9690.70812811720*x);
R2+=0.00000000671*cost(1.19532387143+124.43341522100*x);
R2+=0.00000000661*cost(5.99578306627+501.23677709140*x);
R2+=0.00000000729*cost(0.65312263578+2538.24850425360*x);
R2+=0.00000000825*cost(2.70770030205+3370.10424500320*x);
R2+=0.00000000670*cost(5.44169923277+107.02492748170*x);
R2+=0.00000000739*cost(1.14609907817+2641.34127847220*x);
R2+=0.00000000866*cost(3.02831268213+3046.59882834580*x);
R2+=0.00000000718*cost(4.83684196454+860.30992875280*x);
R2+=0.00000000813*cost(6.01229270247+2214.74308759620*x);
R2+=0.00000000746*cost(1.12371143332+739.80866679490*x);
R2+=0.00000000741*cost(5.93171662010+2634.22773147140*x);
R2+=0.00000000667*cost(0.89885058003+106.27416795630*x);
R2+=0.00000000573*cost(2.42701822581+739.05790726950*x);
R2+=0.00000000734*cost(0.72837704619+1354.43315884340*x);
R2+=0.00000000662*cost(2.21768976390+2015.67108615980*x);
R2+=0.00000000782*cost(2.52401202862+3679.38256765900*x);
R2+=0.00000000779*cost(2.38608991574+3267.01147078460*x);
R2+=0.00000000553*cost(1.85211127676+453.42489381900*x);
R2+=0.00000000701*cost(4.23431087374+9683.59458111640*x);
R2+=0.00000000571*cost(2.98435419019+1262.38608488870*x);
R2+=0.00000000621*cost(1.24462887440+3803.81598288000*x);
R2+=0.00000000563*cost(5.99845316446+1049.08698945070*x);
R2+=0.00000000538*cost(4.92334194042+447.79581952650*x);
R2+=0.00000000534*cost(0.99911551571+462.02291352810*x);
R2+=0.00000000541*cost(6.19275150397+1987.21689815660*x);
R2+=0.00000000511*cost(3.28553278370+4.66586644600*x);
R2+=0.00000000539*cost(5.33214565622+2751.54759969160*x);
R2+=0.00000000651*cost(5.12199308959+3156.80514956520*x);
R2+=0.00000000483*cost(3.03782387056+3281.23856478620*x);
R2+=0.00000000476*cost(2.17592053936+149.56319713460*x);
R2+=0.00000000510*cost(5.35664230912+9.56122755560*x);
R2+=0.00000000490*cost(1.57324553106+1251.34038462480*x);
R2+=0.00000000467*cost(5.92343423840+203.00415469950*x);
R2+=0.00000000528*cost(5.81786945766+2627.11418447060*x);
R2+=0.00000000447*cost(3.51498961805+18.15924726470*x);
R2+=0.00000000429*cost(0.16627197188+74.78159856730*x);
R2+=0.00000000497*cost(0.30985248432+2428.04218303420*x);
R2+=0.00000000516*cost(3.89424540015+2516.90786325120*x);
R2+=0.00000000519*cost(2.43126348834+3686.49611465980*x);
R2+=0.00000000404*cost(2.77840802846+7.16173111060*x);
R2+=0.00000000533*cost(4.77083438961+3473.19701922180*x);
R2+=0.00000000515*cost(3.54549816613+3178.14579056760*x);
R2+=0.00000000533*cost(5.61415688189+2524.02141025200*x);
R2+=0.00000000458*cost(4.91616403047+3067.93946934820*x);
R2+=0.00000000400*cost(3.13887720912+540.73666535850*x);
R2+=0.00000000378*cost(0.86122450940+525.02509864860*x);

double R3=0;
R3+=0.00003519257*cost(6.05800633846+529.69096509460*x);
R3+=0.00001073239*cost(1.67321345760+536.80451209540*x);
R3+=0.00000915666*cost(1.41329676116+522.57741809380*x);
R3+=0.00000341593*cost(0.52296542656+1059.38193018920*x);
R3+=0.00000254893*cost(1.19625473533+7.11354700080*x);
R3+=0.00000221512*cost(0.95225226237+515.46387109300*x);
R3+=0.00000069078*cost(2.26885282314+1066.49547719000*x);
R3-=0.00000089729;
R3+=0.00000057827*cost(1.41389745339+543.91805909620*x);
R3+=0.00000057653*cost(0.52580117593+639.89728631400*x);
R3+=0.00000051079*cost(5.98016364677+412.37109687440*x);
R3+=0.00000046935*cost(1.57864237959+625.67019231240*x);
R3+=0.00000042824*cost(6.11689609099+419.48464387520*x);
R3+=0.00000037477*cost(1.18262762330+14.22709400160*x);
R3+=0.00000033816*cost(1.66671706951+1052.26838318840*x);
R3+=0.00000031195*cost(1.04290245896+1589.07289528380*x);
R3+=0.00000030023*cost(4.63236245032+426.59819087600*x);
R3+=0.00000033531*cost(0.84784977903+206.18554843720*x);
R3+=0.00000020804*cost(2.50071243814+728.76296653100*x);
R3+=0.00000014466*cost(0.96040197071+508.35032409220*x);
R3+=0.00000012969*cost(1.50233788550+1045.15483618760*x);
R3+=0.00000011654*cost(3.55513510121+323.50541665740*x);
R3+=0.00000012319*cost(2.60952614503+735.87651353180*x);
R3+=0.00000015023*cost(0.89136998434+199.07200143640*x);
R3+=0.00000011160*cost(1.79041437555+309.27832265580*x);
R3+=0.00000010554*cost(6.27845112678+956.28915597060*x);
R3+=0.00000009812*cost(6.26016859519+103.09277421860*x);
R3+=0.00000009301*cost(3.45126812476+838.96928775040*x);
R3+=0.00000006672*cost(1.87004905364+302.16477565500*x);
R3+=0.00000007442*cost(1.28047007623+742.99006053260*x);
R3+=0.00000007178*cost(0.92022189637+942.06206196900*x);
R3+=0.00000005577*cost(1.37980792905+95.97922721780*x);
R3+=0.00000006834*cost(3.45228722967+831.85574074960*x);
R3+=0.00000004632*cost(2.82934545414+1596.18644228460*x);
R3+=0.00000003969*cost(1.21290005054+1169.58825140860*x);
R3+=0.00000003869*cost(5.99495313698+213.29909543800*x);
R3+=0.00000003551*cost(6.10714791535+405.25754987360*x);
R3+=0.00000002943*cost(2.32831075458+1155.36115740700*x);
R3+=0.00000002442*cost(1.86965213405+532.87235883230*x);
R3+=0.00000002410*cost(0.42627205128+220.41264243880*x);
R3+=0.00000002289*cost(1.94941487274+1073.60902419080*x);
R3+=0.00000002274*cost(0.09211517505+632.78373931320*x);
R3+=0.00000002189*cost(1.58907745204+2118.76386037840*x);
R3+=0.00000002387*cost(5.97080671477+1162.47470440780*x);
R3+=0.00000002104*cost(1.06751462671+21.34064100240*x);
R3+=0.00000002128*cost(1.51119399925+1258.45393162560*x);
R3+=0.00000002491*cost(0.35125020737+1272.68102562720*x);
R3+=0.00000002006*cost(5.94487388360+110.20632121940*x);
R3+=0.00000001980*cost(2.54989377864+88.86568021700*x);
R3+=0.00000002040*cost(2.16463966964+433.71173787680*x);
R3+=0.00000001955*cost(2.70341589777+721.64941953020*x);
R3+=0.00000001670*cost(4.46255717328+853.19638175200*x);
R3+=0.00000001910*cost(2.25964760758+1361.54670584420*x);
R3+=0.00000001710*cost(1.98372066321+525.75881183150*x);
R3+=0.00000001520*cost(0.11641358425+949.17560896980*x);
R3+=0.00000002003*cost(3.16520599208+1148.24761040620*x);
R3+=0.00000001710*cost(2.70850417287+330.61896365820*x);
R3+=0.00000001629*cost(0.47376028854+526.50957135690*x);
R3+=0.00000001229*cost(3.01987279595+963.40270297140*x);
R3+=0.00000001671*cost(0.44352103086+533.62311835770*x);
R3+=0.00000001207*cost(1.15774089269+1574.84580128220*x);
R3+=0.00000001146*cost(2.54505851138+846.08283475120*x);
R3+=0.00000001355*cost(1.17462112647+1038.04128918680*x);
R3+=0.00000001001*cost(2.70272799283+519.39602435610*x);
R3+=0.00000001372*cost(0.67467128629+551.03160609700*x);
R3+=0.00000000983*cost(4.17198081351+2627.11418447060*x);
R3+=0.00000001084*cost(1.07011164067+227.52618943960*x);
R3+=0.00000000892*cost(2.92543286761+1368.66025284500*x);
R3+=0.00000000823*cost(4.86559196955+611.44309831080*x);
R3+=0.00000001136*cost(1.78981738432+1581.95934828300*x);
R3+=0.00000000897*cost(4.91073630270+1670.82502850000*x);
R3+=0.00000000908*cost(3.68804047330+824.74219374880*x);
R3+=0.00000000789*cost(3.23380893250+2125.87740737920*x);
R3+=0.00000000771*cost(2.39070707004+2317.83586181480*x);
R3+=0.00000000891*cost(0.59692950778+539.98590583310*x);
R3+=0.00000000876*cost(4.52127091462+750.10360753340*x);
R3+=0.00000000802*cost(0.20759322884+1141.13406340540*x);
R3+=0.00000000850*cost(0.94145487094+191.95845443560*x);
R3+=0.00000000762*cost(2.25149516048+2538.24850425360*x);
R3+=0.00000000694*cost(0.67080348659+440.82528487760*x);
R3+=0.00000000741*cost(5.79934203525+1485.98012106520*x);
R3+=0.00000000643*cost(2.48127580335+1265.56747862640*x);
R3+=0.00000000575*cost(6.13756590872+1279.79457262800*x);
R3+=0.00000000636*cost(5.51001645505+2413.81508903260*x);
R3+=0.00000000636*cost(4.40777238491+1382.88734684660*x);
R3+=0.00000000555*cost(2.18233983981+1062.56332392690*x);
R3+=0.00000000564*cost(1.92775967119+2634.22773147140*x);
R3+=0.00000000531*cost(2.04824376019+295.05122865420*x);
R3+=0.00000000541*cost(2.32424368689+1471.75302706360*x);
R3+=0.00000000697*cost(2.27179476322+1699.27921650320*x);
R3+=0.00000000546*cost(1.95774905730+1677.93857550080*x);
R3+=0.00000000465*cost(4.35550844067+1692.16566950240*x);
R3+=0.00000000508*cost(2.50298248836+2207.62954059540*x);
R3+=0.00000000496*cost(5.77087043616+1478.86657406440*x);
R3+=0.00000000440*cost(5.98661963879+934.94851496820*x);
R3+=0.00000000424*cost(2.80194129521+81.75213321620*x);
R3+=0.00000000406*cost(3.93940190897+316.39186965660*x);
R3+=0.00000000506*cost(0.18719982992+10.29494073850*x);

double R4=0;
R4+=0.00000128628*cost(0.08419309557+536.80451209540*x);
R4+=0.00000113458*cost(4.24858855779+529.69096509460*x);
R4+=0.00000082650*cost(3.29754909408+522.57741809380*x);
R4+=0.00000037883*cost(2.73326611144+515.46387109300*x);
R4+=0.00000026694*cost(5.69142588558+7.11354700080*x);
R4+=0.00000017650*cost(5.40012536918+1059.38193018920*x);
R4+=0.00000012612*cost(6.01560416057+543.91805909620*x);
R4+=0.00000009287*cost(0.76813946494+1066.49547719000*x);
R4+=0.00000008107*cost(5.68228065707+14.22709400160*x);
R4+=0.00000006271*cost(5.12286932534+639.89728631400*x);
R4+=0.00000006978*cost(1.42751292055+412.37109687440*x);
R4+=0.00000005377*cost(3.33501947275+625.67019231240*x);
R4+=0.00000002911*cost(3.40334805052+1052.26838318840*x);
R4+=0.00000002593*cost(4.16090412984+728.76296653100*x);
R4+=0.00000002562*cost(2.89802035072+426.59819087600*x);
R4+=0.00000002268*cost(6.22195938856+1589.07289528380*x);
R4+=0.00000002114*cost(3.11758855774+1045.15483618760*x);
R4+=0.00000001673*cost(2.81399290364+206.18554843720*x);
R4+=0.00000001805*cost(2.60030006919+199.07200143640*x);
R4+=0.00000001823*cost(1.89432426038+419.48464387520*x);
R4+=0.00000001522*cost(1.33432648232+1596.18644228460*x);
R4+=0.00000001697;
R4+=0.00000001039*cost(4.41904942302+956.28915597060*x);
R4+=0.00000001161*cost(5.16181311538+831.85574074960*x);
R4+=0.00000000916*cost(3.17245716108+508.35032409220*x);
R4+=0.00000000870*cost(5.79387813500+1169.58825140860*x);
R4+=0.00000000916*cost(1.87129662931+1148.24761040620*x);
R4+=0.00000000955*cost(0.66801367802+1361.54670584420*x);
R4+=0.00000000788*cost(1.47515450553+1272.68102562720*x);
R4+=0.00000000966*cost(5.47457968043+220.41264243880*x);
R4+=0.00000000788*cost(2.42252866885+117.31986822020*x);
R4+=0.00000000712*cost(0.49655897030+1073.60902419080*x);
R4+=0.00000000656*cost(3.53022740783+302.16477565500*x);
R4+=0.00000000681*cost(2.84507174340+191.95845443560*x);
R4+=0.00000000771*cost(2.19893222018+942.06206196900*x);
R4+=0.00000000765*cost(5.31147257700+551.03160609700*x);
R4+=0.00000000667*cost(3.72432305249+88.86568021700*x);
R4+=0.00000000534*cost(1.83172084748+647.01083331480*x);
R4+=0.00000000553*cost(0.85896003802+330.61896365820*x);
R4+=0.00000000543*cost(5.26057584439+21.34064100240*x);
R4+=0.00000000584*cost(3.82243061802+618.55664531160*x);
R4+=0.00000000512*cost(4.44485521707+110.20632121940*x);
R4+=0.00000000612*cost(1.59320941864+3.18139373770*x);
R4+=0.00000000631*cost(1.83863158533+10.29494073850*x);
R4+=0.00000000491*cost(1.52912023181+405.25754987360*x);
R4+=0.00000000521*cost(0.24011424451+433.71173787680*x);

double R5=0;
R5+=0.00000011188*cost(4.75249399945+536.80451209540*x);
R5+=0.00000004255*cost(5.91516229170+522.57741809380*x);
R5+=0.00000002079*cost(5.56781555864+515.46387109300*x);
R5+=0.00000001908*cost(4.29659647286+543.91805909620*x);
R5+=0.00000001875*cost(3.69357495838+7.11354700080*x);
R5+=0.00000001590*cost(5.49312796166+1066.49547719000*x);
R5+=0.00000001612*cost(4.13222808529+1059.38193018920*x);
R5+=0.00000001240*cost(3.77981722506+14.22709400160*x);
R5+=0.00000001033*cost(4.50671820436+529.69096509460*x);

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;

return (R0+R1*x+R2*x2+R3*x3+R4*x4+R5*x5); //END Jupiter
}

//Heliocentric longitude of Saturn
double Lsaturn(double x)
{
double L0=0;
L0+=0.87401354029;
L0+=0.11107659780*cost(3.96205090194+213.29909543800*x);
L0+=0.01414150958*cost(4.58581515873+7.11354700080*x);
L0+=0.00398379386*cost(0.52112025957+206.18554843720*x);
L0+=0.00350769223*cost(3.30329903015+426.59819087600*x);
L0+=0.00206816296*cost(0.24658366938+103.09277421860*x);
L0+=0.00079271288*cost(3.84007078530+220.41264243880*x);
L0+=0.00023990338*cost(4.66976934860+110.20632121940*x);
L0+=0.00016573583*cost(0.43719123541+419.48464387520*x);
L0+=0.00014906995*cost(5.76903283845+316.39186965660*x);
L0+=0.00015820300*cost(0.93808953760+632.78373931320*x);
L0+=0.00014609562*cost(1.56518573691+3.93215326310*x);
L0+=0.00013160308*cost(4.44891180176+14.22709400160*x);
L0+=0.00015053509*cost(2.71670027883+639.89728631400*x);
L0+=0.00013005305*cost(5.98119067061+11.04570026390*x);
L0+=0.00010725066*cost(3.12939596466+202.25339517410*x);
L0+=0.00005863207*cost(0.23657028777+529.69096509460*x);
L0+=0.00005227771*cost(4.20783162380+3.18139373770*x);
L0+=0.00006126308*cost(1.76328499656+277.03499374140*x);
L0+=0.00005019658*cost(3.17787919533+433.71173787680*x);
L0+=0.00004592541*cost(0.61976424374+199.07200143640*x);
L0+=0.00004005862*cost(2.24479893937+63.73589830340*x);
L0+=0.00002953815*cost(0.98280385206+95.97922721780*x);
L0+=0.00003873696*cost(3.22282692566+138.51749687070*x);
L0+=0.00002461172*cost(2.03163631205+735.87651353180*x);
L0+=0.00003269490*cost(0.77491895787+949.17560896980*x);
L0+=0.00001758143*cost(3.26580514774+522.57741809380*x);
L0+=0.00001640183*cost(5.50504966218+846.08283475120*x);
L0+=0.00001391336*cost(4.02331978116+323.50541665740*x);
L0+=0.00001580641*cost(4.37266314120+309.27832265580*x);
L0+=0.00001123515*cost(2.83726793572+415.55249061210*x);
L0+=0.00001017258*cost(3.71698151814+227.52618943960*x);
L0+=0.00000848643*cost(3.19149825839+209.36694217490*x);
L0+=0.00001087237*cost(4.18343232481+2.44768055480*x);
L0+=0.00000956752*cost(0.50740889886+1265.56747862640*x);
L0+=0.00000789205*cost(5.00745123149+0.96320784650*x);
L0+=0.00000686965*cost(1.74714407827+1052.26838318840*x);
L0+=0.00000654470*cost(1.59889331515+0.04818410980*x);
L0+=0.00000748811*cost(2.14398149298+853.19638175200*x);
L0+=0.00000633980*cost(2.29889903023+412.37109687440*x);
L0+=0.00000743584*cost(5.25276954625+224.34479570190*x);
L0+=0.00000852677*cost(3.42141350697+175.16605980020*x);
L0+=0.00000579857*cost(3.09259007048+74.78159856730*x);
L0+=0.00000624904*cost(0.97046831256+210.11770170030*x);
L0+=0.00000529861*cost(4.44938897119+117.31986822020*x);
L0+=0.00000542643*cost(1.51824320514+9.56122755560*x);
L0+=0.00000474279*cost(5.47527185987+742.99006053260*x);
L0+=0.00000448542*cost(1.28990416161+127.47179660680*x);
L0+=0.00000546358*cost(2.12678554211+350.33211960040*x);
L0+=0.00000478054*cost(2.96488054338+137.03302416240*x);
L0+=0.00000354944*cost(3.01286483030+838.96928775040*x);
L0+=0.00000451827*cost(1.04436664241+490.33408917940*x);
L0+=0.00000347413*cost(1.53928227764+340.77089204480*x);
L0+=0.00000343475*cost(0.24604039134+0.52126486180*x);
L0+=0.00000309001*cost(3.49486734909+216.48048917570*x);
L0+=0.00000322185*cost(0.96137456104+203.73786788240*x);
L0+=0.00000372308*cost(2.27819108625+217.23124870110*x);
L0+=0.00000321543*cost(2.57182354537+647.01083331480*x);
L0+=0.00000330196*cost(0.24715617844+1581.95934828300*x);
L0+=0.00000249116*cost(1.47010534421+1368.66025284500*x);
L0+=0.00000286688*cost(2.37043745859+351.81659230870*x);
L0+=0.00000220225*cost(4.20422424873+200.76892246580*x);
L0+=0.00000277775*cost(0.40020408926+211.81462272970*x);
L0+=0.00000204500*cost(6.01082206600+265.98929347750*x);
L0+=0.00000207663*cost(0.48349820488+1162.47470440780*x);
L0+=0.00000208655*cost(1.34516255304+625.67019231240*x);
L0+=0.00000182454*cost(5.49122292426+2.92076130680*x);
L0+=0.00000226609*cost(4.91003163138+12.53017297220*x);
L0+=0.00000207659*cost(1.28302218900+39.35687591520*x);
L0+=0.00000173914*cost(1.86305806814+0.75075952540*x);
L0+=0.00000184690*cost(3.50344404958+149.56319713460*x);
L0+=0.00000183511*cost(0.97254952728+4.19278569400*x);
L0+=0.00000146068*cost(6.23102544071+195.13984817330*x);
L0+=0.00000164541*cost(0.44005517520+5.41662597140*x);
L0+=0.00000147526*cost(1.53529320509+5.62907429250*x);
L0+=0.00000139666*cost(4.29450260069+21.34064100240*x);
L0+=0.00000131283*cost(4.06828961903+10.29494073850*x);
L0+=0.00000117283*cost(2.67920400584+1155.36115740700*x);
L0+=0.00000149299*cost(5.73594349789+52.69019803950*x);
L0+=0.00000122373*cost(1.97588777199+4.66586644600*x);
L0+=0.00000113747*cost(5.59427544714+1059.38193018920*x);
L0+=0.00000102702*cost(1.19748124058+1685.05212250160*x);
L0+=0.00000118156*cost(5.34072933900+554.06998748280*x);
L0+=0.00000109275*cost(3.43812715686+536.80451209540*x);
L0+=0.00000110399*cost(0.16604024090+1.48447270830*x);
L0+=0.00000124969*cost(6.27737805832+1898.35121793960*x);
L0+=0.00000089949*cost(5.80392934702+114.13847448250*x);
L0+=0.00000103956*cost(2.19210363069+88.86568021700*x);
L0+=0.00000112437*cost(1.10502663534+191.20769491020*x);
L0+=0.00000106570*cost(4.01156608514+956.28915597060*x);
L0+=0.00000091430*cost(1.87521577510+38.13303563780*x);
L0+=0.00000083791*cost(5.48810655641+0.11187458460*x);
L0+=0.00000083461*cost(2.28972767279+628.85158605010*x);
L0+=0.00000096987*cost(4.53666595763+302.16477565500*x);
L0+=0.00000100631*cost(4.96513666539+269.92144674060*x);
L0+=0.00000075491*cost(2.18045274099+728.76296653100*x);
L0+=0.00000096330*cost(2.83319189210+275.55052103310*x);
L0+=0.00000082363*cost(3.05469876064+440.82528487760*x);
L0+=0.00000073888*cost(5.08914205084+1375.77379984580*x);
L0+=0.00000071633*cost(5.10940743430+65.22037101170*x);
L0+=0.00000070409*cost(4.86846451411+0.21244832110*x);
L0+=0.00000069760*cost(3.71029022489+14.97785352700*x);
L0+=0.00000088772*cost(3.86334563977+278.51946644970*x);
L0+=0.00000068090*cost(0.73415460990+1478.86657406440*x);
L0+=0.00000066501*cost(0.02677580336+70.84944530420*x);
L0+=0.00000065682*cost(2.02165559602+142.44965013380*x);
L0+=0.00000075765*cost(1.61410487792+284.14854074220*x);
L0+=0.00000063153*cost(3.49493353034+479.28838891550*x);
L0+=0.00000062539*cost(2.58713611532+422.66603761290*x);
L0+=0.00000069313*cost(3.43979731402+515.46387109300*x);
L0+=0.00000079021*cost(4.45154941586+35.42472265210*x);
L0+=0.00000063664*cost(3.31749528708+62.25142559510*x);
L0+=0.00000052939*cost(5.51392725227+0.26063243090*x);
L0+=0.00000053011*cost(3.18480701697+8.07675484730*x);
L0+=0.00000054492*cost(2.45674090515+22.09140052780*x);
L0+=0.00000050514*cost(4.26749346978+99.16062095550*x);
L0+=0.00000055170*cost(0.96797446150+942.06206196900*x);
L0+=0.00000049288*cost(2.38641424063+1471.75302706360*x);
L0+=0.00000047199*cost(2.02515248245+312.19908396260*x);
L0+=0.00000061080*cost(1.50295092063+210.85141488320*x);
L0+=0.00000045126*cost(0.93109376473+2001.44399215820*x);
L0+=0.00000060556*cost(2.68715551585+388.46515523820*x);
L0+=0.00000043452*cost(2.52602011714+288.08069400530*x);
L0+=0.00000042544*cost(3.81793980322+330.61896365820*x);
L0+=0.00000039915*cost(5.71378652900+408.43894361130*x);
L0+=0.00000050145*cost(6.03164759907+2214.74308759620*x);
L0+=0.00000045860*cost(0.54229721801+212.33588759150*x);
L0+=0.00000054165*cost(0.78154835399+191.95845443560*x);
L0+=0.00000047016*cost(4.59934671151+437.64389113990*x);
L0+=0.00000042362*cost(1.90070070955+430.53034413910*x);
L0+=0.00000039722*cost(1.63259419913+1066.49547719000*x);
L0+=0.00000036345*cost(0.84756992711+213.34727954780*x);
L0+=0.00000035468*cost(4.18603772925+215.74677599280*x);
L0+=0.00000036344*cost(3.93295730315+213.25091132820*x);
L0+=0.00000038005*cost(0.31313803095+423.41679713830*x);
L0+=0.00000044746*cost(1.12488341174+6.15033915430*x);
L0+=0.00000037902*cost(1.19795851115+2.70831298570*x);
L0+=0.00000043402*cost(1.37363944007+563.63121503840*x);
L0+=0.00000043764*cost(3.93043802956+525.49817940060*x);
L0+=0.00000034825*cost(1.01566605408+203.00415469950*x);
L0+=0.00000031755*cost(1.69273634405+0.16005869440*x);
L0+=0.00000030880*cost(6.13525703832+417.03696332040*x);
L0+=0.00000036388*cost(6.00586032647+18.15924726470*x);
L0+=0.00000029032*cost(1.19660544505+404.50679034820*x);
L0+=0.00000032812*cost(0.53649479713+107.02492748170*x);
L0+=0.00000030433*cost(0.72335287989+222.86032299360*x);
L0+=0.00000032644*cost(0.81204701486+1795.25844372100*x);
L0+=0.00000037769*cost(3.69666903716+1272.68102562720*x);
L0+=0.00000027679*cost(1.45663979401+7.16173111060*x);
L0+=0.00000027187*cost(1.89731951902+1045.15483618760*x);
L0+=0.00000037699*cost(4.51997049537+24.37902238820*x);
L0+=0.00000034885*cost(4.46095761791+214.26230328450*x);
L0+=0.00000032650*cost(0.66372395761+692.58748435350*x);
L0+=0.00000030324*cost(5.30369950147+33.94024994380*x);
L0+=0.00000027480*cost(6.22702216249+1.27202438720*x);
L0+=0.00000026657*cost(4.56713198392+7.06536289100*x);
L0+=0.00000031745*cost(5.49798599565+56.62235130260*x);
L0+=0.00000028050*cost(5.64447420566+128.95626931510*x);
L0+=0.00000024277*cost(3.93966553574+414.06801790380*x);
L0+=0.00000032017*cost(5.22260660455+92.04707395470*x);
L0+=0.00000026976*cost(0.06705123981+205.22234059070*x);
L0+=0.00000022974*cost(3.65817751770+207.67002114550*x);
L0+=0.00000031775*cost(5.59198119173+6069.77675455340*x);
L0+=0.00000023153*cost(2.10054506119+1788.14489672020*x);
L0+=0.00000031025*cost(0.37190053329+703.63318461740*x);
L0+=0.00000029376*cost(0.14742155778+131.40394986990*x);
L0+=0.00000022562*cost(5.24009182383+212.77783057620*x);
L0+=0.00000026185*cost(5.41311252822+140.00196957900*x);
L0+=0.00000025673*cost(4.36038885283+32.24332891440*x);
L0+=0.00000020392*cost(2.82413909260+429.77958461370*x);
L0+=0.00000020659*cost(0.67091805084+2317.83586181480*x);
L0+=0.00000024397*cost(3.08740396398+145.63104387150*x);
L0+=0.00000023735*cost(2.54365387567+76.26607127560*x);
L0+=0.00000020157*cost(5.06708675157+617.80588578620*x);
L0+=0.00000023307*cost(3.97357729211+483.22054217860*x);
L0+=0.00000022878*cost(6.10452832642+177.87437278590*x);
L0+=0.00000022978*cost(3.20140795404+208.63322899200*x);
L0+=0.00000020638*cost(5.22128727027+6.59228213900*x);
L0+=0.00000021446*cost(0.72034565528+1258.45393162560*x);
L0+=0.00000018034*cost(6.11382719947+210.37833413120*x);
L0+=0.00000022380*cost(5.92299908546+173.94221952280*x);
L0+=0.00000019128*cost(5.77772013766+213.82036029980*x);
L0+=0.00000020871*cost(5.79126331864+2531.13495725280*x);
L0+=0.00000019327*cost(1.64147367403+565.11568774670*x);
L0+=0.00000016806*cost(3.27953583323+98.89998852460*x);
L0+=0.00000020833*cost(2.01655935909+860.30992875280*x);
L0+=0.00000017939*cost(3.14329498012+831.85574074960*x);
L0+=0.00000015653*cost(3.10137669623+106.27416795630*x);
L0+=0.00000018235*cost(5.22595172482+73.29712585900*x);
L0+=0.00000019302*cost(5.93947114050+425.11371816770*x);
L0+=0.00000014514*cost(2.75049388379+1.22384027740*x);
L0+=0.00000014562*cost(5.18795088579+305.34616939270*x);
L0+=0.00000014254*cost(3.88079504939+54.17467074780*x);
L0+=0.00000014594*cost(3.25016810034+78.71375183040*x);
L0+=0.00000013637*cost(2.55486219141+405.25754987360*x);
L0+=0.00000013914*cost(1.72356993808+69.15252427480*x);
L0+=0.00000013689*cost(2.37430586272+125.98732389850*x);
L0+=0.00000013496*cost(0.82683590985+99.91138048090*x);
L0+=0.00000018483*cost(0.73171264866+9999.98645077300*x);
L0+=0.00000013542*cost(3.58584380924+234.63973644040*x);
L0+=0.00000013741*cost(6.18458356845+245.54242435240*x);
L0+=0.00000016944*cost(0.72200792996+2111.65031337760*x);
L0+=0.00000017441*cost(0.23803796878+134.58534360760*x);
L0+=0.00000014181*cost(4.51963935804+59.80374504030*x);
L0+=0.00000013598*cost(2.53776983965+1.69692102940*x);
L0+=0.00000012240*cost(2.11973445754+28.31117565130*x);
L0+=0.00000011988*cost(1.62114832786+1361.54670584420*x);
L0+=0.00000011974*cost(4.07378735120+280.96714700450*x);
L0+=0.00000012758*cost(5.31146919749+344.70304530790*x);
L0+=0.00000016051*cost(3.97093160336+355.74874557180*x);
L0+=0.00000011427*cost(5.51123470805+192.69216761850*x);
L0+=0.00000013133*cost(4.69168003518+767.36908292080*x);
L0+=0.00000014746*cost(3.28998910617+1589.07289528380*x);
L0+=0.00000011417*cost(1.81615681635+2104.53676637680*x);
L0+=0.00000011626*cost(2.79410384978+362.86229257260*x);
L0+=0.00000013234*cost(4.16642914717+225.82926841020*x);
L0+=0.00000010599*cost(5.50554288376+199.28444975750*x);
L0+=0.00000010558*cost(3.57501718639+1.43628859850*x);
L0+=0.00000010485*cost(2.84462532686+85.82729883120*x);
L0+=0.00000010296*cost(0.22225264071+198.32124191100*x);
L0+=0.00000010552*cost(0.18716643576+217.49188113200*x);
L0+=0.00000011853*cost(0.11584857323+7.63481186260*x);
L0+=0.00000010248*cost(0.21904154170+144.14657116320*x);
L0+=0.00000010403*cost(1.68776321208+31.01948863700*x);
L0+=0.00000010313*cost(4.72132701805+216.21985674480*x);
L0+=0.00000010719*cost(2.60869377832+339.28641933650*x);
L0+=0.00000009636*cost(3.66746262954+212.54833591260*x);
L0+=0.00000009631*cost(3.34275630477+223.59403617650*x);
L0+=0.00000009684*cost(0.41556436593+2634.22773147140*x);
L0+=0.00000009885*cost(4.01798130416+207.14875628370*x);
L0+=0.00000013212*cost(6.00683506785+214.78356814630*x);
L0+=0.00000011346*cost(2.61898383052+7.86430652620*x);
L0+=0.00000009158*cost(5.39855118256+342.25536475310*x);
L0+=0.00000011882*cost(4.00188476744+267.47376618580*x);
L0+=0.00000012054*cost(3.59904816676+124.43341522100*x);
L0+=0.00000008921*cost(4.22716773496+6.36278747540*x);
L0+=0.00000010142*cost(3.60807025662+14.01464568050*x);
L0+=0.00000009350*cost(0.72255756005+347.88443904560*x);
L0+=0.00000010529*cost(2.36779614951+831.10498122420*x);
L0+=0.00000008587*cost(4.48439552745+1692.16566950240*x);
L0+=0.00000010142*cost(3.93620624488+207.88246946660*x);
L0+=0.00000009147*cost(4.28032835242+312.45971639350*x);
L0+=0.00000008088*cost(0.81225752596+264.50482076920*x);
L0+=0.00000009241*cost(4.26402650779+20.60692781950*x);
L0+=0.00000009614*cost(0.64291347187+218.92816973050*x);
L0+=0.00000008537*cost(0.48756672382+1574.84580128220*x);
L0+=0.00000007986*cost(4.71088791079+333.65734504400*x);
L0+=0.00000008951*cost(0.90641577433+497.44763618020*x);
L0+=0.00000007959*cost(2.73277594136+4.14460158420*x);
L0+=0.00000009133*cost(5.08250578843+241.61027108930*x);
L0+=0.00000009669*cost(1.60623316904+0.89377187730*x);
L0+=0.00000008883*cost(5.55491009279+2847.52682690940*x);
L0+=0.00000008926*cost(5.80857835271+329.72519178090*x);
L0+=0.00000007226*cost(0.60164771281+206.23373254700*x);
L0+=0.00000007655*cost(5.53676341721+116.42609634290*x);
L0+=0.00000007118*cost(0.18747501525+209.10630974400*x);
L0+=0.00000007507*cost(5.43555636173+621.73803904930*x);
L0+=0.00000008885*cost(5.36210591059+343.21857259960*x);
L0+=0.00000007056*cost(0.41911130648+756.32338265690*x);
L0+=0.00000008124*cost(4.05571025939+237.67811782620*x);
L0+=0.00000008964*cost(1.65023927130+210.33015002140*x);
L0+=0.00000006961*cost(3.17855200943+543.02428721890*x);
L0+=0.00000008916*cost(0.56503620503+2428.04218303420*x);
L0+=0.00000006926*cost(3.66869171435+247.23934538180*x);
L0+=0.00000008982*cost(4.25046722481+46.47042291600*x);
L0+=0.00000007089*cost(5.14399672225+231.45834270270*x);
L0+=0.00000007381*cost(1.25092810119+217.96496188400*x);
L0+=0.00000007134*cost(2.83090354854+1148.24761040620*x);
L0+=0.00000006353*cost(0.82582711056+31.49256938900*x);
L0+=0.00000007558*cost(5.62617378543+518.64526483070*x);
L0+=0.00000006383*cost(3.54809945181+244.31858407500*x);
L0+=0.00000006914*cost(3.70012837706+206.13736432740*x);
L0+=0.00000006286*cost(5.79144749096+179.35884549420*x);
L0+=0.00000006639*cost(4.55197585824+120.35824960600*x);
L0+=0.00000005823*cost(1.40737990571+214.04985496340*x);
L0+=0.00000005850*cost(4.86725483749+320.32402291970*x);
L0+=0.00000006213*cost(1.07959478499+251.43213107580*x);
L0+=0.00000007730*cost(3.82244175824+380.12776796000*x);
L0+=0.00000005716*cost(1.34909972549+1677.93857550080*x);
L0+=0.00000006469*cost(1.34776801494+188.92007304980*x);
L0+=0.00000005668*cost(2.28643368177+20.44686912510*x);
L0+=0.00000006092*cost(3.62275289839+1169.58825140860*x);
L0+=0.00000005711*cost(0.51687421521+148.07872442630*x);
L0+=0.00000005804*cost(1.54831552984+2420.92863603340*x);
L0+=0.00000005703*cost(5.05993483230+2.96894541660*x);
L0+=0.00000005913*cost(1.66225477547+842.15068148810*x);
L0+=0.00000007449*cost(1.36195943673+166.82867252200*x);
L0+=0.00000006482*cost(1.94032041024+357.44566660120*x);
L0+=0.00000006368*cost(2.44556930837+654.12438031560*x);
L0+=0.00000006327*cost(0.40654591365+168.05251279940*x);
L0+=0.00000005573*cost(2.69383455663+750.10360753340*x);
L0+=0.00000007216*cost(2.22547711392+488.84961647110*x);
L0+=0.00000006701*cost(6.03737590382+160.60889739850*x);
L0+=0.00000006938*cost(5.78362034410+700.66423920080*x);
L0+=0.00000006701*cost(3.14738404371+491.81856188770*x);
L0+=0.00000005684*cost(2.59531540359+1.64453140270*x);
L0+=0.00000004900*cost(2.03902856851+0.80314915210*x);
L0+=0.00000005147*cost(4.10182033298+196.62432088160*x);
L0+=0.00000004985*cost(2.96765983996+258.87574647670*x);
L0+=0.00000005911*cost(1.81507526918+252.65597135320*x);
L0+=0.00000006056*cost(3.33431010543+182.27960680100*x);
L0+=0.00000006195*cost(5.01900871714+273.10284047830*x);
L0+=0.00000006316*cost(5.49053160191+206.70681329900*x);
L0+=0.00000005529*cost(3.31498938717+1905.46476494040*x);
L0+=0.00000005102*cost(3.98171453610+254.94359321360*x);
L0+=0.00000004762*cost(2.24463685255+635.96513305090*x);
L0+=0.00000005213*cost(0.53609344278+135.54855145410*x);
L0+=0.00000004639*cost(0.04466373027+213.18722085340*x);
L0+=0.00000005951*cost(0.54565487490+51.20572533120*x);
L0+=0.00000004535*cost(0.16088614438+2950.61960112800*x);
L0+=0.00000004639*cost(4.73769153591+213.41097002260*x);
L0+=0.00000004716*cost(3.13636467789+28.57180808220*x);
L0+=0.00000004748*cost(1.12156952989+6.21977512350*x);
L0+=0.00000005735*cost(0.04425142145+348.84764689210*x);
L0+=0.00000004334*cost(2.68814219154+81.75213321620*x);
L0+=0.00000004538*cost(3.83676888638+487.36514376280*x);
L0+=0.00000005582*cost(3.63486861028+248.72381809010*x);
L0+=0.00000004106*cost(3.39164360376+50.40257617910*x);
L0+=0.00000005657*cost(3.59967787362+282.45161971280*x);
L0+=0.00000005145*cost(1.33329458239+173.68158709190*x);
L0+=0.00000003898*cost(4.11804949361+213.51154375910*x);
L0+=0.00000003898*cost(0.66430577257+213.08664711690*x);
L0+=0.00000004418*cost(0.10784811796+905.88657979150*x);
L0+=0.00000004935*cost(2.19060382431+189.72322220190*x);
L0+=0.00000003799*cost(2.60752583205+546.95644048200*x);
L0+=0.00000003960*cost(1.60339889010+218.71572140940*x);
L0+=0.00000003740*cost(3.30724497407+274.06604832480*x);
L0+=0.00000003778*cost(0.26606330942+636.71589257630*x);
L0+=0.00000004657*cost(0.37532078548+2744.43405269080*x);
L0+=0.00000003682*cost(5.11587898667+458.84151979040*x);
L0+=0.00000004230*cost(5.18313062329+27.08733537390*x);
L0+=0.00000005181*cost(3.75590784411+3127.31333126180*x);
L0+=0.00000003904*cost(2.21738744557+358.93013930950*x);
L0+=0.00000004784*cost(4.60666675927+72.07328558160*x);
L0+=0.00000003552*cost(3.23789349146+543.91805909620*x);
L0+=0.00000003502*cost(3.68869576093+41.64449777560*x);
L0+=0.00000004803*cost(4.73553427126+240.38643081190*x);
L0+=0.00000003768*cost(3.86077796242+2008.55753915900*x);
L0+=0.00000003680*cost(5.36657425183+10.03430830760*x);
L0+=0.00000004298*cost(3.15595944154+738.79727483860*x);
L0+=0.00000003388*cost(0.73176365772+11.30633269480*x);
L0+=0.00000003507*cost(2.62508475661+13.33332212430*x);
L0+=0.00000003552*cost(0.28967392251+1891.23767093880*x);
L0+=0.00000003604*cost(4.69324090480+295.05122865420*x);
L0+=0.00000003621*cost(6.25264336426+129.91947716160*x);
L0+=0.00000003334*cost(5.04221806054+153.49535039770*x);
L0+=0.00000003837*cost(5.31732096284+3163.91869656600*x);
L0+=0.00000003281*cost(5.59031570352+2.00573757010*x);
L0+=0.00000004042*cost(2.37081308090+176.65053250850*x);
L0+=0.00000003500*cost(2.54744268360+1464.63948006280*x);
L0+=0.00000004144*cost(5.46982520458+6.90109867970*x);
L0+=0.00000003691*cost(4.07518441665+969.62247809490*x);
L0+=0.00000003947*cost(4.27108449197+181.80652604900*x);
L0+=0.00000003867*cost(5.48643386310+37.87240320690*x);
L0+=0.00000003339*cost(6.05372370584+9.40116886120*x);
L0+=0.00000003484*cost(5.81097824751+13.49338081870*x);
L0+=0.00000003033*cost(2.38897886651+221.37585028530*x);
L0+=0.00000002990*cost(4.13995939326+66.70484372000*x);
L0+=0.00000003746*cost(5.29902286106+561.18353448360*x);
L0+=0.00000003233*cost(4.27743802321+593.42686339800*x);
L0+=0.00000003170*cost(1.75400477770+235.39049596580*x);
L0+=0.00000004114*cost(2.01006788412+601.76425067620*x);
L0+=0.00000002937*cost(4.76351448561+213.55972786890*x);
L0+=0.00000002932*cost(1.83671373509+501.37978944330*x);
L0+=0.00000002937*cost(0.01884528825+213.03846300710*x);
L0+=0.00000003268*cost(4.44653949711+60.76695288680*x);
L0+=0.00000003608*cost(0.14307251176+552.58551477450*x);
L0+=0.00000002947*cost(0.74753671556+17.52610781830*x);
L0+=0.00000003979*cost(0.76931722276+424.15051032120*x);
L0+=0.00000002803*cost(1.07518176128+1994.33044515740*x);
L0+=0.00000002905*cost(1.27201007426+2737.32050569000*x);
L0+=0.00000003610*cost(0.22394084000+121.25202148330*x);
L0+=0.00000002846*cost(5.11748545179+205.66428357540*x);
L0+=0.00000003156*cost(2.74955723696+494.26624244250*x);
L0+=0.00000003576*cost(4.49826302447+167.08930495290*x);
L0+=0.00000002746*cost(0.66908290712+7.00167241620*x);
L0+=0.00000002780*cost(2.10066625279+894.84087952760*x);
L0+=0.00000002875*cost(2.39009721774+151.04766984290*x);
L0+=0.00000003020*cost(0.25475826890+40.84134862350*x);
L0+=0.00000002731*cost(3.74814908509+429.04587143080*x);
L0+=0.00000002793*cost(4.17938837230+292.01284726840*x);
L0+=0.00000002706*cost(5.34438894925+327.43756992050*x);
L0+=0.00000002965*cost(0.61653881148+643.82943957710*x);
L0+=0.00000002616*cost(4.81901387560+681.54178408960*x);
L0+=0.00000002548*cost(3.78162580820+1485.98012106520*x);
L0+=0.00000003483*cost(5.76091147029+141.22580985640*x);
L0+=0.00000003257*cost(0.75722680616+555.55446019110*x);
L0+=0.00000002887*cost(6.15899159727+425.63498302950*x);
L0+=0.00000002450*cost(1.29619859767+193.65537546500*x);
L0+=0.00000003401*cost(2.48137843009+43.28902917830*x);
L0+=0.00000003208*cost(0.66002842340+776.93031047640*x);
L0+=0.00000002435*cost(4.58097103726+477.80391620720*x);
L0+=0.00000002577*cost(1.41538858001+100.64509366380*x);
L0+=0.00000002600*cost(3.73139519973+17.40848773930*x);
L0+=0.00000002428*cost(1.04400815278+1279.79457262800*x);
L0+=0.00000002569*cost(5.36004101928+7.22542158540*x);
L0+=0.00000002844*cost(2.47228767650+280.00393915800*x);
L0+=0.00000002847*cost(1.52706408796+17.26547538740*x);
L0+=0.00000002461*cost(2.73899140465+172.24529849340*x);
L0+=0.00000003228*cost(4.10258705369+618.55664531160*x);
L0+=0.00000002288*cost(0.18365494079+426.64637498580*x);
L0+=0.00000002952*cost(3.97748947007+650.94298657790*x);
L0+=0.00000002653*cost(0.14255829255+162.89651925890*x);
L0+=0.00000002291*cost(3.26940117011+426.55000676620*x);
L0+=0.00000003118*cost(2.80941831445+2221.85663459700*x);
L0+=0.00000002343*cost(4.24349768377+113.38771495710*x);
L0+=0.00000002780*cost(4.36271946528+130.44074202340*x);
L0+=0.00000002539*cost(5.58396427573+381.35160823740*x);
L0+=0.00000002673*cost(2.74210116623+45.57665103870*x);
L0+=0.00000003017*cost(3.72208070740+228.27694896500*x);
L0+=0.00000002781*cost(0.36312756349+8.59801970910*x);
L0+=0.00000002377*cost(4.49193242045+25.12978191360*x);
L0+=0.00000002140*cost(5.43424670725+630.33605875840*x);
L0+=0.00000002456*cost(1.71617205116+313.68355667090*x);
L0+=0.00000002071*cost(2.40453395841+16.46232623530*x);
L0+=0.00000002050*cost(6.19704773331+3267.01147078460*x);
L0+=0.00000002764*cost(0.40107063007+219.44943459230*x);
L0+=0.00000002307*cost(2.61462153778+26.82670294300*x);
L0+=0.00000002650*cost(0.05892373791+5856.47765911540*x);
L0+=0.00000001974*cost(2.15890150781+746.92221379570*x);
L0+=0.00000001949*cost(3.13157993205+226.63241756230*x);
L0+=0.00000002063*cost(0.75916097286+472.17484191470*x);
L0+=0.00000002172*cost(1.41622302638+23.57587323610*x);
L0+=0.00000002378*cost(3.45446288811+241.87090352020*x);
L0+=0.00000002314*cost(2.92766120608+170.76082578510*x);
L0+=0.00000002409*cost(1.55291842382+112.65400177420*x);
L0+=0.00000002092*cost(4.33481587531+210.59078245230*x);
L0+=0.00000001883*cost(4.75777119721+115.62294719080*x);
L0+=0.00000001963*cost(5.63940648232+454.90936652730*x);
L0+=0.00000001871*cost(2.14579836453+135.33610313300*x);
L0+=0.00000002304*cost(0.11816226543+3060.82592234740*x);
L0+=0.00000002221*cost(4.34506511014+556.51766803760*x);
L0+=0.00000001867*cost(5.70943358261+19.12245511120*x);
L0+=0.00000002269*cost(3.36100653157+696.51963761660*x);
L0+=0.00000002127*cost(0.44754929310+216.00740842370*x);
L0+=0.00000001807*cost(6.15427316170+5.84152261360*x);
L0+=0.00000002213*cost(3.42223891884+533.62311835770*x);
L0+=0.00000001866*cost(3.90535444843+220.36445832900*x);
L0+=0.00000001767*cost(0.94232357739+213.45915413240*x);
L0+=0.00000001767*cost(3.84003619647+213.13903674360*x);
L0+=0.00000001910*cost(3.72504487558+104.05598206510*x);
L0+=0.00000001750*cost(0.82378244287+220.46082654860*x);
L0+=0.00000001838*cost(0.06310147657+436.15941843160*x);
L0+=0.00000002146*cost(4.41415180481+184.09414790940*x);
L0+=0.00000001730*cost(2.21039276178+416.30325013750*x);
L0+=0.00000001715*cost(0.26601715797+103.14095832840*x);
L0+=0.00000001710*cost(0.63515407580+181.05576652360*x);
L0+=0.00000002307*cost(3.29544714308+569.04784100980*x);
L0+=0.00000001906*cost(5.30639447218+405.99126305650*x);
L0+=0.00000001863*cost(4.68613642432+286.59622129700*x);
L0+=0.00000001873*cost(2.26516020863+1781.03134971940*x);
L0+=0.00000002035*cost(3.85188859267+672.14061522840*x);
L0+=0.00000002236*cost(3.01959133214+105.54045477340*x);
L0+=0.00000001767*cost(1.45800271562+16.67477455640*x);
L0+=0.00000001633*cost(0.16030477876+18.91000679010*x);
L0+=0.00000002116*cost(2.90186702031+486.40193591630*x);
L0+=0.00000002202*cost(3.88125957017+427.56139872250*x);
L0+=0.00000001706*cost(3.35213628354+103.04459010880*x);
L0+=0.00000001604*cost(2.48973273967+55.65914345610*x);
L0+=0.00000001744*cost(1.83791106739+1044.40407666220*x);
L0+=0.00000001569*cost(6.10089581118+106.01353552540*x);
L0+=0.00000002081*cost(6.03810192844+916.93228005540*x);
L0+=0.00000001799*cost(5.01592570405+731.94436026870*x);
L0+=0.00000001737*cost(1.49651330833+25.86349509650*x);
L0+=0.00000001695*cost(3.53314158403+627.36711334180*x);
L0+=0.00000001543*cost(0.81384993001+2310.72231481400*x);
L0+=0.00000001896*cost(3.38169845451+2324.94940881560*x);
L0+=0.00000001926*cost(4.66519027283+353.30106501700*x);
L0+=0.00000001765*cost(5.14740716994+107.28555991260*x);
L0+=0.00000001556*cost(1.12431826916+230.82520325630*x);
L0+=0.00000001843*cost(0.02435960281+102.12956637210*x);
L0+=0.00000001501*cost(4.18415120927+194.17664032680*x);
L0+=0.00000001528*cost(1.00328674046+3053.71237534660*x);
L0+=0.00000001529*cost(5.58893570479+212.02707105080*x);
L0+=0.00000001684*cost(5.08547245125+3480.31056622260*x);
L0+=0.00000001461*cost(2.31020597821+721.64941953020*x);
L0+=0.00000001480*cost(5.34331643017+418.52143602870*x);
L0+=0.00000001601*cost(5.53623000915+391.17346822390*x);
L0+=0.00000001893*cost(3.62340803433+204.70107572890*x);
L0+=0.00000001529*cost(6.06535432009+77.96299230500*x);
L0+=0.00000001529*cost(5.47660937625+214.57111982520*x);
L0+=0.00000001552*cost(2.06693539836+36.64856292950*x);
L0+=0.00000001453*cost(6.04709831442+165.60483224460*x);
L0+=0.00000001393*cost(2.28253369060+403.02231763990*x);
L0+=0.00000001444*cost(2.90650214018+447.93883187840*x);
L0+=0.00000001924*cost(1.37028714759+468.24268865160*x);
L0+=0.00000001426*cost(0.13255011458+2207.62954059540*x);
L0+=0.00000001389*cost(2.21739183113+643.07868005170*x);
L0+=0.00000001365*cost(1.63853880518+629.60234557550*x);
L0+=0.00000001362*cost(3.35131049142+93.53154666300*x);
L0+=0.00000001376*cost(5.36989538450+180.16199464630*x);
L0+=0.00000001584*cost(0.85642767335+271.40591944890*x);
L0+=0.00000001405*cost(5.69231057947+25.27279426550*x);
L0+=0.00000001681*cost(5.30308110734+835.03713448730*x);
L0+=0.00000001598*cost(3.04233449432+42.53826965290*x);
L0+=0.00000001759*cost(3.59043066940+508.35032409220*x);
L0+=0.00000001394*cost(4.55070863290+426.07692601420*x);
L0+=0.00000001314*cost(1.81147178081+1382.88734684660*x);
L0+=0.00000001281*cost(4.26508388040+123.53964334370*x);
L0+=0.00000001742*cost(5.71133189432+22.89454967990*x);
L0+=0.00000001483*cost(1.84687831602+289.56516671360*x);
L0+=0.00000001257*cost(3.01131200921+409.92341631960*x);
L0+=0.00000001285*cost(4.41168551011+558.00214074590*x);
L0+=0.00000001355*cost(3.87115897452+1802.37199072180*x);
L0+=0.00000001333*cost(0.08474224795+411.62033734900*x);
L0+=0.00000001235*cost(4.08060394635+28.45418800320*x);
L0+=0.00000001373*cost(5.06955106471+427.11945573780*x);
L0+=0.00000001565*cost(2.32953532704+41.05379694460*x);
L0+=0.00000001656*cost(6.06169130804+268.43697403230*x);
L0+=0.00000001212*cost(3.05966957556+420.96911658350*x);
L0+=0.00000001238*cost(5.25936700679+412.58354519550*x);
L0+=0.00000001220*cost(3.92987038126+2.66012887590*x);
L0+=0.00000001552*cost(1.48184004773+9786.68735533500*x);
L0+=0.00000001240*cost(1.46716327302+291.26208774300*x);
L0+=0.00000001133*cost(5.39046583617+423.67742956920*x);
L0+=0.00000001319*cost(5.79905891015+1108.13997496560*x);
L0+=0.00000001329*cost(0.92291650117+778.41478318470*x);
L0+=0.00000001399*cost(2.55906860098+421.93232443000*x);
L0+=0.00000001120*cost(3.86777259232+1033.35837639830*x);
L0+=0.00000001164*cost(4.10048660918+685.47393735270*x);
L0+=0.00000001321*cost(1.45843550806+1073.60902419080*x);
L0+=0.00000001313*cost(0.11761534168+71.81265315070*x);
L0+=0.00000001438*cost(2.57741975416+100.38446123290*x);
L0+=0.00000001190*cost(5.63379509659+5.10780943070*x);
L0+=0.00000001289*cost(5.20604565993+278.25883401880*x);
L0+=0.00000001157*cost(5.00101860101+230.56457082540*x);
L0+=0.00000001233*cost(2.70207317014+282.66406803390*x);
L0+=0.00000001209*cost(4.02230498135+980.66817835880*x);
L0+=0.00000001070*cost(5.17569455055+313.21047591890*x);
L0+=0.00000001292*cost(4.30946655209+219.89137757700*x);
L0+=0.00000001399*cost(2.58476795858+2538.24850425360*x);
L0+=0.00000001038*cost(0.14212199680+820.05928096030*x);
L0+=0.00000001245*cost(4.08278897130+525.75881183150*x);
L0+=0.00000001254*cost(2.46275017735+457.61767951300*x);
L0+=0.00000001021*cost(1.11239421009+69.36497259590*x);
L0+=0.00000001009*cost(1.01709171385+143.93412284210*x);
L0+=0.00000001075*cost(2.39196853318+48.75804477640*x);
L0+=0.00000001180*cost(6.18938910429+3377.21779200400*x);
L0+=0.00000000989*cost(5.94928603657+3583.40334044120*x);
L0+=0.00000000972*cost(4.25434114756+397.39324334740*x);
L0+=0.00000000983*cost(0.04442608551+140.96517742550*x);
L0+=0.00000000972*cost(5.67683107883+422.40540518200*x);
L0+=0.00000001298*cost(1.34524469231+875.83029900100*x);
L0+=0.00000001190*cost(0.67933974618+699.70103135430*x);
L0+=0.00000000950*cost(2.66964340700+92.30770638560*x);
L0+=0.00000000933*cost(0.63000656580+406.95447090300*x);
L0+=0.00000000959*cost(1.77556884452+67.66805156650*x);
L0+=0.00000001185*cost(3.70140604185+285.63301345050*x);
L0+=0.00000000956*cost(5.18928530992+319.31263096340*x);
L0+=0.00000001014*cost(1.97449310063+2097.42321937600*x);
L0+=0.00000001048*cost(3.69659410655+117.91056905120*x);
L0+=0.00000001153*cost(2.53320305623+104.57724692690*x);
L0+=0.00000001258*cost(2.51536062507+694.07195706180*x);
L0+=0.00000000971*cost(5.19147635849+240.12579838100*x);
L0+=0.00000000940*cost(3.94701776697+35.21227433100*x);
L0+=0.00000001047*cost(6.12360979460+238.90195810360*x);
L0+=0.00000001185*cost(5.28289734361+638.41281360570*x);
L0+=0.00000000893*cost(0.95364488395+14.81779483260*x);
L0+=0.00000001094*cost(3.93009679240+945.24345570670*x);
L0+=0.00000000949*cost(3.46451925897+443.86366626340*x);
L0+=0.00000001002*cost(3.18639902867+337.73251065900*x);
L0+=0.00000001017*cost(2.87111101661+211.60217440860*x);
L0+=0.00000000875*cost(0.58638080067+2.28762186040*x);
L0+=0.00000000925*cost(1.54981519784+19.64371997300*x);
L0+=0.00000001152*cost(1.68528608590+691.10301164520*x);
L0+=0.00000000832*cost(2.64637256467+436.89313161450*x);
L0+=0.00000000834*cost(3.88913521570+331.20966448920*x);
L0+=0.00000000825*cost(2.15437872210+739.80866679490*x);
L0+=0.00000000848*cost(3.18263239100+196.03362005060*x);
L0+=0.00000001044*cost(3.87842686803+532.61172640140*x);
L0+=0.00000000846*cost(5.38853773752+97.67614824720*x);
L0+=0.00000001021*cost(2.93075488512+184.98791978670*x);
L0+=0.00000000843*cost(6.12012061227+616.32141307790*x);
L0+=0.00000000820*cost(1.01380400969+480.77286162380*x);
L0+=0.00000000842*cost(3.56523575381+421.18156490460*x);
L0+=0.00000001076*cost(3.28234305253+5.67725840230*x);
L0+=0.00000000808*cost(2.78227865672+212.07525516060*x);
L0+=0.00000000812*cost(0.94281737163+108.72184851110*x);
L0+=0.00000000808*cost(2.21202653278+610.69233878540*x);
L0+=0.00000000808*cost(2.00008111713+214.52293571540*x);
L0+=0.00000000875*cost(2.14897461363+114.39910691340*x);
L0+=0.00000000791*cost(2.35474255596+1.37259812370*x);
L0+=0.00000000960*cost(0.25496742364+710.74673161820*x);
L0+=0.00000001001*cost(2.34471240227+16.04163511000*x);
L0+=0.00000000994*cost(0.63700664871+84.93352695390*x);
L0+=0.00000000985*cost(2.63664920104+395.57870223900*x);
L0+=0.00000000874*cost(2.59112594967+418.00017116690*x);
L0+=0.00000000758*cost(0.58117487362+2627.11418447060*x);
L0+=0.00000000894*cost(1.48976897396+760.25553592000*x);
L0+=0.00000000768*cost(5.25095392845+305.08553696180*x);
L0+=0.00000001020*cost(2.73153988233+268.95823889410*x);
L0+=0.00000000903*cost(0.13224671457+238.42887735160*x);
L0+=0.00000000750*cost(0.76128043194+724.83081326790*x);
L0+=0.00000000903*cost(3.37105323370+526.50957135690*x);
L0+=0.00000000930*cost(2.83622594110+2641.34127847220*x);
L0+=0.00000000808*cost(5.23759255053+216.26804085460*x);
L0+=0.00000000864*cost(1.22059443823+570.74476203920*x);
L0+=0.00000000798*cost(3.72388187653+124.50285119020*x);
L0+=0.00000000753*cost(0.72747041757+3370.10424500320*x);
L0+=0.00000000844*cost(2.03251767810+511.53171782990*x);
L0+=0.00000000827*cost(4.49936223096+444.75743814070*x);
L0+=0.00000000848*cost(3.74330244183+2118.76386037840*x);
L0+=0.00000000795*cost(0.27939057139+101.86893394120*x);
L0+=0.00000000754*cost(5.68583497533+662.53120356300*x);
L0+=0.00000000750*cost(4.78778128003+102.57150935680*x);
L0+=0.00000000709*cost(1.64518562815+159.12442469020*x);
L0+=0.00000000770*cost(4.02404991950+909.81873305460*x);
L0+=0.00000000765*cost(1.62693133597+465.95506679120*x);
L0+=0.00000000911*cost(5.04635658282+913.96333463880*x);
L0+=0.00000000861*cost(2.78971410809+495.75071515080*x);
L0+=0.00000000688*cost(1.10207467005+1.53686233500*x);
L0+=0.00000000803*cost(4.33043919090+453.42489381900*x);
L0+=0.00000000673*cost(0.03439333853+2524.02141025200*x);
L0+=0.00000000856*cost(3.50639182375+439.12836384820*x);
L0+=0.00000000684*cost(3.93906807606+337.80194662820*x);
L0+=0.00000000716*cost(6.18909854987+310.71461125430*x);
L0+=0.00000000922*cost(1.70634200320+125.18417474640*x);
L0+=0.00000000885*cost(1.69955870744+6283.07584999140*x);
L0+=0.00000000656*cost(1.28102954508+432.01481684740*x);
L0+=0.00000000808*cost(1.64410808383+299.12639426920*x);
L0+=0.00000000656*cost(1.49449164620+849.26422848890*x);
L0+=0.00000000679*cost(4.02962984490+429.51895218280*x);
L0+=0.00000000854*cost(3.04068731741+298.23262239190*x);
L0+=0.00000000676*cost(2.17631477883+576.16138801060*x);
L0+=0.00000000881*cost(5.47733557925+220.93390730060*x);
L0+=0.00000000739*cost(5.85330901725+938.12990870590*x);
L0+=0.00000000637*cost(2.96294462433+425.84743135060*x);
L0+=0.00000000665*cost(1.62998758015+221.16340196420*x);
L0+=0.00000000693*cost(3.53871697600+1182.92157353290*x);
L0+=0.00000000659*cost(1.85319023888+72.33391801250*x);
L0+=0.00000000631*cost(2.01234919422+58.10682401090*x);
L0+=0.00000000806*cost(5.21763933753+428.08266358430*x);
L0+=0.00000000804*cost(5.94281804567+26.02355379090*x);
L0+=0.00000000679*cost(2.11784460940+256.42806592190*x);
L0+=0.00000000692*cost(1.88791537515+214.99601646740*x);
L0+=0.00000000731*cost(1.95762888351+19.01058052660*x);
L0+=0.00000000786*cost(0.91252523635+518.38463239980*x);
L0+=0.00000000684*cost(4.89288171806+3796.70243587920*x);
L0+=0.00000000612*cost(2.08511492036+1038.04128918680*x);
L0+=0.00000000598*cost(3.48814927085+219.66188291340*x);
L0+=0.00000000828*cost(0.31689472200+25.60286266560*x);
L0+=0.00000000773*cost(4.57524006328+624.91943278700*x);
L0+=0.00000000775*cost(6.12920077021+432.22726516850*x);
L0+=0.00000000820*cost(4.11320326130+141.48644228730*x);
L0+=0.00000000588*cost(1.95775535412+211.86280683950*x);
L0+=0.00000000661*cost(5.30100397707+103.61403908040*x);
L0+=0.00000000588*cost(2.82460441973+214.73538403650*x);
L0+=0.00000000651*cost(5.56732715834+393.46109008430*x);
L0+=0.00000000564*cost(4.01666572198+850.01498801430*x);
L0+=0.00000000657*cost(2.58166087726+526.98265210890*x);
L0+=0.00000000722*cost(0.68494219480+953.10776223290*x);
L0+=0.00000000592*cost(2.37190662490+205.43478891180*x);
L0+=0.00000000738*cost(1.07981019512+239.16259053450*x);
L0+=0.00000000590*cost(6.03587790219+188.02630117250*x);
L0+=0.00000000559*cost(5.76010635813+430.79097657000*x);
L0+=0.00000000535*cost(5.80499883199+100.17201291180*x);
L0+=0.00000000611*cost(5.95439360100+3693.60966166060*x);
L0+=0.00000000591*cost(4.22379888536+505.31194270640*x);
L0+=0.00000000691*cost(2.96568305933+606.76018552230*x);
L0+=0.00000000648*cost(2.33387623043+30.75885620610*x);
L0+=0.00000000544*cost(2.21686115865+92.79783348010*x);
L0+=0.00000000517*cost(2.68282421083+262.05714021440*x);
L0+=0.00000000563*cost(1.69735688719+2413.81508903260*x);
L0+=0.00000000569*cost(2.85075508949+227.31374111850*x);
L0+=0.00000000531*cost(2.17713708433+263.02034806090*x);
L0+=0.00000000504*cost(4.44947885193+343.73983746140*x);
L0+=0.00000000578*cost(3.31462999801+33.72780162270*x);
L0+=0.00000000619*cost(1.83409636127+867.42347575360*x);
L0+=0.00000000546*cost(4.82201187196+1048.33622992530*x);
L0+=0.00000000517*cost(1.42016110098+1246.65747183630*x);
L0+=0.00000000681*cost(1.94124532036+25874.60404613620*x);
L0+=0.00000000551*cost(5.70617358907+1119.18567522950*x);
L0+=0.00000000523*cost(5.78878978812+366.79444583570*x);
L0+=0.00000000486*cost(1.90063955671+1063.31408345230*x);
L0+=0.00000000552*cost(3.64325031166+256.58812461630*x);
L0+=0.00000000612*cost(2.39349965241+2854.64037391020*x);
L0+=0.00000000495*cost(3.46833581240+597.35901666110*x);
L0+=0.00000000622*cost(1.86539391351+524.01370669230*x);
L0+=0.00000000480*cost(5.33557742428+29.20494752860*x);
L0+=0.00000000492*cost(4.64109549618+384.05992122310*x);
L0+=0.00000000520*cost(2.32171681836+2957.73314812880*x);
L0+=0.00000000545*cost(0.53274778710+431.26405732200*x);
L0+=0.00000000479*cost(2.13325177240+319.57326339430*x);
L0+=0.00000000526*cost(4.17771910249+136.06981631590*x);
L0+=0.00000000612*cost(4.56148986681+774.48262992160*x);
L0+=0.00000000642*cost(3.25195912708+67.88049988760*x);
L0+=0.00000000527*cost(4.00299045889+2435.15573003500*x);
L0+=0.00000000524*cost(4.69817741494+336.83873878170*x);
L0+=0.00000000495*cost(5.95703962647+765.88461021250*x);
L0+=0.00000000463*cost(6.09780322600+54.33472944220*x);
L0+=0.00000000538*cost(0.22116216124+450.97721326420*x);
L0+=0.00000000465*cost(1.87487942848+958.57677783100*x);
L0+=0.00000000500*cost(1.54084756342+572.22923474750*x);
L0+=0.00000000528*cost(3.54764543325+233.90602325750*x);
L0+=0.00000000451*cost(5.72664397006+3899.79521009780*x);
L0+=0.00000000514*cost(5.00509609437+273.85360000370*x);
L0+=0.00000000471*cost(2.96871670899+306.83064210100*x);
L0+=0.00000000447*cost(1.87279400375+62.03897727400*x);
L0+=0.00000000456*cost(5.45521998520+1171.87587326900*x);
L0+=0.00000000499*cost(1.92821778530+217.44369702220*x);
L0+=0.00000000548*cost(3.21873307934+824.74219374880*x);
L0+=0.00000000579*cost(2.29424247924+810.65811209910*x);
L0+=0.00000000550*cost(0.67875196590+315.16802937920*x);
L0+=0.00000000556*cost(1.30277646899+133.10087089930*x);
L0+=0.00000000449*cost(6.05954557724+141.69889060840*x);
L0+=0.00000000447*cost(5.83737433218+823.99143422340*x);
L0+=0.00000000517*cost(3.62832879827+934.94851496820*x);
L0+=0.00000000482*cost(1.04855231956+1055.44977692610*x);
L0+=0.00000000482*cost(4.07207792722+195.89060769870*x);
L0+=0.00000000428*cost(0.65142455407+427.34895040140*x);
L0+=0.00000000585*cost(5.48406138684+376.19561469690*x);
L0+=0.00000000469*cost(3.87344294455+320.58465535060*x);
L0+=0.00000000488*cost(2.83523964260+460.53844081980*x);
L0+=0.00000000450*cost(4.30419652064+88.11492069160*x);
L0+=0.00000000537*cost(0.85582040238+214.19286731530*x);
L0+=0.00000000438*cost(1.32216133929+963.40270297140*x);
L0+=0.00000000560*cost(2.50374228728+952.09637027660*x);
L0+=0.00000000442*cost(2.80002649649+209.15449385380*x);
L0+=0.00000000443*cost(4.31062007978+9992.87290377220*x);
L0+=0.00000000469*cost(0.45235276525+464.73122651380*x);
L0+=0.00000000488*cost(0.35817443686+36.90919536040*x);
L0+=0.00000000418*cost(4.81080887468+775.23338944700*x);
L0+=0.00000000417*cost(4.93943593579+306.09692891810*x);
L0+=0.00000000483*cost(3.92847922420+39.61750834610*x);
L0+=0.00000000467*cost(1.89153069484+30.05628079050*x);
L0+=0.00000000410*cost(5.52148731635+118.07062774560*x);
L0+=0.00000000406*cost(1.35991757653+945.99421523210*x);
L0+=0.00000000446*cost(4.06656112480+380.38840039090*x);
L0+=0.00000000466*cost(3.65954736664+988.53248488500*x);
L0+=0.00000000418*cost(1.40185532806+313.94418910180*x);
L0+=0.00000000481*cost(1.80873987903+43.12897048390*x);
L0+=0.00000000437*cost(0.86746182155+170.97327410620*x);
L0+=0.00000000483*cost(4.49894122772+46.20979048510*x);
L0+=0.00000000398*cost(2.90977731924+131.54696222180*x);
L0+=0.00000000529*cost(3.74604329884+699.17976649250*x);
L0+=0.00000000396*cost(0.34033987778+2943.50605412720*x);
L0+=0.00000000545*cost(2.97400965609+305.60680182360*x);
L0+=0.00000000412*cost(3.81935995126+84.34282612290*x);
L0+=0.00000000425*cost(2.60672101181+121.84272231430*x);
L0+=0.00000000474*cost(2.41769418569+838.21852822500*x);
L0+=0.00000000457*cost(1.27246488727+107.75864066460*x);
L0+=0.00000000519*cost(3.12247974037+10213.28554621100*x);
L0+=0.00000000495*cost(4.63705386984+301.41401612960*x);
L0+=0.00000000537*cost(3.92653937147+212.40532356070*x);
L0+=0.00000000385*cost(3.33476325050+806.72595883600*x);
L0+=0.00000000477*cost(1.66001855277+175.42669223110*x);
L0+=0.00000000378*cost(0.47722247042+200.55647414470*x);
L0+=0.00000000459*cost(5.14821844812+960.22130923370*x);
L0+=0.00000000401*cost(4.36420932544+739.05790726950*x);
L0+=0.00000000467*cost(2.96423984091+170.01006625970*x);
L0+=0.00000000457*cost(4.45829983338+33.13710079170*x);
L0+=0.00000000476*cost(3.63257697985+20.49505323490*x);
L0+=0.00000000462*cost(3.57494442856+71.60020482960*x);
L0+=0.00000000376*cost(2.94770389653+6062.66320755260*x);
L0+=0.00000000473*cost(5.32759318114+373.90799283650*x);
L0+=0.00000000383*cost(1.84111991862+346.39996633730*x);
L0+=0.00000000366*cost(2.05039240297+87.31177153950*x);
L0+=0.00000000383*cost(2.00608370504+3274.12501778540*x);
L0+=0.00000000374*cost(5.65444305031+540.73666535850*x);
L0+=0.00000000410*cost(5.62629715297+58.31927233200*x);
L0+=0.00000000441*cost(6.26992749567+378.90392768260*x);
L0+=0.00000000451*cost(3.05920369737+898.77303279070*x);
L0+=0.00000000371*cost(5.65787287655+89.75945209430*x);
L0+=0.00000000367*cost(5.71998148487+96.87299909510*x);
L0+=0.00000000410*cost(1.06290837961+1257.70317210020*x);
L0+=0.00000000418*cost(2.03053179312+146.59425171800*x);
L0+=0.00000000492*cost(0.89529424356+423.62924545940*x);
L0+=0.00000000474*cost(2.43080822444+705.11765732570*x);
L0+=0.00000000457*cost(3.42347802916+829.62050851590*x);
L0+=0.00000000419*cost(0.32183412086+90.56260124640*x);
L0+=0.00000000347*cost(3.60116807440+449.23210812500*x);
L0+=0.00000000397*cost(2.29159647723+782.34693644780*x);
L0+=0.00000000433*cost(3.40938468811+32.45577723550*x);
L0+=0.00000000343*cost(4.30952656038+401.32539661050*x);
L0+=0.00000000351*cost(0.42160026295+3686.49611465980*x);
L0+=0.00000000360*cost(5.83204569879+491.55792945680*x);
L0+=0.00000000389*cost(2.73429108352+36.17548217750*x);
L0+=0.00000000434*cost(0.33664392528+55.13787859430*x);
L0+=0.00000000346*cost(5.09191837323+392.65794093220*x);
L0+=0.00000000336*cost(2.38696934868+295.19424100610*x);
L0+=0.00000000336*cost(1.56832822829+233.74596456310*x);
L0+=0.00000000400*cost(3.08774286568+745.91082183940*x);
L0+=0.00000000468*cost(4.21298903633+832.58945393250*x);
L0+=0.00000000400*cost(1.32415028336+551.10104206620*x);
L0+=0.00000000344*cost(1.52193307438+754.83890994860*x);
L0+=0.00000000433*cost(3.06696455642+885.43971066640*x);
L0+=0.00000000346*cost(4.76971433870+4113.09430553580*x);
L0+=0.00000000329*cost(3.31034285904+952.35700270750*x);
L0+=0.00000000425*cost(2.90590905341+462.02291352810*x);
L0+=0.00000000342*cost(5.87738962422+561.93429400900*x);
L0+=0.00000000439*cost(0.20791179302+768.85355562910*x);
L0+=0.00000000330*cost(2.08599193524+614.62449204850*x);
L0+=0.00000000394*cost(3.59805431851+1261.63532536330*x);
L0+=0.00000000369*cost(6.03075127328+199.80571461930*x);
L0+=0.00000000375*cost(2.56075851331+732.69511979410*x);
L0+=0.00000000408*cost(0.69233617038+328.24071907260*x);
L0+=0.00000000331*cost(4.28333309370+541.53981451060*x);
L0+=0.00000000323*cost(0.06694179304+433.75992198660*x);
L0+=0.00000000431*cost(4.50603340920+2914.01423582380*x);
L0+=0.00000000343*cost(2.18898146246+80.19822453870*x);
L0+=0.00000000437*cost(5.34124436008+387.24131496080*x);
L0+=0.00000000371*cost(4.82569229712+103.35340664950*x);
L0+=0.00000000318*cost(3.75720880396+749.20983565610*x);
L0+=0.00000000344*cost(0.70749566894+229.97386999440*x);
L0+=0.00000000312*cost(6.02741985422+361.37781986430*x);
L0+=0.00000000340*cost(0.64358874512+303.86169668440*x);
L0+=0.00000000394*cost(0.49801994278+248.46318565920*x);
L0+=0.00000000309*cost(5.83535487659+236.19364511790*x);
L0+=0.00000000325*cost(2.65292455786+757.21715453420*x);
L0+=0.00000000365*cost(0.56788400592+402.21916848780*x);
L0+=0.00000000342*cost(3.83450185886+519.39602435610*x);
L0+=0.00000000306*cost(0.35126074897+354.99798604640*x);
L0+=0.00000000314*cost(5.42086935152+1151.42900414390*x);
L0+=0.00000000384*cost(0.09367760642+201.51968199120*x);
L0+=0.00000000307*cost(5.62165090342+426.48631629140*x);
L0+=0.00000000301*cost(1.78550205039+1354.43315884340*x);
L0+=0.00000000300*cost(5.23426324539+190.40454575810*x);
L0+=0.00000000296*cost(3.15801280224+192.85222631290*x);
L0+=0.00000000381*cost(1.98600461808+109.94568878850*x);
L0+=0.00000000370*cost(5.57659190517+562.14674233010*x);
L0+=0.00000000305*cost(2.73187068494+840.66620877980*x);
L0+=0.00000000374*cost(3.73375594662+420.44785172170*x);
L0+=0.00000000307*cost(4.03149340189+426.71006546060*x);
L0+=0.00000000320*cost(1.42665180100+2730.20695868920*x);
L0+=0.00000000392*cost(0.14343294900+206.39799675830*x);
L0+=0.00000000288*cost(2.44787565138+623.22251175760*x);
L0+=0.00000000344*cost(1.57825843162+6290.18939699220*x);
L0+=0.00000000317*cost(1.84490263693+214.94362684070*x);
L0+=0.00000000346*cost(2.16849893508+3171.03224356680*x);
L0+=0.00000000286*cost(1.01623455966+315.64111013120*x);
L0+=0.00000000361*cost(3.44807605339+259.76951835400*x);
L0+=0.00000000280*cost(4.64272946177+254.14044406150*x);
L0+=0.00000000285*cost(2.09430258387+335.14181775230*x);
L0+=0.00000000281*cost(4.72136141979+317.14262918200*x);
L0+=0.00000000289*cost(4.70265740009+29.74746424980*x);
L0+=0.00000000290*cost(2.74360609522+551.03160609700*x);
L0+=0.00000000300*cost(5.23308974173+1321.43907040360*x);
L0+=0.00000000283*cost(1.21193797828+1699.27921650320*x);
L0+=0.00000000280*cost(0.45877292284+38.60611638980*x);
L0+=0.00000000273*cost(1.81952809851+1056.20053645150*x);
L0+=0.00000000336*cost(5.63115066542+95.22846769240*x);
L0+=0.00000000309*cost(3.33676739908+1193.96727379680*x);
L0+=0.00000000288*cost(2.57603349418+1166.40685767090*x);
L0+=0.00000000277*cost(3.35359995343+532.87235883230*x);
L0+=0.00000000287*cost(0.37229115993+114.94162363460*x);
L0+=0.00000000274*cost(4.21164027953+90.82323367730*x);
L0+=0.00000000267*cost(5.61367132586+870.46185713940*x);
L0+=0.00000000376*cost(6.14391456675+913.00012679230*x);
L0+=0.00000000296*cost(5.75705165982+4010.00153131720*x);
L0+=0.00000000304*cost(1.97982468634+495.96316347190*x);
L0+=0.00000000308*cost(5.08911712262+481.73606947030*x);
L0+=0.00000000265*cost(0.02893016561+172.45774681450*x);
L0+=0.00000000291*cost(2.10106037916+619.29035849450*x);
L0+=0.00000000273*cost(4.78343050572+771.30123618390*x);
L0+=0.00000000358*cost(0.04093867464+637.44960575920*x);
L0+=0.00000000272*cost(5.86505586319+332.17287233570*x);
L0+=0.00000000266*cost(3.28626000731+560.71045373160*x);
L0+=0.00000000312*cost(3.91213951915+1226.21060271120*x);
L0+=0.00000000258*cost(3.41185135958+426.81063919710*x);
L0+=0.00000000257*cost(1.06772454181+714.67888488130*x);
L0+=0.00000000258*cost(6.24129294573+426.38574255490*x);
L0+=0.00000000256*cost(0.75289096697+103.84353374400*x);
L0+=0.00000000254*cost(3.21116652124+102.34201469320*x);
L0+=0.00000000254*cost(6.14632777985+620.25356634100*x);
L0+=0.00000000266*cost(2.54280196709+132.88842257820*x);
L0+=0.00000000314*cost(0.31303204249+991.71387862270*x);
L0+=0.00000000317*cost(2.93589163442+357.23321828010*x);
L0+=0.00000000266*cost(6.12280636670+57.51612317990*x);
L0+=0.00000000254*cost(2.99730079627+642.34496686880*x);
L0+=0.00000000267*cost(5.54663413439+628.59095361920*x);
L0+=0.00000000348*cost(1.33319249154+815.06334611420*x);
L0+=0.00000000278*cost(5.59573741920+334.55111692130*x);
L0+=0.00000000303*cost(3.22789148979+409.18970313670*x);
L0+=0.00000000246*cost(3.90430259983+441.57604440300*x);
L0+=0.00000000260*cost(3.86355293530+639.37602145220*x);
L0+=0.00000000250*cost(0.07635434166+2840.41327990860*x);
L0+=0.00000000246*cost(5.71009371698+476.31944349890*x);
L0+=0.00000000301*cost(6.15272106984+559.69906177530*x);
L0+=0.00000000268*cost(3.73809606804+658.05653357870*x);
L0+=0.00000000316*cost(4.63035287047+745.27768239300*x);
L0+=0.00000000311*cost(3.51827727424+2751.54759969160*x);
L0+=0.00000000239*cost(0.51133317457+1041.22268292450*x);
L0+=0.00000000238*cost(5.46347279420+4216.18707975440*x);
L0+=0.00000000262*cost(3.20254407166+1251.34038462480*x);
L0+=0.00000000238*cost(1.02679111743+1262.38608488870*x);
L0+=0.00000000277*cost(3.32996713394+545.47196777370*x);
L0+=0.00000000271*cost(0.49229846069+419.53282798500*x);
L0+=0.00000000303*cost(3.77087511317+285.37238101960*x);
L0+=0.00000000234*cost(3.64328189368+407.47573576480*x);
L0+=0.00000000270*cost(3.93080966194+313.47110834980*x);
L0+=0.00000000302*cost(3.15201610429+915.23535902600*x);
L0+=0.00000000264*cost(0.46127639727+720.89866000480*x);
L0+=0.00000000235*cost(1.74238582338+369.08206769610*x);
L0+=0.00000000284*cost(5.20345848078+395.10562148700*x);
L0+=0.00000000295*cost(5.03016292492+594.65070367540*x);
L0+=0.00000000290*cost(1.94941528794+907.37105249980*x);
L0+=0.00000000229*cost(0.11049722694+3259.89792378380*x);
L0+=0.00000000304*cost(1.81516929363+49.72125262290*x);
L0+=0.00000000268*cost(5.54944666204+12352.85260454480*x);
L0+=0.00000000248*cost(4.39993603541+385.54439393140*x);
L0+=0.00000000234*cost(1.63365119249+3590.51688744200*x);
L0+=0.00000000317*cost(4.74907646809+420.00590873700*x);
L0+=0.00000000228*cost(4.89094697746+1181.43710082460*x);
L0+=0.00000000258*cost(2.41510535278+550.13783421970*x);
L0+=0.00000000236*cost(4.10002766188+6467.92575796160*x);
L0+=0.00000000249*cost(1.97767956861+589.49471013490*x);
L0+=0.00000000226*cost(1.60308230318+316.27999507200*x);
L0+=0.00000000286*cost(6.10513234736+484.70501488690*x);
L0+=0.00000000299*cost(3.71741328977+1123.11782849260*x);
L0+=0.00000000263*cost(1.85502475341+608.87779767700*x);
L0+=0.00000000220*cost(0.94624116595+316.50374424120*x);
L0+=0.00000000292*cost(3.12099513976+47.69426319340*x);
L0+=0.00000000217*cost(4.93010394323+281.17959532560*x);
L0+=0.00000000295*cost(3.18346450625+1050.99635880120*x);
L0+=0.00000000248*cost(5.48523310249+638.93407846750*x);
L0+=0.00000000276*cost(1.09325899753+544.50875992720*x);
L0+=0.00000000279*cost(2.65446123759+134.11226285560*x);
L0+=0.00000000247*cost(4.17284927352+950.13881681630*x);
L0+=0.00000000212*cost(2.45582771491+1164.76232626820*x);
L0+=0.00000000266*cost(2.30028827109+314.90739694830*x);
L0+=0.00000000215*cost(3.55148746518+1097.09427470170*x);
L0+=0.00000000223*cost(0.36862624591+81.89514556810*x);
L0+=0.00000000283*cost(0.35013012349+1269.49963188950*x);
L0+=0.00000000263*cost(0.58255768951+386.98068252990*x);
L0+=0.00000000208*cost(4.61303945066+668.20846196530*x);
L0+=0.00000000222*cost(4.51639912193+304.12232911530*x);
L0+=0.00000000274*cost(0.63572336701+679.25416222920*x);
L0+=0.00000000215*cost(0.74685271552+1008.97935401010*x);
L0+=0.00000000268*cost(3.43326489941+598.84348936940*x);
L0+=0.00000000271*cost(3.98364990268+453.68552624990*x);
L0+=0.00000000215*cost(2.24139383226+661.23792731640*x);
L0+=0.00000000264*cost(2.58516335032+2527.20280398970*x);
L0+=0.00000000205*cost(1.94472028389+650.19222705250*x);
L0+=0.00000000258*cost(1.50724315598+1759.83372106890*x);
L0+=0.00000000272*cost(6.27135287672+990.22940591440*x);
L0+=0.00000000201*cost(1.11891338895+97.41551581630*x);
L0+=0.00000000236*cost(4.13547185065+348.63519857100*x);
L0+=0.00000000201*cost(2.67485193508+1546.53462563090*x);
L0+=0.00000000250*cost(5.44391862722+1254.52177836250*x);
L0+=0.00000000203*cost(5.48660442144+557.03893289940*x);
L0+=0.00000000250*cost(0.32142312427+25448.00585526019*x);
L0+=0.00000000198*cost(0.91019549387+1310.39337013970*x);
L0+=0.00000000200*cost(0.90438804926+47.06112374700*x);
L0+=0.00000000194*cost(4.05730813129+426.85882330690*x);
L0+=0.00000000197*cost(0.58292199999+156.67674413540*x);
L0+=0.00000000197*cost(2.59384188520+639.84910220420*x);
L0+=0.00000000201*cost(1.49980256114+827.92358748650*x);
L0+=0.00000000197*cost(5.79126360809+639.94547042380*x);
L0+=0.00000000266*cost(1.45514683392+109.24311337290*x);
L0+=0.00000000239*cost(4.63640382863+868.71675200020*x);
L0+=0.00000000194*cost(5.59582424111+426.33755844510*x);
L0+=0.00000000247*cost(2.91348766248+689.61853893690*x);
L0+=0.00000000205*cost(1.04616771894+448.68959140380*x);
L0+=0.00000000232*cost(1.76503818816+354.26427286350*x);
L0+=0.00000000224*cost(3.45391027762+1190.03512053370*x);
L0+=0.00000000221*cost(6.27951545913+1596.18644228460*x);
L0+=0.00000000237*cost(1.24961141369+882.94384600180*x);
L0+=0.00000000206*cost(5.17010664247+253.45912050530*x);
L0+=0.00000000203*cost(0.25518217825+4002.88798431640*x);
L0+=0.00000000245*cost(3.94368773869+769.81676347560*x);
L0+=0.00000000255*cost(6.11790751550+763.43692965770*x);
L0+=0.00000000194*cost(2.83197251801+263.70167161710*x);
L0+=0.00000000237*cost(2.14007373880+2700.71514038580*x);
L0+=0.00000000203*cost(3.00078001542+1385.17496870700*x);
L0+=0.00000000203*cost(3.88000057282+419.43645976540*x);
L0+=0.00000000186*cost(4.79530535895+843.63515419640*x);
L0+=0.00000000203*cost(0.16707173895+535.91074021810*x);
L0+=0.00000000245*cost(0.76762638475+5643.17856367740*x);
L0+=0.00000000183*cost(2.20151176434+35.16409022120*x);
L0+=0.00000000242*cost(3.41613986919+864.24208201590*x);
L0+=0.00000000249*cost(3.47840802421+1045.88854937050*x);
L0+=0.00000000199*cost(4.70077509959+1276.61317889030*x);
L0+=0.00000000189*cost(1.84247610390+434.67494572330*x);
L0+=0.00000000192*cost(3.83148077309+666.72398925700*x);
L0+=0.00000000201*cost(1.34290804373+1012.91150727320*x);
L0+=0.00000000210*cost(5.12097279511+3494.53766022420*x);
L0+=0.00000000192*cost(1.36630036429+904.40210708320*x);
L0+=0.00000000195*cost(1.62629576534+364.34676528090*x);
L0+=0.00000000179*cost(1.66502999050+244.79166482700*x);
L0+=0.00000000186*cost(4.55663748319+347.41135829360*x);
L0+=0.00000000201*cost(0.50219680740+36.38793049860*x);
L0+=0.00000000179*cost(4.55153097409+97.46369992610*x);
L0+=0.00000000200*cost(0.68398141887+2015.67108615980*x);
L0+=0.00000000195*cost(2.20599546209+66.18357885820*x);
L0+=0.00000000186*cost(4.48925201018+611.44309831080*x);
L0+=0.00000000186*cost(3.13663606153+433.66355376700*x);
L0+=0.00000000177*cost(3.62811326217+326.68681039510*x);
L0+=0.00000000206*cost(0.38552475035+857.12853501510*x);
L0+=0.00000000229*cost(1.22330638216+2906.90068882300*x);
L0+=0.00000000213*cost(6.08436923028+271.61836777000*x);
L0+=0.00000000174*cost(6.18833529233+3576.28979344040*x);
L0+=0.00000000220*cost(2.89866380776+322.61164478010*x);
L0+=0.00000000202*cost(2.43755817264+812.14258480740*x);
L0+=0.00000000211*cost(4.27999470527+1127.26243007680*x);
L0+=0.00000000188*cost(0.97173474238+1080.72257119160*x);
L0+=0.00000000168*cost(0.65008064023+1493.09366806600*x);
L0+=0.00000000208*cost(4.68942071563+5429.87946823940*x);
L0+=0.00000000182*cost(0.76058628096+504.56118318100*x);
L0+=0.00000000167*cost(6.22608046965+108.50940019000*x);
L0+=0.00000000176*cost(2.08816807487+670.91677495100*x);
L0+=0.00000000170*cost(1.55680702386+1670.82502850000*x);
L0+=0.00000000187*cost(4.12687876136+9985.75935677140*x);
L0+=0.00000000166*cost(1.58596354370+1379.70595310890*x);
L0+=0.00000000170*cost(1.30946662341+837.69726336320*x);
L0+=0.00000000166*cost(0.02413278965+224.60542813280*x);
L0+=0.00000000204*cost(6.12072939658+9360.08916445900*x);
L0+=0.00000000189*cost(0.28191962964+1175.80802653210*x);
L0+=0.00000000184*cost(2.87461093640+398.14400287280*x);
L0+=0.00000000172*cost(5.41410693088+2306.79016155090*x);
L0+=0.00000000174*cost(0.94052578814+632.03297978780*x);
L0+=0.00000000181*cost(2.20017945285+1049.08698945070*x);
L0+=0.00000000176*cost(1.09857632660+531.97858695500*x);
L0+=0.00000000201*cost(2.68411933635+795.68025857210*x);
L0+=0.00000000197*cost(1.43444932583+347.36317418380*x);
L0+=0.00000000200*cost(4.33954193534+1364.72809958190*x);
L0+=0.00000000166*cost(2.83936872840+3553.91152213780*x);
L0+=0.00000000160*cost(1.28778451384+962.50893109410*x);
L0+=0.00000000206*cost(3.02518737424+1141.13406340540*x);
L0+=0.00000000200*cost(5.54644533685+308.31511480930*x);
L0+=0.00000000158*cost(4.75462437610+1534.73816584160*x);
L0+=0.00000000156*cost(3.42359004405+241.75328344120*x);
L0+=0.00000000182*cost(5.26192506263+968.13800538660*x);
L0+=0.00000000168*cost(0.37055108740+10007.09999777380*x);
L0+=0.00000000174*cost(4.61279044571+223.33340374560*x);
L0+=0.00000000158*cost(4.23116519562+821.70381236300*x);
L0+=0.00000000212*cost(5.98406058023+432.74853003030*x);
L0+=0.00000000160*cost(4.08093018212+632.73555520340*x);
L0+=0.00000000179*cost(5.74376301842+924.04582705620*x);
L0+=0.00000000185*cost(3.01715709315+55.87159177720*x);
L0+=0.00000000185*cost(0.75718598244+1286.90811962880*x);
L0+=0.00000000170*cost(3.46903106526+1304.92435454160*x);
L0+=0.00000000167*cost(3.19767851189+635.23141986800*x);
L0+=0.00000000153*cost(3.83006208210+318.67949151700*x);
L0+=0.00000000156*cost(1.61558494091+110.25450532920*x);
L0+=0.00000000206*cost(1.62702696825+389.94962794650*x);
L0+=0.00000000184*cost(3.31730160238+1578.02719501990*x);
L0+=0.00000000184*cost(6.19913208096+731.68372783780*x);
L0+=0.00000000158*cost(5.58628906712+42.32582133180*x);
L0+=0.00000000159*cost(2.00727485442+702.14871190910*x);
L0+=0.00000000155*cost(0.02889842368+1357.61455258110*x);
L0+=0.00000000151*cost(5.80616069064+680.05731138130*x);
L0+=0.00000000157*cost(5.67235483479+77837.11123384659*x);
L0+=0.00000000156*cost(2.78001360754+1567.73225428140*x);
L0+=0.00000000203*cost(5.91820261629+971.10695080320*x);
L0+=0.00000000156*cost(5.68482948401+649.45851386960*x);
L0+=0.00000000186*cost(5.72093247348+664.27630870220*x);
L0+=0.00000000184*cost(4.05878767739+976.73602509570*x);
L0+=0.00000000159*cost(3.10978439502+230.70758317730*x);
L0+=0.00000000154*cost(4.54479813612+1239.54392483550*x);
L0+=0.00000000177*cost(4.68148789757+2921.12778282460*x);
L0+=0.00000000158*cost(4.30854435851+633.74694715970*x);
L0+=0.00000000195*cost(5.33376523453+1130.23137549340*x);
L0+=0.00000000188*cost(2.04023570497+1127.04998175570*x);
L0+=0.00000000174*cost(2.88817750136+25668.41849769900*x);
L0+=0.00000000161*cost(2.96300008890+152.74459087230*x);
L0+=0.00000000170*cost(1.70779560770+493.30303459600*x);
L0+=0.00000000156*cost(3.05331862578+913.75088631770*x);
L0+=0.00000000169*cost(3.18325334507+757.80785536520*x);
L0+=0.00000000145*cost(0.89672198690+632.83192342300*x);
L0+=0.00000000149*cost(2.69519361988+203.26478713040*x);
L0+=0.00000000167*cost(2.96547549589+1201.83158032300*x);
L0+=0.00000000187*cost(3.17592113403+842.90144101350*x);
L0+=0.00000000173*cost(1.91528836350+3487.42411322340*x);
L0+=0.00000000154*cost(0.37169915171+285.11174858870*x);
L0+=0.00000000198*cost(3.14620903981+640.86049416050*x);
L0+=0.00000000143*cost(3.42760427364+520.12973753900*x);
L0+=0.00000000157*cost(2.34913118792+5959.57043333400*x);
L0+=0.00000000178*cost(5.34566184657+272.58157561650*x);
L0+=0.00000000171*cost(3.34185265551+3067.93946934820*x);
L0+=0.00000000171*cost(4.87848878292+354.52490529440*x);
L0+=0.00000000189*cost(0.07069084691+1585.89150154610*x);
L0+=0.00000000137*cost(1.28925665885+214.10224459010*x);
L0+=0.00000000137*cost(3.49438482900+212.49594628590*x);
L0+=0.00000000174*cost(3.07450555579+64.95973858080*x);
L0+=0.00000000181*cost(0.78652249647+657.16276170140*x);
L0+=0.00000000158*cost(2.93809799392+211.65456403530*x);
L0+=0.00000000133*cost(5.70724173596+469.72716135990*x);
L0+=0.00000000140*cost(0.35530248121+219.51887056150*x);
L0+=0.00000000132*cost(1.60614108449+1372.59240610810*x);
L0+=0.00000000164*cost(1.68236348359+707.56533788050*x);
L0+=0.00000000128*cost(1.49742950959+45.24658263860*x);
L0+=0.00000000132*cost(4.98075995751+238.57188970350*x);
L0+=0.00000000140*cost(3.62845435388+423.88987789030*x);
L0+=0.00000000134*cost(1.41837795083+3906.90875709860*x);
L0+=0.00000000127*cost(1.48966646069+856.37777548970*x);
L0+=0.00000000158*cost(2.57990141197+369.97583957340*x);
L0+=0.00000000132*cost(2.39662455993+184.72728735580*x);
L0+=0.00000000140*cost(4.36785639279+207.07932031450*x);
L0+=0.00000000157*cost(4.56655940808+251.17149864490*x);
L0+=0.00000000125*cost(4.60433583965+6076.89030155420*x);
L0+=0.00000000121*cost(1.59513269211+184.84490743480*x);
L0+=0.00000000145*cost(5.85121885906+221.89711514710*x);
L0+=0.00000000137*cost(0.76499603885+476.10699517780*x);
L0+=0.00000000139*cost(6.02467582226+429.30650386170*x);
L0+=0.00000000117*cost(0.23611722307+426.75824957040*x);
L0+=0.00000000117*cost(3.13382984215+426.43813218160*x);
L0+=0.00000000116*cost(4.34801448720+418.96337901340*x);
L0+=0.00000000135*cost(2.69789181467+455.16999895820*x);
L0+=0.00000000134*cost(1.19058772772+502.86426215160*x);
L0+=0.00000000123*cost(3.97560160218+499.89531673500*x);
L0+=0.00000000110*cost(2.37032413718+439.93151300030*x);
L0+=0.00000000109*cost(6.20303291896+220.30076785420*x);
L0+=0.00000000109*cost(1.38979633175+325.95309721220*x);
L0+=0.00000000115*cost(0.05845336809+631.82053146670*x);
L0+=0.00000000139*cost(2.21086387259+9573.38825989700*x);
L0+=0.00000000142*cost(6.14666228712+3340.61242669980*x);
L0+=0.00000000122*cost(4.77182119272+604.47256366190*x);
L0+=0.00000000119*cost(3.03461367061+528.20649238630*x);
L0+=0.00000000127*cost(2.97263950543+498.93210888850*x);
L0+=0.00000000111*cost(5.01192320232+220.20019411770*x);
L0+=0.00000000126*cost(3.95743516129+566.60016045500*x);
L0+=0.00000000098*cost(2.36210526249+634.26821202150*x);
L0+=0.00000000108*cost(2.46872857126+83.37961827640*x);
L0+=0.00000000101*cost(4.88259474274+425.32616648880*x);
L0+=0.00000000127*cost(4.89006771254+162.09337010680*x);
L0+=0.00000000099*cost(0.90073463816+586.31331639720*x);
L0+=0.00000000099*cost(0.16310526294+394.35486196160*x);
L0+=0.00000000115*cost(0.49160291262+517.16079212240*x);
L0+=0.00000000101*cost(3.86043866859+198.10879358990*x);
L0+=0.00000000105*cost(3.48222097813+5863.59120611620*x);
L0+=0.00000000104*cost(4.61148354671+220.52451702340*x);
L0+=0.00000000101*cost(4.77041950285+427.87021526320*x);
L0+=0.00000000098*cost(2.90784721214+199.96577331370*x);
L0+=0.00000000127*cost(0.14136936897+2332.06295581640*x);
L0+=0.00000000091*cost(6.22628300117+211.29335786790*x);
L0+=0.00000000100*cost(5.14847283436+226.79247625670*x);
L0+=0.00000000091*cost(4.84054379386+215.30483300810*x);
L0+=0.00000000099*cost(4.37583492400+640.41855117580*x);
L0+=0.00000000093*cost(5.30395179617+222.70026429920*x);
L0+=0.00000000086*cost(4.57481701854+636.97652500720*x);
L0+=0.00000000111*cost(0.61102669309+1089.12939443900*x);
L0+=0.00000000086*cost(4.50969293872+625.88264063350*x);
L0+=0.00000000088*cost(0.36828594935+444.12429869430*x);
L0+=0.00000000093*cost(5.76287499885+203.89792657680*x);
L0+=0.00000000082*cost(2.85558603378+318.83955021140*x);
L0+=0.00000000082*cost(5.19618475111+1467.82087380050*x);
L0+=0.00000000086*cost(0.97633784601+200.03520928290*x);
L0+=0.00000000082*cost(4.78557953017+195.77298761970*x);
L0+=0.00000000106*cost(2.29520624233+799.61241183520*x);
L0+=0.00000000081*cost(3.57727166766+205.97310011610*x);
L0+=0.00000000078*cost(5.50343512580+262.80789973980*x);
L0+=0.00000000087*cost(0.76830756075+201.99276274320*x);
L0+=0.00000000102*cost(2.11516755277+206.93630796260*x);
L0+=0.00000000081*cost(5.29639775054+111.16952906590*x);
L0+=0.00000000075*cost(2.77117107886+255.83736509090*x);
L0+=0.00000000074*cost(5.81587984729+316.44005376640*x);
L0+=0.00000000076*cost(1.78743197928+171.65459766240*x);
L0+=0.00000000094*cost(4.99996904753+378.64329525170*x);
L0+=0.00000000089*cost(5.85818860151+807.94979911340*x);
L0+=0.00000000072*cost(0.99858616883+280.21638747910*x);
L0+=0.00000000099*cost(0.15018241445+186.21176006410*x);
L0+=0.00000000072*cost(5.15715918322+110.15813710960*x);

double L1=0;
L1+=213.54295595986;
L1+=0.01296855005*cost(1.82820544701+213.29909543800*x);
L1+=0.00564347566*cost(2.88500136429+7.11354700080*x);
L1+=0.00098323030*cost(1.08070061328+426.59819087600*x);
L1+=0.00107678770*cost(2.27769911872+206.18554843720*x);
L1+=0.00040254586*cost(2.04128257090+220.41264243880*x);
L1+=0.00019941734*cost(1.27954662736+103.09277421860*x);
L1+=0.00010511706*cost(2.74880392800+14.22709400160*x);
L1+=0.00006939233*cost(0.40493079985+639.89728631400*x);
L1+=0.00004803325*cost(2.44194097666+419.48464387520*x);
L1+=0.00004056325*cost(2.92166618776+110.20632121940*x);
L1+=0.00003768630*cost(3.64965631460+3.93215326310*x);
L1+=0.00003384684*cost(2.41694251653+3.18139373770*x);
L1+=0.00003302200*cost(1.26256486715+433.71173787680*x);
L1+=0.00003071382*cost(2.32739317750+199.07200143640*x);
L1+=0.00001953036*cost(3.56394683300+11.04570026390*x);
L1+=0.00001249348*cost(2.62803737519+95.97922721780*x);
L1+=0.00000921683*cost(1.96089834250+227.52618943960*x);
L1+=0.00000705587*cost(4.41689249330+529.69096509460*x);
L1+=0.00000649654*cost(6.17418093659+202.25339517410*x);
L1+=0.00000627603*cost(6.11088227167+309.27832265580*x);
L1+=0.00000486843*cost(6.03998200305+853.19638175200*x);
L1+=0.00000468377*cost(4.61707843907+63.73589830340*x);
L1+=0.00000478501*cost(4.98776987984+522.57741809380*x);
L1+=0.00000417010*cost(2.11708169277+323.50541665740*x);
L1+=0.00000407630*cost(1.29949556676+209.36694217490*x);
L1+=0.00000343826*cost(3.95854178574+412.37109687440*x);
L1+=0.00000339724*cost(3.63396398752+316.39186965660*x);
L1+=0.00000335936*cost(3.77173072712+735.87651353180*x);
L1+=0.00000331933*cost(2.86077699882+210.11770170030*x);
L1+=0.00000352489*cost(2.31707079463+632.78373931320*x);
L1+=0.00000289429*cost(2.73263080235+117.31986822020*x);
L1+=0.00000265801*cost(0.54344631312+647.01083331480*x);
L1+=0.00000230493*cost(1.64428879621+216.48048917570*x);
L1+=0.00000280911*cost(5.74398845416+2.44768055480*x);
L1+=0.00000191667*cost(2.96512946582+224.34479570190*x);
L1+=0.00000172891*cost(4.07695221044+846.08283475120*x);
L1+=0.00000167131*cost(2.59745202658+21.34064100240*x);
L1+=0.00000136328*cost(2.28580246629+10.29494073850*x);
L1+=0.00000131364*cost(3.44108355646+742.99006053260*x);
L1+=0.00000127838*cost(4.09533471247+217.23124870110*x);
L1+=0.00000108862*cost(6.16141072262+415.55249061210*x);
L1+=0.00000093909*cost(3.48397279899+1052.26838318840*x);
L1+=0.00000092482*cost(3.94755499926+88.86568021700*x);
L1+=0.00000097584*cost(4.72845436677+838.96928775040*x);
L1+=0.00000086600*cost(1.21951325061+440.82528487760*x);
L1+=0.00000083463*cost(3.11269504725+625.67019231240*x);
L1+=0.00000077588*cost(6.24408938835+302.16477565500*x);
L1+=0.00000061557*cost(1.82789612597+195.13984817330*x);
L1+=0.00000061900*cost(4.29344363385+127.47179660680*x);
L1+=0.00000067106*cost(0.28961738595+4.66586644600*x);
L1+=0.00000056919*cost(5.01889578112+137.03302416240*x);
L1+=0.00000054160*cost(5.12628572382+490.33408917940*x);
L1+=0.00000054585*cost(0.28356341456+74.78159856730*x);
L1+=0.00000051425*cost(1.45766406064+536.80451209540*x);
L1+=0.00000065843*cost(5.64757042732+9.56122755560*x);
L1+=0.00000057780*cost(2.47630552035+191.95845443560*x);
L1+=0.00000044444*cost(2.70873627665+5.41662597140*x);
L1+=0.00000046799*cost(1.17721211050+149.56319713460*x);
L1+=0.00000040380*cost(3.88870105683+728.76296653100*x);
L1+=0.00000037768*cost(2.53379013859+12.53017297220*x);
L1+=0.00000046649*cost(5.14818326902+515.46387109300*x);
L1+=0.00000045891*cost(2.23198878761+956.28915597060*x);
L1+=0.00000040400*cost(0.41281520440+269.92144674060*x);
L1+=0.00000037191*cost(3.78239026411+2.92076130680*x);
L1+=0.00000033778*cost(3.21070688046+1368.66025284500*x);
L1+=0.00000037969*cost(0.64665967180+422.66603761290*x);
L1+=0.00000032857*cost(0.30063884563+351.81659230870*x);
L1+=0.00000033050*cost(5.43038091186+1066.49547719000*x);
L1+=0.00000030276*cost(2.84067004928+203.00415469950*x);
L1+=0.00000035116*cost(6.08421794089+5.62907429250*x);
L1+=0.00000029667*cost(3.39052569135+1059.38193018920*x);
L1+=0.00000033217*cost(4.64063092111+277.03499374140*x);
L1+=0.00000031876*cost(4.38622923770+1155.36115740700*x);
L1+=0.00000028913*cost(2.02614760507+330.61896365820*x);
L1+=0.00000028264*cost(2.74178953996+265.98929347750*x);
L1+=0.00000030089*cost(6.18684614308+284.14854074220*x);
L1+=0.00000031329*cost(2.43455855525+52.69019803950*x);
L1+=0.00000026493*cost(4.51214170121+340.77089204480*x);
L1+=0.00000021983*cost(5.14437352579+4.19278569400*x);
L1+=0.00000022230*cost(1.96481952451+203.73786788240*x);
L1+=0.00000020824*cost(6.16048095923+860.30992875280*x);
L1+=0.00000021690*cost(2.67578768862+942.06206196900*x);
L1+=0.00000022552*cost(5.88579123000+210.85141488320*x);
L1+=0.00000019807*cost(2.31345263487+437.64389113990*x);
L1+=0.00000019447*cost(4.76573277668+70.84944530420*x);
L1+=0.00000019310*cost(4.10209060369+18.15924726470*x);
L1+=0.00000022662*cost(4.13732273379+191.20769491020*x);
L1+=0.00000018209*cost(0.90310796389+429.77958461370*x);
L1+=0.00000017667*cost(1.84954766042+234.63973644040*x);
L1+=0.00000017547*cost(2.44735118493+423.41679713830*x);
L1+=0.00000015428*cost(4.23790088205+1162.47470440780*x);
L1+=0.00000014608*cost(3.59713247857+1045.15483618760*x);
L1+=0.00000014111*cost(2.94262468353+1685.05212250160*x);
L1+=0.00000016328*cost(4.05665272725+949.17560896980*x);
L1+=0.00000013348*cost(6.24509592240+38.13303563780*x);
L1+=0.00000015918*cost(1.06434204938+56.62235130260*x);
L1+=0.00000014059*cost(1.43503954068+408.43894361130*x);
L1+=0.00000013093*cost(5.75815864257+138.51749687070*x);
L1+=0.00000015772*cost(5.59350835225+6.15033915430*x);
L1+=0.00000014962*cost(5.77192239389+22.09140052780*x);
L1+=0.00000016024*cost(1.93900586533+1272.68102562720*x);
L1+=0.00000016751*cost(5.96673627422+628.85158605010*x);
L1+=0.00000012843*cost(4.24658666814+405.25754987360*x);
L1+=0.00000013628*cost(4.09892958087+1471.75302706360*x);
L1+=0.00000015067*cost(0.74142807591+200.76892246580*x);
L1+=0.00000010961*cost(1.55022573283+223.59403617650*x);
L1+=0.00000011695*cost(1.81237511034+124.43341522100*x);
L1+=0.00000010346*cost(3.46814088412+1375.77379984580*x);
L1+=0.00000012056*cost(1.85655834555+131.40394986990*x);
L1+=0.00000010123*cost(2.38221133049+107.02492748170*x);
L1+=0.00000009855*cost(3.95166998848+430.53034413910*x);
L1+=0.00000009803*cost(2.55389483994+99.91138048090*x);
L1+=0.00000010614*cost(5.36692189034+215.74677599280*x);
L1+=0.00000012080*cost(4.84549317054+831.85574074960*x);
L1+=0.00000010210*cost(6.07692961370+32.24332891440*x);
L1+=0.00000009245*cost(3.65417467270+142.44965013380*x);
L1+=0.00000008984*cost(1.23808405498+106.27416795630*x);
L1+=0.00000009336*cost(5.81062768434+7.16173111060*x);
L1+=0.00000009717*cost(1.38703872827+145.63104387150*x);
L1+=0.00000008394*cost(4.42341211111+703.63318461740*x);
L1+=0.00000008370*cost(5.64015188458+62.25142559510*x);
L1+=0.00000008244*cost(2.42225929772+1258.45393162560*x);
L1+=0.00000007784*cost(0.52562994711+654.12438031560*x);
L1+=0.00000007626*cost(3.75258725596+312.19908396260*x);
L1+=0.00000007222*cost(0.28429555677+0.75075952540*x);
L1+=0.00000008236*cost(6.22250515902+14.97785352700*x);
L1+=0.00000007054*cost(0.53177810740+388.46515523820*x);
L1+=0.00000006567*cost(3.48657341701+35.42472265210*x);
L1+=0.00000009011*cost(4.94919626910+208.63322899200*x);
L1+=0.00000008980*cost(0.08138173719+288.08069400530*x);
L1+=0.00000006421*cost(3.32905264657+1361.54670584420*x);
L1+=0.00000006489*cost(2.89389587598+114.13847448250*x);
L1+=0.00000006244*cost(0.54973852782+65.22037101170*x);
L1+=0.00000006154*cost(2.67885860584+2001.44399215820*x);
L1+=0.00000006742*cost(0.23586769279+8.07675484730*x);
L1+=0.00000007297*cost(4.85321224483+222.86032299360*x);
L1+=0.00000006302*cost(3.80651124694+1788.14489672020*x);
L1+=0.00000005824*cost(4.39327457448+81.75213321620*x);
L1+=0.00000006102*cost(0.88585782895+92.04707395470*x);
L1+=0.00000006914*cost(2.04631426723+99.16062095550*x);
L1+=0.00000005363*cost(5.47995103139+563.63121503840*x);
L1+=0.00000005172*cost(2.11968421583+214.26230328450*x);
L1+=0.00000005117*cost(5.76987684107+565.11568774670*x);
L1+=0.00000006197*cost(1.62553688800+1589.07289528380*x);
L1+=0.00000004970*cost(0.41949366126+76.26607127560*x);
L1+=0.00000006640*cost(5.82582210639+483.22054217860*x);
L1+=0.00000005277*cost(4.57975789757+134.58534360760*x);
L1+=0.00000004974*cost(4.20243895902+404.50679034820*x);
L1+=0.00000005150*cost(4.67582673243+212.33588759150*x);
L1+=0.00000004764*cost(4.59303997414+554.06998748280*x);
L1+=0.00000004573*cost(3.24875415786+231.45834270270*x);
L1+=0.00000004811*cost(0.46206327592+362.86229257260*x);
L1+=0.00000005148*cost(3.33570646174+1.48447270830*x);
L1+=0.00000004654*cost(5.80233066659+217.96496188400*x);
L1+=0.00000004509*cost(5.37581684215+497.44763618020*x);
L1+=0.00000004443*cost(0.11349392292+295.05122865420*x);
L1+=0.00000004943*cost(3.78020789259+1265.56747862640*x);
L1+=0.00000004211*cost(4.88306021960+98.89998852460*x);
L1+=0.00000004252*cost(5.00120115113+213.34727954780*x);
L1+=0.00000004774*cost(4.53259894142+1148.24761040620*x);
L1+=0.00000003911*cost(0.58582192963+750.10360753340*x);
L1+=0.00000005069*cost(2.20305668335+207.88246946660*x);
L1+=0.00000003553*cost(0.35374030841+333.65734504400*x);
L1+=0.00000003771*cost(0.98542435766+24.37902238820*x);
L1+=0.00000003458*cost(1.84990273999+225.82926841020*x);
L1+=0.00000003401*cost(5.31342401626+347.88443904560*x);
L1+=0.00000003347*cost(0.21414641376+635.96513305090*x);
L1+=0.00000003637*cost(1.61315058382+245.54242435240*x);
L1+=0.00000003416*cost(2.19551489078+1574.84580128220*x);
L1+=0.00000003655*cost(0.80544245690+343.21857259960*x);
L1+=0.00000004260*cost(1.80258750109+213.25091132820*x);
L1+=0.00000003110*cost(3.03815175282+1677.93857550080*x);
L1+=0.00000003052*cost(1.33858964447+543.91805909620*x);
L1+=0.00000003694*cost(0.81606028298+344.70304530790*x);
L1+=0.00000003016*cost(3.36219319026+7.86430652620*x);
L1+=0.00000002937*cost(4.86927342776+144.14657116320*x);
L1+=0.00000002768*cost(2.42707131609+2317.83586181480*x);
L1+=0.00000003059*cost(4.30820099442+6062.66320755260*x);
L1+=0.00000003650*cost(5.12802531219+218.92816973050*x);
L1+=0.00000002963*cost(3.53480751374+2104.53676637680*x);
L1+=0.00000003230*cost(2.88057019783+216.21985674480*x);
L1+=0.00000002984*cost(2.52971310583+1692.16566950240*x);
L1+=0.00000002897*cost(5.73256482240+9992.87290377220*x);
L1+=0.00000002591*cost(3.79880285744+17.26547538740*x);
L1+=0.00000003495*cost(5.29902525443+350.33211960040*x);
L1+=0.00000002859*cost(3.72804950659+6076.89030155420*x);
L1+=0.00000002775*cost(0.23549396237+357.44566660120*x);
L1+=0.00000002976*cost(2.48769315964+46.47042291600*x);
L1+=0.00000002487*cost(4.37868078530+217.49188113200*x);
L1+=0.00000002711*cost(5.15376840150+10007.09999777380*x);
L1+=0.00000003127*cost(1.92343235583+17.40848773930*x);
L1+=0.00000003181*cost(1.72419900322+1169.58825140860*x);
L1+=0.00000002348*cost(0.77373103004+414.06801790380*x);
L1+=0.00000002606*cost(3.42836913440+31.01948863700*x);
L1+=0.00000002556*cost(0.91735028377+479.28838891550*x);
L1+=0.00000002399*cost(4.82440545738+1279.79457262800*x);
L1+=0.00000002245*cost(3.76323995584+425.11371816770*x);
L1+=0.00000003020*cost(0.25310250109+120.35824960600*x);
L1+=0.00000002503*cost(2.10679832121+168.05251279940*x);
L1+=0.00000002564*cost(1.63158205055+182.27960680100*x);
L1+=0.00000002221*cost(3.15472373256+212.77783057620*x);
L1+=0.00000002357*cost(2.33145013714+218.71572140940*x);
L1+=0.00000002510*cost(4.51903989011+198.32124191100*x);
L1+=0.00000002715*cost(5.76330259543+618.55664531160*x);
L1+=0.00000002204*cost(3.35952557362+160.60889739850*x);
L1+=0.00000002648*cost(0.71962005233+85.82729883120*x);
L1+=0.00000002029*cost(5.28642331696+125.98732389850*x);
L1+=0.00000002497*cost(1.36671447252+1905.46476494040*x);
L1+=0.00000002017*cost(1.11498225426+447.93883187840*x);
L1+=0.00000002052*cost(1.27587874735+14.01464568050*x);
L1+=0.00000002254*cost(3.22447674190+273.10284047830*x);
L1+=0.00000002014*cost(0.39787014152+358.93013930950*x);
L1+=0.00000001981*cost(2.33696859021+28.45418800320*x);
L1+=0.00000002197*cost(5.93386789705+13.33332212430*x);
L1+=0.00000002237*cost(3.64433751164+213.82036029980*x);
L1+=0.00000001930*cost(1.85671740340+1.27202438720*x);
L1+=0.00000002037*cost(5.05300562628+424.15051032120*x);
L1+=0.00000001994*cost(1.35690802366+20.60692781950*x);
L1+=0.00000001911*cost(3.44106886717+69.15252427480*x);
L1+=0.00000001925*cost(3.75243031545+28.31117565130*x);
L1+=0.00000002297*cost(4.24557050896+1464.63948006280*x);
L1+=0.00000002117*cost(2.25897766314+116.42609634290*x);
L1+=0.00000001847*cost(5.40631472802+31.49256938900*x);
L1+=0.00000001841*cost(1.56916484272+650.94298657790*x);
L1+=0.00000001884*cost(6.27233535258+25.12978191360*x);
L1+=0.00000001960*cost(4.89484014840+275.55052103310*x);
L1+=0.00000002016*cost(5.45791785675+842.15068148810*x);
L1+=0.00000002282*cost(4.96276947440+258.87574647670*x);
L1+=0.00000001709*cost(3.99098237135+416.30325013750*x);
L1+=0.00000002176*cost(0.00746756006+0.89377187730*x);
L1+=0.00000001634*cost(5.30978165487+251.43213107580*x);
L1+=0.00000001687*cost(0.41586020065+54.17467074780*x);
L1+=0.00000001910*cost(2.59825755790+329.72519178090*x);
L1+=0.00000002113*cost(2.56582292726+59.80374504030*x);
L1+=0.00000001921*cost(2.42279051938+113.38771495710*x);
L1+=0.00000001658*cost(5.47323651540+1073.60902419080*x);
L1+=0.00000001590*cost(2.77545297350+1994.33044515740*x);
L1+=0.00000001936*cost(3.47558926847+1581.95934828300*x);
L1+=0.00000001649*cost(1.82779010589+128.95626931510*x);
L1+=0.00000001598*cost(1.71806465300+129.91947716160*x);
L1+=0.00000001967*cost(1.25160413795+621.73803904930*x);
L1+=0.00000001702*cost(1.91076102800+278.51946644970*x);
L1+=0.00000001569*cost(0.16491194947+643.07868005170*x);
L1+=0.00000001989*cost(5.28799230992+508.35032409220*x);
L1+=0.00000001520*cost(0.56950979689+320.32402291970*x);
L1+=0.00000001501*cost(1.99815894193+1891.23767093880*x);
L1+=0.00000001532*cost(3.27362317849+2420.92863603340*x);
L1+=0.00000001701*cost(2.72041261115+767.36908292080*x);
L1+=0.00000001561*cost(6.09424459628+280.96714700450*x);
L1+=0.00000001331*cost(4.20944443790+546.95644048200*x);
L1+=0.00000001381*cost(2.06768100830+192.69216761850*x);
L1+=0.00000001368*cost(6.28049502257+1795.25844372100*x);
L1+=0.00000001519*cost(2.20299556153+2008.55753915900*x);
L1+=0.00000001356*cost(4.01521042413+721.64941953020*x);
L1+=0.00000001296*cost(4.84815978742+45.57665103870*x);
L1+=0.00000001267*cost(5.28146654999+173.94221952280*x);
L1+=0.00000001402*cost(6.12951551550+39.35687591520*x);
L1+=0.00000001252*cost(2.19169926554+2634.22773147140*x);
L1+=0.00000001466*cost(4.16354845643+26.82670294300*x);
L1+=0.00000001285*cost(3.76170874847+2.28762186040*x);
L1+=0.00000001500*cost(5.41022492529+214.04985496340*x);
L1+=0.00000001396*cost(4.78595583428+219.44943459230*x);
L1+=0.00000001430*cost(0.70934745161+254.94359321360*x);
L1+=0.00000001195*cost(3.71281085322+264.50482076920*x);
L1+=0.00000001181*cost(0.42635230882+41.64449777560*x);
L1+=0.00000001190*cost(2.02079286787+1485.98012106520*x);
L1+=0.00000001160*cost(5.23649231796+181.05576652360*x);
L1+=0.00000001535*cost(3.62746990294+561.18353448360*x);
L1+=0.00000001120*cost(1.09127922130+6.59228213900*x);
L1+=0.00000001100*cost(0.27844612141+184.09414790940*x);
L1+=0.00000001227*cost(1.39969681270+209.10630974400*x);
L1+=0.00000001353*cost(6.12903657666+207.67002114550*x);
L1+=0.00000001124*cost(6.05105541765+291.26208774300*x);
L1+=0.00000001194*cost(4.79565407023+1478.86657406440*x);
L1+=0.00000001082*cost(4.73602931755+78.71375183040*x);
L1+=0.00000001202*cost(3.47301104146+51.20572533120*x);
L1+=0.00000001298*cost(2.34761557822+210.37833413120*x);
L1+=0.00000001166*cost(4.20037524355+417.03696332040*x);
L1+=0.00000001228*cost(3.94985981275+1781.03134971940*x);
L1+=0.00000001401*cost(2.41318931513+636.71589257630*x);
L1+=0.00000001009*cost(6.17414889934+2111.65031337760*x);
L1+=0.00000001084*cost(3.68958647346+274.06604832480*x);
L1+=0.00000001068*cost(0.80258823981+436.89313161450*x);
L1+=0.00000001007*cost(3.42792508860+629.60234557550*x);
L1+=0.00000000998*cost(5.57130056835+205.22234059070*x);
L1+=0.00000001058*cost(1.05742945779+237.67811782620*x);
L1+=0.00000001020*cost(3.33667290300+166.82867252200*x);
L1+=0.00000000965*cost(6.08359503243+601.76425067620*x);
L1+=0.00000001005*cost(3.56310748091+643.82943957710*x);
L1+=0.00000000987*cost(0.97129012811+305.34616939270*x);
L1+=0.00000000927*cost(3.87717400791+135.33610313300*x);
L1+=0.00000001129*cost(5.94840103961+196.62432088160*x);
L1+=0.00000001118*cost(5.25415059584+189.72322220190*x);
L1+=0.00000001200*cost(1.16671933467+2221.85663459700*x);
L1+=0.00000000909*cost(2.14001565047+617.80588578620*x);
L1+=0.00000000899*cost(2.31811625712+312.45971639350*x);
L1+=0.00000001081*cost(0.91006048421+313.21047591890*x);
L1+=0.00000000891*cost(3.74923531791+916.93228005540*x);
L1+=0.00000000886*cost(4.76066858907+776.93031047640*x);
L1+=0.00000000912*cost(0.99592540858+491.81856188770*x);
L1+=0.00000000880*cost(3.67349449376+25.27279426550*x);
L1+=0.00000001203*cost(1.39749267410+337.73251065900*x);
L1+=0.00000000867*cost(0.11684071625+267.47376618580*x);
L1+=0.00000000879*cost(6.12222682852+867.42347575360*x);
L1+=0.00000001080*cost(0.15038819285+175.16605980020*x);
L1+=0.00000000988*cost(3.12456192471+214.78356814630*x);
L1+=0.00000000889*cost(4.70508769146+148.07872442630*x);
L1+=0.00000000827*cost(6.08977582217+488.84961647110*x);
L1+=0.00000000889*cost(5.05124166027+220.46082654860*x);
L1+=0.00000000828*cost(6.27262544155+1382.88734684660*x);
L1+=0.00000001040*cost(5.76735098196+501.37978944330*x);
L1+=0.00000001103*cost(0.48706477230+692.58748435350*x);
L1+=0.00000000810*cost(2.50362385080+2310.72231481400*x);
L1+=0.00000000850*cost(4.55410385197+77.96299230500*x);
L1+=0.00000001108*cost(5.31792012163+235.39049596580*x);
L1+=0.00000000790*cost(0.89213206336+342.25536475310*x);
L1+=0.00000000775*cost(2.85873930879+211.81462272970*x);
L1+=0.00000000842*cost(2.99884993009+2737.32050569000*x);
L1+=0.00000000784*cost(0.05748459240+543.02428721890*x);
L1+=0.00000000754*cost(5.18317747668+244.31858407500*x);
L1+=0.00000000969*cost(1.31760425414+486.40193591630*x);
L1+=0.00000000943*cost(5.48641674428+339.28641933650*x);
L1+=0.00000000759*cost(6.25347177163+151.04766984290*x);
L1+=0.00000000710*cost(2.41619968810+247.23934538180*x);
L1+=0.00000000794*cost(2.59522645936+1.64453140270*x);
L1+=0.00000000857*cost(1.99318788624+248.72381809010*x);
L1+=0.00000000717*cost(4.56798357445+121.25202148330*x);
L1+=0.00000000671*cost(2.50955477476+444.75743814070*x);
L1+=0.00000000683*cost(5.51033310275+487.36514376280*x);
L1+=0.00000000684*cost(0.01892628603+228.27694896500*x);
L1+=0.00000000665*cost(1.47172657769+427.56139872250*x);
L1+=0.00000000761*cost(4.61079808671+23.57587323610*x);
L1+=0.00000000807*cost(3.21513718120+1898.35121793960*x);
L1+=0.00000000645*cost(1.92436523628+2950.61960112800*x);
L1+=0.00000000624*cost(6.05830190539+241.61027108930*x);
L1+=0.00000000699*cost(4.02804515616+425.63498302950*x);
L1+=0.00000000624*cost(5.85966148394+696.51963761660*x);
L1+=0.00000000620*cost(1.86426453489+2207.62954059540*x);
L1+=0.00000000641*cost(5.69868017561+319.57326339430*x);
L1+=0.00000000646*cost(3.78920578728+1038.04128918680*x);
L1+=0.00000000672*cost(2.54160055954+271.40591944890*x);
L1+=0.00000000768*cost(1.80484245332+2324.94940881560*x);
L1+=0.00000000737*cost(1.50539891226+268.43697403230*x);
L1+=0.00000000836*cost(1.26583811010+212.54833591260*x);
L1+=0.00000000753*cost(5.27536166240+204.70107572890*x);
L1+=0.00000000633*cost(2.19920009577+1802.37199072180*x);
L1+=0.00000000720*cost(2.58587107868+472.17484191470*x);
L1+=0.00000000683*cost(3.83223866420+43.28902917830*x);
L1+=0.00000000740*cost(6.21601938401+556.51766803760*x);
L1+=0.00000000795*cost(1.14460330178+381.35160823740*x);
L1+=0.00000000678*cost(3.65930963429+2097.42321937600*x);
L1+=0.00000000568*cost(5.92158661090+2428.04218303420*x);
L1+=0.00000000570*cost(1.18024241664+131.54696222180*x);
L1+=0.00000000566*cost(4.74157739398+380.12776796000*x);
L1+=0.00000000586*cost(5.71168743146+570.74476203920*x);
L1+=0.00000000550*cost(4.92413290959+188.92007304980*x);
L1+=0.00000000712*cost(2.69456114358+16.67477455640*x);
L1+=0.00000000545*cost(5.38725529600+206.23373254700*x);
L1+=0.00000000572*cost(5.79167804981+195.89060769870*x);
L1+=0.00000000602*cost(5.81756794592+963.40270297140*x);
L1+=0.00000000588*cost(4.25026865253+426.64637498580*x);
L1+=0.00000000563*cost(3.28295055824+193.65537546500*x);
L1+=0.00000000583*cost(5.44099997963+526.50957135690*x);
L1+=0.00000000679*cost(4.45748326743+105.54045477340*x);
L1+=0.00000000516*cost(5.99843937287+289.56516671360*x);
L1+=0.00000000520*cost(2.19322568805+180.16199464630*x);
L1+=0.00000000543*cost(4.19333695628+213.18722085340*x);
L1+=0.00000000586*cost(3.03470168346+6275.96230299060*x);
L1+=0.00000000572*cost(3.96788877624+140.00196957900*x);
L1+=0.00000000611*cost(4.15392239870+436.15941843160*x);
L1+=0.00000000505*cost(2.95739392583+135.54855145410*x);
L1+=0.00000000587*cost(4.55320395537+5863.59120611620*x);
L1+=0.00000000492*cost(2.71595874382+84.93352695390*x);
L1+=0.00000000576*cost(5.98300938454+9793.80090233580*x);
L1+=0.00000000489*cost(5.68450383182+533.62311835770*x);
L1+=0.00000000519*cost(3.09688510923+327.43756992050*x);
L1+=0.00000000486*cost(5.24220804875+5849.36411211460*x);
L1+=0.00000000475*cost(4.51295931678+411.62033734900*x);
L1+=0.00000000540*cost(4.44843952768+10206.17199921020*x);
L1+=0.00000000479*cost(0.87707794164+207.14875628370*x);
L1+=0.00000000468*cost(0.46572028197+306.09692891810*x);
L1+=0.00000000586*cost(0.86387928244+2538.24850425360*x);
L1+=0.00000000475*cost(6.19152982788+397.39324334740*x);
L1+=0.00000000541*cost(1.47958133221+42.53826965290*x);
L1+=0.00000000496*cost(6.07879620658+576.16138801060*x);
L1+=0.00000000447*cost(2.59259132013+7.22542158540*x);
L1+=0.00000000445*cost(5.06827300470+778.41478318470*x);
L1+=0.00000000560*cost(0.00461017471+221.37585028530*x);
L1+=0.00000000456*cost(4.60143715337+710.74673161820*x);
L1+=0.00000000449*cost(5.79223649465+685.47393735270*x);
L1+=0.00000000501*cost(1.91370965325+831.10498122420*x);
L1+=0.00000000595*cost(4.90329839607+824.74219374880*x);
L1+=0.00000000447*cost(4.88662794571+429.04587143080*x);
L1+=0.00000000445*cost(1.74764943142+525.75881183150*x);
L1+=0.00000000457*cost(0.80892712530+458.84151979040*x);
L1+=0.00000000543*cost(2.60317945475+213.41097002260*x);
L1+=0.00000000493*cost(0.61947189193+41.05379694460*x);
L1+=0.00000000455*cost(2.69847252264+3053.71237534660*x);
L1+=0.00000000429*cost(3.89071982978+92.79783348010*x);
L1+=0.00000000411*cost(1.34981168865+27.08733537390*x);
L1+=0.00000000448*cost(1.84775051361+980.66817835880*x);
L1+=0.00000000445*cost(4.21745990439+905.88657979150*x);
L1+=0.00000000403*cost(2.33067250642+2627.11418447060*x);
L1+=0.00000000404*cost(5.00179215709+431.26405732200*x);
L1+=0.00000000384*cost(1.65634584042+241.75328344120*x);
L1+=0.00000000410*cost(0.76907037678+395.57870223900*x);
L1+=0.00000000456*cost(1.98353741244+213.51154375910*x);
L1+=0.00000000459*cost(2.04878772547+285.63301345050*x);
L1+=0.00000000396*cost(5.04141834913+298.23262239190*x);
L1+=0.00000000377*cost(5.68073822097+2744.43405269080*x);
L1+=0.00000000415*cost(4.41600504868+179.35884549420*x);
L1+=0.00000000396*cost(4.29872851950+206.70681329900*x);
L1+=0.00000000389*cost(5.69091953122+849.26422848890*x);
L1+=0.00000000369*cost(1.36192003466+835.03713448730*x);
L1+=0.00000000374*cost(0.41402282126+9779.57380833420*x);
L1+=0.00000000379*cost(1.72255764532+184.98791978670*x);
L1+=0.00000000365*cost(5.88205574821+19.64371997300*x);
L1+=0.00000000456*cost(4.81297899859+213.08664711690*x);
L1+=0.00000000359*cost(1.06819138836+206.13736432740*x);
L1+=0.00000000367*cost(1.14184327929+569.04784100980*x);
L1+=0.00000000352*cost(3.04388401587+638.41281360570*x);
L1+=0.00000000463*cost(1.55834877017+421.18156490460*x);
L1+=0.00000000459*cost(5.34648461645+699.70103135430*x);
L1+=0.00000000383*cost(4.05921035379+739.80866679490*x);
L1+=0.00000000354*cost(1.09760553168+738.79727483860*x);
L1+=0.00000000382*cost(0.05348541587+252.65597135320*x);
L1+=0.00000000344*cost(1.18536656224+439.12836384820*x);
L1+=0.00000000382*cost(2.10483762147+532.61172640140*x);
L1+=0.00000000361*cost(0.50215018154+50.40257617910*x);
L1+=0.00000000351*cost(3.49546336297+1354.43315884340*x);
L1+=0.00000000395*cost(4.26278871560+432.22726516850*x);
L1+=0.00000000345*cost(2.38455893509+426.07692601420*x);
L1+=0.00000000350*cost(1.51541607946+259.76951835400*x);
L1+=0.00000000426*cost(5.29998227949+934.94851496820*x);
L1+=0.00000000339*cost(5.59774645356+519.39602435610*x);
L1+=0.00000000388*cost(3.40083809779+2413.81508903260*x);
L1+=0.00000000324*cost(3.68352014131+72.07328558160*x);
L1+=0.00000000323*cost(1.79597508586+405.99126305650*x);
L1+=0.00000000366*cost(3.56764349139+1119.18567522950*x);
L1+=0.00000000358*cost(4.11241839677+37.87240320690*x);
L1+=0.00000000423*cost(1.45116702108+2641.34127847220*x);
L1+=0.00000000314*cost(0.68465789313+757.21715453420*x);
L1+=0.00000000320*cost(3.12697568936+945.99421523210*x);
L1+=0.00000000338*cost(4.89782013581+898.77303279070*x);
L1+=0.00000000319*cost(5.76881401291+69.36497259590*x);
L1+=0.00000000310*cost(5.35598720822+815.06334611420*x);
L1+=0.00000000369*cost(4.46143610142+421.93232443000*x);
L1+=0.00000000311*cost(2.19275640712+5856.47765911540*x);
L1+=0.00000000306*cost(2.99917010799+1130.23137549340*x);
L1+=0.00000000330*cost(0.64102961163+558.00214074590*x);
L1+=0.00000000305*cost(0.40963115602+661.23792731640*x);
L1+=0.00000000320*cost(3.29267319940+760.25553592000*x);
L1+=0.00000000298*cost(5.48693246086+702.14871190910*x);
L1+=0.00000000352*cost(2.18179692198+2118.76386037840*x);
L1+=0.00000000299*cost(5.94980651345+572.22923474750*x);
L1+=0.00000000343*cost(2.62900083650+213.55972786890*x);
L1+=0.00000000296*cost(4.12563821701+73.29712585900*x);
L1+=0.00000000360*cost(2.94387423457+2214.74308759620*x);
L1+=0.00000000293*cost(5.71837797264+60.76695288680*x);
L1+=0.00000000326*cost(1.93806509331+480.77286162380*x);
L1+=0.00000000335*cost(2.60120542851+518.38463239980*x);
L1+=0.00000000322*cost(2.89685459163+427.11945573780*x);
L1+=0.00000000367*cost(2.20489848330+518.64526483070*x);
L1+=0.00000000361*cost(3.31464351282+630.33605875840*x);
L1+=0.00000000288*cost(0.87760478150+887.72733252680*x);
L1+=0.00000000290*cost(0.24071300709+705.11765732570*x);
L1+=0.00000000332*cost(5.96464701829+100.64509366380*x);
L1+=0.00000000284*cost(1.58760551116+681.54178408960*x);
L1+=0.00000000281*cost(1.68339116394+3267.01147078460*x);
L1+=0.00000000287*cost(3.54730637851+756.32338265690*x);
L1+=0.00000000331*cost(2.74250642576+22.89454967990*x);
L1+=0.00000000281*cost(4.79802388453+409.92341631960*x);
L1+=0.00000000372*cost(1.08754087151+426.55000676620*x);
L1+=0.00000000340*cost(0.59629116557+627.36711334180*x);
L1+=0.00000000325*cost(4.07319450014+511.53171782990*x);
L1+=0.00000000273*cost(0.71334827688+305.08553696180*x);
L1+=0.00000000272*cost(1.76124839309+945.24345570670*x);
L1+=0.00000000295*cost(4.00327005783+432.74853003030*x);
L1+=0.00000000271*cost(5.28903262032+1080.72257119160*x);
L1+=0.00000000276*cost(3.89192411657+610.69233878540*x);
L1+=0.00000000294*cost(2.80121651058+724.83081326790*x);
L1+=0.00000000319*cost(5.24824059915+229.97386999440*x);
L1+=0.00000000264*cost(2.36406383589+731.94436026870*x);
L1+=0.00000000288*cost(4.67818844930+170.76082578510*x);
L1+=0.00000000326*cost(3.81328980623+525.49817940060*x);
L1+=0.00000000283*cost(3.52027709716+319.31263096340*x);
L1+=0.00000000264*cost(0.25871603855+494.26624244250*x);
L1+=0.00000000261*cost(4.08135671345+25.86349509650*x);
L1+=0.00000000296*cost(4.49129913731+693.55069220000*x);
L1+=0.00000000292*cost(0.65370180027+25867.49049913539*x);
L1+=0.00000000292*cost(0.12510953311+25881.71759313700*x);
L1+=0.00000000254*cost(4.03912322565+990.22940591440*x);
L1+=0.00000000288*cost(3.98604904657+707.77778620160*x);
L1+=0.00000000285*cost(1.92328297431+3134.42687826260*x);
L1+=0.00000000284*cost(2.45411523294+3120.19978426100*x);
L1+=0.00000000256*cost(3.63282757780+430.79097657000*x);
L1+=0.00000000283*cost(2.51091647682+286.59622129700*x);
L1+=0.00000000325*cost(4.33261281211+732.69511979410*x);
L1+=0.00000000264*cost(0.05450228136+650.19222705250*x);
L1+=0.00000000273*cost(4.90735780421+409.18970313670*x);
L1+=0.00000000304*cost(4.61759348542+468.24268865160*x);
L1+=0.00000000285*cost(5.72467903890+33.94024994380*x);
L1+=0.00000000242*cost(5.28336514054+403.02231763990*x);
L1+=0.00000000270*cost(0.51583145648+263.70167161710*x);
L1+=0.00000000263*cost(4.81670787366+1055.44977692610*x);
L1+=0.00000000237*cost(2.92617048443+913.96333463880*x);
L1+=0.00000000246*cost(2.19675150666+2943.50605412720*x);
L1+=0.00000000278*cost(4.58404840578+398.14400287280*x);
L1+=0.00000000234*cost(2.64374114605+739.05790726950*x);
L1+=0.00000000229*cost(3.80445074468+58.10682401090*x);
L1+=0.00000000300*cost(2.06111081979+429.51895218280*x);
L1+=0.00000000223*cost(3.39888651505+188.02630117250*x);
L1+=0.00000000301*cost(2.96411385108+624.91943278700*x);
L1+=0.00000000221*cost(1.79137414078+2524.02141025200*x);
L1+=0.00000000220*cost(0.95686592581+1894.41906467650*x);
L1+=0.00000000225*cost(4.30669421945+637.44960575920*x);
L1+=0.00000000214*cost(1.70442143644+658.05653357870*x);
L1+=0.00000000227*cost(3.22613053351+638.93407846750*x);
L1+=0.00000000220*cost(2.66798936385+953.10776223290*x);
L1+=0.00000000253*cost(3.09377787768+29.20494752860*x);
L1+=0.00000000244*cost(3.15828383212+7.00167241620*x);
L1+=0.00000000295*cost(4.95843934543+714.67888488130*x);
L1+=0.00000000209*cost(0.94525938634+864.24208201590*x);
L1+=0.00000000216*cost(0.12221236180+28.57180808220*x);
L1+=0.00000000214*cost(2.80190604605+373.90799283650*x);
L1+=0.00000000212*cost(2.07343849515+1357.61455258110*x);
L1+=0.00000000216*cost(1.25531205533+477.80391620720*x);
L1+=0.00000000206*cost(5.35971491902+3060.82592234740*x);
L1+=0.00000000204*cost(3.08579410460+67.66805156650*x);
L1+=0.00000000210*cost(1.91489853604+938.12990870590*x);
L1+=0.00000000209*cost(1.46554109301+952.35700270750*x);
L1+=0.00000000202*cost(3.57670882297+334.55111692130*x);
L1+=0.00000000228*cost(5.66209641464+1699.27921650320*x);
L1+=0.00000000197*cost(4.61055255182+464.73122651380*x);
L1+=0.00000000193*cost(4.24606721746+141.69889060840*x);
L1+=0.00000000266*cost(0.69665031373+2854.64037391020*x);
L1+=0.00000000227*cost(1.31845358943+230.70758317730*x);
L1+=0.00000000192*cost(5.26739976413+504.56118318100*x);
L1+=0.00000000187*cost(0.85537192230+273.85360000370*x);
L1+=0.00000000199*cost(3.91291687807+418.52143602870*x);
L1+=0.00000000192*cost(6.15674105214+611.44309831080*x);
L1+=0.00000000210*cost(1.47873602747+205.43478891180*x);
L1+=0.00000000194*cost(2.37167703302+3370.10424500320*x);
L1+=0.00000000228*cost(2.15266015145+55.13787859430*x);
L1+=0.00000000201*cost(2.71380671608+586.31331639720*x);
L1+=0.00000000194*cost(3.29560033731+1670.82502850000*x);
L1+=0.00000000201*cost(4.23447633663+1493.09366806600*x);
L1+=0.00000000181*cost(3.61567262848+9786.68735533500*x);
L1+=0.00000000181*cost(2.83211558346+1262.38608488870*x);
L1+=0.00000000242*cost(4.69869158516+1141.13406340540*x);
L1+=0.00000000184*cost(4.66807336402+1251.34038462480*x);
L1+=0.00000000221*cost(2.25887876254+355.74874557180*x);
L1+=0.00000000200*cost(1.17340443616+4952.06359328620*x);
L1+=0.00000000222*cost(2.23360866067+2435.15573003500*x);
L1+=0.00000000175*cost(0.04701598422+107.75864066460*x);
L1+=0.00000000171*cost(5.02500742690+93.53154666300*x);
L1+=0.00000000184*cost(5.19723697138+835.78789401270*x);
L1+=0.00000000221*cost(4.49141283681+913.00012679230*x);
L1+=0.00000000195*cost(0.92088046109+551.03160609700*x);
L1+=0.00000000166*cost(5.01778115937+354.99798604640*x);
L1+=0.00000000165*cost(2.26267552932+406.95447090300*x);
L1+=0.00000000189*cost(0.31221126958+420.96911658350*x);
L1+=0.00000000196*cost(2.70333585839+774.48262992160*x);
L1+=0.00000000176*cost(6.12029409039+181.80652604900*x);
L1+=0.00000000172*cost(1.94132177757+3259.89792378380*x);
L1+=0.00000000160*cost(0.55319954265+5429.87946823940*x);
L1+=0.00000000161*cost(2.88623631474+184.84490743480*x);
L1+=0.00000000192*cost(0.26639534884+295.19424100610*x);
L1+=0.00000000167*cost(3.71345214172+1056.20053645150*x);
L1+=0.00000000195*cost(4.83926717598+1596.18644228460*x);
L1+=0.00000000156*cost(2.81916058733+428.08266358430*x);
L1+=0.00000000215*cost(1.88276472005+220.36445832900*x);
L1+=0.00000000167*cost(2.68872854428+423.67742956920*x);
L1+=0.00000000154*cost(1.66553954375+115.62294719080*x);
L1+=0.00000000175*cost(0.20216461467+384.05992122310*x);
L1+=0.00000000201*cost(4.38095931887+418.00017116690*x);
L1+=0.00000000167*cost(1.86485857353+393.46109008430*x);
L1+=0.00000000155*cost(0.92480392431+282.66406803390*x);
L1+=0.00000000146*cost(1.97663966745+9360.08916445900*x);
L1+=0.00000000160*cost(2.62483919699+353.30106501700*x);
L1+=0.00000000186*cost(1.37307151419+292.01284726840*x);
L1+=0.00000000198*cost(1.15631374887+2957.73314812880*x);
L1+=0.00000000144*cost(4.82956915076+453.42489381900*x);
L1+=0.00000000149*cost(3.60682821788+205.66428357540*x);
L1+=0.00000000147*cost(4.48377791879+81.89514556810*x);
L1+=0.00000000147*cost(5.74795037748+856.37777548970*x);
L1+=0.00000000142*cost(3.53823120158+212.02707105080*x);
L1+=0.00000000140*cost(0.70476909062+640.86049416050*x);
L1+=0.00000000139*cost(1.39047667205+1261.63532536330*x);
L1+=0.00000000153*cost(3.29559426243+391.17346822390*x);
L1+=0.00000000158*cost(1.79872341304+326.68681039510*x);
L1+=0.00000000174*cost(3.98677435872+1049.08698945070*x);
L1+=0.00000000171*cost(4.16825100469+213.03846300710*x);
L1+=0.00000000133*cost(4.74095454922+0.04818410980*x);
L1+=0.00000000155*cost(5.32313618730+2015.67108615980*x);
L1+=0.00000000158*cost(2.67557086253+2531.13495725280*x);
L1+=0.00000000158*cost(4.64622526567+427.34895040140*x);
L1+=0.00000000123*cost(2.20103444636+210.59078245230*x);
L1+=0.00000000160*cost(1.85888551524+201.51968199120*x);
L1+=0.00000000119*cost(3.12572799769+238.57188970350*x);
L1+=0.00000000120*cost(4.62897224203+203.26478713040*x);
L1+=0.00000000129*cost(4.92592016162+1286.90811962880*x);
L1+=0.00000000132*cost(3.44682160054+156.67674413540*x);
L1+=0.00000000143*cost(0.67951827513+425.84743135060*x);
L1+=0.00000000114*cost(5.46519773276+552.58551477450*x);
L1+=0.00000000132*cost(1.76335093671+432.01481684740*x);
L1+=0.00000000113*cost(0.68933513038+450.97721326420*x);
L1+=0.00000000128*cost(2.13986068877+2751.54759969160*x);
L1+=0.00000000123*cost(4.59695145319+216.00740842370*x);
L1+=0.00000000119*cost(1.04688666457+462.02291352810*x);
L1+=0.00000000108*cost(5.36873170289+3377.21779200400*x);
L1+=0.00000000142*cost(6.24626256472+299.12639426920*x);
L1+=0.00000000118*cost(0.63448253510+369.97583957340*x);
L1+=0.00000000105*cost(2.31570619675+200.55647414470*x);
L1+=0.00000000124*cost(1.87110815140+850.01498801430*x);
L1+=0.00000000106*cost(0.55623662570+114.39910691340*x);
L1+=0.00000000102*cost(3.95315219638+361.37781986430*x);
L1+=0.00000000095*cost(4.10658529323+10213.28554621100*x);
L1+=0.00000000097*cost(1.13534710734+387.24131496080*x);
L1+=0.00000000096*cost(4.46689094543+401.32539661050*x);
L1+=0.00000000119*cost(2.33636675091+318.83955021140*x);
L1+=0.00000000115*cost(3.37508073115+313.94418910180*x);
L1+=0.00000000106*cost(3.73586211650+220.93390730060*x);
L1+=0.00000000090*cost(0.59788492023+227.31374111850*x);
L1+=0.00000000103*cost(5.09172929383+213.45915413240*x);
L1+=0.00000000097*cost(5.95268532215+1044.40407666220*x);
L1+=0.00000000103*cost(1.70625660572+213.13903674360*x);
L1+=0.00000000080*cost(0.86872596168+233.90602325750*x);
L1+=0.00000000089*cost(5.35990932230+214.19286731530*x);
L1+=0.00000000080*cost(2.69565238975+540.73666535850*x);
L1+=0.00000000095*cost(1.19504849611+460.53844081980*x);
L1+=0.00000000105*cost(0.58624363205+481.73606947030*x);
L1+=0.00000000099*cost(2.68841109007+219.89137757700*x);
L1+=0.00000000098*cost(1.59923557478+484.70501488690*x);
L1+=0.00000000081*cost(1.12279793521+420.44785172170*x);
L1+=0.00000000075*cost(4.58892231446+394.35486196160*x);
L1+=0.00000000099*cost(4.68895851750+448.68959140380*x);
L1+=0.00000000076*cost(1.66929798365+196.03362005060*x);
L1+=0.00000000087*cost(3.12477195090+857.12853501510*x);
L1+=0.00000000078*cost(5.59819387460+364.34676528090*x);
L1+=0.00000000079*cost(3.53267171729+969.62247809490*x);

double L2=0;
L2+=0.00116441181*cost(1.17987850633+7.11354700080*x);
L2+=0.00091920844*cost(0.07425261094+213.29909543800*x);
L2+=0.00090592251;
L2+=0.00015276909*cost(4.06492007503+206.18554843720*x);
L2+=0.00010631396*cost(0.25778277414+220.41264243880*x);
L2+=0.00010604979*cost(5.40963595885+426.59819087600*x);
L2+=0.00004265368*cost(1.04595556630+14.22709400160*x);
L2+=0.00001215527*cost(2.91860042123+103.09277421860*x);
L2+=0.00001164684*cost(4.60942128971+639.89728631400*x);
L2+=0.00001081967*cost(5.69130351670+433.71173787680*x);
L2+=0.00001020079*cost(0.63369182642+3.18139373770*x);
L2+=0.00001044754*cost(4.04206453611+199.07200143640*x);
L2+=0.00000633582*cost(4.38825410036+419.48464387520*x);
L2+=0.00000549329*cost(5.57303134242+3.93215326310*x);
L2+=0.00000456914*cost(1.26840971349+110.20632121940*x);
L2+=0.00000425100*cost(0.20935499279+227.52618943960*x);
L2+=0.00000273739*cost(4.28841011784+95.97922721780*x);
L2+=0.00000161571*cost(1.38139149420+11.04570026390*x);
L2+=0.00000129494*cost(1.56586884170+309.27832265580*x);
L2+=0.00000117008*cost(3.88120915956+853.19638175200*x);
L2+=0.00000105415*cost(4.90003203599+647.01083331480*x);
L2+=0.00000100967*cost(0.89270493100+21.34064100240*x);
L2+=0.00000095227*cost(5.62561150598+412.37109687440*x);
L2+=0.00000081948*cost(1.02477558315+117.31986822020*x);
L2+=0.00000074857*cost(4.76178468163+210.11770170030*x);
L2+=0.00000082727*cost(6.05030934786+216.48048917570*x);
L2+=0.00000095659*cost(2.91093561539+316.39186965660*x);
L2+=0.00000063696*cost(0.35179804917+323.50541665740*x);
L2+=0.00000084860*cost(5.73472777961+209.36694217490*x);
L2+=0.00000060647*cost(4.87517850190+632.78373931320*x);
L2+=0.00000066459*cost(0.48297940601+10.29494073850*x);
L2+=0.00000067184*cost(0.45648612616+522.57741809380*x);
L2+=0.00000053281*cost(2.74730541387+529.69096509460*x);
L2+=0.00000045827*cost(5.69296621745+440.82528487760*x);
L2+=0.00000045293*cost(1.66856699796+202.25339517410*x);
L2+=0.00000042330*cost(5.70768187703+88.86568021700*x);
L2+=0.00000032140*cost(0.07050050346+63.73589830340*x);
L2+=0.00000031573*cost(1.67190022213+302.16477565500*x);
L2+=0.00000031150*cost(4.16379537691+191.95845443560*x);
L2+=0.00000024631*cost(5.65564728570+735.87651353180*x);
L2+=0.00000026558*cost(0.83256214407+224.34479570190*x);
L2+=0.00000020108*cost(5.94364609981+217.23124870110*x);
L2+=0.00000017511*cost(4.90014736798+625.67019231240*x);
L2+=0.00000017130*cost(1.62593421274+742.99006053260*x);
L2+=0.00000013744*cost(3.76497167300+195.13984817330*x);
L2+=0.00000012236*cost(4.71789723976+203.00415469950*x);
L2+=0.00000011940*cost(0.12620714199+234.63973644040*x);
L2+=0.00000016040*cost(0.57886320845+515.46387109300*x);
L2+=0.00000011154*cost(5.92216844780+536.80451209540*x);
L2+=0.00000014068*cost(0.20675293700+838.96928775040*x);
L2+=0.00000011013*cost(5.60207982774+728.76296653100*x);
L2+=0.00000011718*cost(3.12098483554+846.08283475120*x);
L2+=0.00000009962*cost(4.15472049127+860.30992875280*x);
L2+=0.00000010601*cost(3.20327613035+1066.49547719000*x);
L2+=0.00000010072*cost(0.25709351996+330.61896365820*x);
L2+=0.00000009490*cost(0.46379969328+956.28915597060*x);
L2+=0.00000010240*cost(4.98736656070+422.66603761290*x);
L2+=0.00000008287*cost(2.13990364272+269.92144674060*x);
L2+=0.00000007238*cost(5.39724715258+1052.26838318840*x);
L2+=0.00000007730*cost(5.24602742309+429.77958461370*x);
L2+=0.00000006353*cost(4.46211130731+284.14854074220*x);
L2+=0.00000005935*cost(5.40967847103+149.56319713460*x);
L2+=0.00000007550*cost(4.03401153929+9.56122755560*x);
L2+=0.00000005779*cost(4.29380891110+415.55249061210*x);
L2+=0.00000006082*cost(5.93416924841+405.25754987360*x);
L2+=0.00000005711*cost(0.01824076994+124.43341522100*x);
L2+=0.00000005676*cost(6.02235682150+223.59403617650*x);
L2+=0.00000004757*cost(4.92804854717+654.12438031560*x);
L2+=0.00000004727*cost(2.27461984667+18.15924726470*x);
L2+=0.00000004509*cost(4.40688707557+942.06206196900*x);
L2+=0.00000005621*cost(0.29694719379+127.47179660680*x);
L2+=0.00000005453*cost(5.53868222772+949.17560896980*x);
L2+=0.00000004130*cost(4.68673560379+74.78159856730*x);
L2+=0.00000004098*cost(5.30851262200+1045.15483618760*x);
L2+=0.00000004223*cost(2.89014939299+56.62235130260*x);
L2+=0.00000004887*cost(3.20022991216+277.03499374140*x);
L2+=0.00000003905*cost(3.30270187305+490.33408917940*x);
L2+=0.00000003923*cost(6.09732996823+81.75213321620*x);
L2+=0.00000003755*cost(4.93065184796+52.69019803950*x);
L2+=0.00000004602*cost(6.13908576681+1155.36115740700*x);
L2+=0.00000003714*cost(0.40648076787+137.03302416240*x);
L2+=0.00000003407*cost(4.28514461015+99.91138048090*x);
L2+=0.00000003579*cost(0.20402442077+1272.68102562720*x);
L2+=0.00000003946*cost(0.36500928968+12.53017297220*x);
L2+=0.00000003246*cost(1.56761884227+1059.38193018920*x);
L2+=0.00000004063*cost(0.29084229143+831.85574074960*x);
L2+=0.00000003688*cost(0.15467406177+437.64389113990*x);
L2+=0.00000002895*cost(3.13473183482+70.84944530420*x);
L2+=0.00000002800*cost(0.32727938074+191.20769491020*x);
L2+=0.00000002672*cost(1.87612402267+295.05122865420*x);
L2+=0.00000003454*cost(4.77197610696+423.41679713830*x);
L2+=0.00000002623*cost(5.15237415384+1368.66025284500*x);
L2+=0.00000002457*cost(3.89612890177+210.85141488320*x);
L2+=0.00000002461*cost(1.58522876760+32.24332891440*x);
L2+=0.00000002595*cost(3.59007068361+131.40394986990*x);
L2+=0.00000002289*cost(4.76825865118+351.81659230870*x);
L2+=0.00000002357*cost(5.83099000562+106.27416795630*x);
L2+=0.00000002221*cost(5.98277491515+6062.66320755260*x);
L2+=0.00000002221*cost(2.05930402282+6076.89030155420*x);
L2+=0.00000002183*cost(5.94985336393+145.63104387150*x);
L2+=0.00000002718*cost(3.37801252354+408.43894361130*x);
L2+=0.00000002288*cost(3.14000619320+22.09140052780*x);
L2+=0.00000002090*cost(1.12304173562+9992.87290377220*x);
L2+=0.00000002089*cost(3.48276230686+10007.09999777380*x);
L2+=0.00000002570*cost(5.12167203704+265.98929347750*x);
L2+=0.00000001835*cost(4.15379879659+1258.45393162560*x);
L2+=0.00000001820*cost(5.05340615445+1361.54670584420*x);
L2+=0.00000001760*cost(4.13532689228+107.02492748170*x);
L2+=0.00000001921*cost(4.51790997496+138.51749687070*x);
L2+=0.00000001707*cost(1.35864593280+231.45834270270*x);
L2+=0.00000001956*cost(5.87006093798+1471.75302706360*x);
L2+=0.00000002133*cost(5.23409848720+1265.56747862640*x);
L2+=0.00000001595*cost(5.61962698786+447.93883187840*x);
L2+=0.00000001609*cost(3.74893709671+628.85158605010*x);
L2+=0.00000001490*cost(0.48352404940+340.77089204480*x);
L2+=0.00000001560*cost(5.97095003614+430.53034413910*x);
L2+=0.00000001352*cost(0.71405348653+28.45418800320*x);
L2+=0.00000001355*cost(2.91219493604+215.74677599280*x);
L2+=0.00000001298*cost(5.84254169775+543.91805909620*x);
L2+=0.00000001664*cost(6.23834873469+1148.24761040620*x);
L2+=0.00000001205*cost(2.83373725021+200.76892246580*x);
L2+=0.00000001192*cost(3.52219428945+497.44763618020*x);
L2+=0.00000001122*cost(2.60571030270+1279.79457262800*x);
L2+=0.00000001217*cost(6.23528359211+1589.07289528380*x);
L2+=0.00000001420*cost(0.85079202155+6069.77675455340*x);
L2+=0.00000001120*cost(4.95656566453+1685.05212250160*x);
L2+=0.00000001010*cost(3.39689646619+1073.60902419080*x);
L2+=0.00000001352*cost(2.27575429523+9999.98645077300*x);
L2+=0.00000000979*cost(1.58571463442+1375.77379984580*x);
L2+=0.00000001159*cost(0.71823181781+508.35032409220*x);
L2+=0.00000001014*cost(2.40759054741+703.63318461740*x);
L2+=0.00000000956*cost(2.66256831556+134.58534360760*x);
L2+=0.00000001110*cost(1.19713920197+618.55664531160*x);
L2+=0.00000000945*cost(4.68155456977+362.86229257260*x);
L2+=0.00000000953*cost(4.20749172571+288.08069400530*x);
L2+=0.00000001033*cost(1.08781255146+184.84490743480*x);
L2+=0.00000000942*cost(2.43465223460+222.86032299360*x);
L2+=0.00000000909*cost(4.51769385360+38.13303563780*x);
L2+=0.00000001002*cost(1.38543153271+483.22054217860*x);
L2+=0.00000001082*cost(4.52832816548+635.96513305090*x);
L2+=0.00000001008*cost(4.91325851448+750.10360753340*x);
L2+=0.00000000862*cost(4.79998518474+1677.93857550080*x);
L2+=0.00000000828*cost(2.21940849017+333.65734504400*x);
L2+=0.00000000745*cost(3.97279299984+1574.84580128220*x);
L2+=0.00000000903*cost(5.58963782799+1788.14489672020*x);
L2+=0.00000000735*cost(2.28191723259+1162.47470440780*x);
L2+=0.00000000773*cost(5.82270096882+416.30325013750*x);
L2+=0.00000000734*cost(2.35356586018+120.35824960600*x);
L2+=0.00000000745*cost(4.84266000843+76.26607127560*x);
L2+=0.00000000765*cost(2.50840146722+343.21857259960*x);
L2+=0.00000000908*cost(5.01046293458+1581.95934828300*x);
L2+=0.00000000707*cost(3.66631544506+347.88443904560*x);
L2+=0.00000000870*cost(0.77106152694+113.38771495710*x);
L2+=0.00000000686*cost(2.88543836068+92.04707395470*x);
L2+=0.00000000673*cost(3.75650667651+203.73786788240*x);
L2+=0.00000000656*cost(3.77718582702+217.96496188400*x);
L2+=0.00000000675*cost(5.62875135263+17.26547538740*x);
L2+=0.00000000691*cost(0.21330089609+99.16062095550*x);
L2+=0.00000000786*cost(4.49318079175+643.07868005170*x);
L2+=0.00000000641*cost(0.67588390141+46.47042291600*x);
L2+=0.00000000663*cost(5.74837848383+721.64941953020*x);
L2+=0.00000000809*cost(5.94893988352+1464.63948006280*x);
L2+=0.00000000638*cost(4.86195439622+357.44566660120*x);
L2+=0.00000000740*cost(6.00053422445+337.73251065900*x);
L2+=0.00000000555*cost(4.95858934298+358.93013930950*x);
L2+=0.00000000581*cost(3.87669679805+565.11568774670*x);
L2+=0.00000000541*cost(1.22296838713+62.25142559510*x);
L2+=0.00000000697*cost(0.00715950269+1169.58825140860*x);
L2+=0.00000000524*cost(1.53830423608+195.89060769870*x);
L2+=0.00000000518*cost(5.41992758537+312.19908396260*x);
L2+=0.00000000626*cost(5.26580317026+436.89313161450*x);
L2+=0.00000000537*cost(6.17031657600+182.27960680100*x);
L2+=0.00000000574*cost(5.98607898826+1905.46476494040*x);
L2+=0.00000000541*cost(0.30589337713+98.89998852460*x);
L2+=0.00000000603*cost(3.26888470585+208.63322899200*x);
L2+=0.00000000504*cost(3.80930996688+168.05251279940*x);
L2+=0.00000000477*cost(3.56642391994+563.63121503840*x);
L2+=0.00000000511*cost(4.70719837179+2001.44399215820*x);
L2+=0.00000000475*cost(1.06025557585+5856.47765911540*x);
L2+=0.00000000540*cost(0.87230551412+1692.16566950240*x);
L2+=0.00000000454*cost(2.48128029368+9786.68735533500*x);
L2+=0.00000000456*cost(3.18303484133+218.92816973050*x);
L2+=0.00000000462*cost(0.71358186864+258.87574647670*x);
L2+=0.00000000424*cost(4.89778948357+636.71589257630*x);
L2+=0.00000000537*cost(2.59376221736+313.21047591890*x);
L2+=0.00000000410*cost(4.22147787617+867.42347575360*x);
L2+=0.00000000408*cost(3.06057772788+424.15051032120*x);
L2+=0.00000000407*cost(3.79376013938+24.37902238820*x);
L2+=0.00000000569*cost(3.68547825941+350.33211960040*x);
L2+=0.00000000404*cost(0.91401255827+114.13847448250*x);
L2+=0.00000000395*cost(3.50478374207+129.91947716160*x);
L2+=0.00000000395*cost(2.86309689622+212.33588759150*x);
L2+=0.00000000386*cost(5.00762729432+388.46515523820*x);
L2+=0.00000000393*cost(6.26835522096+241.75328344120*x);
L2+=0.00000000401*cost(4.60258908692+1994.33044515740*x);
L2+=0.00000000385*cost(0.91582119643+160.60889739850*x);
L2+=0.00000000467*cost(0.54876489832+404.50679034820*x);
L2+=0.00000000368*cost(0.35674031808+214.26230328450*x);
L2+=0.00000000471*cost(0.67360047481+207.88246946660*x);
L2+=0.00000000379*cost(0.92901327825+767.36908292080*x);
L2+=0.00000000420*cost(5.69797398044+225.82926841020*x);
L2+=0.00000000356*cost(3.10092792842+842.15068148810*x);
L2+=0.00000000428*cost(5.35375368944+2104.53676637680*x);
L2+=0.00000000422*cost(2.67975581832+77.96299230500*x);
L2+=0.00000000370*cost(5.46144813372+1038.04128918680*x);
L2+=0.00000000379*cost(5.56429091578+131.54696222180*x);
L2+=0.00000000441*cost(5.68196668399+1781.03134971940*x);
L2+=0.00000000361*cost(5.20616019966+629.60234557550*x);
L2+=0.00000000341*cost(5.92928351979+26.82670294300*x);
L2+=0.00000000419*cost(5.26851686707+85.82729883120*x);
L2+=0.00000000322*cost(0.80223983857+6283.07584999140*x);
L2+=0.00000000323*cost(3.86700993914+576.16138801060*x);
L2+=0.00000000321*cost(2.17186032970+10213.28554621100*x);
L2+=0.00000000355*cost(2.80560859177+344.70304530790*x);
L2+=0.00000000311*cost(3.77477255556+1891.23767093880*x);
L2+=0.00000000318*cost(5.22020784209+142.44965013380*x);
L2+=0.00000000315*cost(0.52272202855+5849.36411211460*x);
L2+=0.00000000428*cost(4.63722058283+1898.35121793960*x);
L2+=0.00000000337*cost(0.68198429948+45.57665103870*x);
L2+=0.00000000316*cost(0.54074780109+444.75743814070*x);
L2+=0.00000000310*cost(1.41032075652+273.10284047830*x);
L2+=0.00000000311*cost(3.53744556230+251.43213107580*x);
L2+=0.00000000295*cost(1.93253015677+436.15941843160*x);
L2+=0.00000000296*cost(1.97705648834+9779.57380833420*x);
L2+=0.00000000326*cost(3.67854047003+963.40270297140*x);
L2+=0.00000000389*cost(5.76841276132+39.35687591520*x);
L2+=0.00000000277*cost(5.73995694175+92.79783348010*x);
L2+=0.00000000315*cost(4.96371610197+757.21715453420*x);
L2+=0.00000000295*cost(1.81638833900+1493.09366806600*x);
L2+=0.00000000287*cost(0.97698377929+685.47393735270*x);
L2+=0.00000000281*cost(2.66463042095+1286.90811962880*x);
L2+=0.00000000330*cost(5.79776922760+650.94298657790*x);
L2+=0.00000000292*cost(3.97858181479+472.17484191470*x);
L2+=0.00000000266*cost(4.13716111320+601.76425067620*x);
L2+=0.00000000262*cost(0.91887592474+245.54242435240*x);
L2+=0.00000000278*cost(3.08964256591+778.41478318470*x);
L2+=0.00000000277*cost(3.08750916880+621.73803904930*x);
L2+=0.00000000255*cost(3.93981592051+181.05576652360*x);
L2+=0.00000000333*cost(2.04835822938+561.18353448360*x);
L2+=0.00000000247*cost(2.92754257675+219.44943459230*x);
L2+=0.00000000306*cost(0.36127922606+824.74219374880*x);
L2+=0.00000000253*cost(1.80130756458+5643.17856367740*x);
L2+=0.00000000337*cost(4.97764462199+175.16605980020*x);
L2+=0.00000000273*cost(0.66599369335+2008.55753915900*x);
L2+=0.00000000227*cost(4.87285356383+661.23792731640*x);
L2+=0.00000000249*cost(3.14202895058+144.14657116320*x);
L2+=0.00000000220*cost(3.93526603081+319.57326339430*x);
L2+=0.00000000212*cost(5.85248164087+546.95644048200*x);
L2+=0.00000000234*cost(1.65314711167+554.06998748280*x);
L2+=0.00000000204*cost(0.88373842674+31.49256938900*x);
L2+=0.00000000205*cost(2.93169866171+1596.18644228460*x);
L2+=0.00000000201*cost(3.36504567824+1080.72257119160*x);
L2+=0.00000000224*cost(4.34612745705+1382.88734684660*x);
L2+=0.00000000192*cost(5.13697232918+329.72519178090*x);
L2+=0.00000000208*cost(3.08549771485+41.64449777560*x);
L2+=0.00000000236*cost(0.07998742860+1141.13406340540*x);
L2+=0.00000000203*cost(4.13011580915+2627.11418447060*x);
L2+=0.00000000203*cost(0.13969067385+1485.98012106520*x);
L2+=0.00000000204*cost(3.38137545713+699.70103135430*x);
L2+=0.00000000212*cost(4.52370676085+2310.72231481400*x);
L2+=0.00000000218*cost(5.79277335862+2221.85663459700*x);
L2+=0.00000000213*cost(0.50441377637+934.94851496820*x);
L2+=0.00000000210*cost(5.04017633795+2420.92863603340*x);
L2+=0.00000000214*cost(4.64286758581+2317.83586181480*x);
L2+=0.00000000178*cost(0.84588580004+128.36556848410*x);
L2+=0.00000000170*cost(2.75006619605+710.74673161820*x);
L2+=0.00000000171*cost(4.32615182967+291.26208774300*x);
L2+=0.00000000172*cost(3.46971306920+501.37978944330*x);
L2+=0.00000000170*cost(1.05408992106+526.50957135690*x);
L2+=0.00000000162*cost(1.15683042950+519.39602435610*x);
L2+=0.00000000180*cost(4.96266204107+1670.82502850000*x);
L2+=0.00000000172*cost(1.65385549578+916.93228005540*x);
L2+=0.00000000170*cost(2.30821101766+429.04587143080*x);
L2+=0.00000000170*cost(5.98716489326+643.82943957710*x);
L2+=0.00000000173*cost(5.19933564968+1354.43315884340*x);
L2+=0.00000000195*cost(4.50165508529+2214.74308759620*x);
L2+=0.00000000156*cost(4.16290662749+572.22923474750*x);
L2+=0.00000000153*cost(1.23776248578+2413.81508903260*x);
L2+=0.00000000150*cost(0.63076983213+1478.86657406440*x);
L2+=0.00000000169*cost(4.28090123029+305.34616939270*x);
L2+=0.00000000174*cost(6.23077892653+3384.33133900480*x);
L2+=0.00000000149*cost(3.13274908516+9573.38825989700*x);
L2+=0.00000000162*cost(6.25601818345+213.25091132820*x);
L2+=0.00000000149*cost(4.81749019484+945.99421523210*x);
L2+=0.00000000162*cost(0.88610129190+216.21985674480*x);
L2+=0.00000000133*cost(2.31915371262+156.67674413540*x);
L2+=0.00000000165*cost(6.06456216591+732.69511979410*x);
L2+=0.00000000141*cost(6.14293754333+1795.25844372100*x);
L2+=0.00000000133*cost(0.06530337135+218.71572140940*x);
L2+=0.00000000162*cost(3.17058130506+213.34727954780*x);
L2+=0.00000000125*cost(2.07143636845+425.11371816770*x);
L2+=0.00000000146*cost(1.88627500632+211.81462272970*x);
L2+=0.00000000113*cost(2.79541965778+235.39049596580*x);
L2+=0.00000000117*cost(0.76464798684+479.28838891550*x);
L2+=0.00000000108*cost(3.95650672786+570.74476203920*x);
L2+=0.00000000106*cost(0.12820734703+188.02630117250*x);
L2+=0.00000000134*cost(3.58244908862+849.26422848890*x);
L2+=0.00000000114*cost(0.25990388555+398.14400287280*x);
L2+=0.00000000112*cost(2.39181495831+217.49188113200*x);
L2+=0.00000000091*cost(2.50716605179+121.25202148330*x);
L2+=0.00000000091*cost(1.75367948574+213.82036029980*x);
L2+=0.00000000088*cost(5.26121947108+395.57870223900*x);
L2+=0.00000000096*cost(3.98832609364+289.56516671360*x);
L2+=0.00000000091*cost(0.35318362186+312.45971639350*x);
L2+=0.00000000112*cost(1.14387590923+1802.37199072180*x);
L2+=0.00000000082*cost(3.73605217214+207.67002114550*x);
L2+=0.00000000082*cost(6.06283262812+210.37833413120*x);
L2+=0.00000000084*cost(3.34470673492+67.66805156650*x);
L2+=0.00000000086*cost(2.73917300180+5863.59120611620*x);
L2+=0.00000000083*cost(2.81499116485+776.93031047640*x);
L2+=0.00000000091*cost(1.26160093170+212.77783057620*x);
L2+=0.00000000090*cost(2.08722491981+2111.65031337760*x);
L2+=0.00000000080*cost(2.13136842916+421.93232443000*x);
L2+=0.00000000082*cost(4.16358350281+9793.80090233580*x);
L2+=0.00000000077*cost(2.96973341607+431.26405732200*x);
L2+=0.00000000079*cost(3.42790361067+417.03696332040*x);
L2+=0.00000000079*cost(3.18693585419+320.32402291970*x);
L2+=0.00000000080*cost(0.78975763683+204.70107572890*x);
L2+=0.00000000077*cost(1.89354243952+556.51766803760*x);
L2+=0.00000000073*cost(4.85923277221+2118.76386037840*x);
L2+=0.00000000071*cost(3.64551577433+198.32124191100*x);

double L3=0;
L3+=0.00016038734*cost(5.73945377424+7.11354700080*x);
L3+=0.00004249793*cost(4.58539675603+213.29909543800*x);
L3+=0.00001906524*cost(4.76082050205+220.41264243880*x);
L3+=0.00001465687*cost(5.91326678323+206.18554843720*x);
L3+=0.00001162041*cost(5.61973132428+14.22709400160*x);
L3+=0.00001066581*cost(3.60816533142+426.59819087600*x);
L3+=0.00000239377*cost(3.86088273439+433.71173787680*x);
L3+=0.00000236975*cost(5.76826451465+199.07200143640*x);
L3+=0.00000165641*cost(5.11641150216+3.18139373770*x);
L3+=0.00000131409*cost(4.74327544615+227.52618943960*x);
L3+=0.00000151352*cost(2.73594641861+639.89728631400*x);
L3+=0.00000061630*cost(4.74287052463+103.09277421860*x);
L3+=0.00000063365*cost(0.22850089497+419.48464387520*x);
L3+=0.00000040437*cost(5.47298059144+21.34064100240*x);
L3+=0.00000040205*cost(5.96420266720+95.97922721780*x);
L3+=0.00000038746*cost(5.83386199529+110.20632121940*x);
L3+=0.00000028025*cost(3.01235311514+647.01083331480*x);
L3+=0.00000025029*cost(0.98808170740+3.93215326310*x);
L3+=0.00000018101*cost(1.02506397063+412.37109687440*x);
L3+=0.00000017879*cost(3.31913418974+309.27832265580*x);
L3+=0.00000016208*cost(3.89825272754+440.82528487760*x);
L3+=0.00000015763*cost(5.61667809625+117.31986822020*x);
L3+=0.00000019014*cost(1.91614237463+853.19638175200*x);
L3+=0.00000018262*cost(4.96738415934+10.29494073850*x);
L3+=0.00000012947*cost(1.18068953942+88.86568021700*x);
L3+=0.00000017919*cost(4.20376505349+216.48048917570*x);
L3+=0.00000011453*cost(5.57520615096+11.04570026390*x);
L3+=0.00000010548*cost(5.92906266269+191.95845443560*x);
L3+=0.00000010389*cost(3.94838736947+209.36694217490*x);
L3+=0.00000008650*cost(3.39335369698+302.16477565500*x);
L3+=0.00000007580*cost(4.87736913157+323.50541665740*x);
L3+=0.00000006697*cost(0.38198725552+632.78373931320*x);
L3+=0.00000005864*cost(1.05621157685+210.11770170030*x);
L3+=0.00000005449*cost(4.64268475485+234.63973644040*x);
L3+=0.00000006327*cost(2.25492722762+522.57741809380*x);
L3+=0.00000003602*cost(2.30677010956+515.46387109300*x);
L3+=0.00000003229*cost(2.20309400066+860.30992875280*x);
L3-=0.00000003701;
L3+=0.00000002583*cost(4.93447677059+224.34479570190*x);
L3+=0.00000002543*cost(0.42393884183+625.67019231240*x);
L3+=0.00000002213*cost(3.19814958289+202.25339517410*x);
L3+=0.00000002421*cost(4.76621391814+330.61896365820*x);
L3+=0.00000002850*cost(0.58604395010+529.69096509460*x);
L3+=0.00000001965*cost(4.39525359412+124.43341522100*x);
L3+=0.00000002154*cost(1.35488209144+405.25754987360*x);
L3+=0.00000002296*cost(3.34809165905+429.77958461370*x);
L3+=0.00000002018*cost(3.06693569701+654.12438031560*x);
L3+=0.00000001979*cost(1.02981005658+728.76296653100*x);
L3+=0.00000001868*cost(3.09383546177+422.66603761290*x);
L3+=0.00000001846*cost(4.15225985450+536.80451209540*x);
L3+=0.00000002194*cost(1.18918501013+1066.49547719000*x);
L3+=0.00000002090*cost(4.15631351317+223.59403617650*x);
L3+=0.00000001481*cost(0.37916705169+316.39186965660*x);
L3+=0.00000001720*cost(5.82865773356+195.13984817330*x);
L3+=0.00000001460*cost(1.57663426355+81.75213321620*x);
L3+=0.00000001623*cost(6.03706764648+742.99006053260*x);
L3+=0.00000001286*cost(1.66154726117+63.73589830340*x);
L3+=0.00000001304*cost(5.02409881054+956.28915597060*x);
L3+=0.00000001446*cost(2.10575519127+838.96928775040*x);
L3+=0.00000001245*cost(3.88109752770+269.92144674060*x);
L3+=0.00000001018*cost(3.72599601656+295.05122865420*x);
L3+=0.00000001323*cost(1.38492882986+735.87651353180*x);
L3+=0.00000001318*cost(2.33460998999+217.23124870110*x);
L3+=0.00000000943*cost(2.75813531246+284.14854074220*x);
L3+=0.00000000906*cost(0.71155526266+846.08283475120*x);
L3+=0.00000000886*cost(3.83754799777+447.93883187840*x);
L3+=0.00000000943*cost(3.31480217015+18.15924726470*x);
L3+=0.00000000800*cost(4.71386673963+56.62235130260*x);
L3+=0.00000000908*cost(2.02119147951+831.85574074960*x);
L3+=0.00000000787*cost(0.80410269937+1045.15483618760*x);
L3+=0.00000000709*cost(4.27064410504+437.64389113990*x);
L3+=0.00000000651*cost(6.17565900032+942.06206196900*x);
L3+=0.00000000785*cost(2.40767785311+203.00415469950*x);
L3+=0.00000000702*cost(1.64585301418+423.41679713830*x);
L3+=0.00000000543*cost(2.86326941725+184.84490743480*x);
L3+=0.00000000532*cost(6.25762144463+1059.38193018920*x);
L3+=0.00000000521*cost(3.43013038466+149.56319713460*x);
L3+=0.00000000484*cost(4.88366060720+1272.68102562720*x);
L3+=0.00000000437*cost(5.40220619672+408.43894361130*x);
L3+=0.00000000388*cost(2.57589594168+508.35032409220*x);
L3+=0.00000000421*cost(4.05836524024+543.91805909620*x);
L3+=0.00000000375*cost(1.22747948298+2324.94940881560*x);
L3+=0.00000000347*cost(0.59237194522+22.09140052780*x);
L3+=0.00000000433*cost(1.69090148012+1155.36115740700*x);
L3+=0.00000000389*cost(1.46170367972+1073.60902419080*x);
L3+=0.00000000307*cost(1.82185086955+628.85158605010*x);
L3+=0.00000000409*cost(1.21858750514+1052.26838318840*x);
L3+=0.00000000309*cost(0.33610530663+6076.89030155420*x);
L3+=0.00000000309*cost(1.42279282226+6062.66320755260*x);
L3+=0.00000000340*cost(1.83325770310+1141.13406340540*x);
L3+=0.00000000303*cost(2.41584747330+127.47179660680*x);
L3+=0.00000000305*cost(5.34154702988+131.40394986990*x);
L3+=0.00000000298*cost(2.28594631393+635.96513305090*x);
L3+=0.00000000372*cost(1.03723911390+313.21047591890*x);
L3+=0.00000000338*cost(0.69100012338+1361.54670584420*x);
L3+=0.00000000325*cost(1.78816356937+1148.24761040620*x);
L3+=0.00000000322*cost(1.18628805010+721.64941953020*x);
L3+=0.00000000271*cost(2.45663156460+415.55249061210*x);
L3+=0.00000000251*cost(3.12046701975+1382.88734684660*x);
L3+=0.00000000254*cost(3.00353256829+618.55664531160*x);
L3+=0.00000000295*cost(0.35280179538+2730.20695868920*x);
L3+=0.00000000242*cost(1.52154324392+70.84944530420*x);
L3+=0.00000000296*cost(0.89576757167+2104.53676637680*x);
L3+=0.00000000264*cost(3.00987438634+661.23792731640*x);
L3+=0.00000000267*cost(0.31623829657+1677.93857550080*x);
L3+=0.00000000270*cost(2.56774718753+643.07868005170*x);
L3+=0.00000000261*cost(1.55058302472+1457.52593306200*x);
L3+=0.00000000246*cost(2.29214585472+867.42347575360*x);
L3+=0.00000000269*cost(3.18157515051+750.10360753340*x);
L3+=0.00000000272*cost(1.12208982319+1788.14489672020*x);
L3+=0.00000000256*cost(0.37673546414+1279.79457262800*x);
L3+=0.00000000206*cost(1.81129778306+497.44763618020*x);
L3+=0.00000000251*cost(0.61933213502+2413.81508903260*x);
L3+=0.00000000237*cost(3.35941544147+436.89313161450*x);
L3+=0.00000000247*cost(0.10102936687+99.91138048090*x);
L3+=0.00000000247*cost(0.93125798111+52.69019803950*x);
L3+=0.00000000221*cost(2.07880035795+824.74219374880*x);
L3+=0.00000000197*cost(6.16682223437+1258.45393162560*x);
L3+=0.00000000229*cost(5.57917534840+2943.50605412720*x);
L3+=0.00000000227*cost(0.43324651601+2737.32050569000*x);
L3+=0.00000000203*cost(4.12623986247+337.73251065900*x);
L3+=0.00000000214*cost(3.57607524509+934.94851496820*x);
L3+=0.00000000212*cost(1.25688162158+1773.91780271860*x);
L3+=0.00000000215*cost(0.88867647880+1038.04128918680*x);
L3+=0.00000000244*cost(5.51572084570+231.45834270270*x);
L3+=0.00000000181*cost(2.13821830481+416.30325013750*x);
L3+=0.00000000210*cost(4.19139167658+2221.85663459700*x);
L3+=0.00000000178*cost(2.91685344537+74.78159856730*x);
L3+=0.00000000201*cost(0.46214583002+2854.64037391020*x);
L3+=0.00000000236*cost(4.64388694899+1905.46476494040*x);
L3+=0.00000000199*cost(1.54991619669+1471.75302706360*x);
L3+=0.00000000199*cost(0.70725247497+2420.92863603340*x);
L3+=0.00000000162*cost(2.51488345020+430.53034413910*x);
L3+=0.00000000160*cost(1.23508694599+1596.18644228460*x);
L3+=0.00000000175*cost(4.14605894816+2090.30967237520*x);
L3+=0.00000000152*cost(0.05796022559+32.24332891440*x);
L3+=0.00000000176*cost(1.29002070623+490.33408917940*x);
L3+=0.00000000154*cost(3.60622857548+650.94298657790*x);
L3+=0.00000000185*cost(4.74969742128+319.57326339430*x);
L3+=0.00000000154*cost(1.54587199996+1464.63948006280*x);
L3+=0.00000000108*cost(4.25125786500+145.63104387150*x);
L3+=0.00000000106*cost(1.04047809351+1162.47470440780*x);
L3+=0.00000000114*cost(2.64055737100+362.86229257260*x);
L3+=0.00000000093*cost(3.36746275886+483.22054217860*x);
L3+=0.00000000091*cost(2.05796248692+210.85141488320*x);
L3+=0.00000000091*cost(4.53336314765+241.75328344120*x);
L3+=0.00000000072*cost(3.74361312157+1485.98012106520*x);
L3+=0.00000000076*cost(3.33892447677+195.89060769870*x);

double L4=0;
L4+=0.00001661894*cost(3.99826248978+7.11354700080*x);
L4+=0.00000257107*cost(2.98436499013+220.41264243880*x);
L4+=0.00000236344*cost(3.90241428075+14.22709400160*x);
L4+=0.00000149418*cost(2.74110824208+213.29909543800*x);
L4+=0.00000109598*cost(1.51515739251+206.18554843720*x);
L4-=0.00000113953;
L4+=0.00000068390*cost(1.72120953337+426.59819087600*x);
L4+=0.00000037699*cost(1.23795458356+199.07200143640*x);
L4+=0.00000040060*cost(2.04644897412+433.71173787680*x);
L4+=0.00000031219*cost(3.01094184090+227.52618943960*x);
L4+=0.00000015111*cost(0.82897064529+639.89728631400*x);
L4+=0.00000009444*cost(3.71485300868+21.34064100240*x);
L4+=0.00000005690*cost(2.41995290633+419.48464387520*x);
L4+=0.00000004470*cost(1.45120818748+95.97922721780*x);
L4+=0.00000005608*cost(1.15607095740+647.01083331480*x);
L4+=0.00000004463*cost(2.11783225176+440.82528487760*x);
L4+=0.00000003229*cost(4.09278077834+110.20632121940*x);
L4+=0.00000002871*cost(2.77203153866+412.37109687440*x);
L4+=0.00000002796*cost(3.00730249564+88.86568021700*x);
L4+=0.00000002638*cost(0.00255721254+853.19638175200*x);
L4+=0.00000002574*cost(0.39246854091+103.09277421860*x);
L4+=0.00000001862*cost(5.07955457727+309.27832265580*x);
L4+=0.00000002225*cost(3.77689198137+117.31986822020*x);
L4+=0.00000001769*cost(5.19176876406+302.16477565500*x);
L4+=0.00000001921*cost(2.82884328662+234.63973644040*x);
L4+=0.00000001805*cost(2.23816036743+216.48048917570*x);
L4+=0.00000001211*cost(1.54685246534+191.95845443560*x);
L4+=0.00000000765*cost(3.44501766503+323.50541665740*x);
L4+=0.00000000763*cost(4.83197222448+210.11770170030*x);
L4+=0.00000000613*cost(4.19052656353+515.46387109300*x);
L4+=0.00000000648*cost(2.28591710303+209.36694217490*x);
L4+=0.00000000616*cost(4.03194472161+522.57741809380*x);
L4+=0.00000000630*cost(2.37952532019+632.78373931320*x);
L4+=0.00000000639*cost(0.29772678242+860.30992875280*x);
L4+=0.00000000559*cost(2.17110060530+124.43341522100*x);
L4+=0.00000000442*cost(2.23500083592+447.93883187840*x);
L4+=0.00000000407*cost(5.44515970990+1066.49547719000*x);
L4+=0.00000000469*cost(1.26889429317+654.12438031560*x);
L4+=0.00000000488*cost(3.20329778617+405.25754987360*x);
L4+=0.00000000415*cost(3.12435410343+330.61896365820*x);
L4+=0.00000000442*cost(3.38933498625+81.75213321620*x);
L4+=0.00000000332*cost(4.12464206608+838.96928775040*x);
L4+=0.00000000320*cost(3.18332026736+529.69096509460*x);
L4+=0.00000000312*cost(1.40962796637+429.77958461370*x);
L4+=0.00000000291*cost(3.18885372262+1464.63948006280*x);
L4+=0.00000000333*cost(2.94355912397+728.76296653100*x);
L4+=0.00000000235*cost(3.67049647573+1148.24761040620*x);
L4+=0.00000000286*cost(2.57895004576+1045.15483618760*x);
L4+=0.00000000223*cost(3.57980034401+1155.36115740700*x);
L4+=0.00000000261*cost(2.04564143519+1677.93857550080*x);
L4+=0.00000000218*cost(2.61967125327+536.80451209540*x);
L4+=0.00000000262*cost(2.48322150677+625.67019231240*x);
L4+=0.00000000191*cost(4.39064160974+1574.84580128220*x);
L4+=0.00000000176*cost(1.26161895188+422.66603761290*x);
L4+=0.00000000190*cost(2.32693171200+223.59403617650*x);
L4+=0.00000000185*cost(1.08713469614+742.99006053260*x);
L4+=0.00000000168*cost(0.69946458053+824.74219374880*x);
L4+=0.00000000177*cost(5.02663339078+203.00415469950*x);
L4+=0.00000000218*cost(0.40426546037+867.42347575360*x);
L4+=0.00000000178*cost(3.67593243311+831.85574074960*x);
L4+=0.00000000175*cost(5.75326979098+1073.60902419080*x);
L4+=0.00000000156*cost(3.02120117572+1781.03134971940*x);
L4+=0.00000000148*cost(2.28313808274+295.05122865420*x);
L4+=0.00000000150*cost(3.48436135302+956.28915597060*x);
L4+=0.00000000152*cost(1.91404443241+942.06206196900*x);
L4+=0.00000000146*cost(6.16519696640+316.39186965660*x);
L4+=0.00000000096*cost(2.93247663741+224.34479570190*x);
L4+=0.00000000088*cost(4.48383632427+423.41679713830*x);

double L5=0;
L5+=0.00000123615*cost(2.25923345732+7.11354700080*x);
L5+=0.00000034190*cost(2.16250652689+14.22709400160*x);
L5+=0.00000027546*cost(1.19868150215+220.41264243880*x);
L5+=0.00000005818*cost(1.21584270184+227.52618943960*x);
L5+=0.00000005318*cost(0.23550400093+433.71173787680*x);
L5+=0.00000003677*cost(6.22669694355+426.59819087600*x);
L5+=0.00000003057*cost(2.97372046322+199.07200143640*x);
L5+=0.00000002861*cost(4.28710932685+206.18554843720*x);
L5+=0.00000001617*cost(6.25265362286+213.29909543800*x);
L5+=0.00000001279*cost(5.27612561266+639.89728631400*x);
L5+=0.00000000932*cost(5.56741549127+647.01083331480*x);
L5+=0.00000000756*cost(6.17716234487+191.95845443560*x);
L5+=0.00000000760*cost(0.69475544472+302.16477565500*x);
L5+=0.00000001038*cost(0.23516951637+440.82528487760*x);
L5-=0.00000001007;
L5+=0.00000000549*cost(4.87733288264+88.86568021700*x);
L5+=0.00000000504*cost(4.77955496203+419.48464387520*x);
L5+=0.00000000346*cost(4.31847547394+853.19638175200*x);
L5+=0.00000000392*cost(5.69922389094+654.12438031560*x);
L5+=0.00000000242*cost(2.05052677361+323.50541665740*x);
L5+=0.00000000266*cost(1.11384528244+234.63973644040*x);
L5+=0.00000000199*cost(0.88505901097+309.27832265580*x);
L5+=0.00000000258*cost(5.10074489186+95.97922721780*x);
L5+=0.00000000166*cost(2.40063312194+515.46387109300*x);
L5+=0.00000000155*cost(4.70433216164+860.30992875280*x);
L5+=0.00000000089*cost(1.36371070380+412.37109687440*x);
L5+=0.00000000102*cost(0.49450039082+117.31986822020*x);

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
double rtd=180/3.141592653589793;

return rtd*trunc2(L0+L1*x+L2*x2+L3*x3+L4*x4+L5*x5); //END Saturn
}


//Heliocentric latitude of Saturn
double Bsaturn(double x)
{
double  Bx0=0;
 Bx0+=0.04330678040*cost(3.60284428399+213.29909543800*x);
 Bx0+=0.00240348303*cost(2.85238489390+426.59819087600*x);
 Bx0+=0.00084745939;
 Bx0+=0.00030863357*cost(3.48441504465+220.41264243880*x);
 Bx0+=0.00034116063*cost(0.57297307844+206.18554843720*x);
 Bx0+=0.00014734070*cost(2.11846597870+639.89728631400*x);
 Bx0+=0.00009916668*cost(5.79003189405+419.48464387520*x);
 Bx0+=0.00006993564*cost(4.73604689179+7.11354700080*x);
 Bx0+=0.00004807587*cost(5.43305315602+316.39186965660*x);
 Bx0+=0.00004788392*cost(4.96512927420+110.20632121940*x);
 Bx0+=0.00003432125*cost(2.73255752123+433.71173787680*x);
 Bx0+=0.00001506129*cost(6.01304536144+103.09277421860*x);
 Bx0+=0.00001060298*cost(5.63099292414+529.69096509460*x);
 Bx0+=0.00000969071*cost(5.20434966103+632.78373931320*x);
 Bx0+=0.00000942050*cost(1.39646678088+853.19638175200*x);
 Bx0+=0.00000707645*cost(3.80302329547+323.50541665740*x);
 Bx0+=0.00000552313*cost(5.13149109045+202.25339517410*x);
 Bx0+=0.00000399675*cost(3.35891413961+227.52618943960*x);
 Bx0+=0.00000316063*cost(1.99716764199+647.01083331480*x);
 Bx0+=0.00000319380*cost(3.62571550980+209.36694217490*x);
 Bx0+=0.00000284494*cost(4.88648481625+224.34479570190*x);
 Bx0+=0.00000314225*cost(0.46510272410+217.23124870110*x);
 Bx0+=0.00000236442*cost(2.13887472281+11.04570026390*x);
 Bx0+=0.00000215354*cost(5.94982610103+846.08283475120*x);
 Bx0+=0.00000208522*cost(2.12003893769+415.55249061210*x);
 Bx0+=0.00000178958*cost(2.95361514672+63.73589830340*x);
 Bx0+=0.00000207213*cost(0.73021462851+199.07200143640*x);
 Bx0+=0.00000139140*cost(1.99821990940+735.87651353180*x);
 Bx0+=0.00000134884*cost(5.24500819605+742.99006053260*x);
 Bx0+=0.00000140585*cost(0.64417620299+490.33408917940*x);
 Bx0+=0.00000121669*cost(3.11537140876+522.57741809380*x);
 Bx0+=0.00000139240*cost(4.59535168021+14.22709400160*x);
 Bx0+=0.00000115524*cost(3.10891547171+216.48048917570*x);
 Bx0+=0.00000114218*cost(0.96261442133+210.11770170030*x);
 Bx0+=0.00000096376*cost(4.48164339766+117.31986822020*x);
 Bx0+=0.00000080593*cost(1.31692750150+277.03499374140*x);
 Bx0+=0.00000072952*cost(3.05988482370+536.80451209540*x);
 Bx0+=0.00000069261*cost(4.92378633635+309.27832265580*x);
 Bx0+=0.00000074302*cost(2.89376539620+149.56319713460*x);
 Bx0+=0.00000068040*cost(2.18002263974+351.81659230870*x);
 Bx0+=0.00000061734*cost(0.67728106562+1066.49547719000*x);
 Bx0+=0.00000056598*cost(2.60963391288+440.82528487760*x);
 Bx0+=0.00000048864*cost(5.78725874107+95.97922721780*x);
 Bx0+=0.00000048243*cost(2.18211837430+74.78159856730*x);
 Bx0+=0.00000038304*cost(5.29151303843+1059.38193018920*x);
 Bx0+=0.00000036323*cost(1.63348365121+628.85158605010*x);
 Bx0+=0.00000035055*cost(1.71279210041+1052.26838318840*x);
 Bx0+=0.00000034270*cost(2.45740470599+422.66603761290*x);
 Bx0+=0.00000034313*cost(5.97994514798+412.37109687440*x);
 Bx0+=0.00000033787*cost(1.14073392951+949.17560896980*x);
 Bx0+=0.00000031633*cost(4.14722153007+437.64389113990*x);
 Bx0+=0.00000036833*cost(6.27769966148+1162.47470440780*x);
 Bx0+=0.00000026980*cost(1.27154816810+860.30992875280*x);
 Bx0+=0.00000023516*cost(2.74936525342+838.96928775040*x);
 Bx0+=0.00000023460*cost(0.98962849901+210.85141488320*x);
 Bx0+=0.00000023600*cost(4.11386961467+3.93215326310*x);
 Bx0+=0.00000023631*cost(3.07427204313+215.74677599280*x);
 Bx0+=0.00000020813*cost(3.51084686918+330.61896365820*x);
 Bx0+=0.00000019509*cost(2.81857577372+127.47179660680*x);
 Bx0+=0.00000017103*cost(3.89784279922+214.26230328450*x);
 Bx0+=0.00000017635*cost(6.19715516746+703.63318461740*x);
 Bx0+=0.00000017824*cost(2.28524493886+388.46515523820*x);
 Bx0+=0.00000020935*cost(0.14356167048+430.53034413910*x);
 Bx0+=0.00000016551*cost(1.66649120724+38.13303563780*x);
 Bx0+=0.00000019100*cost(2.97699096081+137.03302416240*x);
 Bx0+=0.00000015517*cost(4.54798410406+956.28915597060*x);
 Bx0+=0.00000017065*cost(0.16611115812+212.33588759150*x);
 Bx0+=0.00000014169*cost(0.48937283445+213.34727954780*x);
 Bx0+=0.00000019027*cost(6.27326062836+423.41679713830*x);
 Bx0+=0.00000013344*cost(2.37136126257+429.77958461370*x);
 Bx0+=0.00000012565*cost(1.03178071173+563.63121503840*x);
 Bx0+=0.00000014173*cost(3.57477564831+213.25091132820*x);
 Bx0+=0.00000011374*cost(1.45300927024+1368.66025284500*x);
 Bx0+=0.00000010585*cost(6.17633425930+200.76892246580*x);
 Bx0+=0.00000010600*cost(3.84358958373+138.51749687070*x);
 Bx0+=0.00000010263*cost(2.17423692422+76.26607127560*x);
 Bx0+=0.00000010072*cost(1.33197220789+565.11568774670*x);
 Bx0+=0.00000012058*cost(0.44149242700+222.86032299360*x);
 Bx0+=0.00000010367*cost(1.85278552549+350.33211960040*x);
 Bx0+=0.00000008706*cost(2.58144528603+1155.36115740700*x);
 Bx0+=0.00000008470*cost(1.97890349826+625.67019231240*x);
 Bx0+=0.00000008518*cost(4.51649648578+3.18139373770*x);
 Bx0+=0.00000007439*cost(4.92597321442+212.77783057620*x);
 Bx0+=0.00000007409*cost(2.03506679104+288.08069400530*x);
 Bx0+=0.00000008137*cost(3.98500592467+85.82729883120*x);
 Bx0+=0.00000007985*cost(2.20794292064+362.86229257260*x);
 Bx0+=0.00000006610*cost(6.14944028835+417.03696332040*x);
 Bx0+=0.00000007753*cost(6.23664549070+1478.86657406440*x);
 Bx0+=0.00000006318*cost(1.87388481013+654.12438031560*x);
 Bx0+=0.00000006319*cost(1.17328438271+1265.56747862640*x);
 Bx0+=0.00000005841*cost(2.35829915285+750.10360753340*x);
 Bx0+=0.00000005808*cost(5.01602242794+479.28838891550*x);
 Bx0+=0.00000008079*cost(0.42574715104+554.06998748280*x);
 Bx0+=0.00000006014*cost(5.58952234348+425.11371816770*x);
 Bx0+=0.00000007444*cost(5.41859596459+213.82036029980*x);
 Bx0+=0.00000007567*cost(2.68446523795+191.20769491020*x);
 Bx0+=0.00000007421*cost(4.19354269508+9.56122755560*x);
 Bx0+=0.00000005466*cost(3.21737829505+234.63973644040*x);
 Bx0+=0.00000005661*cost(1.46982713550+265.98929347750*x);
 Bx0+=0.00000005851*cost(4.81776629912+1.48447270830*x);
 Bx0+=0.00000005341*cost(3.45755372717+203.73786788240*x);
 Bx0+=0.00000004960*cost(1.04628615559+12.53017297220*x);
 Bx0+=0.00000004920*cost(3.85622235967+173.94221952280*x);
 Bx0+=0.00000004883*cost(1.94823282939+195.13984817330*x);
 Bx0+=0.00000005621*cost(0.81869581274+52.69019803950*x);
 Bx0+=0.00000005200*cost(3.32827437636+515.46387109300*x);
 Bx0+=0.00000004927*cost(3.81806549732+225.82926841020*x);
 Bx0+=0.00000005033*cost(0.10756875163+252.65597135320*x);
 Bx0+=0.00000004416*cost(5.45506938037+408.43894361130*x);
 Bx0+=0.00000004169*cost(1.21145214135+1685.05212250160*x);
 Bx0+=0.00000004066*cost(6.24213578122+1279.79457262800*x);
 Bx0+=0.00000003972*cost(6.13850317719+217.49188113200*x);
 Bx0+=0.00000005398*cost(5.67212179194+1375.77379984580*x);
 Bx0+=0.00000003916*cost(5.96105725915+210.37833413120*x);
 Bx0+=0.00000004017*cost(0.99840226682+842.15068148810*x);
 Bx0+=0.00000003899*cost(4.58983662507+1272.68102562720*x);
 Bx0+=0.00000003764*cost(3.30663337976+212.54833591260*x);
 Bx0+=0.00000004345*cost(3.18562241830+414.06801790380*x);
 Bx0+=0.00000003565*cost(4.75262007127+207.88246946660*x);
 Bx0+=0.00000003542*cost(2.30814954338+1471.75302706360*x);
 Bx0+=0.00000003732*cost(1.61040235688+635.96513305090*x);
 Bx0+=0.00000003709*cost(2.97082943086+223.59403617650*x);
 Bx0+=0.00000003576*cost(3.83436862558+483.22054217860*x);
 Bx0+=0.00000004053*cost(3.72105017218+942.06206196900*x);
 Bx0+=0.00000003756*cost(0.74987556308+214.04985496340*x);
 Bx0+=0.00000003162*cost(3.64550741000+207.67002114550*x);
 Bx0+=0.00000003149*cost(2.27647454229+728.76296653100*x);
 Bx0+=0.00000003971*cost(4.37874143597+216.21985674480*x);
 Bx0+=0.00000003541*cost(5.62281936827+218.71572140940*x);
 Bx0+=0.00000002965*cost(3.40117024932+650.94298657790*x);
 Bx0+=0.00000003949*cost(4.19728912450+209.10630974400*x);
 Bx0+=0.00000002853*cost(4.81077453523+231.45834270270*x);
 Bx0+=0.00000002826*cost(0.86682282341+217.96496188400*x);
 Bx0+=0.00000002970*cost(5.75162134301+160.60889739850*x);
 Bx0+=0.00000002724*cost(0.47941267764+497.44763618020*x);
 Bx0+=0.00000002787*cost(4.03144791896+62.25142559510*x);
 Bx0+=0.00000002605*cost(5.04152791794+65.22037101170*x);
 Bx0+=0.00000002652*cost(0.30602610654+424.15051032120*x);
 Bx0+=0.00000002543*cost(2.76499056123+543.91805909620*x);
 Bx0+=0.00000002485*cost(5.78396049817+99.16062095550*x);
 Bx0+=0.00000003209*cost(0.42853440759+218.92816973050*x);
 Bx0+=0.00000002509*cost(2.94704589100+70.84944530420*x);
 Bx0+=0.00000002308*cost(0.63861650866+251.43213107580*x);
 Bx0+=0.00000002869*cost(4.31959346745+767.36908292080*x);
 Bx0+=0.00000002232*cost(0.56929937568+1073.60902419080*x);
 Bx0+=0.00000002245*cost(1.69945964547+488.84961647110*x);
 Bx0+=0.00000002283*cost(1.55589787463+601.76425067620*x);
 Bx0+=0.00000002384*cost(4.44583493310+21.34064100240*x);
 Bx0+=0.00000002096*cost(5.77425542767+88.86568021700*x);
 Bx0+=0.00000002363*cost(3.35786310868+124.43341522100*x);
 Bx0+=0.00000002162*cost(6.24029269257+1795.25844372100*x);
 Bx0+=0.00000002452*cost(3.19804814047+208.63322899200*x);
 Bx0+=0.00000002033*cost(4.87029603776+327.43756992050*x);
 Bx0+=0.00000001950*cost(5.56004000293+18.15924726470*x);
 Bx0+=0.00000002283*cost(4.22375355881+22.09140052780*x);
 Bx0+=0.00000002217*cost(4.61433094630+302.16477565500*x);
 Bx0+=0.00000001888*cost(5.45600788064+142.44965013380*x);
 Bx0+=0.00000002075*cost(3.55622165076+1169.58825140860*x);
 Bx0+=0.00000002069*cost(2.75786819366+491.81856188770*x);
 Bx0+=0.00000001810*cost(5.96568495526+213.18722085340*x);
 Bx0+=0.00000001813*cost(1.39785500313+211.81462272970*x);
 Bx0+=0.00000001843*cost(1.15001484281+203.00415469950*x);
 Bx0+=0.00000001854*cost(1.41350087782+1581.95934828300*x);
 Bx0+=0.00000001697*cost(3.23613719814+427.56139872250*x);
 Bx0+=0.00000001736*cost(5.45933992115+916.93228005540*x);
 Bx0+=0.00000001714*cost(6.14729146384+643.82943957710*x);
 Bx0+=0.00000001948*cost(5.70817363392+425.63498302950*x);
 Bx0+=0.00000001770*cost(3.36194411768+248.72381809010*x);
 Bx0+=0.00000001611*cost(0.97888081762+2001.44399215820*x);
 Bx0+=0.00000001971*cost(2.59654430358+429.04587143080*x);
 Bx0+=0.00000001628*cost(0.74011617198+177.87437278590*x);
 Bx0+=0.00000001564*cost(2.04342011485+1788.14489672020*x);
 Bx0+=0.00000001574*cost(6.01995224314+426.64637498580*x);
 Bx0+=0.00000001939*cost(5.48134669380+636.71589257630*x);
 Bx0+=0.00000001651*cost(4.61629429952+621.73803904930*x);
 Bx0+=0.00000001552*cost(2.55542734908+692.58748435350*x);
 Bx0+=0.00000001484*cost(6.17173980637+56.62235130260*x);
 Bx0+=0.00000001782*cost(3.26122906302+175.16605980020*x);
 Bx0+=0.00000001503*cost(2.59953333916+228.27694896500*x);
 Bx0+=0.00000001559*cost(0.36281050773+776.93031047640*x);
 Bx0+=0.00000001799*cost(3.46395976970+1258.45393162560*x);
 Bx0+=0.00000001521*cost(3.75588462293+213.51154375910*x);
 Bx0+=0.00000001810*cost(4.37552745264+213.41097002260*x);
 Bx0+=0.00000001521*cost(0.30214462385+213.08664711690*x);
 Bx0+=0.00000001608*cost(4.66724132818+269.92144674060*x);
 Bx0+=0.00000001525*cost(1.47939329423+198.32124191100*x);
 Bx0+=0.00000001408*cost(1.38491846750+501.37978944330*x);
 Bx0+=0.00000001327*cost(0.23760037979+148.07872442630*x);
 Bx0+=0.00000001305*cost(2.41201772023+275.55052103310*x);
 Bx0+=0.00000001578*cost(2.82443242444+426.55000676620*x);
 Bx0+=0.00000001203*cost(1.36928065935+235.39049596580*x);
 Bx0+=0.00000001296*cost(5.75203277385+1692.16566950240*x);
 Bx0+=0.00000001295*cost(3.04090959062+831.85574074960*x);
 Bx0+=0.00000001283*cost(1.62400181159+643.07868005170*x);
 Bx0+=0.00000001617*cost(1.31181209458+214.78356814630*x);
 Bx0+=0.00000001346*cost(4.01262069353+278.51946644970*x);
 Bx0+=0.00000001166*cost(0.09590019561+340.77089204480*x);
 Bx0+=0.00000001115*cost(2.20460481017+221.37585028530*x);
 Bx0+=0.00000001176*cost(1.07528227869+312.19908396260*x);
 Bx0+=0.00000001107*cost(1.50329021421+289.56516671360*x);
 Bx0+=0.00000001143*cost(4.40125874383+213.55972786890*x);
 Bx0+=0.00000001253*cost(0.21632769953+404.50679034820*x);
 Bx0+=0.00000001074*cost(3.17412275025+98.89998852460*x);
 Bx0+=0.00000001103*cost(0.23626839162+617.80588578620*x);
 Bx0+=0.00000001077*cost(3.51670933532+312.45971639350*x);
 Bx0+=0.00000001039*cost(0.53953974796+778.41478318470*x);
 Bx0+=0.00000001195*cost(2.11232088496+205.22234059070*x);
 Bx0+=0.00000001093*cost(5.16243153571+630.33605875840*x);
 Bx0+=0.00000001143*cost(5.93977485365+213.03846300710*x);
 Bx0+=0.00000001040*cost(4.79631324365+106.27416795630*x);
 Bx0+=0.00000001100*cost(0.02509241739+219.44943459230*x);
 Bx0+=0.00000001311*cost(5.93900415785+436.15941843160*x);
 Bx0+=0.00000001260*cost(0.72481995446+355.74874557180*x);
 Bx0+=0.00000000950*cost(2.00801292252+1045.15483618760*x);
 Bx0+=0.00000001186*cost(1.84906064486+151.04766984290*x);
 Bx0+=0.00000000974*cost(3.01092368346+696.51963761660*x);
 Bx0+=0.00000000924*cost(4.88158186437+39.35687591520*x);
 Bx0+=0.00000000961*cost(2.80113869315+738.79727483860*x);
 Bx0+=0.00000001011*cost(6.27004359435+121.25202148330*x);
 Bx0+=0.00000000904*cost(4.15218356485+426.07692601420*x);
 Bx0+=0.00000000904*cost(4.24232505252+10.29494073850*x);
 Bx0+=0.00000000895*cost(2.47587956888+447.93883187840*x);
 Bx0+=0.00000001186*cost(0.85270715988+525.49817940060*x);
 Bx0+=0.00000000824*cost(3.97540449663+210.59078245230*x);
 Bx0+=0.00000000831*cost(4.05299295705+207.14875628370*x);
 Bx0+=0.00000000937*cost(5.44353432307+344.70304530790*x);
 Bx0+=0.00000000823*cost(2.08766677969+358.93013930950*x);
 Bx0+=0.00000000971*cost(5.09512804595+1589.07289528380*x);
 Bx0+=0.00000001037*cost(1.04152859909+2.44768055480*x);
 Bx0+=0.00000000816*cost(0.62175655307+188.92007304980*x);
 Bx0+=0.00000000798*cost(3.36396062989+237.67811782620*x);
 Bx0+=0.00000000755*cost(5.90983584858+284.14854074220*x);
 Bx0+=0.00000000870*cost(1.62765846893+114.13847448250*x);
 Bx0+=0.00000000734*cost(6.23523714922+2111.65031337760*x);
 Bx0+=0.00000000767*cost(2.73651219269+627.36711334180*x);
 Bx0+=0.00000000701*cost(0.72526525525+10213.28554621100*x);
 Bx0+=0.00000000801*cost(5.84130533519+905.88657979150*x);
 Bx0+=0.00000000710*cost(1.78740818763+2104.53676637680*x);
 Bx0+=0.00000000670*cost(0.75839374890+2317.83586181480*x);
 Bx0+=0.00000000720*cost(4.95645178898+638.41281360570*x);
 Bx0+=0.00000000796*cost(4.87623914638+342.25536475310*x);
 Bx0+=0.00000000703*cost(0.35096991676+220.46082654860*x);
 Bx0+=0.00000000835*cost(3.19492825640+1574.84580128220*x);
 Bx0+=0.00000000824*cost(0.08813665925+216.00740842370*x);
 Bx0+=0.00000000653*cost(4.19599635390+247.23934538180*x);
 Bx0+=0.00000000826*cost(4.66845240923+427.11945573780*x);
 Bx0+=0.00000000690*cost(0.41873449575+5856.47765911540*x);
 Bx0+=0.00000000690*cost(1.34023204821+6283.07584999140*x);
 Bx0+=0.00000000690*cost(0.58291546593+213.45915413240*x);
 Bx0+=0.00000000639*cost(1.20304559619+867.42347575360*x);
 Bx0+=0.00000000830*cost(1.57233214789+1898.35121793960*x);
 Bx0+=0.00000000753*cost(1.51187970880+576.16138801060*x);
 Bx0+=0.00000000629*cost(2.83598833891+420.96911658350*x);
 Bx0+=0.00000000690*cost(3.48062808501+213.13903674360*x);
 Bx0+=0.00000000600*cost(5.22938546212+212.02707105080*x);
 Bx0+=0.00000000565*cost(5.28099337758+423.67742956920*x);
 Bx0+=0.00000000552*cost(5.83265103738+84.34282612290*x);
 Bx0+=0.00000000546*cost(3.56588711151+1485.98012106520*x);
 Bx0+=0.00000000642*cost(6.15007145598+179.35884549420*x);
 Bx0+=0.00000000697*cost(1.91977327925+134.58534360760*x);
 Bx0+=0.00000000648*cost(5.15917450752+8.07675484730*x);
 Bx0+=0.00000000551*cost(3.33109164145+980.66817835880*x);
 Bx0+=0.00000000511*cost(3.87073988213+125.98732389850*x);
 Bx0+=0.00000000506*cost(0.80261216855+181.05576652360*x);
 Bx0+=0.00000000564*cost(4.05871107615+831.10498122420*x);
 Bx0+=0.00000000681*cost(3.45804290093+220.36445832900*x);
 Bx0+=0.00000000541*cost(2.39252901431+421.93232443000*x);
 Bx0+=0.00000000498*cost(3.11515053568+439.12836384820*x);
 Bx0+=0.00000000517*cost(2.75430004800+1148.24761040620*x);
 Bx0+=0.00000000491*cost(4.47199498503+558.00214074590*x);
 Bx0+=0.00000000467*cost(4.18144797677+444.75743814070*x);
 Bx0+=0.00000000458*cost(0.60848440253+206.23373254700*x);
 Bx0+=0.00000000542*cost(3.28613020157+245.54242435240*x);
 Bx0+=0.00000000477*cost(5.48556902348+35.42472265210*x);
 Bx0+=0.00000000474*cost(2.42545073874+436.89313161450*x);
 Bx0+=0.00000000481*cost(3.72498040536+206.13736432740*x);
 Bx0+=0.00000000435*cost(1.61732308614+191.95845443560*x);
 Bx0+=0.00000000488*cost(0.26059969650+416.30325013750*x);
 Bx0+=0.00000000493*cost(4.13699180247+518.64526483070*x);
 Bx0+=0.00000000595*cost(5.11706007934+214.57111982520*x);
 Bx0+=0.00000000486*cost(5.17710069856+67.66805156650*x);
 Bx0+=0.00000000463*cost(5.53192185211+418.52143602870*x);
 Bx0+=0.00000000421*cost(5.57377685121+430.79097657000*x);
 Bx0+=0.00000000446*cost(6.20735049659+73.29712585900*x);
 Bx0+=0.00000000421*cost(4.65837340438+543.02428721890*x);
 Bx0+=0.00000000435*cost(2.95256554350+5.41662597140*x);
 Bx0+=0.00000000416*cost(4.36391909218+113.38771495710*x);
 Bx0+=0.00000000495*cost(5.38121485133+391.17346822390*x);
 Bx0+=0.00000000520*cost(3.99939347071+618.55664531160*x);
 Bx0+=0.00000000429*cost(3.26903461513+144.14657116320*x);
 Bx0+=0.00000000435*cost(1.60816661416+2214.74308759620*x);
 Bx0+=0.00000000398*cost(2.38329818919+299.12639426920*x);
 Bx0+=0.00000000399*cost(0.06301179341+206.70681329900*x);
 Bx0+=0.00000000394*cost(2.75496219113+425.84743135060*x);
 Bx0+=0.00000000508*cost(2.86873328929+337.73251065900*x);
 Bx0+=0.00000000475*cost(5.68530292289+320.32402291970*x);
 Bx0+=0.00000000432*cost(0.68132398291+116.42609634290*x);
 Bx0+=0.00000000404*cost(1.84249441289+9786.68735533500*x);
 Bx0+=0.00000000371*cost(5.83382962844+2008.55753915900*x);
 Bx0+=0.00000000382*cost(4.24995364794+387.24131496080*x);
 Bx0+=0.00000000416*cost(3.81986946256+429.51895218280*x);
 Bx0+=0.00000000491*cost(4.18623117082+219.89137757700*x);
 Bx0+=0.00000000352*cost(1.65610545221+963.40270297140*x);
 Bx0+=0.00000000353*cost(5.50209003460+305.34616939270*x);
 Bx0+=0.00000000431*cost(4.39380503963+353.30106501700*x);
 Bx0+=0.00000000375*cost(2.67828133567+319.57326339430*x);
 Bx0+=0.00000000359*cost(3.54801032661+421.18156490460*x);
 Bx0+=0.00000000339*cost(5.19074405462+69.15252427480*x);
 Bx0+=0.00000000358*cost(1.11857595997+1044.40407666220*x);
 Bx0+=0.00000000334*cost(1.84260994740+1361.54670584420*x);
 Bx0+=0.00000000328*cost(6.07106596408+710.74673161820*x);
 Bx0+=0.00000000328*cost(1.48618893585+2420.92863603340*x);
 Bx0+=0.00000000359*cost(5.62797136991+78.71375183040*x);
 Bx0+=0.00000000405*cost(2.91366762549+1891.23767093880*x);
 Bx0+=0.00000000398*cost(2.08900381937+4.66586644600*x);
 Bx0+=0.00000000326*cost(1.62373774313+5.62907429250*x);
 Bx0+=0.00000000405*cost(1.87470341223+114.39910691340*x);
 Bx0+=0.00000000393*cost(0.56487847337+128.95626931510*x);
 Bx0+=0.00000000312*cost(5.29291124448+347.88443904560*x);
 Bx0+=0.00000000310*cost(0.31232452686+427.34895040140*x);
 Bx0+=0.00000000308*cost(2.84912656825+487.36514376280*x);
 Bx0+=0.00000000291*cost(3.25977762780+494.26624244250*x);
 Bx0+=0.00000000303*cost(4.93962873690+373.90799283650*x);
 Bx0+=0.00000000289*cost(2.83591185309+212.07525516060*x);
 Bx0+=0.00000000289*cost(2.05371431350+214.52293571540*x);
 Bx0+=0.00000000398*cost(6.03822674845+432.22726516850*x);
 Bx0+=0.00000000288*cost(6.16001418475+969.62247809490*x);
 Bx0+=0.00000000296*cost(0.30332524090+1055.44977692610*x);
 Bx0+=0.00000000280*cost(1.29728455136+241.61027108930*x);
 Bx0+=0.00000000280*cost(5.41630221077+1493.09366806600*x);
 Bx0+=0.00000000315*cost(6.24003908326+465.95506679120*x);
 Bx0+=0.00000000274*cost(5.03981944861+458.84151979040*x);
 Bx0+=0.00000000296*cost(3.04457317761+211.60217440860*x);
 Bx0+=0.00000000274*cost(2.72607352851+145.63104387150*x);
 Bx0+=0.00000000293*cost(1.32452002382+159.12442469020*x);
 Bx0+=0.00000000263*cost(6.11559198968+2428.04218303420*x);
 Bx0+=0.00000000323*cost(1.17502395659+815.06334611420*x);
 Bx0+=0.00000000345*cost(5.37083374878+428.08266358430*x);
 Bx0+=0.00000000258*cost(0.43205106363+2634.22773147140*x);
 Bx0+=0.00000000275*cost(0.91628212149+849.26422848890*x);
 Bx0+=0.00000000340*cost(1.29378813067+329.72519178090*x);
 Bx0+=0.00000000294*cost(4.29399534634+4.19278569400*x);
 Bx0+=0.00000000339*cost(1.03883773894+32.24332891440*x);
 Bx0+=0.00000000244*cost(3.52504227332+184.98791978670*x);
 Bx0+=0.00000000243*cost(3.13047989401+525.75881183150*x);
 Bx0+=0.00000000260*cost(5.99216785208+20.60692781950*x);
 Bx0+=0.00000000303*cost(3.96772261614+934.94851496820*x);
 Bx0+=0.00000000285*cost(5.69474711283+220.93390730060*x);
 Bx0+=0.00000000239*cost(2.09516779457+292.01284726840*x);
 Bx0+=0.00000000242*cost(0.98744748894+282.45161971280*x);
 Bx0+=0.00000000278*cost(2.81667003542+87.31177153950*x);
 Bx0+=0.00000000285*cost(4.76303256917+54.17467074780*x);
 Bx0+=0.00000000236*cost(5.79560286324+280.96714700450*x);
 Bx0+=0.00000000246*cost(1.83689902078+214.99601646740*x);
 Bx0+=0.00000000221*cost(0.48302467341+153.49535039770*x);
 Bx0+=0.00000000238*cost(3.52738705554+267.47376618580*x);
 Bx0+=0.00000000293*cost(5.91401607974+14.97785352700*x);
 Bx0+=0.00000000235*cost(0.29884419224+14.01464568050*x);
 Bx0+=0.00000000229*cost(3.91975580405+182.27960680100*x);
 Bx0+=0.00000000217*cost(3.96328561940+894.84087952760*x);
 Bx0+=0.00000000218*cost(1.46057992688+2531.13495725280*x);
 Bx0+=0.00000000210*cost(2.01138855049+211.86280683950*x);
 Bx0+=0.00000000210*cost(2.87823761610+214.73538403650*x);
 Bx0+=0.00000000223*cost(2.49651288358+1464.63948006280*x);
 Bx0+=0.00000000217*cost(4.03234048538+835.03713448730*x);
 Bx0+=0.00000000209*cost(2.97542058241+273.10284047830*x);
 Bx0+=0.00000000210*cost(2.56849303008+593.42686339800*x);
 Bx0+=0.00000000218*cost(1.71859101510+0.96320784650*x);
 Bx0+=0.00000000232*cost(1.86083014117+221.16340196420*x);
 Bx0+=0.00000000199*cost(3.53454927143+219.66188291340*x);
 Bx0+=0.00000000197*cost(2.65338829617+864.24208201590*x);
 Bx0+=0.00000000219*cost(3.46267185338+1182.92157353290*x);
 Bx0+=0.00000000199*cost(2.56046317223+264.50482076920*x);
 Bx0+=0.00000000199*cost(2.03508708900+757.21715453420*x);
 Bx0+=0.00000000237*cost(5.05443109284+254.94359321360*x);
 Bx0+=0.00000000191*cost(2.07106909876+756.32338265690*x);
 Bx0+=0.00000000192*cost(1.67985944172+1677.93857550080*x);
 Bx0+=0.00000000191*cost(1.05067348453+702.14871190910*x);
 Bx0+=0.00000000181*cost(1.89151852263+6.15033915430*x);
 Bx0+=0.00000000205*cost(1.98151360584+199.28444975750*x);
 Bx0+=0.00000000181*cost(1.25381796494+2737.32050569000*x);
 Bx0+=0.00000000186*cost(2.81416016738+569.04784100980*x);
 Bx0+=0.00000000215*cost(4.52373060846+3060.82592234740*x);
 Bx0+=0.00000000222*cost(2.90133577623+205.43478891180*x);
 Bx0+=0.00000000246*cost(3.55891849574+1251.34038462480*x);
 Bx0+=0.00000000191*cost(4.20221553993+556.51766803760*x);
 Bx0+=0.00000000217*cost(2.64509967170+2207.62954059540*x);
 Bx0+=0.00000000225*cost(0.14271906959+131.40394986990*x);
 Bx0+=0.00000000189*cost(1.27260556263+192.69216761850*x);
 Bx0+=0.00000000179*cost(6.15189171649+2.92076130680*x);
 Bx0+=0.00000000178*cost(2.01622328964+705.11765732570*x);
 Bx0+=0.00000000181*cost(3.62483757675+233.90602325750*x);
 Bx0+=0.00000000188*cost(2.92836809840+227.31374111850*x);
 Bx0+=0.00000000164*cost(3.50682537694+1382.88734684660*x);
 Bx0+=0.00000000166*cost(5.85452227121+637.44960575920*x);
 Bx0+=0.00000000160*cost(0.13309484488+431.26405732200*x);
 Bx0+=0.00000000158*cost(5.92242110049+96.87299909510*x);
 Bx0+=0.00000000178*cost(4.55557913565+46.47042291600*x);
 Bx0+=0.00000000157*cost(1.35908014451+51.20572533120*x);
 Bx0+=0.00000000155*cost(6.24092514222+464.73122651380*x);
 Bx0+=0.00000000155*cost(6.02684189458+1286.90811962880*x);
 Bx0+=0.00000000155*cost(1.36669731999+206.93630796260*x);
 Bx0+=0.00000000175*cost(4.95121713507+1905.46476494040*x);
 Bx0+=0.00000000153*cost(6.06094547271+561.18353448360*x);
 Bx0+=0.00000000208*cost(4.50537355579+24.37902238820*x);
 Bx0+=0.00000000185*cost(5.49802440713+205.66428357540*x);
 Bx0+=0.00000000160*cost(4.18196878816+3340.61242669980*x);
 Bx0+=0.00000000160*cost(2.85370771355+209.15449385380*x);
 Bx0+=0.00000000161*cost(4.98020340619+2648.45482547300*x);
 Bx0+=0.00000000152*cost(0.85558875667+570.74476203920*x);
 Bx0+=0.00000000156*cost(2.03601440129+217.44369702220*x);
 Bx0+=0.00000000192*cost(3.98017256784+212.40532356070*x);
 Bx0+=0.00000000192*cost(0.90945359875+214.19286731530*x);
 Bx0+=0.00000000198*cost(3.54289000289+533.62311835770*x);
 Bx0+=0.00000000160*cost(2.51522796187+3127.31333126180*x);
 Bx0+=0.00000000145*cost(0.93414637377+1994.33044515740*x);
 Bx0+=0.00000000141*cost(5.66801998888+120.35824960600*x);
 Bx0+=0.00000000141*cost(3.88995778619+454.90936652730*x);
 Bx0+=0.00000000152*cost(1.01453902153+2840.41327990860*x);
 Bx0+=0.00000000172*cost(4.15145223592+2.96894541660*x);
 Bx0+=0.00000000146*cost(5.26789260159+7.06536289100*x);
 Bx0+=0.00000000177*cost(0.43196690516+140.00196957900*x);
 Bx0+=0.00000000144*cost(3.95680110579+300.61086697750*x);
 Bx0+=0.00000000152*cost(4.29475572258+555.55446019110*x);
 Bx0+=0.00000000143*cost(4.15264164139+31.01948863700*x);
 Bx0+=0.00000000138*cost(4.20096561019+731.94436026870*x);
 Bx0+=0.00000000139*cost(0.79924371385+166.82867252200*x);
 Bx0+=0.00000000135*cost(1.27192121638+92.94084583200*x);
 Bx0+=0.00000000165*cost(1.94881873062+107.02492748170*x);
 Bx0+=0.00000000153*cost(3.07590434707+3480.31056622260*x);
 Bx0+=0.00000000125*cost(3.41796878361+1802.37199072180*x);
 Bx0+=0.00000000128*cost(5.83700968658+2324.94940881560*x);
 Bx0+=0.00000000129*cost(2.75851443754+480.77286162380*x);
 Bx0+=0.00000000122*cost(4.75728514255+2854.64037391020*x);
 Bx0+=0.00000000129*cost(4.67730374872+913.96333463880*x);
 Bx0+=0.00000000121*cost(1.19957548726+572.22923474750*x);
 Bx0+=0.00000000146*cost(3.71232877850+546.95644048200*x);
 Bx0+=0.00000000120*cost(4.59083886034+339.28641933650*x);
 Bx0+=0.00000000127*cost(6.19372294369+59.80374504030*x);
 Bx0+=0.00000000123*cost(5.98484393970+477.80391620720*x);
 Bx0+=0.00000000122*cost(5.82973501131+990.22940591440*x);
 Bx0+=0.00000000151*cost(2.39413061881+2524.02141025200*x);
 Bx0+=0.00000000147*cost(4.98199291770+850.01498801430*x);
 Bx0+=0.00000000127*cost(0.47350572907+6.59228213900*x);
 Bx0+=0.00000000116*cost(4.71488890981+1130.23137549340*x);
 Bx0+=0.00000000129*cost(5.42665311725+2538.24850425360*x);
 Bx0+=0.00000000111*cost(4.51520219898+1699.27921650320*x);
 Bx0+=0.00000000114*cost(2.06120434865+952.09637027660*x);
 Bx0+=0.00000000112*cost(4.14736642579+422.40540518200*x);
 Bx0+=0.00000000111*cost(5.53230411085+857.12853501510*x);
 Bx0+=0.00000000109*cost(3.00005651288+420.44785172170*x);
 Bx0+=0.00000000112*cost(2.20667724213+395.57870223900*x);
 Bx0+=0.00000000147*cost(1.52324472511+552.58551477450*x);
 Bx0+=0.00000000118*cost(5.47495367121+2957.73314812880*x);
 Bx0+=0.00000000113*cost(2.57036693965+462.02291352810*x);
 Bx0+=0.00000000122*cost(4.96246567897+638.93407846750*x);
 Bx0+=0.00000000104*cost(1.91139383428+472.17484191470*x);
 Bx0+=0.00000000116*cost(2.82742160564+450.97721326420*x);
 Bx0+=0.00000000115*cost(2.26043201622+1781.03134971940*x);
 Bx0+=0.00000000110*cost(4.86686492403+2914.01423582380*x);
 Bx0+=0.00000000109*cost(4.43848727280+405.99126305650*x);
 Bx0+=0.00000000102*cost(5.90112611078+99.91138048090*x);
 Bx0+=0.00000000101*cost(2.53392410330+640.86049416050*x);
 Bx0+=0.00000000112*cost(5.53802838779+381.35160823740*x);
 Bx0+=0.00000000099*cost(5.92199927896+411.62033734900*x);
 Bx0+=0.00000000100*cost(5.21941099517+426.48631629140*x);
 Bx0+=0.00000000137*cost(2.20269111622+7.16173111060*x);
 Bx0+=0.00000000097*cost(1.27914551364+2847.52682690940*x);
 Bx0+=0.00000000115*cost(5.22953781515+1119.18567522950*x);
 Bx0+=0.00000000095*cost(4.26135357007+540.73666535850*x);
 Bx0+=0.00000000098*cost(5.27107833435+639.94547042380*x);
 Bx0+=0.00000000107*cost(4.38879925113+412.58354519550*x);
 Bx0+=0.00000000093*cost(5.35954173624+334.55111692130*x);
 Bx0+=0.00000000094*cost(1.16749092536+5643.17856367740*x);
 Bx0+=0.00000000106*cost(4.19443004843+486.40193591630*x);
 Bx0+=0.00000000096*cost(0.59816870672+714.67888488130*x);
 Bx0+=0.00000000094*cost(0.54205024076+423.62924545940*x);
 Bx0+=0.00000000109*cost(2.82817225044+468.24268865160*x);
 Bx0+=0.00000000083*cost(6.12100285205+380.12776796000*x);
 Bx0+=0.00000000084*cost(2.20217125255+909.81873305460*x);
 Bx0+=0.00000000085*cost(5.20920130934+562.14674233010*x);
 Bx0+=0.00000000105*cost(2.66415710279+460.53844081980*x);
 Bx0+=0.00000000084*cost(0.14646013561+681.54178408960*x);
 Bx0+=0.00000000080*cost(3.03551986945+409.92341631960*x);
 Bx0+=0.00000000097*cost(5.09373549436+92.04707395470*x);
 Bx0+=0.00000000110*cost(2.03622569317+642.34496686880*x);
 Bx0+=0.00000000080*cost(5.71035549752+361.37781986430*x);
 Bx0+=0.00000000084*cost(3.00961145133+426.81063919710*x);
 Bx0+=0.00000000085*cost(4.28770375688+135.54855145410*x);
 Bx0+=0.00000000093*cost(5.32943472274+432.01481684740*x);
 Bx0+=0.00000000086*cost(1.51247258028+760.25553592000*x);
 Bx0+=0.00000000084*cost(5.83905303748+426.38574255490*x);
 Bx0+=0.00000000100*cost(3.62925349363+426.71006546060*x);
 Bx0+=0.00000000094*cost(4.30151510535+3377.21779200400*x);
 Bx0+=0.00000000098*cost(2.07334671974+639.84910220420*x);
 Bx0+=0.00000000080*cost(4.11576173565+774.48262992160*x);
 Bx0+=0.00000000075*cost(2.89122656610+806.72595883600*x);
 Bx0+=0.00000000080*cost(0.88468467902+856.37777548970*x);
 Bx0+=0.00000000072*cost(4.85259171933+392.65794093220*x);
 Bx0+=0.00000000083*cost(0.11133738383+402.21916848780*x);

double B1=0;
B1+=0.00397554998*cost(5.33289992556+213.29909543800*x);
B1-=0.00049478641;
B1+=0.00018571607*cost(6.09919206378+426.59819087600*x);
B1+=0.00014800587*cost(2.30586060520+206.18554843720*x);
B1+=0.00009643981*cost(1.69674660120+220.41264243880*x);
B1+=0.00003757161*cost(1.25429514018+419.48464387520*x);
B1+=0.00002716647*cost(5.91166664787+639.89728631400*x);
B1+=0.00001455309*cost(0.85161616532+433.71173787680*x);
B1+=0.00001290595*cost(2.91770857090+7.11354700080*x);
B1+=0.00000852630*cost(0.43572078997+316.39186965660*x);
B1+=0.00000284386*cost(1.61881754773+227.52618943960*x);
B1+=0.00000292185*cost(5.31574251270+853.19638175200*x);
B1+=0.00000275090*cost(3.88864137336+103.09277421860*x);
B1+=0.00000297726*cost(0.91909206723+632.78373931320*x);
B1+=0.00000172359*cost(0.05215146556+647.01083331480*x);
B1+=0.00000127731*cost(1.20711452525+529.69096509460*x);
B1+=0.00000166237*cost(2.44351613165+199.07200143640*x);
B1+=0.00000158220*cost(5.20850125766+110.20632121940*x);
B1+=0.00000109839*cost(2.45695551627+217.23124870110*x);
B1+=0.00000081759*cost(2.75839171353+210.11770170030*x);
B1+=0.00000081010*cost(2.86038377187+14.22709400160*x);
B1+=0.00000068658*cost(1.65537623146+202.25339517410*x);
B1+=0.00000059281*cost(1.82410768234+323.50541665740*x);
B1+=0.00000065161*cost(1.25527521313+216.48048917570*x);
B1+=0.00000061024*cost(1.25273412095+209.36694217490*x);
B1+=0.00000046386*cost(0.81534705304+440.82528487760*x);
B1+=0.00000036163*cost(1.81851057689+224.34479570190*x);
B1+=0.00000034041*cost(2.83971297997+117.31986822020*x);
B1+=0.00000032164*cost(1.18676132343+846.08283475120*x);
B1+=0.00000033114*cost(1.30557080010+412.37109687440*x);
B1+=0.00000027282*cost(4.64744847591+1066.49547719000*x);
B1+=0.00000022805*cost(4.12923703368+415.55249061210*x);
B1+=0.00000027128*cost(4.44228739187+11.04570026390*x);
B1+=0.00000018100*cost(5.56392353608+860.30992875280*x);
B1+=0.00000020851*cost(1.40999273740+309.27832265580*x);
B1+=0.00000014947*cost(1.34302610607+95.97922721780*x);
B1+=0.00000015316*cost(1.22393617996+63.73589830340*x);
B1+=0.00000014601*cost(1.00753704970+536.80451209540*x);
B1+=0.00000012842*cost(2.27059911053+742.99006053260*x);
B1+=0.00000012832*cost(4.88898877901+522.57741809380*x);
B1+=0.00000013137*cost(2.45991904379+490.33408917940*x);
B1+=0.00000011883*cost(1.87308666696+423.41679713830*x);
B1+=0.00000013027*cost(3.21731634178+277.03499374140*x);
B1+=0.00000009946*cost(3.11650057543+625.67019231240*x);
B1+=0.00000012710*cost(0.29501589197+422.66603761290*x);
B1+=0.00000009644*cost(1.74586356703+330.61896365820*x);
B1+=0.00000008079*cost(2.41931187953+430.53034413910*x);
B1+=0.00000008245*cost(4.68121931659+215.74677599280*x);
B1+=0.00000008958*cost(0.46482448501+429.77958461370*x);
B1+=0.00000006547*cost(3.01351967549+949.17560896980*x);
B1+=0.00000007251*cost(5.97098186912+149.56319713460*x);
B1+=0.00000006056*cost(1.49115011100+234.63973644040*x);
B1+=0.00000005791*cost(5.36720639912+735.87651353180*x);
B1+=0.00000005994*cost(0.02442871989+654.12438031560*x);
B1+=0.00000006647*cost(3.90879134581+351.81659230870*x);
B1+=0.00000006824*cost(1.52456408861+437.64389113990*x);
B1+=0.00000005134*cost(3.81149834833+74.78159856730*x);
B1+=0.00000003959*cost(5.63505813057+210.85141488320*x);
B1+=0.00000003811*cost(2.63992803111+3.18139373770*x);
B1+=0.00000003643*cost(1.73267151007+1059.38193018920*x);
B1+=0.00000003554*cost(4.98621474362+3.93215326310*x);
B1+=0.00000004568*cost(4.33599514584+628.85158605010*x);
B1+=0.00000003145*cost(2.51404811765+1162.47470440780*x);
B1+=0.00000003522*cost(1.16093567319+223.59403617650*x);
B1+=0.00000002933*cost(2.06057834252+956.28915597060*x);
B1+=0.00000002644*cost(5.62559379305+203.73786788240*x);
B1+=0.00000002992*cost(5.06312015437+515.46387109300*x);
B1+=0.00000002304*cost(2.73123930535+21.34064100240*x);
B1+=0.00000002168*cost(2.91805928238+203.00415469950*x);
B1+=0.00000002398*cost(3.99421633537+1279.79457262800*x);
B1+=0.00000002146*cost(0.87500689888+408.43894361130*x);
B1+=0.00000002074*cost(1.65731069687+137.03302416240*x);
B1+=0.00000001797*cost(1.56879308343+124.43341522100*x);
B1+=0.00000002088*cost(1.85721384366+138.51749687070*x);
B1+=0.00000001769*cost(4.82294294946+1073.60902419080*x);
B1+=0.00000001635*cost(1.20387813348+88.86568021700*x);
B1+=0.00000002202*cost(5.93027042684+1052.26838318840*x);
B1+=0.00000001843*cost(0.22126910774+750.10360753340*x);
B1+=0.00000001851*cost(2.45470409290+340.77089204480*x);
B1+=0.00000001890*cost(0.41025631859+127.47179660680*x);
B1+=0.00000001582*cost(5.63360832372+214.26230328450*x);
B1+=0.00000001920*cost(3.77935901504+350.33211960040*x);
B1+=0.00000001786*cost(5.78644477326+635.96513305090*x);
B1+=0.00000001497*cost(3.13026893210+703.63318461740*x);
B1+=0.00000001583*cost(3.46882532865+38.13303563780*x);
B1+=0.00000001577*cost(4.02973226017+388.46515523820*x);
B1+=0.00000001645*cost(5.59115773632+483.22054217860*x);
B1+=0.00000001405*cost(4.07880624509+728.76296653100*x);
B1+=0.00000001498*cost(5.87094430469+362.86229257260*x);
B1+=0.00000001317*cost(2.22386203585+213.34727954780*x);
B1+=0.00000001321*cost(2.91534782718+1265.56747862640*x);
B1+=0.00000001307*cost(5.41748323885+217.96496188400*x);
B1+=0.00000001483*cost(0.91111666841+543.91805909620*x);
B1+=0.00000001291*cost(2.62333801070+554.06998748280*x);
B1+=0.00000001406*cost(0.34582712649+85.82729883120*x);
B1+=0.00000001287*cost(2.82247279651+231.45834270270*x);
B1+=0.00000001563*cost(4.88438049382+208.63322899200*x);
B1+=0.00000001316*cost(5.30963570131+213.25091132820*x);
B1+=0.00000001164*cost(1.39531381032+210.37833413120*x);
B1+=0.00000001295*cost(2.46089213219+200.76892246580*x);
B1+=0.00000001236*cost(3.03659580871+838.96928775040*x);
B1+=0.00000001449*cost(4.00934078371+195.13984817330*x);
B1+=0.00000001251*cost(1.46674521697+218.71572140940*x);
B1+=0.00000001568*cost(1.89939852487+212.33588759150*x);
B1+=0.00000001067*cost(5.34734443894+207.67002114550*x);
B1+=0.00000001111*cost(0.70962013461+447.93883187840*x);
B1+=0.00000001012*cost(1.37217220640+636.71589257630*x);
B1+=0.00000001163*cost(6.00108996618+191.20769491020*x);
B1+=0.00000000887*cost(2.84483069917+191.95845443560*x);
B1+=0.00000001005*cost(2.72373040634+1478.86657406440*x);
B1+=0.00000000879*cost(1.19585734916+417.03696332040*x);
B1+=0.00000000829*cost(4.94182950387+497.44763618020*x);
B1+=0.00000000878*cost(6.24981924813+265.98929347750*x);
B1+=0.00000000781*cost(4.61973017912+424.15051032120*x);
B1+=0.00000000924*cost(3.64210508536+222.86032299360*x);
B1+=0.00000000971*cost(2.89404568581+563.63121503840*x);
B1+=0.00000000946*cost(5.72987725592+1368.66025284500*x);
B1+=0.00000000834*cost(6.12384852532+209.10630974400*x);
B1+=0.00000000911*cost(1.06795057723+650.94298657790*x);
B1+=0.00000000731*cost(0.81660632103+142.44965013380*x);
B1+=0.00000000795*cost(5.54574074566+76.26607127560*x);
B1+=0.00000001012*cost(5.97140626297+643.07868005170*x);
B1+=0.00000000703*cost(2.41479303782+10.29494073850*x);
B1+=0.00000000726*cost(4.52598413209+565.11568774670*x);
B1+=0.00000000691*cost(2.31682364985+160.60889739850*x);
B1+=0.00000000695*cost(0.37889317398+212.77783057620*x);
B1+=0.00000000676*cost(4.43606270900+842.15068148810*x);
B1+=0.00000000769*cost(4.47368582271+52.69019803950*x);
B1+=0.00000000658*cost(0.32331118921+621.73803904930*x);
B1+=0.00000000838*cost(4.68035046143+288.08069400530*x);
B1+=0.00000000674*cost(5.63961963995+867.42347575360*x);
B1+=0.00000000695*cost(1.32062509205+1169.58825140860*x);
B1+=0.00000000841*cost(2.46995220838+1375.77379984580*x);
B1+=0.00000000633*cost(3.46145143241+18.15924726470*x);
B1+=0.00000000722*cost(0.04119071457+269.92144674060*x);
B1+=0.00000000757*cost(2.15030650611+207.88246946660*x);
B1+=0.00000000692*cost(0.87072324976+213.82036029980*x);
B1+=0.00000000602*cost(0.85288769518+225.82926841020*x);
B1+=0.00000000635*cost(4.76109030475+831.85574074960*x);
B1+=0.00000000701*cost(1.20410854661+479.28838891550*x);
B1+=0.00000000624*cost(2.30585779534+643.82943957710*x);
B1+=0.00000000582*cost(0.18811617696+1.48447270830*x);
B1+=0.00000000513*cost(2.56525967840+404.50679034820*x);
B1+=0.00000000502*cost(4.97423814367+212.54833591260*x);
B1+=0.00000000644*cost(2.10955154583+1272.68102562720*x);
B1+=0.00000000467*cost(4.47217820662+235.39049596580*x);
B1+=0.00000000566*cost(4.44740324446+429.04587143080*x);
B1+=0.00000000448*cost(0.57491120802+22.09140052780*x);
B1+=0.00000000520*cost(1.15131866397+337.73251065900*x);
B1+=0.00000000476*cost(4.78513362967+218.92816973050*x);
B1+=0.00000000519*cost(0.61616177345+436.89313161450*x);
B1+=0.00000000442*cost(2.10204008144+416.30325013750*x);
B1+=0.00000000536*cost(1.08779067908+344.70304530790*x);
B1+=0.00000000477*cost(2.42483193385+216.21985674480*x);
B1+=0.00000000469*cost(5.22622034028+942.06206196900*x);
B1+=0.00000000392*cost(0.41137926465+302.16477565500*x);
B1+=0.00000000400*cost(5.17216478470+414.06801790380*x);
B1+=0.00000000383*cost(3.58419227076+1045.15483618760*x);
B1+=0.00000000443*cost(1.11051326413+425.11371816770*x);
B1+=0.00000000517*cost(3.44547026103+12.53017297220*x);
B1+=0.00000000369*cost(1.60095273908+56.62235130260*x);
B1+=0.00000000354*cost(2.79123486392+1581.95934828300*x);
B1+=0.00000000405*cost(5.93402105921+173.94221952280*x);
B1+=0.00000000319*cost(4.31850876624+219.44943459230*x);
B1+=0.00000000330*cost(0.62529198264+358.93013930950*x);
B1+=0.00000000305*cost(0.82404423420+1485.98012106520*x);
B1+=0.00000000391*cost(2.59385552893+1795.25844372100*x);
B1+=0.00000000291*cost(3.12019266878+217.49188113200*x);
B1+=0.00000000294*cost(2.18552193901+444.75743814070*x);
B1+=0.00000000281*cost(0.77791302266+757.21715453420*x);
B1+=0.00000000355*cost(5.44570491928+1685.05212250160*x);
B1+=0.00000000305*cost(2.65927043884+355.74874557180*x);
B1+=0.00000000269*cost(6.00323720265+934.94851496820*x);
B1+=0.00000000287*cost(2.60486363576+113.38771495710*x);
B1+=0.00000000348*cost(0.98872551635+70.84944530420*x);
B1+=0.00000000331*cost(5.62133883922+9.56122755560*x);
B1+=0.00000000255*cost(4.14086605030+284.14854074220*x);
B1+=0.00000000311*cost(6.27145060602+207.14875628370*x);
B1+=0.00000000267*cost(4.72606312146+696.51963761660*x);
B1+=0.00000000319*cost(4.68828119248+1155.36115740700*x);
B1+=0.00000000227*cost(3.10352674343+1361.54670584420*x);
B1+=0.00000000228*cost(1.19253095837+1589.07289528380*x);
B1+=0.00000000244*cost(5.36327976010+245.54242435240*x);
B1+=0.00000000218*cost(2.16069250901+177.87437278590*x);
B1+=0.00000000254*cost(4.51652534648+1148.24761040620*x);
B1+=0.00000000211*cost(2.82699627326+106.27416795630*x);
B1+=0.00000000230*cost(4.63171743406+107.02492748170*x);
B1+=0.00000000201*cost(4.52152562223+508.35032409220*x);
B1+=0.00000000230*cost(5.93560798508+618.55664531160*x);
B1+=0.00000000253*cost(2.08074949572+252.65597135320*x);
B1+=0.00000000234*cost(2.43423283339+1692.16566950240*x);
B1+=0.00000000196*cost(1.01284131123+114.39910691340*x);
B1+=0.00000000196*cost(2.73629728926+214.04985496340*x);
B1+=0.00000000191*cost(1.51642829677+6069.77675455340*x);
B1+=0.00000000252*cost(5.10097595426+1258.45393162560*x);
B1+=0.00000000240*cost(2.93712394928+916.93228005540*x);
B1+=0.00000000224*cost(4.42406538277+251.43213107580*x);
B1+=0.00000000223*cost(2.34400676548+1677.93857550080*x);
B1+=0.00000000228*cost(5.00073557208+1574.84580128220*x);
B1+=0.00000000183*cost(5.09056895026+220.46082654860*x);
B1+=0.00000000178*cost(6.05669760153+206.13736432740*x);
B1+=0.00000000185*cost(3.73859309582+114.13847448250*x);
B1+=0.00000000200*cost(1.89409546254+2420.92863603340*x);
B1+=0.00000000158*cost(2.78517362162+2008.55753915900*x);
B1+=0.00000000191*cost(2.28724146195+2435.15573003500*x);
B1+=0.00000000188*cost(4.29343910228+1471.75302706360*x);
B1+=0.00000000155*cost(5.35194123420+576.16138801060*x);
B1+=0.00000000174*cost(2.80423114755+1781.03134971940*x);
B1+=0.00000000166*cost(5.32531835813+2001.44399215820*x);
B1+=0.00000000165*cost(2.62993712087+525.49817940060*x);
B1+=0.00000000141*cost(4.73916921092+501.37978944330*x);
B1+=0.00000000161*cost(5.83368523750+181.05576652360*x);
B1+=0.00000000137*cost(1.45135867137+131.54696222180*x);
B1+=0.00000000157*cost(3.22870773657+1493.09366806600*x);
B1+=0.00000000136*cost(4.20279658293+710.74673161820*x);
B1+=0.00000000144*cost(4.61003572124+121.25202148330*x);
B1+=0.00000000131*cost(5.85409245557+175.16605980020*x);
B1+=0.00000000144*cost(0.96056164245+214.78356814630*x);
B1+=0.00000000146*cost(3.95687956474+421.93232443000*x);
B1+=0.00000000138*cost(1.03080573610+4.66586644600*x);
B1+=0.00000000167*cost(1.97508934614+62.25142559510*x);
B1+=0.00000000123*cost(2.28640485589+1898.35121793960*x);
B1+=0.00000000168*cost(4.63122081226+1891.23767093880*x);
B1+=0.00000000129*cost(0.05327999225+211.81462272970*x);
B1+=0.00000000134*cost(3.49720535944+488.84961647110*x);
B1+=0.00000000117*cost(3.43819501459+436.15941843160*x);
B1+=0.00000000125*cost(5.87007326241+963.40270297140*x);
B1+=0.00000000120*cost(0.70795300239+81.75213321620*x);
B1+=0.00000000125*cost(4.50999471095+2317.83586181480*x);
B1+=0.00000000116*cost(6.11600926571+558.00214074590*x);
B1+=0.00000000117*cost(4.78666549046+601.76425067620*x);
B1+=0.00000000108*cost(0.45464469172+1802.37199072180*x);
B1+=0.00000000111*cost(1.44669239244+2531.13495725280*x);
B1+=0.00000000109*cost(6.14289264597+151.04766984290*x);
B1+=0.00000000113*cost(4.05600865495+1286.90811962880*x);
B1+=0.00000000129*cost(5.13936946160+849.26422848890*x);
B1+=0.00000000127*cost(3.88189432056+98.89998852460*x);
B1+=0.00000000133*cost(2.38290634070+2111.65031337760*x);
B1+=0.00000000122*cost(4.40757611742+778.41478318470*x);
B1+=0.00000000095*cost(0.07909774752+213.41097002260*x);
B1+=0.00000000095*cost(1.66925524906+213.18722085340*x);
B1+=0.00000000103*cost(1.88058957173+99.16062095550*x);
B1+=0.00000000119*cost(3.62785705509+248.72381809010*x);
B1+=0.00000000090*cost(4.63029999228+228.27694896500*x);
B1+=0.00000000092*cost(5.48700119144+767.36908292080*x);
B1+=0.00000000089*cost(4.61331934339+431.26405732200*x);
B1+=0.00000000099*cost(3.60670326134+776.93031047640*x);
B1+=0.00000000085*cost(4.93878023673+2.44768055480*x);
B1+=0.00000000089*cost(6.24541644164+661.23792731640*x);
B1+=0.00000000085*cost(0.45896349060+1382.88734684660*x);
B1+=0.00000000088*cost(3.81144552178+1788.14489672020*x);
B1+=0.00000000103*cost(3.20558404998+312.19908396260*x);
B1+=0.00000000080*cost(2.28889729136+213.08664711690*x);
B1+=0.00000000080*cost(5.74264101239+213.51154375910*x);
B1+=0.00000000082*cost(3.23546757052+198.32124191100*x);
B1+=0.00000000078*cost(6.03841191050+835.03713448730*x);
B1+=0.00000000080*cost(0.22601918692+427.56139872250*x);
B1+=0.00000000072*cost(2.05164614795+2634.22773147140*x);
B1+=0.00000000091*cost(5.97938003596+556.51766803760*x);
B1+=0.00000000087*cost(2.71469794199+617.80588578620*x);

double B2=0;
B2+=0.00020629977*cost(0.50482422817+213.29909543800*x);
B2+=0.00003719555*cost(3.99833475829+206.18554843720*x);
B2+=0.00001627158*cost(6.18189939500+220.41264243880*x);
B2+=0.00001346067;
B2+=0.00000705842*cost(3.03914308836+419.48464387520*x);
B2+=0.00000365042*cost(5.09928680706+426.59819087600*x);
B2+=0.00000329632*cost(5.27899210039+433.71173787680*x);
B2+=0.00000219335*cost(3.82841533795+639.89728631400*x);
B2+=0.00000139393*cost(1.04272623499+7.11354700080*x);
B2+=0.00000103980*cost(6.15730992966+227.52618943960*x);
B2+=0.00000092961*cost(1.97994412845+316.39186965660*x);
B2+=0.00000071242*cost(4.14754353431+199.07200143640*x);
B2+=0.00000051927*cost(2.88364833898+632.78373931320*x);
B2+=0.00000048961*cost(4.43390206741+647.01083331480*x);
B2+=0.00000041373*cost(3.15927770079+853.19638175200*x);
B2+=0.00000028602*cost(4.52978327558+210.11770170030*x);
B2+=0.00000023969*cost(1.11595912146+14.22709400160*x);
B2+=0.00000020511*cost(4.35095844197+217.23124870110*x);
B2+=0.00000019532*cost(5.30779711223+440.82528487760*x);
B2+=0.00000018263*cost(0.85391476786+110.20632121940*x);
B2+=0.00000015742*cost(4.25767226302+103.09277421860*x);
B2+=0.00000016840*cost(5.68112084135+216.48048917570*x);
B2+=0.00000013613*cost(2.99904334066+412.37109687440*x);
B2+=0.00000011567*cost(2.52679928410+529.69096509460*x);
B2+=0.00000007963*cost(3.31512423920+202.25339517410*x);
B2+=0.00000006599*cost(0.28766025146+323.50541665740*x);
B2+=0.00000006312*cost(1.16121321336+117.31986822020*x);
B2+=0.00000005891*cost(3.58260177246+309.27832265580*x);
B2+=0.00000006648*cost(5.55714129949+209.36694217490*x);
B2+=0.00000005590*cost(2.47783944511+1066.49547719000*x);
B2+=0.00000006192*cost(3.61231886519+860.30992875280*x);
B2+=0.00000004231*cost(3.02212363572+846.08283475120*x);
B2+=0.00000003612*cost(4.79935735435+625.67019231240*x);
B2+=0.00000003398*cost(3.76732731354+423.41679713830*x);
B2+=0.00000003387*cost(6.04222745633+234.63973644040*x);
B2+=0.00000002578*cost(5.63610668746+735.87651353180*x);
B2+=0.00000002831*cost(4.81642822334+429.77958461370*x);
B2+=0.00000002817*cost(4.47516563908+654.12438031560*x);
B2+=0.00000002573*cost(0.22467245054+522.57741809380*x);
B2+=0.00000002610*cost(3.29126967191+95.97922721780*x);
B2+=0.00000002419*cost(0.02986335489+415.55249061210*x);
B2+=0.00000002112*cost(4.55964179603+422.66603761290*x);
B2+=0.00000002304*cost(6.25081073546+330.61896365820*x);
B2+=0.00000001758*cost(5.53430456858+536.80451209540*x);
B2+=0.00000001814*cost(5.05675881426+277.03499374140*x);
B2+=0.00000001550*cost(5.60375604692+223.59403617650*x);
B2+=0.00000001457*cost(4.47767649852+430.53034413910*x);
B2+=0.00000001607*cost(5.53599550100+224.34479570190*x);
B2+=0.00000001172*cost(4.71017775994+203.00415469950*x);
B2+=0.00000001231*cost(0.25115931880+3.93215326310*x);
B2+=0.00000001105*cost(1.01595427676+21.34064100240*x);
B2+=0.00000000868*cost(4.84623483952+949.17560896980*x);
B2+=0.00000000939*cost(1.35429452093+742.99006053260*x);
B2+=0.00000000693*cost(6.03599130692+124.43341522100*x);
B2+=0.00000000712*cost(4.45550701473+191.95845443560*x);
B2+=0.00000000690*cost(5.44243765037+437.64389113990*x);
B2+=0.00000000810*cost(0.46198177342+515.46387109300*x);
B2+=0.00000000694*cost(5.23748122403+447.93883187840*x);
B2+=0.00000000604*cost(2.95749705544+88.86568021700*x);
B2+=0.00000000669*cost(0.08457977809+215.74677599280*x);
B2+=0.00000000579*cost(0.65329445948+3.18139373770*x);
B2+=0.00000000712*cost(6.05964117622+11.04570026390*x);
B2+=0.00000000698*cost(2.91371419321+1073.60902419080*x);
B2+=0.00000000526*cost(2.24947851818+1059.38193018920*x);
B2+=0.00000000511*cost(2.86838724347+408.43894361130*x);
B2+=0.00000000589*cost(5.79268515755+63.73589830340*x);
B2+=0.00000000519*cost(1.76641574095+1279.79457262800*x);
B2+=0.00000000503*cost(5.73762297081+728.76296653100*x);
B2+=0.00000000482*cost(4.68234512154+838.96928775040*x);
B2+=0.00000000494*cost(4.04363805503+490.33408917940*x);
B2+=0.00000000458*cost(1.17998315936+210.85141488320*x);
B2+=0.00000000380*cost(5.28045750432+1052.26838318840*x);
B2+=0.00000000404*cost(4.58953258519+302.16477565500*x);
B2+=0.00000000377*cost(5.20131800999+74.78159856730*x);
B2+=0.00000000328*cost(0.11893501088+956.28915597060*x);
B2+=0.00000000290*cost(3.99300398632+1162.47470440780*x);
B2+=0.00000000262*cost(2.04320741578+1471.75302706360*x);
B2+=0.00000000259*cost(3.76206113036+635.96513305090*x);
B2+=0.00000000254*cost(0.16694559092+195.13984817330*x);
B2+=0.00000000309*cost(5.44921175960+543.91805909620*x);
B2+=0.00000000237*cost(1.27761853769+231.45834270270*x);
B2+=0.00000000288*cost(1.32449995239+203.73786788240*x);
B2+=0.00000000229*cost(4.19748765966+1265.56747862640*x);
B2+=0.00000000238*cost(4.02925601887+643.07868005170*x);
B2+=0.00000000238*cost(0.49997895983+10.29494073850*x);
B2+=0.00000000257*cost(3.69107889837+867.42347575360*x);
B2+=0.00000000191*cost(0.17807919948+628.85158605010*x);
B2+=0.00000000246*cost(5.62469599682+351.81659230870*x);
B2+=0.00000000183*cost(3.38184740572+636.71589257630*x);
B2+=0.00000000172*cost(3.83173494030+1581.95934828300*x);
B2+=0.00000000220*cost(1.03443668151+483.22054217860*x);
B2+=0.00000000217*cost(4.65210162713+750.10360753340*x);
B2+=0.00000000143*cost(2.31969979791+18.15924726470*x);
B2+=0.00000000137*cost(5.50046852846+1169.58825140860*x);
B2+=0.00000000120*cost(3.70151294359+416.30325013750*x);
B2+=0.00000000136*cost(3.38453909352+1155.36115740700*x);
B2+=0.00000000149*cost(0.85459831932+1375.77379984580*x);
B2+=0.00000000150*cost(5.71949902293+618.55664531160*x);
B2+=0.00000000125*cost(4.82446274394+436.89313161450*x);
B2+=0.00000000120*cost(3.26968058035+1478.86657406440*x);
B2+=0.00000000131*cost(0.11496484259+1898.35121793960*x);
B2+=0.00000000099*cost(4.57241894541+643.82943957710*x);
B2+=0.00000000095*cost(4.92115458463+650.94298657790*x);
B2+=0.00000000090*cost(2.09300085806+621.73803904930*x);
B2+=0.00000000111*cost(0.11975665259+831.85574074960*x);
B2+=0.00000000089*cost(2.54351587616+85.82729883120*x);
B2+=0.00000000080*cost(5.09103451442+340.77089204480*x);
B2+=0.00000000078*cost(3.17395501851+497.44763618020*x);
B2+=0.00000000085*cost(0.18997660997+1258.45393162560*x);
B2+=0.00000000081*cost(1.16732337173+217.96496188400*x);
B2+=0.00000000072*cost(5.47328223678+337.73251065900*x);

double B3=0;
B3+=0.00000666252*cost(1.99006340181+213.29909543800*x);
B3+=0.00000632350*cost(5.69778316807+206.18554843720*x);
B3+=0.00000398051;
B3+=0.00000187838*cost(4.33779804809+220.41264243880*x);
B3+=0.00000091884*cost(4.84104208217+419.48464387520*x);
B3+=0.00000042369*cost(2.38073239056+426.59819087600*x);
B3+=0.00000051548*cost(3.42149490328+433.71173787680*x);
B3+=0.00000025661*cost(4.40167213109+227.52618943960*x);
B3+=0.00000020551*cost(5.85313509872+199.07200143640*x);
B3+=0.00000018081*cost(1.99321433229+639.89728631400*x);
B3+=0.00000010874*cost(5.37344546547+7.11354700080*x);
B3+=0.00000009590*cost(2.54901825866+647.01083331480*x);
B3+=0.00000007085*cost(3.45518372721+316.39186965660*x);
B3+=0.00000006002*cost(4.80055225135+632.78373931320*x);
B3+=0.00000005778*cost(0.01680378777+210.11770170030*x);
B3+=0.00000004881*cost(5.63719730884+14.22709400160*x);
B3+=0.00000004501*cost(1.22424419010+853.19638175200*x);
B3+=0.00000005542*cost(3.51756747774+440.82528487760*x);
B3+=0.00000003548*cost(4.71299370890+412.37109687440*x);
B3+=0.00000002851*cost(0.62679207578+103.09277421860*x);
B3+=0.00000002173*cost(3.71982274459+216.48048917570*x);
B3+=0.00000001991*cost(6.10867071657+217.23124870110*x);
B3+=0.00000001435*cost(1.69177141453+860.30992875280*x);
B3+=0.00000001217*cost(4.30778838827+234.63973644040*x);
B3+=0.00000001157*cost(5.75027789902+309.27832265580*x);
B3+=0.00000000795*cost(5.69026441157+117.31986822020*x);
B3+=0.00000000733*cost(0.59842720676+1066.49547719000*x);
B3+=0.00000000713*cost(0.21700311697+625.67019231240*x);
B3+=0.00000000773*cost(5.48361981990+202.25339517410*x);
B3+=0.00000000897*cost(2.65577866867+654.12438031560*x);
B3+=0.00000000509*cost(2.86079833766+429.77958461370*x);
B3+=0.00000000462*cost(4.17742567173+529.69096509460*x);
B3+=0.00000000390*cost(6.11288036049+191.95845443560*x);
B3+=0.00000000505*cost(4.51905764563+323.50541665740*x);
B3+=0.00000000379*cost(3.74436004151+223.59403617650*x);
B3+=0.00000000332*cost(5.49370890570+21.34064100240*x);
B3+=0.00000000377*cost(5.25624813434+95.97922721780*x);
B3+=0.00000000384*cost(4.48187414769+330.61896365820*x);
B3+=0.00000000367*cost(5.03190929680+846.08283475120*x);
B3+=0.00000000281*cost(1.14133888637+735.87651353180*x);
B3+=0.00000000245*cost(5.81618253250+423.41679713830*x);
B3+=0.00000000241*cost(1.70335120180+522.57741809380*x);
B3+=0.00000000258*cost(3.69110118716+447.93883187840*x);
B3+=0.00000000231*cost(4.15697626494+110.20632121940*x);
B3+=0.00000000305*cost(5.97746884029+302.16477565500*x);
B3+=0.00000000284*cost(0.66224572127+203.00415469950*x);
B3+=0.00000000204*cost(1.54683820621+209.36694217490*x);
B3+=0.00000000194*cost(4.21193801453+124.43341522100*x);
B3+=0.00000000145*cost(4.79689259614+88.86568021700*x);
B3+=0.00000000151*cost(3.82010884134+536.80451209540*x);
B3+=0.00000000100*cost(0.03596545368+949.17560896980*x);
B3+=0.00000000097*cost(0.91303450276+1073.60902419080*x);
B3+=0.00000000110*cost(2.21197473966+515.46387109300*x);
B3+=0.00000000084*cost(2.53842533109+422.66603761290*x);
B3+=0.00000000085*cost(5.11102520704+3.93215326310*x);
B3+=0.00000000077*cost(6.04074586787+838.96928775040*x);
B3+=0.00000000085*cost(1.18898817378+728.76296653100*x);
B3+=0.00000000084*cost(4.10158366806+224.34479570190*x);

double B4=0;
B4+=0.00000080384*cost(1.11918414679+206.18554843720*x);
B4+=0.00000031660*cost(3.12218745098+213.29909543800*x);
B4+=0.00000017143*cost(2.48073200414+220.41264243880*x);
B4-=0.00000011844;
B4+=0.00000009005*cost(0.38441424927+419.48464387520*x);
B4+=0.00000006164*cost(1.56186379537+433.71173787680*x);
B4+=0.00000004660*cost(1.28235639570+199.07200143640*x);
B4+=0.00000004775*cost(2.63498295487+227.52618943960*x);
B4+=0.00000001487*cost(1.43096671616+426.59819087600*x);
B4+=0.00000001424*cost(0.66988083613+647.01083331480*x);
B4+=0.00000001075*cost(6.18092274059+639.89728631400*x);
B4+=0.00000001145*cost(1.72041928134+440.82528487760*x);
B4+=0.00000000682*cost(3.84841098180+14.22709400160*x);
B4+=0.00000000655*cost(3.49486258327+7.11354700080*x);
B4+=0.00000000456*cost(0.47338193402+632.78373931320*x);
B4+=0.00000000509*cost(0.31432285584+412.37109687440*x);
B4+=0.00000000343*cost(5.86413875355+853.19638175200*x);
B4+=0.00000000270*cost(2.50125594913+234.63973644040*x);
B4+=0.00000000197*cost(5.39156324804+316.39186965660*x);
B4+=0.00000000236*cost(2.11084590211+210.11770170030*x);
B4+=0.00000000172*cost(6.09682874401+860.30992875280*x);
B4+=0.00000000159*cost(5.95049154821+216.48048917570*x);
B4+=0.00000000100*cost(1.98534903594+625.67019231240*x);
B4+=0.00000000112*cost(0.85526419268+654.12438031560*x);
B4+=0.00000000115*cost(5.03884718594+117.31986822020*x);
B4+=0.00000000115*cost(0.44589613974+110.20632121940*x);

double B5=0;
B5+=0.00000007895*cost(2.81927558645+206.18554843720*x);
B5+=0.00000001014*cost(0.51187210270+220.41264243880*x);
B5+=0.00000000772*cost(2.99484124049+199.07200143640*x);
B5-=0.00000000967;
B5+=0.00000000583*cost(5.96456944075+433.71173787680*x);
B5+=0.00000000588*cost(0.78008666397+227.52618943960*x);
B5+=0.00000000445*cost(2.38630799074+419.48464387520*x);
B5+=0.00000000098*cost(5.10622131539+647.01083331480*x);
B5+=0.00000000091*cost(5.81659714144+7.11354700080*x);
B5+=0.00000000088*cost(6.17828532308+440.82528487760*x);
B5+=0.00000000089*cost(0.58396864530+213.29909543800*x);

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;
double rtd=180/3.141592653589793;

return rtd*( Bx0+B1*x+B2*x2+B3*x3+B4*x4+B5*x5); //END Saturn
}


//Distance Saturn-Sun [AU]
double Rsaturn(double x)
{
double R0=0;
R0+=9.55758135801;
R0+=0.52921382465*cost(2.39226219733+213.29909543800*x);
R0+=0.01873679934*cost(5.23549605091+206.18554843720*x);
R0+=0.01464663959*cost(1.64763045468+426.59819087600*x);
R0+=0.00821891059*cost(5.93520025371+316.39186965660*x);
R0+=0.00547506899*cost(5.01532628454+103.09277421860*x);
R0+=0.00371684449*cost(2.27114833428+220.41264243880*x);
R0+=0.00361778433*cost(3.13904303264+7.11354700080*x);
R0+=0.00140617548*cost(5.70406652991+632.78373931320*x);
R0+=0.00108974737*cost(3.29313595577+110.20632121940*x);
R0+=0.00069007015*cost(5.94099622447+419.48464387520*x);
R0+=0.00061053350*cost(0.94037761156+639.89728631400*x);
R0+=0.00048913044*cost(1.55733388472+202.25339517410*x);
R0+=0.00034143794*cost(0.19518550682+277.03499374140*x);
R0+=0.00032401718*cost(5.47084606947+949.17560896980*x);
R0+=0.00020936573*cost(0.46349163993+735.87651353180*x);
R0+=0.00020839118*cost(1.52102590640+433.71173787680*x);
R0+=0.00020746678*cost(5.33255667599+199.07200143640*x);
R0+=0.00015298457*cost(3.05943652881+529.69096509460*x);
R0+=0.00014296479*cost(2.60433537909+323.50541665740*x);
R0+=0.00011993314*cost(5.98051421881+846.08283475120*x);
R0+=0.00011380261*cost(1.73105746566+522.57741809380*x);
R0+=0.00012884128*cost(1.64892310393+138.51749687070*x);
R0+=0.00007752769*cost(5.85191318903+95.97922721780*x);
R0+=0.00009796061*cost(5.20475863996+1265.56747862640*x);
R0+=0.00006465967*cost(0.17733160145+1052.26838318840*x);
R0+=0.00006770621*cost(3.00433479284+14.22709400160*x);
R0+=0.00005850443*cost(1.45519636076+415.55249061210*x);
R0+=0.00005307481*cost(0.59737534050+63.73589830340*x);
R0+=0.00004695746*cost(2.14919036956+227.52618943960*x);
R0+=0.00004043988*cost(1.64010323863+209.36694217490*x);
R0+=0.00003688132*cost(0.78016133170+412.37109687440*x);
R0+=0.00003376457*cost(3.69528478828+224.34479570190*x);
R0+=0.00002885348*cost(1.38764077631+838.96928775040*x);
R0+=0.00002976033*cost(5.68467931117+210.11770170030*x);
R0+=0.00003419551*cost(4.94549148887+1581.95934828300*x);
R0+=0.00003460943*cost(1.85088802878+175.16605980020*x);
R0+=0.00003400616*cost(0.55386747515+350.33211960040*x);
R0+=0.00002507630*cost(3.53851863255+742.99006053260*x);
R0+=0.00002448325*cost(6.18412386316+1368.66025284500*x);
R0+=0.00002406138*cost(2.96559220267+117.31986822020*x);
R0+=0.00002881181*cost(0.17960757891+853.19638175200*x);
R0+=0.00002173959*cost(0.01508587396+340.77089204480*x);
R0+=0.00002024483*cost(5.05411271271+11.04570026390*x);
R0+=0.00001740254*cost(2.34657043464+309.27832265580*x);
R0+=0.00001861397*cost(5.93361638244+625.67019231240*x);
R0+=0.00001888436*cost(0.02968443389+3.93215326310*x);
R0+=0.00001610859*cost(1.17302463549+74.78159856730*x);
R0+=0.00001462631*cost(1.92588134017+216.48048917570*x);
R0+=0.00001474547*cost(5.67670461130+203.73786788240*x);
R0+=0.00001395109*cost(5.93669404929+127.47179660680*x);
R0+=0.00001781165*cost(0.76314388077+217.23124870110*x);
R0+=0.00001817186*cost(5.77713225779+490.33408917940*x);
R0+=0.00001472392*cost(1.40064915651+137.03302416240*x);
R0+=0.00001304089*cost(0.77235613966+647.01083331480*x);
R0+=0.00001149773*cost(5.74021249703+1162.47470440780*x);
R0+=0.00001126667*cost(4.46707803791+265.98929347750*x);
R0+=0.00001277489*cost(2.98412586423+1059.38193018920*x);
R0+=0.00001207053*cost(0.75285933160+351.81659230870*x);
R0+=0.00001071399*cost(1.13567265104+1155.36115740700*x);
R0+=0.00001020922*cost(5.91233512844+1685.05212250160*x);
R0+=0.00001315042*cost(5.11202572637+211.81462272970*x);
R0+=0.00001295553*cost(4.69184139933+1898.35121793960*x);
R0+=0.00001099037*cost(1.81765118601+149.56319713460*x);
R0+=0.00000998462*cost(2.63131596867+200.76892246580*x);
R0+=0.00000985869*cost(2.25992849742+956.28915597060*x);
R0+=0.00000932434*cost(3.66980793184+554.06998748280*x);
R0+=0.00000664481*cost(0.60297724821+728.76296653100*x);
R0+=0.00000659850*cost(4.66635439533+195.13984817330*x);
R0+=0.00000617740*cost(5.62092000007+942.06206196900*x);
R0+=0.00000626382*cost(5.94208232590+1478.86657406440*x);
R0+=0.00000482230*cost(1.84070179496+479.28838891550*x);
R0+=0.00000487689*cost(2.79373616806+3.18139373770*x);
R0+=0.00000470086*cost(0.83847755040+1471.75302706360*x);
R0+=0.00000451817*cost(5.64468459871+2001.44399215820*x);
R0+=0.00000553128*cost(3.41088600844+269.92144674060*x);
R0+=0.00000534397*cost(1.26443331367+275.55052103310*x);
R0+=0.00000472572*cost(1.88198584660+515.46387109300*x);
R0+=0.00000405434*cost(1.64001413521+536.80451209540*x);
R0+=0.00000517196*cost(4.44310450526+2214.74308759620*x);
R0+=0.00000452848*cost(3.00349117198+302.16477565500*x);
R0+=0.00000494340*cost(2.28626675074+278.51946644970*x);
R0+=0.00000489825*cost(5.80631420383+191.20769491020*x);
R0+=0.00000427459*cost(0.05741344372+284.14854074220*x);
R0+=0.00000339763*cost(1.40198657693+440.82528487760*x);
R0+=0.00000340627*cost(0.89091104306+628.85158605010*x);
R0+=0.00000385974*cost(1.99700402508+1272.68102562720*x);
R0+=0.00000288298*cost(1.12160250272+422.66603761290*x);
R0+=0.00000294444*cost(0.42577061903+312.19908396260*x);
R0+=0.00000262490*cost(0.31753439818+1045.15483618760*x);
R0+=0.00000295331*cost(0.67144493789+88.86568021700*x);
R0+=0.00000342968*cost(5.85600322299+1795.25844372100*x);
R0+=0.00000341117*cost(2.37585247250+525.49817940060*x);
R0+=0.00000234018*cost(4.22756813216+114.13847448250*x);
R0+=0.00000223729*cost(2.28129446763+330.61896365820*x);
R0+=0.00000275814*cost(0.47832439352+38.13303563780*x);
R0+=0.00000224592*cost(0.54754005675+1788.14489672020*x);
R0+=0.00000303300*cost(0.87946670205+6069.77675455340*x);
R0+=0.00000292103*cost(6.21420611920+210.85141488320*x);
R0+=0.00000226121*cost(0.37495223398+142.44965013380*x);
R0+=0.00000277257*cost(5.31917702012+692.58748435350*x);
R0+=0.00000242911*cost(5.37187983246+1258.45393162560*x);
R0+=0.00000205571*cost(0.95755250527+288.08069400530*x);
R0+=0.00000207567*cost(5.38126259725+2317.83586181480*x);
R0+=0.00000186835*cost(6.03591766061+404.50679034820*x);
R0+=0.00000218536*cost(5.25607043545+212.33588759150*x);
R0+=0.00000222155*cost(5.94588016768+39.35687591520*x);
R0+=0.00000179673*cost(4.41045924362+408.43894361130*x);
R0+=0.00000241440*cost(1.12525868110+388.46515523820*x);
R0+=0.00000197093*cost(3.90141942850+52.69019803950*x);
R0+=0.00000236639*cost(0.90802744873+1375.77379984580*x);
R0+=0.00000171915*cost(5.56318632797+213.34727954780*x);
R0+=0.00000169865*cost(2.85667554010+99.16062095550*x);
R0+=0.00000214398*cost(4.20253525974+2531.13495725280*x);
R0+=0.00000172010*cost(2.36537801012+213.25091132820*x);
R0+=0.00000165707*cost(2.63679789706+215.74677599280*x);
R0+=0.00000230892*cost(5.49463421262+191.95845443560*x);
R0+=0.00000177585*cost(0.38155817719+430.53034413910*x);
R0+=0.00000191514*cost(2.95906900704+437.64389113990*x);
R0+=0.00000163250*cost(3.45832517280+617.80588578620*x);
R0+=0.00000162305*cost(5.73050678664+203.00415469950*x);
R0+=0.00000175108*cost(5.71404465044+1066.49547719000*x);
R0+=0.00000183041*cost(5.66851947172+2111.65031337760*x);
R0+=0.00000150077*cost(4.40663921925+417.03696332040*x);
R0+=0.00000187935*cost(6.07916265661+563.63121503840*x);
R0+=0.00000145127*cost(5.08176368814+423.41679713830*x);
R0+=0.00000137491*cost(5.43912787991+222.86032299360*x);
R0+=0.00000172824*cost(1.84920994090+1589.07289528380*x);
R0+=0.00000165478*cost(2.89132196119+214.26230328450*x);
R0+=0.00000145727*cost(1.56565192483+831.85574074960*x);
R0+=0.00000176864*cost(2.30323752987+9999.98645077300*x);
R0+=0.00000128877*cost(2.55338644107+414.06801790380*x);
R0+=0.00000120093*cost(0.04329750542+1361.54670584420*x);
R0+=0.00000143441*cost(0.99817357720+76.26607127560*x);
R0+=0.00000108747*cost(2.09282278191+207.67002114550*x);
R0+=0.00000132106*cost(2.85902597898+312.45971639350*x);
R0+=0.00000112238*cost(0.26221759151+2104.53676637680*x);
R0+=0.00000125186*cost(4.78354048063+205.22234059070*x);
R0+=0.00000104427*cost(3.63671899047+65.22037101170*x);
R0+=0.00000107447*cost(3.67064138701+212.77783057620*x);
R0+=0.00000108642*cost(2.85492389024+21.34064100240*x);
R0+=0.00000097743*cost(5.12231845599+2634.22773147140*x);
R0+=0.00000109097*cost(1.63231061493+208.63322899200*x);
R0+=0.00000096852*cost(4.19928280035+305.34616939270*x);
R0+=0.00000096507*cost(2.56002066845+1692.16566950240*x);
R0+=0.00000085829*cost(4.54545085982+210.37833413120*x);
R0+=0.00000099249*cost(5.13816222131+1574.84580128220*x);
R0+=0.00000112532*cost(5.03109281265+703.63318461740*x);
R0+=0.00000084023*cost(1.18337717265+429.77958461370*x);
R0+=0.00000089021*cost(5.38791571457+107.02492748170*x);
R0+=0.00000110191*cost(2.43656081234+355.74874557180*x);
R0+=0.00000090659*cost(4.20908809746+213.82036029980*x);
R0+=0.00000095885*cost(5.44594259071+2428.04218303420*x);
R0+=0.00000094109*cost(2.39786381418+483.22054217860*x);
R0+=0.00000085609*cost(0.03354346966+860.30992875280*x);
R0+=0.00000088796*cost(4.05766306750+128.95626931510*x);
R0+=0.00000081951*cost(1.66499731549+62.25142559510*x);
R0+=0.00000091240*cost(3.96942332591+2847.52682690940*x);
R0+=0.00000083961*cost(4.60845858022+177.87437278590*x);
R0+=0.00000088376*cost(3.86800515885+140.00196957900*x);
R0+=0.00000093308*cost(0.73846639887+831.10498122420*x);
R0+=0.00000091872*cost(2.94977605320+35.42472265210*x);
R0+=0.00000087077*cost(1.33390590052+1905.46476494040*x);
R0+=0.00000096584*cost(4.84438390997+131.40394986990*x);
R0+=0.00000071010*cost(0.99334817658+405.25754987360*x);
R0+=0.00000095266*cost(2.51506908152+2.44768055480*x);
R0+=0.00000072514*cost(4.63213873657+245.54242435240*x);
R0+=0.00000082580*cost(1.52823217919+145.63104387150*x);
R0+=0.00000076693*cost(3.15240783008+767.36908292080*x);
R0+=0.00000070317*cost(4.04253707270+173.94221952280*x);
R0+=0.00000086015*cost(2.30103727270+85.82729883120*x);
R0+=0.00000066529*cost(4.75053522835+70.84944530420*x);
R0+=0.00000065835*cost(2.46869725001+280.96714700450*x);
R0+=0.00000064824*cost(0.09343869325+9.56122755560*x);
R0+=0.00000071557*cost(0.01212415296+565.11568774670*x);
R0+=0.00000066533*cost(1.08034871114+339.28641933650*x);
R0+=0.00000063488*cost(2.01740971153+234.63973644040*x);
R0+=0.00000060786*cost(5.12026947473+756.32338265690*x);
R0+=0.00000058123*cost(6.05732868566+1677.93857550080*x);
R0+=0.00000064236*cost(1.28586474622+1148.24761040620*x);
R0+=0.00000073124*cost(4.37810889148+425.11371816770*x);
R0+=0.00000055012*cost(3.85865703217+342.25536475310*x);
R0+=0.00000057101*cost(6.26689214029+2420.92863603340*x);
R0+=0.00000064090*cost(4.09854757476+327.43756992050*x);
R0+=0.00000055306*cost(1.60456896521+543.02428721890*x);
R0+=0.00000057987*cost(5.47269124340+347.88443904560*x);
R0+=0.00000073581*cost(3.72292337326+92.04707395470*x);
R0+=0.00000073760*cost(3.57045342615+1.48447270830*x);
R0+=0.00000064940*cost(2.44739629174+267.47376618580*x);
R0+=0.00000054414*cost(3.71479080197+344.70304530790*x);
R0+=0.00000049783*cost(3.93453970179+192.69216761850*x);
R0+=0.00000049537*cost(3.22831070579+333.65734504400*x);
R0+=0.00000047539*cost(3.92925402178+199.28444975750*x);
R0+=0.00000049368*cost(4.90341763553+217.49188113200*x);
R0+=0.00000062711*cost(4.40120079629+214.78356814630*x);
R0+=0.00000046359*cost(2.09430260266+212.54833591260*x);
R0+=0.00000046289*cost(2.64038453480+10.29494073850*x);
R0+=0.00000054335*cost(1.07179534996+362.86229257260*x);
R0+=0.00000058742*cost(2.62270940799+225.82926841020*x);
R0+=0.00000048457*cost(3.15166418511+216.21985674480*x);
R0+=0.00000046316*cost(4.86226642770+2950.61960112800*x);
R0+=0.00000045970*cost(4.97297391881+198.32124191100*x);
R0+=0.00000046678*cost(2.44960215701+207.14875628370*x);
R0+=0.00000044905*cost(1.77616995803+223.59403617650*x);
R0+=0.00000044521*cost(5.55987055442+264.50482076920*x);
R0+=0.00000055914*cost(4.29520232351+329.72519178090*x);
R0+=0.00000049643*cost(5.20789299388+2744.43405269080*x);
R0+=0.00000058829*cost(4.23073947869+700.66423920080*x);
R0+=0.00000052629*cost(3.79230629070+343.21857259960*x);
R0+=0.00000041532*cost(0.74488808688+125.98732389850*x);
R0+=0.00000047767*cost(2.39260015876+207.88246946660*x);
R0+=0.00000056157*cost(2.07214273531+124.43341522100*x);
R0+=0.00000043345*cost(1.83707598036+106.27416795630*x);
R0+=0.00000039793*cost(4.00870764324+12.53017297220*x);
R0+=0.00000053882*cost(4.97905460628+134.58534360760*x);
R0+=0.00000050135*cost(5.75914508514+320.32402291970*x);
R0+=0.00000044960*cost(5.35721924134+218.92816973050*x);
R0+=0.00000041089*cost(4.92252591399+1891.23767093880*x);
R0+=0.00000046509*cost(2.06623129884+2008.55753915900*x);
R0+=0.00000042949*cost(0.39856812529+357.44566660120*x);
R0+=0.00000037992*cost(2.06495914285+247.23934538180*x);
R0+=0.00000048733*cost(5.32762223699+3127.31333126180*x);
R0+=0.00000034583*cost(5.62555932761+99.91138048090*x);
R0+=0.00000041092*cost(2.47264897370+237.67811782620*x);
R0+=0.00000040763*cost(4.08408559215+621.73803904930*x);
R0+=0.00000034213*cost(0.73077393007+750.10360753340*x);
R0+=0.00000033967*cost(5.31264617621+206.23373254700*x);
R0+=0.00000036509*cost(1.68826775750+22.09140052780*x);
R0+=0.00000039361*cost(3.45730719990+241.61027108930*x);
R0+=0.00000034796*cost(2.24780137629+487.36514376280*x);
R0+=0.00000033049*cost(4.86593901955+209.10630974400*x);
R0+=0.00000032584*cost(2.22713131846+319.57326339430*x);
R0+=0.00000039035*cost(3.73870591196+3163.91869656600*x);
R0+=0.00000032722*cost(1.06640549236+252.65597135320*x);
R0+=0.00000038671*cost(4.39617126814+18.15924726470*x);
R0+=0.00000034514*cost(1.82607500690+380.12776796000*x);
R0+=0.00000041539*cost(0.08136234251+210.33015002140*x);
R0+=0.00000033527*cost(5.80475568528+251.43213107580*x);
R0+=0.00000031221*cost(1.96489151107+244.31858407500*x);
R0+=0.00000030521*cost(2.26854188579+1169.58825140860*x);
R0+=0.00000034828*cost(5.96324553131+217.96496188400*x);
R0+=0.00000038481*cost(4.43707551964+160.60889739850*x);
R0+=0.00000035998*cost(3.83262381556+56.62235130260*x);
R0+=0.00000031041*cost(4.89914223233+144.14657116320*x);
R0+=0.00000032342*cost(3.58191018804+231.45834270270*x);
R0+=0.00000028838*cost(5.80081031514+1994.33044515740*x);
R0+=0.00000032175*cost(2.13166877923+206.13736432740*x);
R0+=0.00000032643*cost(1.93131580544+98.89998852460*x);
R0+=0.00000034917*cost(5.65276617691+497.44763618020*x);
R0+=0.00000028928*cost(2.21653288920+14.97785352700*x);
R0+=0.00000031569*cost(3.81846560564+73.29712585900*x);
R0+=0.00000032199*cost(0.99811846290+1464.63948006280*x);
R0+=0.00000029153*cost(5.98414099408+2737.32050569000*x);
R0+=0.00000036706*cost(4.75493516597+348.84764689210*x);
R0+=0.00000028665*cost(1.68732054583+78.71375183040*x);
R0+=0.00000027501*cost(6.12086395418+214.04985496340*x);
R0+=0.00000028795*cost(0.04448605904+5.62907429250*x);
R0+=0.00000027205*cost(0.24587543816+313.21047591890*x);
R0+=0.00000032441*cost(3.77921585847+33.94024994380*x);
R0+=0.00000027088*cost(5.20310098020+148.07872442630*x);
R0+=0.00000034956*cost(3.43886187587+273.10284047830*x);
R0+=0.00000033076*cost(2.44662095168+969.62247809490*x);
R0+=0.00000027745*cost(1.44598606685+258.87574647670*x);
R0+=0.00000027178*cost(4.25918596220+179.35884549420*x);
R0+=0.00000027872*cost(0.78772093522+546.95644048200*x);
R0+=0.00000029106*cost(4.83947711462+905.88657979150*x);
R0+=0.00000027417*cost(2.44930366818+254.94359321360*x);
R0+=0.00000034296*cost(6.00920969644+166.82867252200*x);
R0+=0.00000028859*cost(6.02917249910+188.92007304980*x);
R0+=0.00000026001*cost(0.65046992484+654.12438031560*x);
R0+=0.00000033560*cost(1.23732329127+2221.85663459700*x);
R0+=0.00000024356*cost(0.52248751330+894.84087952760*x);
R0+=0.00000027767*cost(5.17820678484+5.41662597140*x);
R0+=0.00000025568*cost(3.35897159622+0.96320784650*x);
R0+=0.00000022879*cost(3.51293480690+458.84151979040*x);
R0+=0.00000024496*cost(0.00976884124+69.15252427480*x);
R0+=0.00000028794*cost(0.75545700854+488.84961647110*x);
R0+=0.00000031228*cost(2.05299907796+282.45161971280*x);
R0+=0.00000025438*cost(5.29037729250+636.71589257630*x);
R0+=0.00000025332*cost(4.97007969450+3060.82592234740*x);
R0+=0.00000023596*cost(2.54766434769+196.62432088160*x);
R0+=0.00000029602*cost(3.92688207792+206.70681329900*x);
R0+=0.00000028255*cost(2.72125009693+32.24332891440*x);
R0+=0.00000022115*cost(4.75775237642+213.18722085340*x);
R0+=0.00000022130*cost(3.25436709191+681.54178408960*x);
R0+=0.00000021675*cost(4.61403328597+3267.01147078460*x);
R0+=0.00000022115*cost(3.16759500067+213.41097002260*x);
R0+=0.00000026912*cost(2.86269769133+24.37902238820*x);
R0+=0.00000020737*cost(1.66895754198+274.06604832480*x);
R0+=0.00000028309*cost(4.73122154345+552.58551477450*x);
R0+=0.00000025252*cost(5.11986371899+168.05251279940*x);
R0+=0.00000026364*cost(1.59272536419+491.81856188770*x);
R0+=0.00000021995*cost(0.88079009280+635.96513305090*x);
R0+=0.00000027076*cost(5.53694832022+555.55446019110*x);
R0+=0.00000019683*cost(2.14388519695+54.17467074780*x);
R0+=0.00000027266*cost(3.57891326986+561.18353448360*x);
R0+=0.00000025162*cost(1.78070903718+182.27960680100*x);
R0+=0.00000021386*cost(3.86030772476+116.42609634290*x);
R0+=0.00000025572*cost(1.62093861709+2324.94940881560*x);
R0+=0.00000020025*cost(2.90618582553+120.35824960600*x);
R0+=0.00000019882*cost(5.59203696008+4.19278569400*x);
R0+=0.00000019454*cost(0.10623632006+218.71572140940*x);
R0+=0.00000025617*cost(2.09931460158+248.72381809010*x);
R0+=0.00000019804*cost(2.52180124343+1485.98012106520*x);
R0+=0.00000018516*cost(2.54810951896+213.51154375910*x);
R0+=0.00000019831*cost(0.07955320843+842.15068148810*x);
R0+=0.00000018516*cost(5.37755110510+213.08664711690*x);
R0+=0.00000023655*cost(1.59974907716+738.79727483860*x);
R0+=0.00000020375*cost(2.94653107321+59.80374504030*x);
R0+=0.00000024247*cost(3.15387696867+240.38643081190*x);
R0+=0.00000018294*cost(3.18715992969+295.05122865420*x);
R0+=0.00000017464*cost(2.90471803626+477.80391620720*x);
R0+=0.00000020698*cost(1.07232100334+494.26624244250*x);
R0+=0.00000020400*cost(1.83665590916+533.62311835770*x);
R0+=0.00000021285*cost(0.63341794388+189.72322220190*x);
R0+=0.00000016116*cost(0.60069688498+746.92221379570*x);
R0+=0.00000016297*cost(3.98317294128+2.92076130680*x);
R0+=0.00000016922*cost(4.74266972033+2207.62954059540*x);
R0+=0.00000020479*cost(6.05098286202+173.68158709190*x);
R0+=0.00000015447*cost(1.49120311247+543.91805909620*x);
R0+=0.00000019944*cost(4.94086632750+121.25202148330*x);
R0+=0.00000017127*cost(0.71458025372+1781.03134971940*x);
R0+=0.00000017240*cost(0.67749766724+151.04766984290*x);
R0+=0.00000015574*cost(5.70296527381+3053.71237534660*x);
R0+=0.00000015036*cost(5.52770334605+2310.72231481400*x);
R0+=0.00000015928*cost(4.45642717299+643.82943957710*x);
R0+=0.00000016165*cost(0.63286131026+358.93013930950*x);
R0+=0.00000014589*cost(5.26158292613+472.17484191470*x);
R0+=0.00000016545*cost(3.52813228069+3480.31056622260*x);
R0+=0.00000018912*cost(0.55218675639+4.66586644600*x);
R0+=0.00000017595*cost(2.26495491189+672.14061522840*x);
R0+=0.00000018104*cost(2.71285673689+181.80652604900*x);
R0+=0.00000015918*cost(5.23446779429+135.54855145410*x);
R0+=0.00000013931*cost(3.19357128657+213.55972786890*x);
R0+=0.00000014058*cost(0.82375896652+221.37585028530*x);
R0+=0.00000013931*cost(4.73208739639+213.03846300710*x);
R0+=0.00000014690*cost(2.65882838685+292.01284726840*x);
R0+=0.00000014454*cost(0.21819892811+235.39049596580*x);
R0+=0.00000016168*cost(0.91025406068+280.00393915800*x);
R0+=0.00000013327*cost(3.54947442109+205.66428357540*x);
R0+=0.00000016104*cost(0.82547975762+176.65053250850*x);
R0+=0.00000016441*cost(5.39398801335+424.15051032120*x);
R0+=0.00000012747*cost(0.75780958758+721.64941953020*x);
R0+=0.00000012754*cost(3.55466871752+153.49535039770*x);
R0+=0.00000014448*cost(0.12049617049+313.68355667090*x);
R0+=0.00000016499*cost(3.26383140489+6283.07584999140*x);
R0+=0.00000016564*cost(1.62649604519+5856.47765911540*x);
R0+=0.00000014950*cost(1.23923264394+2641.34127847220*x);
R0+=0.00000015724*cost(1.18874754834+486.40193591630*x);
R0+=0.00000011893*cost(0.91693668558+416.30325013750*x);
R0+=0.00000011684*cost(1.11385455828+81.75213321620*x);
R0+=0.00000012985*cost(4.74373293725+3377.21779200400*x);
R0+=0.00000011864*cost(0.64411806416+28.31117565130*x);
R0+=0.00000013216*cost(4.95904024430+1279.79457262800*x);
R0+=0.00000016121*cost(0.98185208328+2538.24850425360*x);
R0+=0.00000014900*cost(1.76649832526+569.04784100980*x);
R0+=0.00000011337*cost(4.36555105334+3583.40334044120*x);
R0+=0.00000011253*cost(5.98638731448+193.65537546500*x);
R0+=0.00000014753*cost(2.92291248767+167.08930495290*x);
R0+=0.00000013774*cost(2.50808183571+1802.37199072180*x);
R0+=0.00000011068*cost(0.00471764868+629.60234557550*x);
R0+=0.00000012781*cost(3.62178749219+67.66805156650*x);
R0+=0.00000012238*cost(0.27163151602+1044.40407666220*x);
R0+=0.00000011021*cost(0.15223056578+501.37978944330*x);
R0+=0.00000014206*cost(2.63254885854+618.55664531160*x);
R0+=0.00000014365*cost(0.37819794671+601.76425067620*x);
R0+=0.00000015034*cost(2.67095006272+46.47042291600*x);
R0+=0.00000012248*cost(2.19751851112+650.94298657790*x);
R0+=0.00000010783*cost(2.86375137884+113.38771495710*x);
R0+=0.00000011418*cost(1.20874560246+172.24529849340*x);
R0+=0.00000014613*cost(6.05645353059+468.24268865160*x);
R0+=0.00000010580*cost(2.05903854864+429.04587143080*x);
R0+=0.00000013721*cost(2.20936291526+228.27694896500*x);
R0+=0.00000012180*cost(1.82585577726+241.87090352020*x);
R0+=0.00000010787*cost(5.06924118186+162.89651925890*x);
R0+=0.00000012056*cost(3.20018724042+72.07328558160*x);
R0+=0.00000012233*cost(4.50741930970+425.63498302950*x);
R0+=0.00000012101*cost(4.14977794161+1108.13997496560*x);
R0+=0.00000009843*cost(1.49451039604+226.63241756230*x);
R0+=0.00000010287*cost(2.10680007784+1033.35837639830*x);
R0+=0.00000009975*cost(2.81640446254+518.64526483070*x);
R0+=0.00000009597*cost(4.80028087522+426.64637498580*x);
R0+=0.00000010746*cost(4.66838299108+129.91947716160*x);
R0+=0.00000012961*cost(5.11568581806+219.44943459230*x);
R0+=0.00000012302*cost(5.33568547700+776.93031047640*x);
R0+=0.00000009484*cost(4.85702954575+820.05928096030*x);
R0+=0.00000011441*cost(3.85769732764+405.99126305650*x);
R0+=0.00000009625*cost(1.60280478656+426.55000676620*x);
R0+=0.00000009164*cost(0.70204567980+403.02231763990*x);
R0+=0.00000010112*cost(2.76486875630+210.59078245230*x);
R0+=0.00000010816*cost(1.36864298163+170.76082578510*x);
R0+=0.00000010187*cost(2.36063948382+685.47393735270*x);
R0+=0.00000012397*cost(6.06349943525+875.83029900100*x);
R0+=0.00000012146*cost(2.04060386262+508.35032409220*x);
R0+=0.00000009574*cost(3.19555214859+286.59622129700*x);
R0+=0.00000010193*cost(4.01123146905+381.35160823740*x);
R0+=0.00000008900*cost(3.63260235880+319.31263096340*x);
R0+=0.00000010052*cost(5.16107251040+216.00740842370*x);
R0+=0.00000008528*cost(3.88076551354+630.33605875840*x);
R0+=0.00000008875*cost(5.46623776078+3370.10424500320*x);
R0+=0.00000008401*cost(5.65557131026+213.45915413240*x);
R0+=0.00000010033*cost(5.97497644283+6.15033915430*x);
R0+=0.00000008401*cost(2.27009862215+213.13903674360*x);
R0+=0.00000011661*cost(0.95163302252+694.07195706180*x);
R0+=0.00000008696*cost(2.33868966556+220.36445832900*x);
R0+=0.00000008141*cost(5.54059747150+220.46082654860*x);
R0+=0.00000009615*cost(2.75755414306+556.51766803760*x);
R0+=0.00000009120*cost(0.44322374149+2097.42321937600*x);
R0+=0.00000008109*cost(5.53989498262+181.05576652360*x);
R0+=0.00000010763*cost(0.05616402982+691.10301164520*x);
R0+=0.00000009579*cost(2.84979792871+184.09414790940*x);
R0+=0.00000009958*cost(2.38581008546+945.24345570670*x);
R0+=0.00000008526*cost(0.17821781104+289.56516671360*x);
R0+=0.00000007700*cost(0.00481375410+7.16173111060*x);
R0+=0.00000008613*cost(0.82900327241+2957.73314812880*x);
R0+=0.00000009517*cost(2.27516458273+8.07675484730*x);
R0+=0.00000009049*cost(3.37335025790+731.94436026870*x);
R0+=0.00000007888*cost(5.78452089815+230.82520325630*x);
R0+=0.00000007684*cost(3.10462250617+7.06536289100*x);
R0+=0.00000007391*cost(5.29648701813+2627.11418447060*x);
R0+=0.00000009875*cost(4.69411059509+10213.28554621100*x);
R0+=0.00000007328*cost(0.09051133382+100.64509366380*x);
R0+=0.00000007999*cost(1.60928374337+696.51963761660*x);
R0+=0.00000007600*cost(4.90078510977+51.20572533120*x);
R0+=0.00000009928*cost(5.25713005643+699.70103135430*x);
R0+=0.00000007333*cost(5.61982406824+31.49256938900*x);
R0+=0.00000007376*cost(4.52737009022+616.32141307790*x);
R0+=0.00000009422*cost(2.44475274779+2118.76386037840*x);
R0+=0.00000007300*cost(4.01885475010+212.02707105080*x);
R0+=0.00000007502*cost(4.71301501745+436.15941843160*x);
R0+=0.00000009071*cost(2.75662160229+130.44074202340*x);
R0+=0.00000008913*cost(2.19608557019+427.56139872250*x);
R0+=0.00000008801*cost(4.26655882704+141.22580985640*x);
R0+=0.00000006853*cost(5.69082635009+480.77286162380*x);
R0+=0.00000007765*cost(3.27218537808+3796.70243587920*x);
R0+=0.00000009159*cost(3.04713671650+9786.68735533500*x);
R0+=0.00000009034*cost(2.04165937353+204.70107572890*x);
R0+=0.00000006902*cost(4.61962635489+2524.02141025200*x);
R0+=0.00000006728*cost(0.58794595002+739.80866679490*x);
R0+=0.00000006741*cost(0.52362906624+135.33610313300*x);
R0+=0.00000008201*cost(5.03994203224+411.62033734900*x);
R0+=0.00000007240*cost(3.90653111215+214.57111982520*x);
R0+=0.00000006887*cost(4.11954799957+662.53120356300*x);
R0+=0.00000006566*cost(2.67659365854+194.17664032680*x);
R0+=0.00000006539*cost(6.25585361704+31.01948863700*x);
R0+=0.00000007484*cost(5.56871021201+271.40591944890*x);
R0+=0.00000008078*cost(3.09955817560+353.30106501700*x);
R0+=0.00000007072*cost(1.10066698352+282.66406803390*x);
R0+=0.00000006089*cost(0.79684364835+593.42686339800*x);
R0+=0.00000006140*cost(3.79672343724+180.16199464630*x);
R0+=0.00000006703*cost(3.82854248620+412.58354519550*x);
R0+=0.00000006024*cost(5.46288776207+724.83081326790*x);
R0+=0.00000008102*cost(4.51051495778+268.43697403230*x);
R0+=0.00000006033*cost(1.24326252021+447.93883187840*x);
R0+=0.00000007425*cost(2.29394888999+532.61172640140*x);
R0+=0.00000006007*cost(2.87215425398+426.07692601420*x);
R0+=0.00000007568*cost(0.79147591036+2854.64037391020*x);
R0+=0.00000005816*cost(1.70824982811+50.40257617910*x);
R0+=0.00000007534*cost(5.38598292680+953.10776223290*x);
R0+=0.00000005863*cost(2.04201456623+454.90936652730*x);
R0+=0.00000007291*cost(0.88044346877+457.61767951300*x);
R0+=0.00000006235*cost(4.51960341418+3693.60966166060*x);
R0+=0.00000006359*cost(6.27053660532+313.94418910180*x);
R0+=0.00000005722*cost(0.47241118592+610.69233878540*x);
R0+=0.00000005704*cost(0.45599464136+643.07868005170*x);
R0+=0.00000006176*cost(3.98739420856+835.03713448730*x);
R0+=0.00000005730*cost(0.50814242490+1038.04128918680*x);
R0+=0.00000006812*cost(4.20463385690+938.12990870590*x);
R0+=0.00000005620*cost(4.08049141112+3899.79521009780*x);
R0+=0.00000006770*cost(4.22172125738+916.93228005540*x);
R0+=0.00000006069*cost(3.46762401122+278.25883401880*x);
R0+=0.00000005875*cost(5.51773010551+1073.60902419080*x);
R0+=0.00000005558*cost(3.29478679376+20.60692781950*x);
R0+=0.00000006274*cost(4.88767368263+0.52126486180*x);
R0+=0.00000005794*cost(4.09991767938+391.17346822390*x);
R0+=0.00000005442*cost(2.79802608247+397.39324334740*x);
R0+=0.00000005754*cost(4.42718264879+165.60483224460*x);
R0+=0.00000005879*cost(6.17871525366+291.26208774300*x);
R0+=0.00000006716*cost(2.18663847730+627.36711334180*x);
R0+=0.00000005761*cost(0.62536160332+114.39910691340*x);
R0+=0.00000005359*cost(2.29390692216+331.20966448920*x);
R0+=0.00000006210*cost(4.92273259045+450.97721326420*x);
R0+=0.00000006686*cost(2.13438181268+285.63301345050*x);
R0+=0.00000005173*cost(4.10128119721+6.59228213900*x);
R0+=0.00000005707*cost(3.48716972669+230.56457082540*x);
R0+=0.00000006363*cost(5.64626069194+518.38463239980*x);
R0+=0.00000005241*cost(3.78081098206+418.52143602870*x);
R0+=0.00000005191*cost(4.39595146262+84.34282612290*x);
R0+=0.00000006710*cost(2.96748528229+624.91943278700*x);
R0+=0.00000004931*cost(2.71959451867+558.00214074590*x);
R0+=0.00000005225*cost(4.65463431385+310.71461125430*x);
R0+=0.00000004857*cost(2.61373582429+66.70484372000*x);
R0+=0.00000004847*cost(3.76991373317+423.67742956920*x);
R0+=0.00000005284*cost(1.96024672163+1182.92157353290*x);
R0+=0.00000005933*cost(2.74003948393+219.89137757700*x);
R0+=0.00000006373*cost(1.41296346460+606.76018552230*x);
R0+=0.00000004728*cost(0.23421038001+1063.31408345230*x);
R0+=0.00000006408*cost(1.16687419680+268.95823889410*x);
R0+=0.00000004782*cost(1.56813683227+420.96911658350*x);
R0+=0.00000005399*cost(4.57611449409+238.90195810360*x);
R0+=0.00000005161*cost(0.14436456585+2413.81508903260*x);
R0+=0.00000004858*cost(5.21378840436+3686.49611465980*x);
R0+=0.00000005086*cost(1.73392381835+337.73251065900*x);
R0+=0.00000004650*cost(3.71029121290+305.08553696180*x);
R0+=0.00000004896*cost(3.67786531840+240.12579838100*x);
R0+=0.00000005949*cost(0.29956165181+524.01370669230*x);
R0+=0.00000004968*cost(2.53258931342+980.66817835880*x);
R0+=0.00000004944*cost(2.16189522746+104.05598206510*x);
R0+=0.00000005366*cost(3.54867806985+107.28555991260*x);
R0+=0.00000004917*cost(0.48641512683+3274.12501778540*x);
R0+=0.00000005617*cost(6.27593478237+112.65400177420*x);
R0+=0.00000004524*cost(5.09539085552+103.14095832840*x);
R0+=0.00000005643*cost(1.52724336480+105.54045477340*x);
R0+=0.00000004504*cost(1.68251875362+196.03362005060*x);
R0+=0.00000004897*cost(4.90011892854+102.12956637210*x);
R0+=0.00000004525*cost(1.88735156553+103.04459010880*x);
R0+=0.00000004327*cost(1.45407229380+409.92341631960*x);
R0+=0.00000005095*cost(3.40640608336+427.11945573780*x);
R0+=0.00000005782*cost(3.55197606731+25874.60404613620*x);
R0+=0.00000004192*cost(0.16603430914+958.57677783100*x);
R0+=0.00000004976*cost(0.50639895683+511.53171782990*x);
R0+=0.00000004167*cost(5.94725762070+316.44005376640*x);
R0+=0.00000004353*cost(3.78587101731+1171.87587326900*x);
R0+=0.00000005387*cost(2.03693287651+2435.15573003500*x);
R0+=0.00000004067*cost(4.66592603130+106.01353552540*x);
R0+=0.00000004817*cost(3.53529781673+960.22130923370*x);
R0+=0.00000004048*cost(3.20024146722+775.23338944700*x);
R0+=0.00000004016*cost(6.00569143107+945.99421523210*x);
R0+=0.00000003989*cost(3.15130319196+115.62294719080*x);
R0+=0.00000004559*cost(5.59555355771+778.41478318470*x);
R0+=0.00000004153*cost(2.75042736587+316.34368554680*x);
R0+=0.00000003983*cost(2.00842137744+597.35901666110*x);
R0+=0.00000004212*cost(4.16852690218+823.99143422340*x);
R0+=0.00000005193*cost(0.71717111984+810.65811209910*x);
R0+=0.00000003927*cost(5.04361736754+2943.50605412720*x);
R0+=0.00000004225*cost(0.02571003853+0.75075952540*x);
R0+=0.00000004926*cost(1.12994881124+526.98265210890*x);
R0+=0.00000004170*cost(3.94116290117+422.40540518200*x);
R0+=0.00000004432*cost(3.99599046800+393.46109008430*x);
R0+=0.00000003840*cost(1.21234108241+212.07525516060*x);
R0+=0.00000003866*cost(4.20930793423+97.67614824720*x);
R0+=0.00000004440*cost(1.35536679738+211.60217440860*x);
R0+=0.00000003840*cost(0.43014354282+214.52293571540*x);
R0+=0.00000004724*cost(3.62039208608+638.41281360570*x);
R0+=0.00000004870*cost(5.75874599620+1246.65747183630*x);
R0+=0.00000004449*cost(1.43384065964+184.98791978670*x);
R0+=0.00000003931*cost(2.36660272585+909.81873305460*x);
R0+=0.00000003787*cost(5.98932416906+325.95309721220*x);
R0+=0.00000003665*cost(0.72917314141+20.44686912510*x);
R0+=0.00000004243*cost(2.29103096797+453.42489381900*x);
R0+=0.00000003730*cost(6.24831601183+159.12442469020*x);
R0+=0.00000003900*cost(1.31013240315+850.01498801430*x);
R0+=0.00000005134*cost(1.97348901289+526.50957135690*x);
R0+=0.00000003621*cost(2.77435773661+123.53964334370*x);
R0+=0.00000003607*cost(5.32058842710+406.95447090300*x);
R0+=0.00000003802*cost(1.94444523548+421.18156490460*x);
R0+=0.00000003906*cost(3.02475451573+317.35507750310*x);
R0+=0.00000004473*cost(0.80804073855+838.21852822500*x);
R0+=0.00000004081*cost(2.08732468180+988.53248488500*x);
R0+=0.00000003843*cost(4.99347148246+7.63481186260*x);
R0+=0.00000004467*cost(6.09037793116+760.25553592000*x);
R0+=0.00000003514*cost(3.97285766412+426.48631629140*x);
R0+=0.00000003504*cost(0.85064201666+299.12639426920*x);
R0+=0.00000004397*cost(1.68577228317+824.74219374880*x);
R0+=0.00000003581*cost(2.35235960566+337.80194662820*x);
R0+=0.00000004606*cost(3.48411642192+913.96333463880*x);
R0+=0.00000003790*cost(3.64538213705+216.26804085460*x);
R0+=0.00000003496*cost(0.95035381131+436.89313161450*x);
R0+=0.00000004422*cost(0.82822191292+43.28902917830*x);
R0+=0.00000003688*cost(2.83785443800+739.05790726950*x);
R0+=0.00000004439*cost(1.19409419107+421.93232443000*x);
R0+=0.00000003572*cost(2.77298538478+444.75743814070*x);
R0+=0.00000004420*cost(5.44308967028+963.40270297140*x);
R0+=0.00000004443*cost(3.73070830296+37.87240320690*x);
R0+=0.00000004322*cost(4.75680702521+40.84134862350*x);
R0+=0.00000003724*cost(0.59005210557+256.42806592190*x);
R0+=0.00000004471*cost(2.22367643527+318.83955021140*x);
R0+=0.00000004184*cost(1.52719196640+298.23262239190*x);
R0+=0.00000003534*cost(5.01937599570+386.98068252990*x);
R0+=0.00000003400*cost(3.22663067085+4113.09430553580*x);
R0+=0.00000004556*cost(1.35715974815+495.75071515080*x);
R0+=0.00000004453*cost(1.80417064247+829.62050851590*x);
R0+=0.00000003617*cost(1.51036385224+41.64449777560*x);
R0+=0.00000003789*cost(4.80357656146+238.42887735160*x);
R0+=0.00000003514*cost(2.38272766645+426.71006546060*x);
R0+=0.00000003208*cost(1.74465274123+952.35700270750*x);
R0+=0.00000004398*cost(2.65839000906+832.58945393250*x);
R0+=0.00000004092*cost(3.07954777295+60.76695288680*x);
R0+=0.00000003813*cost(5.63047104819+315.42866181010*x);
R0+=0.00000003219*cost(6.22278803635+754.83890994860*x);
R0+=0.00000003102*cost(2.69222024257+343.73983746140*x);
R0+=0.00000004045*cost(4.02463772100+376.19561469690*x);
R0+=0.00000003576*cost(0.38532787280+214.99601646740*x);
R0+=0.00000003291*cost(5.49542015261+143.93412284210*x);
R0+=0.00000003981*cost(5.75449411958+239.16259053450*x);
R0+=0.00000003249*cost(0.58789568678+619.29035849450*x);
R0+=0.00000003114*cost(0.02831060137+221.16340196420*x);
R0+=0.00000003555*cost(3.12207684735+1048.33622992530*x);
R0+=0.00000003010*cost(1.91180343491+93.53154666300*x);
R0+=0.00000003384*cost(1.81702854004+443.86366626340*x);
R0+=0.00000003222*cost(2.37342117781+429.51895218280*x);
R0+=0.00000003431*cost(5.92099840679+570.74476203920*x);
R0+=0.00000003271*cost(2.04947945059+806.72595883600*x);
R0+=0.00000003207*cost(5.44018976766+402.21916848780*x);
R0+=0.00000003091*cost(0.10717557454+3590.51688744200*x);
R0+=0.00000002951*cost(1.76365810296+426.81063919710*x);
R0+=0.00000002958*cost(0.23653889192+1354.43315884340*x);
R0+=0.00000002948*cost(4.59289832104+426.38574255490*x);
R0+=0.00000003506*cost(5.43222584214+84.93352695390*x);
R0+=0.00000002894*cost(5.69678330542+1262.38608488870*x);
R0+=0.00000003682*cost(1.07122313007+395.57870223900*x);
R0+=0.00000002983*cost(5.25093816048+313.47110834980*x);
R0+=0.00000003117*cost(4.18767239237+366.79444583570*x);
R0+=0.00000002873*cost(4.45472312727+361.37781986430*x);
R0+=0.00000003521*cost(2.05528981993+1261.63532536330*x);
R0+=0.00000003496*cost(1.87950759078+439.12836384820*x);
R0+=0.00000003012*cost(0.64439385874+263.02034806090*x);
R0+=0.00000002849*cost(1.12491777974+262.05714021440*x);
R0+=0.00000002910*cost(2.76192171681+541.53981451060*x);
R0+=0.00000003322*cost(6.08893948791+108.72184851110*x);
R0+=0.00000003181*cost(1.01419299056+418.00017116690*x);
R0+=0.00000002793*cost(0.38781777981+211.86280683950*x);
R0+=0.00000003091*cost(2.18216748751+306.83064210100*x);
R0+=0.00000003748*cost(3.89145855821+220.93390730060*x);
R0+=0.00000002982*cost(1.99831689446+117.91056905120*x);
R0+=0.00000002793*cost(1.25466684542+214.73538403650*x);
R0+=0.00000003512*cost(1.50965040301+885.43971066640*x);
R0+=0.00000002716*cost(0.80710391613+757.21715453420*x);
R0+=0.00000003137*cost(2.09889265033+2751.54759969160*x);
R0+=0.00000002738*cost(4.89270330923+464.73122651380*x);
R0+=0.00000002875*cost(4.28436709414+4010.00153131720*x);
R0+=0.00000003313*cost(3.01452486457+336.83873878170*x);
R0+=0.00000002746*cost(2.69963506928+380.38840039090*x);
R0+=0.00000003132*cost(2.19562786872+2.96894541660*x);
R0+=0.00000003233*cost(0.60809684558+3171.03224356680*x);
R0+=0.00000003034*cost(0.93246285284+205.43478891180*x);
R0+=0.00000003006*cost(5.91067479448+2.70831298570*x);
R0+=0.00000003643*cost(5.58302397259+423.62924545940*x);
R0+=0.00000002625*cost(1.07042050691+23.57587323610*x);
R0+=0.00000003495*cost(0.19887562030+576.16138801060*x);
R0+=0.00000002590*cost(0.21252773750+110.25450532920*x);
R0+=0.00000002704*cost(6.12908233599+572.22923474750*x);
R0+=0.00000002568*cost(0.17571588314+1056.20053645150*x);
R0+=0.00000002583*cost(2.96927378731+384.05992122310*x);
R0+=0.00000002555*cost(3.96441052072+430.79097657000*x);
R0+=0.00000002786*cost(2.54945911818+195.89060769870*x);
R0+=0.00000002869*cost(4.82964665921+710.74673161820*x);
R0+=0.00000002534*cost(5.31005598763+427.34895040140*x);
R0+=0.00000002618*cost(1.22081401503+36.64856292950*x);
R0+=0.00000003464*cost(2.32811328200+285.37238101960*x);
R0+=0.00000003374*cost(3.34109586766+162.09337010680*x);
R0+=0.00000002694*cost(4.64149271687+140.96517742550*x);
R0+=0.00000002603*cost(0.99527295832+92.30770638560*x);
R0+=0.00000003140*cost(5.40790277580+328.24071907260*x);
R0+=0.00000002603*cost(4.31532790880+561.93429400900*x);
R0+=0.00000002987*cost(0.82758128867+45.57665103870*x);
R0+=0.00000002959*cost(3.35623851523+273.85360000370*x);
R0+=0.00000002561*cost(0.54160683162+107.75864066460*x);
R0+=0.00000002900*cost(1.20691455948+462.02291352810*x);
R0+=0.00000002648*cost(1.90547819027+88.11492069160*x);
R0+=0.00000002461*cost(4.68211868869+2840.41327990860*x);
R0+=0.00000002534*cost(5.00311256556+431.26405732200*x);
R0+=0.00000002521*cost(3.32160472310+136.06981631590*x);
R0+=0.00000002945*cost(1.06452531856+732.69511979410*x);
R0+=0.00000002654*cost(1.36744710395+460.53844081980*x);
R0+=0.00000003297*cost(1.33975572602+305.60680182360*x);
R0+=0.00000002634*cost(2.29995533800+519.39602435610*x);
R0+=0.00000002805*cost(5.62255444533+1699.27921650320*x);
R0+=0.00000002439*cost(5.14733660159+303.86169668440*x);
R0+=0.00000002434*cost(3.71460437051+4216.18707975440*x);
R0+=0.00000002416*cost(3.76296045457+77.75054398390*x);
R0+=0.00000002803*cost(2.55280894914+505.31194270640*x);
R0+=0.00000002592*cost(3.32836551071+110.15813710960*x);
R0+=0.00000003074*cost(1.71462387764+256.58812461630*x);
R0+=0.00000003295*cost(0.81766682522+705.11765732570*x);
R0+=0.00000003183*cost(6.15742006608+109.24311337290*x);
R0+=0.00000002908*cost(5.38534195293+315.16802937920*x);
R0+=0.00000002326*cost(1.42604031905+131.54696222180*x);
R0+=0.00000002427*cost(2.04627850740+124.50285119020*x);
R0+=0.00000002632*cost(1.41253794767+211.65456403530*x);
R0+=0.00000002297*cost(1.38016674676+425.84743135060*x);
R0+=0.00000002318*cost(6.27716072818+317.14262918200*x);
R0+=0.00000002310*cost(4.86442292404+3259.89792378380*x);
R0+=0.00000002873*cost(1.10206537875+7.86430652620*x);
R0+=0.00000002616*cost(0.11849676899+133.10087089930*x);
R0+=0.00000003213*cost(4.49320461690+432.22726516850*x);
R0+=0.00000002276*cost(6.04688191978+214.10224459010*x);
R0+=0.00000002276*cost(1.96882478275+212.49594628590*x);
R0+=0.00000002917*cost(0.96774661857+100.38446123290*x);
R0+=0.00000002890*cost(5.72610904534+322.02094394910*x);
R0+=0.00000002829*cost(2.66887892162+141.48644228730*x);
R0+=0.00000002695*cost(1.47488571070+42.53826965290*x);
R0+=0.00000002697*cost(5.34002228297+432.01481684740*x);
R0+=0.00000002229*cost(4.40717937246+540.73666535850*x);
R0+=0.00000002214*cost(2.43714413196+426.85882330690*x);
R0+=0.00000002512*cost(4.68291916658+1596.18644228460*x);
R0+=0.00000002202*cost(5.91122030007+867.42347575360*x);
R0+=0.00000002856*cost(0.94736445171+41.05379694460*x);
R0+=0.00000002396*cost(0.10516628717+206.93630796260*x);
R0+=0.00000002345*cost(1.16685267780+640.86049416050*x);
R0+=0.00000002263*cost(4.62327588198+188.02630117250*x);
R0+=0.00000002214*cost(3.97566024178+426.33755844510*x);
R0+=0.00000002274*cost(4.94055830720+4002.88798431640*x);
R0+=0.00000002541*cost(0.83705615200+12352.85260454480*x);
R0+=0.00000002145*cost(3.40120044084+111.16952906590*x);
R0+=0.00000002895*cost(6.07389082608+2914.01423582380*x);
R0+=0.00000002520*cost(1.05396310009+184.72728735580*x);
R0+=0.00000002448*cost(3.49820841117+481.73606947030*x);
R0+=0.00000002343*cost(2.86472924644+207.07932031450*x);
R0+=0.00000002964*cost(5.96264929181+465.95506679120*x);
R0+=0.00000002122*cost(4.04560058177+118.07062774560*x);
R0+=0.00000002452*cost(4.35251210402+1382.88734684660*x);
R0+=0.00000002131*cost(0.61211416273+335.14181775230*x);
R0+=0.00000002116*cost(4.76181734842+765.88461021250*x);
R0+=0.00000002245*cost(5.67078632283+6467.92575796160*x);
R0+=0.00000002425*cost(0.84789834075+550.13783421970*x);
R0+=0.00000002227*cost(1.15684015463+227.31374111850*x);
R0+=0.00000002314*cost(6.13104971819+2730.20695868920*x);
R0+=0.00000002344*cost(0.35844885568+217.44369702220*x);
R0+=0.00000002529*cost(3.07975959821+774.48262992160*x);
R0+=0.00000002523*cost(1.75026771081+1578.02719501990*x);
R0+=0.00000002111*cost(4.24637589094+96.87299909510*x);
R0+=0.00000002826*cost(1.01974994073+87.31177153950*x);
R0+=0.00000002906*cost(3.75374302356+428.08266358430*x);
R0+=0.00000002113*cost(2.19787343926+449.23210812500*x);
R0+=0.00000002142*cost(1.19671359858+209.15449385380*x);
R0+=0.00000002882*cost(2.59371585952+39.61750834610*x);
R0+=0.00000002078*cost(2.87503604503+14.01464568050*x);
R0+=0.00000002090*cost(1.99032225653+441.57604440300*x);
R0+=0.00000002519*cost(2.99001165551+745.27768239300*x);
R0+=0.00000002035*cost(5.37147785849+1041.22268292450*x);
R0+=0.00000002054*cost(1.11817372961+842.90144101350*x);
R0+=0.00000002023*cost(2.94559148702+668.20846196530*x);
R0+=0.00000002529*cost(4.34280159004+221.89711514710*x);
R0+=0.00000002554*cost(5.56906955622+214.19286731530*x);
R0+=0.00000002712*cost(1.60469055827+1050.99635880120*x);
R0+=0.00000002350*cost(3.36541706919+220.20019411770*x);
R0+=0.00000002015*cost(2.60446576036+315.64111013120*x);
R0+=0.00000002158*cost(1.64945261993+219.66188291340*x);
R0+=0.00000002120*cost(2.93968038721+304.12232911530*x);
R0+=0.00000002357*cost(1.94433441808+233.90602325750*x);
R0+=0.00000002579*cost(4.54124062411+484.70501488690*x);
R0+=0.00000002046*cost(5.45531068264+200.55647414470*x);
R0+=0.00000002040*cost(2.04492641594+1097.09427470170*x);
R0+=0.00000002675*cost(1.20234167733+28.57180808220*x);
R0+=0.00000002528*cost(4.69268465973+637.44960575920*x);
R0+=0.00000002314*cost(2.81193072994+25.12978191360*x);
R0+=0.00000002689*cost(5.03868493349+1269.49963188950*x);
R0+=0.00000002115*cost(3.10772296248+1276.61317889030*x);
R0+=0.00000002712*cost(1.49710379127+3340.61242669980*x);
R0+=0.00000002138*cost(4.52114042624+378.90392768260*x);
R0+=0.00000002708*cost(0.01014338204+389.94962794650*x);
R0+=0.00000002560*cost(5.75783882561+544.50875992720*x);
R0+=0.00000002028*cost(0.24331359951+146.59425171800*x);
R0+=0.00000002096*cost(1.44475430956+864.24208201590*x);
R0+=0.00000001897*cost(4.63194412388+220.30076785420*x);
R0+=0.00000001901*cost(1.78319572727+192.85222631290*x);
R0+=0.00000002011*cost(4.11578325523+315.87060479480*x);
R0+=0.00000002014*cost(2.26726355818+198.10879358990*x);
R0+=0.00000001905*cost(2.15527255015+326.68681039510*x);
R0+=0.00000001949*cost(3.95440811214+103.61403908040*x);
R0+=0.00000002098*cost(5.24613314798+175.42669223110*x);
R0+=0.00000001884*cost(5.66018186202+1310.39337013970*x);
R0+=0.00000001911*cost(2.60665446600+301.41401612960*x);
R0+=0.00000002160*cost(3.42888079793+420.00590873700*x);
R0+=0.00000002325*cost(5.89632178100+815.06334611420*x);
R0+=0.00000001914*cost(0.22451332248+171.65459766240*x);
R0+=0.00000001854*cost(0.04278915026+233.74596456310*x);
R0+=0.00000001973*cost(2.68640259480+769.81676347560*x);
R0+=0.00000001941*cost(0.61369890353+3487.42411322340*x);
R0+=0.00000001836*cost(3.41496980986+195.77298761970*x);
R0+=0.00000002554*cost(2.35660179716+212.40532356070*x);
R0+=0.00000001822*cost(4.05510232882+639.94547042380*x);
R0+=0.00000001883*cost(6.27079329518+16.67477455640*x);
R0+=0.00000001865*cost(0.17460226411+244.79166482700*x);
R0+=0.00000002097*cost(4.58369520569+316.91313451840*x);
R0+=0.00000001879*cost(2.76480572708+28.45418800320*x);
R0+=0.00000002111*cost(2.92457831824+328.92204262880*x);
R0+=0.00000002077*cost(0.35943033580+589.49471013490*x);
R0+=0.00000001825*cost(4.04945265223+190.40454575810*x);
R0+=0.00000001895*cost(3.89414880651+334.55111692130*x);
R0+=0.00000002425*cost(3.76754213762+25558.21217647960*x);
R0+=0.00000002218*cost(1.85341154236+635.23141986800*x);
R0+=0.00000001782*cost(0.86927461254+92.79783348010*x);
R0+=0.00000002432*cost(3.78026263567+1254.52177836250*x);
R0+=0.00000002106*cost(0.17285594964+354.26427286350*x);
R0+=0.00000001791*cost(6.23892012939+1670.82502850000*x);
R0+=0.00000001996*cost(1.40940081042+230.70758317730*x);
R0+=0.00000001753*cost(1.86660297451+241.75328344120*x);
R0+=0.00000002093*cost(2.39366777880+187.43560034150*x);
R0+=0.00000002007*cost(3.54083120293+226.79247625670*x);
R0+=0.00000001949*cost(1.36533052698+1385.17496870700*x);
R0+=0.00000001737*cost(2.67583588366+6.36278747540*x);
R0+=0.00000001868*cost(4.24454204649+1119.18567522950*x);
R0+=0.00000001896*cost(3.81474515719+310.97524368520*x);
R0+=0.00000001860*cost(3.67887919389+1321.43907040360*x);
R0+=0.00000002305*cost(3.53252557028+1570.91364801910*x);
R0+=0.00000002008*cost(3.88504783546+638.93407846750*x);
R0+=0.00000001928*cost(2.64393870433+525.75881183150*x);
R0+=0.00000001807*cost(0.76057354967+66.18357885820*x);
R0+=0.00000001824*cost(0.85822155861+639.84910220420*x);
R0+=0.00000002221*cost(4.82210413830+1585.89150154610*x);
R0+=0.00000002227*cost(4.58488941022+271.61836777000*x);
R0+=0.00000001897*cost(0.64334758250+55.65914345610*x);
R0+=0.00000001792*cost(0.00514800434+827.92358748650*x);
R0+=0.00000001831*cost(3.69768852728+172.45774681450*x);
R0+=0.00000001790*cost(4.80062977720+3576.28979344040*x);
R0+=0.00000001698*cost(0.72475212282+295.19424100610*x);
R0+=0.00000001744*cost(3.45256183290+238.57188970350*x);
R0+=0.00000002334*cost(1.51845210531+170.01006625970*x);
R0+=0.00000001669*cost(4.44620549295+4319.27985397300*x);
R0+=0.00000001939*cost(3.43927826945+102.57150935680*x);
R0+=0.00000001733*cost(5.96815907422+837.69726336320*x);
R0+=0.00000001686*cost(2.12870436615+491.55792945680*x);
R0+=0.00000001651*cost(3.20586624475+281.17959532560*x);
R0+=0.00000001884*cost(4.24447812450+13.49338081870*x);
R0+=0.00000001880*cost(0.33845094634+214.94362684070*x);
R0+=0.00000001817*cost(3.07678560214+220.52451702340*x);
R0+=0.00000001872*cost(3.79328892492+392.65794093220*x);
R0+=0.00000002195*cost(1.93786776664+259.76951835400*x);
R0+=0.00000001881*cost(4.49314034712+199.80571461930*x);
R0+=0.00000001662*cost(0.29659841675+314.90739694830*x);
R0+=0.00000001626*cost(2.29697402942+3067.93946934820*x);
R0+=0.00000001927*cost(1.00706624515+26.82670294300*x);
R0+=0.00000001621*cost(0.01495920679+1379.70595310890*x);
R0+=0.00000001655*cost(4.15494230496+4326.39340097380*x);
R0+=0.00000001719*cost(5.97443860990+152.53214255120*x);
R0+=0.00000001653*cost(5.65633302949+448.68959140380*x);
R0+=0.00000001790*cost(3.73709604091+10.03430830760*x);
R0+=0.00000001600*cost(2.28430251221+749.20983565610*x);
R0+=0.00000001770*cost(0.03256515992+364.34676528090*x);
R0+=0.00000001939*cost(5.93191442558+249.94765836750*x);
R0+=0.00000001988*cost(4.78810872536+101.86893394120*x);
R0+=0.00000001667*cost(5.52149899431+229.97386999440*x);
R0+=0.00000002215*cost(3.55121116323+594.65070367540*x);
R0+=0.00000001950*cost(0.80878923373+1049.08698945070*x);
R0+=0.00000001773*cost(2.55608046714+9985.75935677140*x);
R0+=0.00000002088*cost(2.33165208016+420.44785172170*x);
R0+=0.00000002107*cost(2.43624356568+453.68552624990*x);
R0+=0.00000001907*cost(4.72569972805+857.12853501510*x);
R0+=0.00000001609*cost(4.96540433043+285.11174858870*x);
R0+=0.00000002152*cost(4.87024306306+186.21176006410*x);
R0+=0.00000001685*cost(5.68609178354+200.03520928290*x);
R0+=0.00000001752*cost(5.21532265401+25448.00585526019*x);
R0+=0.00000001870*cost(6.14683645342+347.36317418380*x);
R0+=0.00000001731*cost(1.95944272122+934.94851496820*x);
R0+=0.00000001680*cost(5.56246697700+170.97327410620*x);
R0+=0.00000001652*cost(1.24521351050+398.14400287280*x);
R0+=0.00000001548*cost(0.38524522125+17.26547538740*x);
R0+=0.00000001577*cost(0.23430114545+434.67494572330*x);
R0+=0.00000001652*cost(2.84480428863+385.54439393140*x);
R0+=0.00000001770*cost(1.15057996280+199.96577331370*x);
R0+=0.00000001528*cost(4.02240583348+236.19364511790*x);
R0+=0.00000002118*cost(5.47803429266+369.08206769610*x);
R0+=0.00000001543*cost(2.54353574089+632.73555520340*x);
R0+=0.00000001504*cost(5.94300855424+280.21638747910*x);
R0+=0.00000001495*cost(2.19380669867+407.47573576480*x);
R0+=0.00000001894*cost(1.88797605501+598.84348936940*x);
R0+=0.00000001515*cost(4.70072295492+211.29335786790*x);
R0+=0.00000001767*cost(3.11910667879+2921.12778282460*x);
R0+=0.00000001515*cost(3.31498374761+215.30483300810*x);
R0+=0.00000001728*cost(5.28095966912+219.51887056150*x);
R0+=0.00000001906*cost(5.24236020775+248.46318565920*x);
R0+=0.00000001607*cost(0.80041605735+642.34496686880*x);
R0+=0.00000001640*cost(2.93387205029+1364.72809958190*x);
R0+=0.00000001585*cost(0.77219822539+661.23792731640*x);
R0+=0.00000001458*cost(5.67666822477+632.83192342300*x);
R0+=0.00000001866*cost(4.40562835971+971.10695080320*x);
R0+=0.00000001838*cost(0.48492190760+1127.04998175570*x);
R0+=0.00000001903*cost(5.18692835916+2015.67108615980*x);
R0+=0.00000001590*cost(2.80043208070+633.74694715970*x);
R0+=0.00000001489*cost(4.10155671855+77837.11123384659*x);
R0+=0.00000001573*cost(4.23741356107+203.89792657680*x);
R0+=0.00000001690*cost(0.65475720351+2700.71514038580*x);
R0+=0.00000001872*cost(3.54376036064+354.52490529440*x);
R0+=0.00000001419*cost(4.53129346734+224.60542813280*x);
R0+=0.00000001575*cost(3.52476647615+373.90799283650*x);
R0+=0.00000001817*cost(3.95203885550+6076.89030155420*x);
R0+=0.00000001446*cost(5.41423319377+317.87634236490*x);
R0+=0.00000001552*cost(1.89030720529+1304.92435454160*x);
R0+=0.00000001394*cost(1.86243646383+913.75088631770*x);
R0+=0.00000001940*cost(4.36562864826+432.74853003030*x);
R0+=0.00000001655*cost(1.31748248488+25668.41849769900*x);
R0+=0.00000001438*cost(5.12958189872+71.81265315070*x);
R0+=0.00000001929*cost(4.90721606846+206.39799675830*x);
R0+=0.00000001533*cost(2.10965059985+378.64329525170*x);
R0+=0.00000001421*cost(6.22897936063+904.40210708320*x);
R0+=0.00000001450*cost(1.98065714692+205.97310011610*x);
R0+=0.00000001584*cost(5.94110940455+1226.21060271120*x);
R0+=0.00000001510*cost(3.77771207288+222.70026429920*x);
R0+=0.00000001670*cost(2.51954641624+976.73602509570*x);
R0+=0.00000001823*cost(1.60093991502+1141.13406340540*x);
R0+=0.00000001564*cost(3.94804398924+9566.27471289620*x);
R0+=0.00000001406*cost(3.65940442223+316.50374424120*x);
R0+=0.00000001653*cost(3.62394476466+968.13800538660*x);
R0+=0.00000001495*cost(0.77832279170+5959.57043333400*x);
R0+=0.00000001408*cost(5.24970924980+316.27999507200*x);
R0+=0.00000001724*cost(0.25483952164+125.18417474640*x);
R0+=0.00000001426*cost(2.26871672572+17.40848773930*x);
R0+=0.00000001881*cost(4.12588105003+562.14674233010*x);
R0+=0.00000001370*cost(4.74474866880+1357.61455258110*x);
R0+=0.00000001485*cost(2.18712736768+9889.78012955360*x);
R0+=0.00000001369*cost(1.31846306523+1160.83017300510*x);
R0+=0.00000001394*cost(5.66924517860+1736.99156101570*x);
R0+=0.00000001375*cost(0.16983286236+346.39996633730*x);
R0+=0.00000001525*cost(2.40244831911+419.43645976540*x);
R0+=0.00000001359*cost(2.68668516027+310.76279536410*x);
R0+=0.00000001396*cost(3.67055397940+253.45912050530*x);
R0+=0.00000001454*cost(5.49356262440+504.56118318100*x);
R0+=0.00000001813*cost(0.21882066860+263.70167161710*x);
R0+=0.00000001330*cost(3.01736059716+254.14044406150*x);
R0+=0.00000001498*cost(0.17578085903+155.78297225810*x);
R0+=0.00000001509*cost(5.13129901759+768.85355562910*x);
R0+=0.00000001550*cost(1.44225397189+1894.41906467650*x);
R0+=0.00000001447*cost(1.44933809994+893.35640681930*x);
R0+=0.00000001306*cost(5.76425101758+714.67888488130*x);
R0+=0.00000001660*cost(1.34160526151+322.61164478010*x);
R0+=0.00000001347*cost(3.00388920953+843.63515419640*x);
R0+=0.00000001432*cost(3.43786149731+251.17149864490*x);
R0+=0.00000001510*cost(4.39762427873+25.27279426550*x);
R0+=0.00000001587*cost(5.17106904014+141.69889060840*x);
R0+=0.00000001477*cost(5.47518377610+226.04171673130*x);
R0+=0.00000001356*cost(4.24406292182+332.17287233570*x);
R0+=0.00000001644*cost(1.74367211793+67.88049988760*x);
R0+=0.00000001407*cost(5.79229630947+188.16931352440*x);
R0+=0.00000001575*cost(0.09808372057+702.14871190910*x);
R0+=0.00000001765*cost(4.93410889383+201.51968199120*x);
R0+=0.00000001318*cost(4.91605557404+17.52610781830*x);
R0+=0.00000001701*cost(4.47360878108+384.27236954420*x);
R0+=0.00000001304*cost(6.04155032791+25.86349509650*x);
R0+=0.00000001269*cost(4.91035989349+354.99798604640*x);
R0+=0.00000001620*cost(5.54960841244+260.36021918500*x);
R0+=0.00000001263*cost(1.16521999431+255.83736509090*x);
R0+=0.00000001744*cost(3.70453251764+147.11551657980*x);
R0+=0.00000001579*cost(4.31561365365+2228.97018159780*x);
R0+=0.00000001557*cost(0.57740217353+3178.14579056760*x);
R0+=0.00000001302*cost(0.32055726013+119.76754877500*x);
R0+=0.00000001405*cost(3.20407486040+395.10562148700*x);
R0+=0.00000001234*cost(2.34766954239+318.67949151700*x);
R0+=0.00000001519*cost(4.74629629688+100.17201291180*x);
R0+=0.00000001573*cost(4.00132484524+1264.29545423920*x);
R0+=0.00000001222*cost(0.10709243166+1372.59240610810*x);
R0+=0.00000001205*cost(0.24105241435+466.75821594330*x);
R0+=0.00000001188*cost(1.27112537278+1184.40604624120*x);
R0+=0.00000001280*cost(4.85454052139+535.91074021810*x);
R0+=0.00000001482*cost(4.47166692910+763.43692965770*x);
R0+=0.00000001233*cost(1.64803509193+433.66355376700*x);
R0+=0.00000001476*cost(3.76634399110+272.58157561650*x);
R0+=0.00000001199*cost(1.78020373551+102.34201469320*x);
R0+=0.00000001186*cost(4.72162748523+795.68025857210*x);
R0+=0.00000001291*cost(4.42697938285+10220.39909321180*x);
R0+=0.00000001576*cost(2.40263038916+348.63519857100*x);
R0+=0.00000001497*cost(3.44614317326+3024.22055704320*x);
R0+=0.00000001175*cost(4.85145058205+433.75992198660*x);
R0+=0.00000001262*cost(5.79416346069+531.97858695500*x);
R0+=0.00000001486*cost(4.39599352105+1055.44977692610*x);
R0+=0.00000001351*cost(0.46461977407+707.56533788050*x);
R0+=0.00000001230*cost(5.18147817992+752.39122939380*x);
R0+=0.00000001175*cost(4.35535063059+3892.68166309700*x);
R0+=0.00000001581*cost(5.49361132323+419.53282798500*x);
R0+=0.00000001247*cost(4.22328749428+113.12708252620*x);
R0+=0.00000001145*cost(2.26067253357+199.12018554620*x);
R0+=0.00000001385*cost(0.89711064123+6073.70890781650*x);
R0+=0.00000001228*cost(4.55057016747+680.05731138130*x);
R0+=0.00000001470*cost(1.58708185256+409.18970313670*x);
R0+=0.00000001366*cost(3.99684537321+6065.84460129030*x);
R0+=0.00000001131*cost(1.56474593118+196.83676920270*x);
R0+=0.00000001163*cost(5.75528918663+2303.60876781320*x);
R0+=0.00000001142*cost(4.35845106342+1834.61531963620*x);
R0+=0.00000001244*cost(1.93187654929+623.22251175760*x);
R0+=0.00000001136*cost(3.13253323524+611.44309831080*x);
R0+=0.00000001425*cost(2.65840274172+1253.77101883710*x);
R0+=0.00000001114*cost(3.43048279234+771.30123618390*x);
R0+=0.00000001314*cost(0.15326588489+493.30303459600*x);
R0+=0.00000001109*cost(2.95808402860+1091.62525910360*x);
R0+=0.00000001177*cost(3.88159541809+128.36556848410*x);
R0+=0.00000001150*cost(4.69140569690+1.27202438720*x);
R0+=0.00000001527*cost(1.09983755253+683.02625679790*x);
R0+=0.00000001304*cost(5.24544813643+5650.29211067820*x);
R0+=0.00000001347*cost(4.11616699496+97.46369992610*x);
R0+=0.00000001085*cost(0.70231952018+1166.40685767090*x);
R0+=0.00000001224*cost(4.22994822530+827.17282796110*x);
R0+=0.00000001142*cost(5.36157631813+199.02381732660*x);
R0+=0.00000001373*cost(0.89371361814+799.61241183520*x);
R0+=0.00000001085*cost(1.15969472512+398.28701522470*x);
R0+=0.00000001098*cost(3.75659421786+318.39760722670*x);
R0+=0.00000001136*cost(1.35127769399+205.92491600630*x);
R0+=0.00000001108*cost(6.03201954623+206.44618086810*x);
R0+=0.00000001146*cost(0.18236094571+6386.16862421000*x);
R0+=0.00000001216*cost(0.49809632153+1178.98942026980*x);
R0+=0.00000001295*cost(2.32056477953+10003.91860403610*x);
R0+=0.00000001082*cost(1.96611069200+3700.72320866140*x);
R0+=0.00000001094*cost(5.12244388591+314.38613208650*x);
R0+=0.00000001464*cost(4.54056066665+1248.14194454460*x);
R0+=0.00000001277*cost(5.42029902662+9996.05429750990*x);
R0+=0.00000001248*cost(0.21625135029+101.60830151030*x);
R0+=0.00000001055*cost(5.53725373260+1578.77795454530*x);
R0+=0.00000001265*cost(5.85587479852+82.85835341460*x);
R0+=0.00000001058*cost(0.73824266822+670.91677495100*x);
R0+=0.00000001127*cost(3.63458498010+582.38116313410*x);
R0+=0.00000001188*cost(2.10062104535+423.88987789030*x);
R0+=0.00000001217*cost(2.49656109071+311.72600321060*x);
R0+=0.00000001080*cost(3.96349373526+118.87377689770*x);
R0+=0.00000001175*cost(0.91096377814+740.06929922580*x);
R0+=0.00000001087*cost(5.46774426742+494.47869076360*x);
R0+=0.00000001080*cost(3.49168860514+847.04604259770*x);
R0+=0.00000001095*cost(0.97418295319+1159.29331067010*x);
R0+=0.00000001078*cost(1.75579678521+1457.52593306200*x);
R0+=0.00000001087*cost(4.81206824168+109.68505635760*x);
R0+=0.00000001293*cost(0.02397468965+2723.09341168840*x);
R0+=0.00000001190*cost(4.49552956868+429.30650386170*x);
R0+=0.00000001127*cost(0.84707518843+48.75804477640*x);
R0+=0.00000001047*cost(4.58416926615+89.75945209430*x);
R0+=0.00000001251*cost(1.16783030789+455.16999895820*x);
R0+=0.00000001122*cost(5.72161306640+78263.70942472259*x);
R0+=0.00000001027*cost(0.16330222064+229.76142167330*x);
R0+=0.00000001069*cost(2.37188773221+848.53051530600*x);
R0+=0.00000001252*cost(5.28238896229+6080.82245481730*x);
R0+=0.00000001181*cost(5.22299379363+1459.95656727430*x);
R0+=0.00000001382*cost(0.51603096285+774.00954916960*x);
R0+=0.00000001064*cost(5.95222326171+1144.31545714310*x);
R0+=0.00000001083*cost(5.04862249728+629.86297800640*x);
R0+=0.00000001061*cost(3.38604454777+27.08733537390*x);
R0+=0.00000001415*cost(4.85796248007+2332.06295581640*x);
R0+=0.00000001082*cost(4.07686503205+1245.17299912800*x);
R0+=0.00000001112*cost(6.07617329506+870.46185713940*x);
R0+=0.00000001072*cost(0.73647405514+1482.79872732750*x);
R0+=0.00000001322*cost(2.81015928946+223.33340374560*x);
R0+=0.00000001398*cost(1.55232715558+25771.51127191760*x);
R0+=0.00000001065*cost(3.98884050015+683.18631549230*x);
R0+=0.00000001008*cost(5.19594380826+316.13123722570*x);
R0+=0.00000001197*cost(0.79148395839+9580.50180689780*x);
R0+=0.00000001402*cost(4.82957073563+883.79517926370*x);
R0+=0.00000001064*cost(4.65334775068+201.99276274320*x);
R0+=0.00000001108*cost(5.88857586823+657.16276170140*x);
R0+=0.00000000996*cost(4.99081076034+426.75824957040*x);
R0+=0.00000000996*cost(1.60533807224+426.43813218160*x);
R0+=0.00000001028*cost(5.92128319450+108.50940019000*x);
R0+=0.00000001004*cost(3.54259597860+754.03576079650*x);
R0+=0.00000001214*cost(0.81213286478+1773.91780271860*x);
R0+=0.00000001318*cost(0.60269176130+1123.11782849260*x);
R0+=0.00000001327*cost(4.75885008900+321.80849562800*x);
R0+=0.00000001014*cost(5.79119811472+6460.81221096080*x);
R0+=0.00000001178*cost(0.47169015111+495.96316347190*x);
R0+=0.00000000999*cost(5.95030119388+3906.90875709860*x);
R0+=0.00000001033*cost(3.75433174131+414.81877742920*x);
R0+=0.00000001002*cost(1.39171012432+1251.34038462480*x);
R0+=0.00000000990*cost(1.32621236288+1268.74887236410*x);
R0+=0.00000001275*cost(1.95417923977+757.80785536520*x);
R0+=0.00000001174*cost(6.04352585298+225.07850888480*x);
R0+=0.00000001174*cost(5.43253033568+849.26422848890*x);
R0+=0.00000001004*cost(5.33434806968+46.20979048510*x);
R0+=0.00000001108*cost(1.28177889943+294.30046912880*x);
R0+=0.00000000976*cost(1.83523959034+5.88970672340*x);
R0+=0.00000000971*cost(3.38563950019+306.09692891810*x);
R0+=0.00000001050*cost(3.88449467091+632.26247445140*x);
R0+=0.00000001050*cost(3.26096036982+159.71512552120*x);
R0+=0.00000001041*cost(2.36429894351+821.54375366860*x);
R0+=0.00000001218*cost(4.61739999906+990.22940591440*x);
R0+=0.00000001342*cost(1.55614528399+498.93210888850*x);
R0+=0.00000000967*cost(3.84645372731+604.47256366190*x);
R0+=0.00000001171*cost(0.42265751679+10011.03215103690*x);
R0+=0.00000000965*cost(0.05396772193+962.50893109410*x);
R0+=0.00000001096*cost(3.04685199735+608.40471692500*x);
R0+=0.00000001166*cost(6.14999706886+737.31280213030*x);
R0+=0.00000000986*cost(3.71830385737+1235.61177157240*x);
R0+=0.00000000953*cost(0.79704964354+16.46232623530*x);
R0+=0.00000000976*cost(1.05304205075+8.33738727820*x);
R0+=0.00000001142*cost(1.06057209808+369.97583957340*x);
R0+=0.00000001060*cost(4.36236322604+633.30500417500*x);
R0+=0.00000001138*cost(4.31859245106+98.42690777260*x);
R0+=0.00000001006*cost(5.89037944896+10007.09999777380*x);
R0+=0.00000000967*cost(1.56852913547+157.63995198190*x);
R0+=0.00000001082*cost(0.99548769517+4.14460158420*x);
R0+=0.00000001009*cost(6.15037679495+401.32539661050*x);
R0+=0.00000000981*cost(2.37620383333+35.21227433100*x);
R0+=0.00000001011*cost(5.42685471402+110.72758608120*x);
R0+=0.00000000989*cost(4.11575312649+413.85556958270*x);
R0+=0.00000001024*cost(1.90798238649+1175.80802653210*x);
R0+=0.00000001079*cost(4.95981991427+631.82053146670*x);
R0+=0.00000000982*cost(3.02842195594+347.41135829360*x);
R0+=0.00000000979*cost(3.74615289445+700.45179087970*x);
R0+=0.00000000928*cost(5.22236951137+1173.52040467170*x);
R0+=0.00000000912*cost(4.14451390992+469.72716135990*x);
R0+=0.00000000938*cost(1.18273838991+254.35289238260*x);
R0+=0.00000000977*cost(1.26684849112+104.57724692690*x);
R0+=0.00000001134*cost(5.87478488618+6058.73105428950*x);
R0+=0.00000001092*cost(4.51789158271+532.13864564940*x);
R0+=0.00000001132*cost(4.55420027150+1912.57831194120*x);
R0+=0.00000000915*cost(4.87266214195+18.91000679010*x);
R0+=0.00000000915*cost(5.96624579967+1987.21689815660*x);
R0+=0.00000001039*cost(2.40020830681+6475.03930496240*x);
R0+=0.00000000965*cost(4.98927479154+394.35486196160*x);
R0+=0.00000000964*cost(3.60903715900+3281.23856478620*x);
R0+=0.00000000897*cost(2.81660605059+316.23181096220*x);
R0+=0.00000001008*cost(5.78024010734+502.86426215160*x);
R0+=0.00000001005*cost(6.12431717236+6275.96230299060*x);
R0+=0.00000000895*cost(6.09245508513+316.55192835100*x);
R0+=0.00000001224*cost(1.73535287415+5120.60114558360*x);
R0+=0.00000001138*cost(2.92901543353+1037.29052966140*x);
R0+=0.00000000924*cost(5.70601816488+614.83694036960*x);
R0+=0.00000000893*cost(5.25155704274+475.35623565240*x);
R0+=0.00000001042*cost(1.10027795842+1518.22344997960*x);
R0+=0.00000000890*cost(4.03192782386+1314.32552340280*x);
R0+=0.00000000926*cost(3.35110915055+635.70450062000*x);
R0+=0.00000001130*cost(5.49282680494+92.94084583200*x);
R0+=0.00000000890*cost(2.12933822393+3384.33133900480*x);
R0+=0.00000000967*cost(5.86215202069+13.33332212430*x);
R0+=0.00000001004*cost(1.73116475997+10316.37832042960*x);
R0+=0.00000001226*cost(3.52834223937+80.41067285980*x);
R0+=0.00000001029*cost(4.90620832171+19.12245511120*x);
R0+=0.00000000996*cost(0.76740358631+733.42883297700*x);
R0+=0.00000000910*cost(4.08904906301+3333.49887969900*x);
R0+=0.00000001235*cost(1.23871819142+357.23321828010*x);
R0+=0.00000001218*cost(0.18349810348+1090.40141882620*x);
R0+=0.00000000864*cost(4.71917415767+620.25356634100*x);
R0+=0.00000000935*cost(1.45887009044+1042.91960395390*x);
R0+=0.00000000866*cost(4.04792682992+522.52923398400*x);
R0+=0.00000001158*cost(5.43322209110+1089.12939443900*x);
R0+=0.00000000860*cost(0.49220052417+64.95973858080*x);
R0+=0.00000001190*cost(5.58965369650+2810.92146160520*x);
R0+=0.00000000957*cost(3.12914047010+628.59095361920*x);
R0+=0.00000000861*cost(5.69790389801+103.84353374400*x);
R0+=0.00000001037*cost(5.91424823262+11.30633269480*x);
R0+=0.00000000918*cost(0.21424702155+373.01422095920*x);
R0+=0.00000000836*cost(3.02501867546+387.24131496080*x);
R0+=0.00000001158*cost(3.33343863758+6290.18939699220*x);
R0+=0.00000000856*cost(0.81593288669+907.37105249980*x);
R0+=0.00000001036*cost(3.11936047271+5429.87946823940*x);
R0+=0.00000000853*cost(6.23618175592+938.88066823130*x);
R0+=0.00000000982*cost(3.39082880963+521.61421024730*x);
R0+=0.00000000851*cost(5.14029961564+802.79380557290*x);
R0+=0.00000000828*cost(0.28399876908+338.48327018440*x);
R0+=0.00000000868*cost(1.89151676387+627.15466502070*x);
R0+=0.00000000878*cost(2.67671626912+688.65533109040*x);
R0+=0.00000000921*cost(0.18441593712+3803.81598288000*x);
R0+=0.00000000821*cost(0.74694467095+1152.17976366930*x);
R0+=0.00000000841*cost(2.42616504698+625.88264063350*x);
R0+=0.00000000862*cost(3.35273419872+425.32616648880*x);
R0+=0.00000000887*cost(3.46938383985+1748.78802080500*x);
R0+=0.00000000815*cost(5.95428642326+321.05773610260*x);
R0+=0.00000000958*cost(1.35525670354+1201.83158032300*x);
R0+=0.00000000905*cost(5.43093361027+236.87496867410*x);
R0+=0.00000000862*cost(3.24167644516+427.87021526320*x);
R0+=0.00000000793*cost(5.01131700831+109.99387289830*x);
R0+=0.00000000791*cost(2.21809404489+110.41876954050*x);
R0+=0.00000000842*cost(5.04957483651+444.12429869430*x);
R0+=0.00000000887*cost(4.23752031714+3553.91152213780*x);
R0+=0.00000000851*cost(4.64229745145+4105.98075853500*x);
R0+=0.00000001067*cost(4.69271921916+559.69906177530*x);
R0+=0.00000000966*cost(4.55013458162+9360.08916445900*x);
R0+=0.00000000977*cost(1.50925667031+186.47239249500*x);
R0+=0.00000001092*cost(0.58153747940+203.26478713040*x);
R0+=0.00000000997*cost(0.24589891452+439.93151300030*x);
R0+=0.00000000786*cost(3.84829878956+194.38908864790*x);
R0+=0.00000000774*cost(3.76050639310+219.14061805160*x);
R0+=0.00000000845*cost(4.21602090805+2648.45482547300*x);
R0+=0.00000000962*cost(0.30590569897+229.34073054800*x);
R0+=0.00000000763*cost(0.05577842075+846.13101886100*x);
R0+=0.00000000839*cost(5.68124142701+2620.00063746980*x);
R0+=0.00000000818*cost(2.52609626540+26301.20223701220*x);
R0+=0.00000000929*cost(0.71906225883+740.28174754690*x);
R0+=0.00000000895*cost(5.83218231202+4539.69249641180*x);
R0+=0.00000000939*cost(3.68460642343+817.77165909990*x);
R0+=0.00000000755*cost(4.90024080821+532.87235883230*x);
R0+=0.00000000784*cost(1.14096100609+551.03160609700*x);
R0+=0.00000000899*cost(1.85252071775+835.78789401270*x);
R0+=0.00000000753*cost(0.04254534997+1534.73816584160*x);
R0+=0.00000001033*cost(1.00137993270+134.11226285560*x);
R0+=0.00000000851*cost(6.12272864540+1475.68518032670*x);
R0+=0.00000000797*cost(5.14322789256+473.65931462300*x);
R0+=0.00000000729*cost(4.94931618796+476.10699517780*x);
R0+=0.00000000852*cost(3.11058720799+232.42155054920*x);
R0+=0.00000000783*cost(4.50805467439+1151.42900414390*x);
R0+=0.00000000751*cost(0.92289775523+1884.12412393800*x);
R0+=0.00000000832*cost(4.19686348297+29.20494752860*x);
R0+=0.00000000720*cost(0.40961041030+522.62560220360*x);
R0+=0.00000000722*cost(3.96121088528+1474.93442080130*x);
R0+=0.00000000788*cost(0.99170388242+121.84272231430*x);
R0+=0.00000000722*cost(4.16734185316+232.20910222810*x);
R0+=0.00000000970*cost(2.32204039048+566.60016045500*x);
R0+=0.00000000814*cost(5.19337022083+948.21240112330*x);
R0+=0.00000000724*cost(2.30837674225+949.12742486000*x);
R0+=0.00000000770*cost(5.89605163084+156.67674413540*x);
R0+=0.00000000705*cost(5.40102118863+1193.96727379680*x);
R0+=0.00000000809*cost(3.56474059969+845.33207522580*x);
R0+=0.00000000755*cost(3.94580797273+451.72797278960*x);
R0+=0.00000000731*cost(6.11847213487+1239.54392483550*x);
R0+=0.00000000747*cost(1.40599730465+782.34693644780*x);
R0+=0.00000000861*cost(1.84312374221+984.60033162190*x);
R0+=0.00000000695*cost(4.78088165969+10419.47109464820*x);
R0+=0.00000000804*cost(1.07998437400+89.00869256890*x);
R0+=0.00000000828*cost(5.86080569334+845.11962690470*x);
R0+=0.00000000692*cost(3.38736418117+6489.26139842860*x);
R0+=0.00000000694*cost(3.07863807714+316.60431797770*x);
R0+=0.00000000690*cost(5.86681311380+316.17942133550*x);
R0+=0.00000000714*cost(5.38707933404+567.82400073240*x);
R0+=0.00000000767*cost(0.12081849650+485.88067105450*x);
R0+=0.00000000820*cost(1.87877245664+499.89531673500*x);
R0+=0.00000000705*cost(0.57839934869+1053.75285589670*x);
R0+=0.00000000684*cost(4.88442270630+2545.36205125440*x);
R0+=0.00000000689*cost(6.14296395253+622.48879857470*x);
R0+=0.00000000823*cost(3.50224755884+877.57540414020*x);
R0+=0.00000000827*cost(2.59300433753+232.94281541100*x);
R0+=0.00000000735*cost(3.05650026582+66.91729204110*x);

double R1=0;
R1+=0.06182981282*cost(0.25843515034+213.29909543800*x);
R1+=0.00506577574*cost(0.71114650941+206.18554843720*x);
R1+=0.00341394136*cost(5.79635773960+426.59819087600*x);
R1+=0.00188491375*cost(0.47215719444+220.41264243880*x);
R1-=0.00186261540;
R1+=0.00143891176*cost(1.40744864239+7.11354700080*x);
R1+=0.00049621111*cost(6.01744469580+103.09277421860*x);
R1+=0.00020928189*cost(5.09245654470+639.89728631400*x);
R1+=0.00019952612*cost(1.17560125007+419.48464387520*x);
R1+=0.00018839639*cost(1.60819563173+110.20632121940*x);
R1+=0.00012892827*cost(5.94330258435+433.71173787680*x);
R1+=0.00013876565*cost(0.75886204364+199.07200143640*x);
R1+=0.00005396699*cost(1.28852405908+14.22709400160*x);
R1+=0.00004869308*cost(0.86793894213+323.50541665740*x);
R1+=0.00004247455*cost(0.39299384543+227.52618943960*x);
R1+=0.00003252084*cost(1.25853470491+95.97922721780*x);
R1+=0.00002856006*cost(2.16731405366+735.87651353180*x);
R1+=0.00002909411*cost(4.60679154788+202.25339517410*x);
R1+=0.00003081408*cost(3.43662557418+522.57741809380*x);
R1+=0.00001987689*cost(2.45054204795+412.37109687440*x);
R1+=0.00001941309*cost(6.02393385142+209.36694217490*x);
R1+=0.00001581446*cost(1.29191789712+210.11770170030*x);
R1+=0.00001339511*cost(4.30801821806+853.19638175200*x);
R1+=0.00001315590*cost(1.25296446023+117.31986822020*x);
R1+=0.00001203085*cost(1.86654673794+316.39186965660*x);
R1+=0.00001091088*cost(0.07527246854+216.48048917570*x);
R1+=0.00000954403*cost(5.15173410519+647.01083331480*x);
R1+=0.00000966012*cost(0.47991379141+632.78373931320*x);
R1+=0.00000881827*cost(1.88471724478+1052.26838318840*x);
R1+=0.00000874215*cost(1.40224683864+224.34479570190*x);
R1+=0.00000897512*cost(0.98343776092+529.69096509460*x);
R1+=0.00000784866*cost(3.06377517461+838.96928775040*x);
R1+=0.00000739892*cost(1.38225356694+625.67019231240*x);
R1+=0.00000612961*cost(3.03307306767+63.73589830340*x);
R1+=0.00000658210*cost(4.14362930980+309.27832265580*x);
R1+=0.00000649600*cost(1.72489486160+742.99006053260*x);
R1+=0.00000599236*cost(2.54924174765+217.23124870110*x);
R1+=0.00000502886*cost(2.12958819475+3.93215326310*x);
R1+=0.00000413017*cost(4.59334402271+415.55249061210*x);
R1+=0.00000356117*cost(2.30312127651+728.76296653100*x);
R1+=0.00000344777*cost(5.88787577835+440.82528487760*x);
R1+=0.00000395004*cost(0.53349091102+956.28915597060*x);
R1+=0.00000335526*cost(1.61614647174+1368.66025284500*x);
R1+=0.00000362772*cost(4.70691652867+302.16477565500*x);
R1+=0.00000321611*cost(0.97931764923+3.18139373770*x);
R1+=0.00000277783*cost(0.26007031431+195.13984817330*x);
R1+=0.00000291173*cost(2.83129427918+1155.36115740700*x);
R1+=0.00000264971*cost(2.42670902733+88.86568021700*x);
R1+=0.00000264864*cost(5.82860588985+149.56319713460*x);
R1+=0.00000316777*cost(3.58395655749+515.46387109300*x);
R1+=0.00000294324*cost(2.81632778983+11.04570026390*x);
R1+=0.00000244864*cost(1.04493438899+942.06206196900*x);
R1+=0.00000215368*cost(3.56535574833+490.33408917940*x);
R1+=0.00000264047*cost(1.28547685567+1059.38193018920*x);
R1+=0.00000246245*cost(0.90730313861+191.95845443560*x);
R1+=0.00000222077*cost(5.13193212050+269.92144674060*x);
R1+=0.00000194973*cost(4.56665009915+846.08283475120*x);
R1+=0.00000182802*cost(2.67913220473+127.47179660680*x);
R1+=0.00000181645*cost(4.93431600689+74.78159856730*x);
R1+=0.00000174651*cost(3.44560172182+137.03302416240*x);
R1+=0.00000165515*cost(5.99775895715+536.80451209540*x);
R1+=0.00000154809*cost(1.19720845085+265.98929347750*x);
R1+=0.00000169743*cost(4.63464467495+284.14854074220*x);
R1+=0.00000151526*cost(0.52928231044+330.61896365820*x);
R1+=0.00000152461*cost(5.43886711695+422.66603761290*x);
R1+=0.00000157687*cost(2.99559914619+340.77089204480*x);
R1+=0.00000140630*cost(2.02069760726+1045.15483618760*x);
R1+=0.00000139834*cost(1.35282959390+1685.05212250160*x);
R1+=0.00000140977*cost(1.27099900689+203.00415469950*x);
R1+=0.00000136013*cost(5.01678984678+351.81659230870*x);
R1+=0.00000153391*cost(0.26968607873+1272.68102562720*x);
R1+=0.00000129476*cost(1.14344730612+21.34064100240*x);
R1+=0.00000127831*cost(2.53876158952+1471.75302706360*x);
R1+=0.00000126538*cost(3.00310970076+277.03499374140*x);
R1+=0.00000100277*cost(3.61360169153+1066.49547719000*x);
R1+=0.00000103169*cost(0.38175114761+203.73786788240*x);
R1+=0.00000107527*cost(4.31870663477+210.85141488320*x);
R1+=0.00000095934*cost(0.79463744168+1258.45393162560*x);
R1+=0.00000082663*cost(0.28181414606+234.63973644040*x);
R1+=0.00000097986*cost(2.56085956186+191.20769491020*x);
R1+=0.00000097389*cost(3.26245865063+831.85574074960*x);
R1+=0.00000072227*cost(4.37984630380+860.30992875280*x);
R1+=0.00000070639*cost(0.73191513920+437.64389113990*x);
R1+=0.00000070447*cost(0.87698401733+423.41679713830*x);
R1+=0.00000072057*cost(5.58013290518+429.77958461370*x);
R1+=0.00000073332*cost(0.62505906432+1375.77379984580*x);
R1+=0.00000066433*cost(2.68414462465+405.25754987360*x);
R1+=0.00000063812*cost(1.75051498180+1361.54670584420*x);
R1+=0.00000061601*cost(1.09332288242+2001.44399215820*x);
R1+=0.00000067006*cost(0.06872766216+408.43894361130*x);
R1+=0.00000068945*cost(2.47127505057+949.17560896980*x);
R1+=0.00000060456*cost(2.25094790113+1788.14489672020*x);
R1+=0.00000067074*cost(5.45365870159+200.76892246580*x);
R1+=0.00000065579*cost(0.05539079332+1589.07289528380*x);
R1+=0.00000049320*cost(4.17243429807+138.51749687070*x);
R1+=0.00000050648*cost(6.26867505289+223.59403617650*x);
R1+=0.00000055166*cost(4.59491533823+628.85158605010*x);
R1+=0.00000047916*cost(0.83929741626+10.29494073850*x);
R1+=0.00000046691*cost(2.17322569098+312.19908396260*x);
R1+=0.00000054179*cost(0.28360076018+124.43341522100*x);
R1+=0.00000049511*cost(3.79960349195+215.74677599280*x);
R1+=0.00000040136*cost(5.18161452756+1478.86657406440*x);
R1+=0.00000039302*cost(0.56257369109+1574.84580128220*x);
R1+=0.00000034962*cost(4.68487505703+38.13303563780*x);
R1+=0.00000042770*cost(2.98582069454+1148.24761040620*x);
R1+=0.00000036521*cost(0.63453270366+52.69019803950*x);
R1+=0.00000039752*cost(0.28412706854+131.40394986990*x);
R1+=0.00000031777*cost(5.19036499973+76.26607127560*x);
R1+=0.00000033041*cost(1.97964846430+142.44965013380*x);
R1+=0.00000042053*cost(4.83017951800+288.08069400530*x);
R1+=0.00000030757*cost(1.47903923433+1677.93857550080*x);
R1+=0.00000042829*cost(3.38225543528+208.63322899200*x);
R1+=0.00000029245*cost(5.09869866956+654.12438031560*x);
R1+=0.00000029165*cost(4.95664881649+1795.25844372100*x);
R1+=0.00000029136*cost(2.74747553685+404.50679034820*x);
R1+=0.00000032689*cost(6.12099521344+145.63104387150*x);
R1+=0.00000028008*cost(0.83185907283+2317.83586181480*x);
R1+=0.00000027725*cost(2.24364073545+430.53034413910*x);
R1+=0.00000029939*cost(1.96415498448+2104.53676637680*x);
R1+=0.00000032982*cost(3.28236160491+222.86032299360*x);
R1+=0.00000031772*cost(6.02453027348+1905.46476494040*x);
R1+=0.00000026959*cost(5.24308283338+388.46515523820*x);
R1+=0.00000026514*cost(0.99638302878+107.02492748170*x);
R1+=0.00000025421*cost(2.87336642463+703.63318461740*x);
R1+=0.00000024908*cost(1.07713811775+99.91138048090*x);
R1+=0.00000024955*cost(6.23974037842+106.27416795630*x);
R1+=0.00000024894*cost(0.81040976807+312.45971639350*x);
R1+=0.00000024340*cost(0.54867402916+214.26230328450*x);
R1+=0.00000028441*cost(0.82630052794+1692.16566950240*x);
R1+=0.00000023219*cost(5.07995629354+479.28838891550*x);
R1+=0.00000024362*cost(3.10643455533+212.33588759150*x);
R1+=0.00000021951*cost(6.06688237952+85.82729883120*x);
R1+=0.00000022046*cost(3.89863665506+563.63121503840*x);
R1+=0.00000022596*cost(4.86725457223+295.05122865420*x);
R1+=0.00000021256*cost(5.10797617452+333.65734504400*x);
R1+=0.00000025985*cost(2.20813879137+1265.56747862640*x);
R1+=0.00000020904*cost(3.28855303434+70.84944530420*x);
R1+=0.00000021505*cost(3.79541155976+347.88443904560*x);
R1+=0.00000022067*cost(4.22716352578+217.96496188400*x);
R1+=0.00000020629*cost(1.68732248608+231.45834270270*x);
R1+=0.00000021429*cost(3.08914428467+554.06998748280*x);
R1+=0.00000021310*cost(0.38868340861+319.57326339430*x);
R1+=0.00000020521*cost(2.45651851283+18.15924726470*x);
R1+=0.00000026055*cost(4.27554951169+483.22054217860*x);
R1+=0.00000020703*cost(5.12057936320+362.86229257260*x);
R1+=0.00000022047*cost(5.51249354809+343.21857259960*x);
R1+=0.00000019443*cost(2.02441679295+313.21047591890*x);
R1+=0.00000020163*cost(5.08481373110+750.10360753340*x);
R1+=0.00000020125*cost(3.42997916125+213.34727954780*x);
R1+=0.00000024196*cost(0.64787472796+207.88246946660*x);
R1+=0.00000021977*cost(0.72894956852+99.16062095550*x);
R1+=0.00000021120*cost(2.69286728009+1464.63948006280*x);
R1+=0.00000017192*cost(4.71525117969+2111.65031337760*x);
R1+=0.00000018540*cost(0.04817255506+245.54242435240*x);
R1+=0.00000017521*cost(3.83662880684+497.44763618020*x);
R1+=0.00000016107*cost(4.22374822303+565.11568774670*x);
R1+=0.00000021607*cost(4.16647257628+2.44768055480*x);
R1+=0.00000015979*cost(0.27376396113+225.82926841020*x);
R1+=0.00000016831*cost(1.41134653939+114.13847448250*x);
R1+=0.00000015626*cost(2.82768623405+81.75213321620*x);
R1+=0.00000015499*cost(1.20606390539+1994.33044515740*x);
R1+=0.00000015168*cost(3.84591816174+1162.47470440780*x);
R1+=0.00000016436*cost(3.04752365976+134.58534360760*x);
R1+=0.00000015870*cost(0.33026420429+1891.23767093880*x);
R1+=0.00000020370*cost(0.23170286692+213.25091132820*x);
R1+=0.00000016291*cost(1.70643197929+2420.92863603340*x);
R1+=0.00000016280*cost(4.94159427320+357.44566660120*x);
R1+=0.00000018076*cost(5.69515344123+56.62235130260*x);
R1+=0.00000013724*cost(0.57240190030+2634.22773147140*x);
R1+=0.00000017355*cost(3.55311137444+218.92816973050*x);
R1+=0.00000013740*cost(5.70545527289+92.04707395470*x);
R1+=0.00000015328*cost(1.31338692850+216.21985674480*x);
R1+=0.00000012538*cost(5.19222019427+635.96513305090*x);
R1+=0.00000012815*cost(1.60151130870+320.32402291970*x);
R1+=0.00000013043*cost(0.45068441373+1169.58825140860*x);
R1+=0.00000011984*cost(5.94916123570+543.91805909620*x);
R1+=0.00000011753*cost(2.80279347133+217.49188113200*x);
R1+=0.00000014746*cost(5.56520105813+344.70304530790*x);
R1+=0.00000012762*cost(1.63557330778+273.10284047830*x);
R1+=0.00000011855*cost(2.46234840263+721.64941953020*x);
R1+=0.00000013309*cost(5.75641013916+2221.85663459700*x);
R1+=0.00000014471*cost(0.45316163629+2008.55753915900*x);
R1+=0.00000011840*cost(1.75720772380+160.60889739850*x);
R1+=0.00000012374*cost(1.01456317602+329.72519178090*x);
R1+=0.00000010747*cost(1.58065203003+212.77783057620*x);
R1+=0.00000012758*cost(1.91952373240+1581.95934828300*x);
R1+=0.00000011944*cost(4.44720922423+32.24332891440*x);
R1+=0.00000011865*cost(5.10696147162+4.66586644600*x);
R1+=0.00000011861*cost(4.30847607078+618.55664531160*x);
R1+=0.00000010036*cost(0.48709852137+305.34616939270*x);
R1+=0.00000012777*cost(3.74412991331+508.35032409220*x);
R1+=0.00000010677*cost(0.76645916273+218.71572140940*x);
R1+=0.00000011351*cost(3.00009819697+198.32124191100*x);
R1+=0.00000010249*cost(2.40923650192+546.95644048200*x);
R1+=0.00000009984*cost(2.63882014753+416.30325013750*x);
R1+=0.00000009345*cost(5.45917317860+414.06801790380*x);
R1+=0.00000009317*cost(4.46380159546+2428.04218303420*x);
R1+=0.00000009928*cost(4.04821559448+62.25142559510*x);
R1+=0.00000012767*cost(3.43273835457+258.87574647670*x);
R1+=0.00000009733*cost(1.61066324680+327.43756992050*x);
R1+=0.00000011163*cost(2.40665325234+1781.03134971940*x);
R1+=0.00000010608*cost(2.07480020830+213.82036029980*x);
R1+=0.00000009125*cost(2.92369523159+1279.79457262800*x);
R1+=0.00000009525*cost(1.10338403136+113.38771495710*x);
R1+=0.00000009805*cost(3.28427768485+275.55052103310*x);
R1+=0.00000011263*cost(1.89402915826+561.18353448360*x);
R1+=0.00000008572*cost(2.17858055966+425.11371816770*x);
R1+=0.00000008577*cost(1.95484887975+35.42472265210*x);
R1+=0.00000010157*cost(0.09037368733+182.27960680100*x);
R1+=0.00000011807*cost(3.71278037583+350.33211960040*x);
R1+=0.00000008595*cost(1.83382454431+629.60234557550*x);
R1+=0.00000008396*cost(3.76782674303+251.43213107580*x);
R1+=0.00000008460*cost(0.35676476459+617.80588578620*x);
R1+=0.00000008250*cost(5.31140994372+65.22037101170*x);
R1+=0.00000008342*cost(1.38307663880+1.48447270830*x);
R1+=0.00000007987*cost(5.13622898170+22.09140052780*x);
R1+=0.00000008377*cost(0.91817077859+1485.98012106520*x);
R1+=0.00000007980*cost(0.94199750915+2310.72231481400*x);
R1+=0.00000008898*cost(0.54037636841+168.05251279940*x);
R1+=0.00000008233*cost(3.45785310349+424.15051032120*x);
R1+=0.00000008034*cost(3.38451795597+144.14657116320*x);
R1+=0.00000007871*cost(5.14041888473+358.93013930950*x);
R1+=0.00000008868*cost(6.13541788772+621.73803904930*x);
R1+=0.00000007523*cost(5.75475671698+447.93883187840*x);
R1+=0.00000007515*cost(2.18967849979+264.50482076920*x);
R1+=0.00000008083*cost(1.42661116937+2737.32050569000*x);
R1+=0.00000008199*cost(0.96419579079+767.36908292080*x);
R1+=0.00000008232*cost(0.35471613534+278.51946644970*x);
R1+=0.00000008226*cost(5.44467204721+254.94359321360*x);
R1+=0.00000006779*cost(1.19567671732+5.41662597140*x);
R1+=0.00000008928*cost(4.88240256153+120.35824960600*x);
R1+=0.00000007845*cost(4.56376829397+280.96714700450*x);
R1+=0.00000006566*cost(3.50152072308+9.56122755560*x);
R1+=0.00000006398*cost(0.33471834269+2950.61960112800*x);
R1+=0.00000006881*cost(3.39438820076+98.89998852460*x);
R1+=0.00000007418*cost(4.52451404934+5.62907429250*x);
R1+=0.00000008021*cost(0.94470052446+636.71589257630*x);
R1+=0.00000006134*cost(0.18013315689+2207.62954059540*x);
R1+=0.00000007153*cost(3.85218295688+214.04985496340*x);
R1+=0.00000006046*cost(4.66733263196+543.02428721890*x);
R1+=0.00000006365*cost(2.12000811873+274.06604832480*x);
R1+=0.00000006481*cost(5.31032923608+6076.89030155420*x);
R1+=0.00000005935*cost(6.16808119163+650.94298657790*x);
R1+=0.00000005752*cost(3.55773840903+1073.60902419080*x);
R1+=0.00000006438*cost(0.44934410249+10007.09999777380*x);
R1+=0.00000006283*cost(3.20942251433+219.44943459230*x);
R1+=0.00000005542*cost(3.61193204407+125.98732389850*x);
R1+=0.00000005522*cost(3.84217355164+181.05576652360*x);
R1+=0.00000005777*cost(3.00590926498+121.25202148330*x);
R1+=0.00000006670*cost(1.65236689367+1898.35121793960*x);
R1+=0.00000007591*cost(0.10483002359+2324.94940881560*x);
R1+=0.00000005881*cost(1.04006410206+9992.87290377220*x);
R1+=0.00000005609*cost(4.83142709229+643.07868005170*x);
R1+=0.00000005569*cost(2.23863483508+1038.04128918680*x);
R1+=0.00000005755*cost(5.91598458372+6062.66320755260*x);
R1+=0.00000005845*cost(6.10234689502+209.10630974400*x);
R1+=0.00000005577*cost(0.81426649853+472.17484191470*x);
R1+=0.00000005247*cost(0.56496127013+192.69216761850*x);
R1+=0.00000005493*cost(5.81071309534+237.67811782620*x);
R1+=0.00000005148*cost(4.85160826999+267.47376618580*x);
R1+=0.00000006122*cost(2.11480301005+2097.42321937600*x);
R1+=0.00000006188*cost(4.59441762166+207.67002114550*x);
R1+=0.00000006303*cost(0.75806431119+210.37833413120*x);
R1+=0.00000005102*cost(4.01017179605+205.22234059070*x);
R1+=0.00000006583*cost(1.79054357427+12.53017297220*x);
R1+=0.00000004902*cost(0.85099521860+247.23934538180*x);
R1+=0.00000004918*cost(4.03512681632+487.36514376280*x);
R1+=0.00000005818*cost(5.48495503489+2538.24850425360*x);
R1+=0.00000004855*cost(4.18197778083+2744.43405269080*x);
R1+=0.00000004885*cost(0.25103933716+129.91947716160*x);
R1+=0.00000005748*cost(0.55968589618+116.42609634290*x);
R1+=0.00000004901*cost(4.48628916012+291.26208774300*x);
R1+=0.00000004720*cost(5.57686152365+342.25536475310*x);
R1+=0.00000005962*cost(5.12885837444+692.58748435350*x);
R1+=0.00000005629*cost(4.39847572369+196.62432088160*x);
R1+=0.00000005596*cost(0.94874135403+1802.37199072180*x);
R1+=0.00000006197*cost(3.80364010966+339.28641933650*x);
R1+=0.00000004668*cost(3.16816375033+148.07872442630*x);
R1+=0.00000004891*cost(2.67234862638+417.03696332040*x);
R1+=0.00000004959*cost(1.63453587065+166.82867252200*x);
R1+=0.00000004408*cost(4.95179678525+184.09414790940*x);
R1+=0.00000004449*cost(5.69134789394+252.65597135320*x);
R1+=0.00000004943*cost(0.85358212806+46.47042291600*x);
R1+=0.00000005153*cost(3.82176885491+842.15068148810*x);
R1+=0.00000005930*cost(5.95484153666+486.40193591630*x);
R1+=0.00000004206*cost(2.97664198894+380.12776796000*x);
R1+=0.00000004467*cost(0.24914978400+128.95626931510*x);
R1+=0.00000005419*cost(6.19106890918+337.73251065900*x);
R1+=0.00000004499*cost(4.71434958315+151.04766984290*x);
R1+=0.00000004233*cost(4.18702525973+685.47393735270*x);
R1+=0.00000004695*cost(1.54881559549+214.78356814630*x);
R1+=0.00000004084*cost(4.87173226400+14.97785352700*x);
R1+=0.00000004321*cost(5.42615168860+436.89313161450*x);
R1+=0.00000005145*cost(0.49931857511+248.72381809010*x);
R1+=0.00000003897*cost(0.74661138504+2627.11418447060*x);
R1+=0.00000003995*cost(3.07750371135+710.74673161820*x);
R1+=0.00000004089*cost(5.81996977038+491.81856188770*x);
R1+=0.00000004532*cost(3.67494714028+189.72322220190*x);
R1+=0.00000003690*cost(1.26565281569+211.81462272970*x);
R1+=0.00000004036*cost(1.15473702593+3053.71237534660*x);
R1+=0.00000003672*cost(4.52661018437+488.84961647110*x);
R1+=0.00000003662*cost(2.87243745783+411.62033734900*x);
R1+=0.00000003653*cost(3.06205147988+409.92341631960*x);
R1+=0.00000003908*cost(3.45947158106+220.46082654860*x);
R1+=0.00000004989*cost(3.36376245705+824.74219374880*x);
R1+=0.00000003677*cost(3.55713278092+244.31858407500*x);
R1+=0.00000003580*cost(1.57825591891+643.82943957710*x);
R1+=0.00000003546*cost(2.19846245030+135.33610313300*x);
R1+=0.00000003560*cost(4.51362022045+601.76425067620*x);
R1+=0.00000003843*cost(0.98567531677+271.40591944890*x);
R1+=0.00000003559*cost(1.11005765159+6283.07584999140*x);
R1+=0.00000004266*cost(6.19696005871+268.43697403230*x);
R1+=0.00000003442*cost(4.27628882392+867.42347575360*x);
R1+=0.00000004844*cost(3.73706907228+235.39049596580*x);
R1+=0.00000003659*cost(2.21859531609+2.92076130680*x);
R1+=0.00000003958*cost(5.17084570945+114.39910691340*x);
R1+=0.00000003609*cost(5.54387488088+458.84151979040*x);
R1+=0.00000004470*cost(3.74256930900+699.70103135430*x);
R1+=0.00000003293*cost(4.48068043469+289.56516671360*x);
R1+=0.00000003240*cost(5.94728881707+131.54696222180*x);
R1+=0.00000003477*cost(3.54553285172+963.40270297140*x);
R1+=0.00000003838*cost(4.77967877681+175.16605980020*x);
R1+=0.00000003223*cost(1.95410765469+212.02707105080*x);
R1+=0.00000004053*cost(4.19011281964+501.37978944330*x);
R1+=0.00000003100*cost(2.11956558345+916.93228005540*x);
R1+=0.00000003183*cost(1.93201605379+1354.43315884340*x);
R1+=0.00000003301*cost(1.80825506815+756.32338265690*x);
R1+=0.00000004187*cost(5.96622666047+212.54833591260*x);
R1+=0.00000003716*cost(3.70660462807+204.70107572890*x);
R1+=0.00000003000*cost(6.15443664698+3267.01147078460*x);
R1+=0.00000002993*cost(4.20888489881+533.62311835770*x);
R1+=0.00000004125*cost(6.09715151219+2641.34127847220*x);
R1+=0.00000003145*cost(2.55483540896+905.88657979150*x);
R1+=0.00000002982*cost(1.52760656472+945.99421523210*x);
R1+=0.00000003015*cost(1.76012152992+28.31117565130*x);
R1+=0.00000003453*cost(1.42473508236+2214.74308759620*x);
R1+=0.00000002926*cost(5.50138147476+24.37902238820*x);
R1+=0.00000002978*cost(4.27440059910+195.89060769870*x);
R1+=0.00000003526*cost(3.63935401565+229.97386999440*x);
R1+=0.00000002860*cost(4.52551886503+241.61027108930*x);
R1+=0.00000003059*cost(5.68165832697+282.66406803390*x);
R1+=0.00000003415*cost(5.26311934884+67.66805156650*x);
R1+=0.00000002819*cost(5.42053027567+305.08553696180*x);
R1+=0.00000003503*cost(1.31670335802+69.15252427480*x);
R1+=0.00000002746*cost(0.82597971627+444.75743814070*x);
R1+=0.00000002796*cost(0.07021047160+681.54178408960*x);
R1+=0.00000003366*cost(4.03843228994+6.15033915430*x);
R1+=0.00000003242*cost(2.63461047831+739.80866679490*x);
R1+=0.00000002718*cost(3.40899287465+188.92007304980*x);
R1+=0.00000002741*cost(3.22092213412+776.93031047640*x);
R1+=0.00000002793*cost(3.39766347322+431.26405732200*x);
R1+=0.00000002966*cost(3.91429372950+526.50957135690*x);
R1+=0.00000002693*cost(3.38996413068+778.41478318470*x);
R1+=0.00000002680*cost(3.82192393959+3060.82592234740*x);
R1+=0.00000002954*cost(2.69669880207+426.64637498580*x);
R1+=0.00000002681*cost(1.04615621583+28.45418800320*x);
R1+=0.00000003182*cost(2.72333374876+432.22726516850*x);
R1+=0.00000002633*cost(2.55029306465+10213.28554621100*x);
R1+=0.00000002923*cost(0.85695094024+2435.15573003500*x);
R1+=0.00000002596*cost(5.42890752137+207.14875628370*x);
R1+=0.00000003225*cost(0.96538615730+2118.76386037840*x);
R1+=0.00000002774*cost(0.33260844270+326.68681039510*x);
R1+=0.00000002550*cost(5.88893697427+439.12836384820*x);
R1+=0.00000002716*cost(3.15505406487+170.76082578510*x);
R1+=0.00000002942*cost(4.88555233562+397.39324334740*x);
R1+=0.00000003121*cost(1.87815629157+2413.81508903260*x);
R1+=0.00000003263*cost(2.59868619716+213.03846300710*x);
R1+=0.00000002518*cost(0.15471130491+945.24345570670*x);
R1+=0.00000003169*cost(5.70993651497+381.35160823740*x);
R1+=0.00000002515*cost(0.06248441393+427.56139872250*x);
R1+=0.00000003279*cost(4.95751323467+313.94418910180*x);
R1+=0.00000002595*cost(5.13169797457+299.12639426920*x);
R1+=0.00000002572*cost(3.42558391509+4.19278569400*x);
R1+=0.00000002580*cost(2.03280916494+319.31263096340*x);
R1+=0.00000003294*cost(6.24566168486+421.18156490460*x);
R1+=0.00000002580*cost(2.62721090534+213.18722085340*x);
R1+=0.00000002879*cost(0.45679876898+285.63301345050*x);
R1+=0.00000002406*cost(4.57473098758+228.27694896500*x);
R1+=0.00000002518*cost(2.55500085830+140.00196957900*x);
R1+=0.00000002422*cost(2.36310658303+84.34282612290*x);
R1+=0.00000002374*cost(2.25544718932+17.26547538740*x);
R1+=0.00000002627*cost(1.26370339212+724.83081326790*x);
R1+=0.00000002346*cost(3.77641630157+206.23373254700*x);
R1+=0.00000002463*cost(5.42094278240+395.57870223900*x);
R1+=0.00000002352*cost(0.63041319237+210.59078245230*x);
R1+=0.00000003166*cost(0.26273580642+201.51968199120*x);
R1+=0.00000002405*cost(0.78919759458+426.07692601420*x);
R1+=0.00000002390*cost(5.89523812458+738.79727483860*x);
R1+=0.00000002515*cost(0.70044371265+2943.50605412720*x);
R1+=0.00000002332*cost(4.06963624306+519.39602435610*x);
R1+=0.00000003132*cost(2.79331632190+732.69511979410*x);
R1+=0.00000002658*cost(3.34020209714+1141.13406340540*x);
R1+=0.00000002258*cost(0.12403309730+2524.02141025200*x);
R1+=0.00000002697*cost(2.58404587754+425.63498302950*x);
R1+=0.00000002416*cost(3.85003724506+696.51963761660*x);
R1+=0.00000002597*cost(2.54164936697+436.15941843160*x);
R1+=0.00000002192*cost(3.07202313269+203.26478713040*x);
R1+=0.00000002424*cost(2.60715310452+511.53171782990*x);
R1+=0.00000002126*cost(0.14811901148+405.99126305650*x);
R1+=0.00000002306*cost(1.25068142377+427.11945573780*x);
R1+=0.00000002121*cost(0.43505808954+184.98791978670*x);
R1+=0.00000002755*cost(3.02380019321+468.24268865160*x);
R1+=0.00000002333*cost(3.02634928771+216.00740842370*x);
R1+=0.00000002182*cost(4.27912012069+7.16173111060*x);
R1+=0.00000002101*cost(4.31781498012+572.22923474750*x);
R1+=0.00000002362*cost(4.82914341110+556.51766803760*x);
R1+=0.00000002218*cost(0.82936075453+3370.10424500320*x);
R1+=0.00000002103*cost(5.25950154713+661.23792731640*x);
R1+=0.00000002580*cost(1.03705340380+213.41097002260*x);
R1+=0.00000002366*cost(6.14368355608+205.43478891180*x);
R1+=0.00000002042*cost(0.21462094901+3259.89792378380*x);
R1+=0.00000002547*cost(4.69969204009+221.37585028530*x);
R1+=0.00000001987*cost(3.22670561632+1382.88734684660*x);
R1+=0.00000002213*cost(0.89932827487+286.59622129700*x);
R1+=0.00000002191*cost(0.08759174058+259.76951835400*x);
R1+=0.00000001968*cost(0.57824086026+180.16199464630*x);
R1+=0.00000002037*cost(2.35713099759+610.69233878540*x);
R1+=0.00000001959*cost(2.18553775379+72.07328558160*x);
R1+=0.00000002061*cost(1.68041202479+1670.82502850000*x);
R1+=0.00000001940*cost(0.62951066481+406.95447090300*x);
R1+=0.00000002043*cost(4.39130144045+576.16138801060*x);
R1+=0.00000001936*cost(1.05286934530+1262.38608488870*x);
R1+=0.00000001975*cost(0.31945835160+938.12990870590*x);
R1+=0.00000002015*cost(1.66410213484+193.65537546500*x);
R1+=0.00000001971*cost(0.72639439054+200.55647414470*x);
R1+=0.00000001952*cost(6.25320630177+241.75328344120*x);
R1+=0.00000001976*cost(1.31263772699+135.54855145410*x);
R1+=0.00000002448*cost(0.52850194172+429.51895218280*x);
R1+=0.00000001977*cost(3.13944703383+421.93232443000*x);
R1+=0.00000001853*cost(0.17184530353+196.03362005060*x);
R1+=0.00000002552*cost(5.39764879348+2854.64037391020*x);
R1+=0.00000001830*cost(1.47821899466+638.41281360570*x);
R1+=0.00000002245*cost(6.00427164270+230.70758317730*x);
R1+=0.00000001822*cost(6.08626100417+1261.63532536330*x);
R1+=0.00000002168*cost(0.41741136149+213.51154375910*x);
R1+=0.00000001869*cost(3.67791368036+403.02231763990*x);
R1+=0.00000001866*cost(1.59662677545+391.17346822390*x);
R1+=0.00000002034*cost(1.21814866092+3046.59882834580*x);
R1+=0.00000001929*cost(4.93193335031+420.96911658350*x);
R1+=0.00000001746*cost(5.09757251683+107.75864066460*x);
R1+=0.00000002168*cost(3.24685294764+213.08664711690*x);
R1+=0.00000002178*cost(5.09777299346+558.00214074590*x);
R1+=0.00000001992*cost(2.29524873043+1773.91780271860*x);
R1+=0.00000001761*cost(2.88655624670+141.69889060840*x);
R1+=0.00000001769*cost(5.47051542758+206.13736432740*x);
R1+=0.00000001734*cost(2.11941015901+430.79097657000*x);
R1+=0.00000002377*cost(1.07633521570+59.80374504030*x);
R1+=0.00000001797*cost(2.90984583978+92.79783348010*x);
R1+=0.00000001725*cost(5.22827286197+757.21715453420*x);
R1+=0.00000002305*cost(5.88235807192+426.55000676620*x);
R1+=0.00000001751*cost(5.28990803470+87.31177153950*x);
R1+=0.00000002202*cost(1.28096946505+624.91943278700*x);
R1+=0.00000002043*cost(0.46193065602+831.10498122420*x);
R1+=0.00000001931*cost(1.26974971942+219.89137757700*x);
R1+=0.00000001953*cost(2.96900002385+398.14400287280*x);
R1+=0.00000001676*cost(4.81683149512+181.80652604900*x);
R1+=0.00000001902*cost(2.74426125465+4952.06359328620*x);
R1+=0.00000002133*cost(5.37177705284+627.36711334180*x);
R1+=0.00000001962*cost(3.52111949662+213.45915413240*x);
R1+=0.00000001709*cost(6.14073761844+952.35700270750*x);
R1+=0.00000001784*cost(1.05243716682+353.30106501700*x);
R1+=0.00000001700*cost(1.17418864170+739.05790726950*x);
R1+=0.00000001609*cost(1.35009554392+84.93352695390*x);
R1+=0.00000002038*cost(2.47570829812+26.82670294300*x);
R1+=0.00000001870*cost(5.61729116529+2957.73314812880*x);
R1+=0.00000001962*cost(0.13564680851+213.13903674360*x);
R1+=0.00000002041*cost(3.31354526279+1596.18644228460*x);
R1+=0.00000001612*cost(6.19495100885+432.01481684740*x);
R1+=0.00000001742*cost(2.87947098602+179.35884549420*x);
R1+=0.00000001964*cost(2.84253666387+429.04587143080*x);
R1+=0.00000001805*cost(0.60932632638+532.61172640140*x);
R1+=0.00000001647*cost(0.82347900016+214.57111982520*x);
R1+=0.00000001893*cost(4.33962647901+173.94221952280*x);
R1+=0.00000001689*cost(1.13037158144+586.31331639720*x);
R1+=0.00000001523*cost(2.71561930244+73.29712585900*x);
R1+=0.00000001524*cost(5.26558677448+5429.87946823940*x);
R1+=0.00000001582*cost(2.79533721474+842.90144101350*x);
R1+=0.00000001608*cost(2.33230359324+418.52143602870*x);
R1+=0.00000001579*cost(1.15182102801+731.94436026870*x);
R1+=0.00000001689*cost(1.91915438546+630.33605875840*x);
R1+=0.00000001990*cost(5.23790221176+550.13783421970*x);
R1+=0.00000001772*cost(2.95372411478+172.24529849340*x);
R1+=0.00000001596*cost(0.99004701777+953.10776223290*x);
R1+=0.00000001784*cost(3.91391032360+159.12442469020*x);
R1+=0.00000001592*cost(2.99690086808+45.57665103870*x);
R1+=0.00000001968*cost(0.23073879009+220.36445832900*x);
R1+=0.00000001549*cost(5.88699595922+60.55450456570*x);
R1+=0.00000001459*cost(5.51999778036+273.85360000370*x);
R1+=0.00000001909*cost(2.78415262815+418.00017116690*x);
R1+=0.00000001445*cost(3.25530914937+453.42489381900*x);
R1+=0.00000001454*cost(0.16250693313+115.62294719080*x);
R1+=0.00000001566*cost(2.24077018103+1056.20053645150*x);
R1+=0.00000001412*cost(3.45442909885+354.99798604640*x);
R1+=0.00000001564*cost(3.38591337689+409.18970313670*x);
R1+=0.00000001631*cost(1.06286709889+213.55972786890*x);
R1+=0.00000001415*cost(1.32091877590+373.90799283650*x);
R1+=0.00000001389*cost(0.40584159469+9360.08916445900*x);
R1+=0.00000001663*cost(2.33357114562+188.02630117250*x);
R1+=0.00000001426*cost(5.44677783737+864.24208201590*x);
R1+=0.00000001716*cost(3.96056093028+1699.27921650320*x);
R1+=0.00000001682*cost(0.39747670320+17.40848773930*x);
R1+=0.00000001368*cost(5.83289186692+569.04784100980*x);
R1+=0.00000001416*cost(3.65464640816+6.85291456990*x);
R1+=0.00000001469*cost(3.49069193830+934.94851496820*x);
R1+=0.00000001330*cost(4.41794310534+3914.02230409940*x);
R1+=0.00000001309*cost(1.29979865382+428.08266358430*x);
R1+=0.00000001300*cost(1.57748627871+238.57188970350*x);
R1+=0.00000001389*cost(1.31202796503+6275.96230299060*x);
R1+=0.00000001384*cost(0.67585082323+2751.54759969160*x);
R1+=0.00000001471*cost(1.21149871903+2531.13495725280*x);
R1+=0.00000001334*cost(4.11154515525+206.93630796260*x);
R1+=0.00000001601*cost(0.93356520728+355.74874557180*x);
R1+=0.00000001259*cost(2.56678207309+850.01498801430*x);
R1+=0.00000001277*cost(0.41764451386+100.64509366380*x);
R1+=0.00000001436*cost(4.06045514506+177.87437278590*x);
R1+=0.00000001308*cost(1.01324076289+423.67742956920*x);
R1+=0.00000001541*cost(6.03020449918+292.01284726840*x);
R1+=0.00000001307*cost(5.83815678434+5863.59120611620*x);
R1+=0.00000001613*cost(2.45074803642+1049.08698945070*x);
R1+=0.00000001249*cost(3.01518429832+464.73122651380*x);
R1+=0.00000001250*cost(6.23516728885+823.99143422340*x);
R1+=0.00000001275*cost(2.68217384213+637.44960575920*x);
R1+=0.00000001249*cost(2.97028182853+51749.20809227239*x);
R1+=0.00000001240*cost(2.66940683813+2700.71514038580*x);
R1+=0.00000001456*cost(1.85558224828+96.87299909510*x);
R1+=0.00000001491*cost(4.98649587341+295.19424100610*x);
R1+=0.00000001230*cost(4.27283851216+12139.55350910680*x);
R1+=0.00000001292*cost(2.73196017809+10206.17199921020*x);
R1+=0.00000001247*cost(3.77399749791+504.56118318100*x);
R1+=0.00000001408*cost(1.02955773079+518.38463239980*x);
R1+=0.00000001223*cost(1.12202093840+221.16340196420*x);
R1+=0.00000001420*cost(4.39795293289+606.76018552230*x);
R1+=0.00000001190*cost(1.57292553631+820.05928096030*x);
R1+=0.00000001247*cost(0.99102599652+9793.80090233580*x);
R1+=0.00000001234*cost(1.10826361423+2303.60876781320*x);
R1+=0.00000001186*cost(4.55984967028+9808.53818466140*x);
R1+=0.00000001346*cost(4.94456950019+384.05992122310*x);
R1+=0.00000001514*cost(3.60392291730+2015.67108615980*x);
R1+=0.00000001432*cost(2.28704432909+525.49817940060*x);
R1+=0.00000001129*cost(0.87100340620+162.09337010680*x);
R1+=0.00000001196*cost(5.13485214850+227.31374111850*x);
R1+=0.00000001339*cost(2.48923887712+206.70681329900*x);
R1+=0.00000001421*cost(1.65379789078+857.12853501510*x);
R1+=0.00000001162*cost(1.92099315083+220.93390730060*x);
R1+=0.00000001277*cost(4.85435999187+54.17467074780*x);
R1+=0.00000001153*cost(5.33028034679+233.90602325750*x);
R1+=0.00000001214*cost(4.11324721963+3377.21779200400*x);
R1+=0.00000001109*cost(5.68915582674+162.89651925890*x);
R1+=0.00000001068*cost(4.85383480876+611.44309831080*x);
R1+=0.00000001119*cost(1.40805686363+1987.21689815660*x);
R1+=0.00000001085*cost(0.64208148190+731.68372783780*x);
R1+=0.00000001435*cost(3.20880139888+835.78789401270*x);
R1+=0.00000001184*cost(2.99776919968+199.28444975750*x);
R1+=0.00000001281*cost(3.12245339510+427.34895040140*x);
R1+=0.00000001058*cost(5.17851282929+306.09692891810*x);
R1+=0.00000001152*cost(4.39244449554+199.96577331370*x);
R1+=0.00000001036*cost(3.68027119804+597.35901666110*x);
R1+=0.00000001055*cost(3.25561743426+394.35486196160*x);
R1+=0.00000001127*cost(4.33255371960+552.58551477450*x);
R1+=0.00000001213*cost(6.21447612110+42.53826965290*x);
R1+=0.00000001117*cost(3.74367882111+214.19286731530*x);
R1+=0.00000001023*cost(3.84199833949+894.84087952760*x);
R1+=0.00000001042*cost(5.30120078590+450.97721326420*x);
R1+=0.00000001290*cost(3.96221234564+318.83955021140*x);
R1+=0.00000001073*cost(4.10012122884+188.16931352440*x);
R1+=0.00000001204*cost(0.37702365750+393.46109008430*x);
R1+=0.00000001214*cost(2.01826978554+401.32539661050*x);
R1+=0.00000001018*cost(0.02946649279+2840.41327990860*x);
R1+=0.00000001237*cost(5.41088851225+425.84743135060*x);
R1+=0.00000001187*cost(5.16511890602+838.21852822500*x);
R1+=0.00000001276*cost(2.93572146232+1457.52593306200*x);
R1+=0.00000000994*cost(3.40079885702+211.60217440860*x);
R1+=0.00000001042*cost(2.42209320898+361.37781986430*x);
R1+=0.00000001093*cost(3.66289018246+226.63241756230*x);
R1+=0.00000000978*cost(3.76334208607+5856.47765911540*x);
R1+=0.00000001263*cost(2.09195268609+78.71375183040*x);
R1+=0.00000001009*cost(5.85963705048+1268.74887236410*x);
R1+=0.00000001148*cost(4.39543895068+570.74476203920*x);
R1+=0.00000001051*cost(3.27272240682+153.49535039770*x);
R1+=0.00000000975*cost(3.42924642244+105.54045477340*x);
R1+=0.00000000997*cost(4.30943991893+212.40532356070*x);
R1+=0.00000000954*cost(3.88548755058+171.65459766240*x);
R1+=0.00000000960*cost(1.90180005280+1159.29331067010*x);
R1+=0.00000000953*cost(3.40787141587+244.79166482700*x);
R1+=0.00000000969*cost(1.93369993197+525.75881183150*x);
R1+=0.00000000918*cost(1.73738789723+223.33340374560*x);
R1+=0.00000001164*cost(5.05392864346+263.70167161710*x);
R1+=0.00000000951*cost(4.23581224839+92.94084583200*x);
R1+=0.00000001160*cost(5.80630916592+460.53844081980*x);
R1+=0.00000001186*cost(4.46262000755+465.95506679120*x);
R1+=0.00000000931*cost(2.09868057209+205.66428357540*x);
R1+=0.00000000942*cost(3.86810837922+238.42887735160*x);
R1+=0.00000001020*cost(5.53181822898+0.04818410980*x);
R1+=0.00000000995*cost(2.03457885490+6290.18939699220*x);
R1+=0.00000000888*cost(2.60957592990+1912.57831194120*x);
R1+=0.00000000873*cost(5.78433393020+480.77286162380*x);
R1+=0.00000000854*cost(1.63255087291+328.24071907260*x);
R1+=0.00000001123*cost(4.07401922216+3693.60966166060*x);
R1+=0.00000000934*cost(3.52355235083+10220.39909321180*x);
R1+=0.00000000833*cost(3.03302227840+532.87235883230*x);
R1+=0.00000001007*cost(2.73615455688+4841.85727206680*x);
R1+=0.00000000870*cost(1.06968760644+51.20572533120*x);
R1+=0.00000000891*cost(1.36817544763+700.45179087970*x);
R1+=0.00000000833*cost(5.39754715806+159.71512552120*x);
R1+=0.00000000854*cost(1.91765015557+622.48879857470*x);
R1+=0.00000000976*cost(3.09106001923+2332.06295581640*x);
R1+=0.00000000819*cost(5.55683690482+462.02291352810*x);
R1+=0.00000000800*cost(1.47042677460+969.62247809490*x);
R1+=0.00000000933*cost(1.40166917666+287.93768165340*x);
R1+=0.00000000784*cost(1.69235162770+477.80391620720*x);
R1+=0.00000000782*cost(3.98153416585+702.14871190910*x);
R1+=0.00000000810*cost(5.87689161549+561.93429400900*x);
R1+=0.00000000858*cost(4.02964773169+41.64449777560*x);
R1+=0.00000000819*cost(0.98885784755+960.22130923370*x);
R1+=0.00000000882*cost(1.49559638306+760.25553592000*x);
R1+=0.00000000767*cost(2.46787654531+402.21916848780*x);
R1+=0.00000000851*cost(3.64678001195+348.63519857100*x);
R1+=0.00000000852*cost(1.03470840672+2620.00063746980*x);
R1+=0.00000000770*cost(4.67090683753+16.67477455640*x);
R1+=0.00000000849*cost(5.27994730935+74.63858621540*x);
R1+=0.00000000854*cost(2.56811257488+432.74853003030*x);
R1+=0.00000000767*cost(1.11806243753+2847.52682690940*x);
R1+=0.00000000729*cost(0.44171990710+898.77303279070*x);
R1+=0.00000000776*cost(5.54603607568+3171.03224356680*x);
R1+=0.00000000721*cost(6.05392551158+91.78644152380*x);
R1+=0.00000000739*cost(3.57172839746+775.23338944700*x);
R1+=0.00000000730*cost(4.98865345688+705.11765732570*x);
R1+=0.00000000705*cost(0.44942445750+219.66188291340*x);
R1+=0.00000000708*cost(0.69014726046+1048.33622992530*x);
R1+=0.00000000706*cost(2.22974712805+29.20494752860*x);
R1+=0.00000000711*cost(0.00981284716+2115.58246664070*x);
R1+=0.00000000722*cost(4.14075205197+225.07850888480*x);
R1+=0.00000000735*cost(1.54083195463+201.99276274320*x);
R1+=0.00000000746*cost(4.08997409526+849.26422848890*x);
R1+=0.00000000729*cost(2.81779134868+419.53282798500*x);
R1+=0.00000000837*cost(1.00844734156+4127.32139953740*x);
R1+=0.00000000939*cost(0.46037763932+5488.86810538160*x);
R1+=0.00000000939*cost(1.85473712038+5062.26991450560*x);
R1+=0.00000000721*cost(1.62872794201+2200.51599359460*x);

double R2=0;
R2+=0.00436902464*cost(4.78671673044+213.29909543800*x);
R2+=0.00071922760*cost(2.50069994874+206.18554843720*x);
R2+=0.00049766792*cost(4.97168150870+220.41264243880*x);
R2+=0.00043220894*cost(3.86940443794+426.59819087600*x);
R2+=0.00029645554*cost(5.96310264282+7.11354700080*x);
R2+=0.00004141650*cost(4.10670940823+433.71173787680*x);
R2+=0.00004720909*cost(2.47527992423+199.07200143640*x);
R2+=0.00003789370*cost(3.09771025067+639.89728631400*x);
R2+=0.00002963990*cost(1.37206248846+103.09277421860*x);
R2+=0.00002556363*cost(2.85065721526+419.48464387520*x);
R2+=0.00002208457*cost(6.27588858707+110.20632121940*x);
R2+=0.00002187621*cost(5.85545832218+14.22709400160*x);
R2+=0.00001956896*cost(4.92448618045+227.52618943960*x);
R2+=0.00002326801;
R2+=0.00000923840*cost(5.46392422737+323.50541665740*x);
R2+=0.00000705936*cost(2.97081280098+95.97922721780*x);
R2+=0.00000546115*cost(4.12854181522+412.37109687440*x);
R2+=0.00000373838*cost(5.83435991809+117.31986822020*x);
R2+=0.00000360882*cost(3.27703082368+647.01083331480*x);
R2+=0.00000356350*cost(3.19152043942+210.11770170030*x);
R2+=0.00000390627*cost(4.48106176893+216.48048917570*x);
R2+=0.00000431485*cost(5.17825414612+522.57741809380*x);
R2+=0.00000325598*cost(2.26867601656+853.19638175200*x);
R2+=0.00000405018*cost(4.17294157872+209.36694217490*x);
R2+=0.00000204494*cost(0.08774848590+202.25339517410*x);
R2+=0.00000206854*cost(4.02188336738+735.87651353180*x);
R2+=0.00000178474*cost(4.09716541453+440.82528487760*x);
R2+=0.00000180143*cost(3.59704903955+632.78373931320*x);
R2+=0.00000153656*cost(3.13470530382+625.67019231240*x);
R2+=0.00000147779*cost(0.13614300541+302.16477565500*x);
R2+=0.00000123189*cost(4.18895309647+88.86568021700*x);
R2+=0.00000133076*cost(2.59350469420+191.95845443560*x);
R2+=0.00000100367*cost(5.46056190585+3.18139373770*x);
R2+=0.00000131975*cost(5.93293968941+309.27832265580*x);
R2+=0.00000097235*cost(4.01832604356+728.76296653100*x);
R2+=0.00000110709*cost(4.77853798276+838.96928775040*x);
R2+=0.00000119053*cost(5.55385105975+224.34479570190*x);
R2+=0.00000093852*cost(4.38395529912+217.23124870110*x);
R2+=0.00000108701*cost(5.29310899841+515.46387109300*x);
R2+=0.00000078609*cost(5.72525447528+21.34064100240*x);
R2+=0.00000081468*cost(5.10897365253+956.28915597060*x);
R2+=0.00000096412*cost(6.25859229567+742.99006053260*x);
R2+=0.00000069228*cost(4.04901237761+3.93215326310*x);
R2+=0.00000065168*cost(3.77713343518+1052.26838318840*x);
R2+=0.00000064088*cost(5.81235002453+529.69096509460*x);
R2+=0.00000062541*cost(2.18445116349+195.13984817330*x);
R2+=0.00000056987*cost(3.14666549033+203.00415469950*x);
R2+=0.00000055979*cost(4.84108422860+234.63973644040*x);
R2+=0.00000052940*cost(5.07780548444+330.61896365820*x);
R2+=0.00000050635*cost(2.77318570728+942.06206196900*x);
R2+=0.00000041649*cost(4.79014211005+63.73589830340*x);
R2+=0.00000044858*cost(0.56460613593+269.92144674060*x);
R2+=0.00000041357*cost(3.73496404402+316.39186965660*x);
R2+=0.00000052847*cost(3.92623831484+949.17560896980*x);
R2+=0.00000038398*cost(3.73966157784+1045.15483618760*x);
R2+=0.00000037583*cost(4.18924633757+536.80451209540*x);
R2+=0.00000035285*cost(2.90795856092+284.14854074220*x);
R2+=0.00000033576*cost(3.80465978802+149.56319713460*x);
R2+=0.00000041073*cost(4.57870454147+1155.36115740700*x);
R2+=0.00000030412*cost(2.48140171991+860.30992875280*x);
R2+=0.00000031373*cost(4.84075951849+1272.68102562720*x);
R2+=0.00000030218*cost(4.35186294470+405.25754987360*x);
R2+=0.00000039430*cost(3.50858482049+422.66603761290*x);
R2+=0.00000029658*cost(1.58886982096+1066.49547719000*x);
R2+=0.00000035202*cost(5.94478241578+1059.38193018920*x);
R2+=0.00000025829*cost(3.54946335477+1368.66025284500*x);
R2+=0.00000026283*cost(4.81567477177+124.43341522100*x);
R2+=0.00000029963*cost(3.66312205813+429.77958461370*x);
R2+=0.00000033011*cost(4.96879544579+831.85574074960*x);
R2+=0.00000024305*cost(5.31133255082+10.29494073850*x);
R2+=0.00000026332*cost(4.45253273390+223.59403617650*x);
R2+=0.00000022108*cost(2.76092021113+415.55249061210*x);
R2+=0.00000027187*cost(1.66347897738+277.03499374140*x);
R2+=0.00000021639*cost(1.03836302307+11.04570026390*x);
R2+=0.00000019713*cost(2.52194629263+1258.45393162560*x);
R2+=0.00000017062*cost(3.27669927228+654.12438031560*x);
R2+=0.00000017261*cost(3.49414816663+1361.54670584420*x);
R2+=0.00000016097*cost(1.73396878598+490.33408917940*x);
R2+=0.00000021099*cost(3.62102032955+1265.56747862640*x);
R2+=0.00000017692*cost(4.31141612385+1471.75302706360*x);
R2+=0.00000013458*cost(0.32327889681+295.05122865420*x);
R2+=0.00000012586*cost(3.13794576887+74.78159856730*x);
R2+=0.00000012023*cost(2.32917797741+210.85141488320*x);
R2+=0.00000015120*cost(3.59558424278+265.98929347750*x);
R2+=0.00000012959*cost(4.62359706368+1589.07289528380*x);
R2+=0.00000015424*cost(5.01335704925+127.47179660680*x);
R2+=0.00000011193*cost(4.54981248285+81.75213321620*x);
R2+=0.00000013449*cost(4.88710089777+437.64389113990*x);
R2+=0.00000010673*cost(5.05234757424+191.20769491020*x);
R2+=0.00000013963*cost(3.04990968366+423.41679713830*x);
R2+=0.00000010614*cost(5.02845923229+137.03302416240*x);
R2+=0.00000014382*cost(4.68720080027+1148.24761040620*x);
R2+=0.00000013470*cost(1.90280407135+408.43894361130*x);
R2+=0.00000010077*cost(5.20426583827+340.77089204480*x);
R2+=0.00000010323*cost(3.34460279759+1685.05212250160*x);
R2+=0.00000009563*cost(3.17317920222+351.81659230870*x);
R2+=0.00000011295*cost(5.47808960704+1375.77379984580*x);
R2+=0.00000008617*cost(2.81294528041+99.91138048090*x);
R2+=0.00000008460*cost(3.22691940753+1677.93857550080*x);
R2+=0.00000007914*cost(2.35624291874+1574.84580128220*x);
R2+=0.00000007587*cost(6.08171425316+231.45834270270*x);
R2+=0.00000009175*cost(3.40072244924+1581.95934828300*x);
R2+=0.00000007337*cost(2.00393601815+131.40394986990*x);
R2+=0.00000008240*cost(4.04095881407+1788.14489672020*x);
R2+=0.00000007579*cost(3.68311134272+846.08283475120*x);
R2+=0.00000006691*cost(4.37253800717+145.63104387150*x);
R2+=0.00000007539*cost(3.29482043104+750.10360753340*x);
R2+=0.00000006367*cost(4.00239137708+447.93883187840*x);
R2+=0.00000006249*cost(4.55603671940+106.27416795630*x);
R2+=0.00000006489*cost(1.33782087599+215.74677599280*x);
R2+=0.00000006501*cost(3.78204726337+313.21047591890*x);
R2+=0.00000005978*cost(0.55276980086+18.15924726470*x);
R2+=0.00000006171*cost(2.84712795642+138.51749687070*x);
R2+=0.00000006837*cost(4.83481646949+319.57326339430*x);
R2+=0.00000006678*cost(5.43046031699+508.35032409220*x);
R2+=0.00000007175*cost(4.37855723752+1464.63948006280*x);
R2+=0.00000005753*cost(4.14268749228+543.91805909620*x);
R2+=0.00000005727*cost(4.35383078313+1905.46476494040*x);
R2+=0.00000005101*cost(2.63866058897+288.08069400530*x);
R2+=0.00000005311*cost(3.62520849510+6076.89030155420*x);
R2+=0.00000005498*cost(4.19972735173+721.64941953020*x);
R2+=0.00000005089*cost(5.04845206653+10007.09999777380*x);
R2+=0.00000005505*cost(1.13479635941+56.62235130260*x);
R2+=0.00000004820*cost(3.30043078578+76.26607127560*x);
R2+=0.00000004915*cost(6.17790518458+483.22054217860*x);
R2+=0.00000005048*cost(2.44627820757+628.85158605010*x);
R2+=0.00000004534*cost(1.19648682598+200.76892246580*x);
R2+=0.00000004817*cost(3.11549733365+2001.44399215820*x);
R2+=0.00000004712*cost(1.26507812515+6062.66320755260*x);
R2+=0.00000004811*cost(5.78388270496+184.84490743480*x);
R2+=0.00000004775*cost(0.76197795755+333.65734504400*x);
R2+=0.00000004514*cost(0.95293919611+343.21857259960*x);
R2+=0.00000004525*cost(2.68827745072+9992.87290377220*x);
R2+=0.00000004378*cost(0.80241129896+222.86032299360*x);
R2+=0.00000004873*cost(5.92092913946+618.55664531160*x);
R2+=0.00000004142*cost(1.91878383159+497.44763618020*x);
R2+=0.00000005112*cost(4.50449287745+416.30325013750*x);
R2+=0.00000004125*cost(1.98204847532+347.88443904560*x);
R2+=0.00000004045*cost(2.87666810085+38.13303563780*x);
R2+=0.00000004133*cost(2.90478811425+107.02492748170*x);
R2+=0.00000004035*cost(2.92972681787+1994.33044515740*x);
R2+=0.00000004916*cost(3.12316267561+1898.35121793960*x);
R2+=0.00000003657*cost(3.24680246734+362.86229257260*x);
R2+=0.00000003753*cost(0.87719890943+703.63318461740*x);
R2+=0.00000003576*cost(3.48080143501+388.46515523820*x);
R2+=0.00000003555*cost(4.08436297683+430.53034413910*x);
R2+=0.00000003598*cost(0.05255328597+32.24332891440*x);
R2+=0.00000003561*cost(5.46414552453+6283.07584999140*x);
R2+=0.00000003480*cost(1.81622589595+70.84944530420*x);
R2+=0.00000003827*cost(3.12041228490+635.96513305090*x);
R2+=0.00000003399*cost(0.54882815021+10213.28554621100*x);
R2+=0.00000003399*cost(3.51833356080+629.60234557550*x);
R2+=0.00000003364*cost(3.27821747958+357.44566660120*x);
R2+=0.00000003260*cost(1.97623748027+203.73786788240*x);
R2+=0.00000003118*cost(2.18465627368+1891.23767093880*x);
R2+=0.00000003163*cost(1.26040995242+134.58534360760*x);
R2+=0.00000004004*cost(5.45434102599+1692.16566950240*x);
R2+=0.00000003180*cost(2.46319174788+867.42347575360*x);
R2+=0.00000003389*cost(4.20503159673+337.73251065900*x);
R2+=0.00000003026*cost(2.19331614526+217.96496188400*x);
R2+=0.00000003573*cost(5.55097240810+113.38771495710*x);
R2+=0.00000003682*cost(3.78966280284+2104.53676637680*x);
R2+=0.00000003125*cost(4.09203641264+1478.86657406440*x);
R2+=0.00000002881*cost(3.90810650240+312.19908396260*x);
R2+=0.00000003199*cost(3.92123638342+1038.04128918680*x);
R2+=0.00000004014*cost(5.17826893553+404.50679034820*x);
R2+=0.00000003907*cost(4.11767191780+1781.03134971940*x);
R2+=0.00000003144*cost(1.61185684069+1073.60902419080*x);
R2+=0.00000003072*cost(5.00675625396+312.45971639350*x);
R2+=0.00000003034*cost(5.46288652854+258.87574647670*x);
R2+=0.00000002884*cost(2.38477237305+181.05576652360*x);
R2+=0.00000002986*cost(0.88783591586+1279.79457262800*x);
R2+=0.00000002683*cost(0.00956197492+195.89060769870*x);
R2+=0.00000003081*cost(5.60034737330+216.21985674480*x);
R2+=0.00000002626*cost(6.12701960244+273.10284047830*x);
R2+=0.00000002665*cost(2.31576422128+565.11568774670*x);
R2+=0.00000003245*cost(3.87540558646+85.82729883120*x);
R2+=0.00000002740*cost(5.73784096806+160.60889739850*x);
R2+=0.00000002876*cost(4.74720607366+213.25091132820*x);
R2+=0.00000002523*cost(5.30458920892+444.75743814070*x);
R2+=0.00000002752*cost(5.08984539930+1169.58825140860*x);
R2+=0.00000002889*cost(1.66674437398+213.34727954780*x);
R2+=0.00000002923*cost(4.21481009033+650.94298657790*x);
R2+=0.00000003036*cost(2.55426675350+6069.77675455340*x);
R2+=0.00000003116*cost(2.67220972004+52.69019803950*x);
R2+=0.00000002371*cost(0.89591351822+121.25202148330*x);
R2+=0.00000002993*cost(3.96957827454+9999.98645077300*x);
R2+=0.00000003088*cost(0.40656113014+561.18353448360*x);
R2+=0.00000002385*cost(4.74063881551+218.71572140940*x);
R2+=0.00000002632*cost(1.12706218927+344.70304530790*x);
R2+=0.00000002316*cost(4.08445262041+131.54696222180*x);
R2+=0.00000002214*cost(3.37726228553+22.09140052780*x);
R2+=0.00000002129*cost(3.32497715011+358.93013930950*x);
R2+=0.00000002679*cost(1.68971401870+208.63322899200*x);
R2+=0.00000002607*cost(5.10250482155+824.74219374880*x);
R2+=0.00000002250*cost(2.60474848767+305.34616939270*x);
R2+=0.00000002087*cost(3.37293958793+320.32402291970*x);
R2+=0.00000002693*cost(3.62159456470+436.89313161450*x);
R2+=0.00000002492*cost(2.96129217279+2214.74308759620*x);
R2+=0.00000002704*cost(2.88483697319+643.07868005170*x);
R2+=0.00000002124*cost(1.61210282593+218.92816973050*x);
R2+=0.00000002037*cost(4.63481160778+188.02630117250*x);
R2+=0.00000002394*cost(3.46386258552+6275.96230299060*x);
R2+=0.00000001973*cost(2.28886138203+2627.11418447060*x);
R2+=0.00000001937*cost(5.67082364247+28.45418800320*x);
R2+=0.00000001920*cost(4.25647211328+546.95644048200*x);
R2+=0.00000002498*cost(3.57572154405+2420.92863603340*x);
R2+=0.00000001898*cost(1.30987536388+212.33588759150*x);
R2+=0.00000001852*cost(1.58508015515+424.15051032120*x);
R2+=0.00000001850*cost(3.57830449726+329.72519178090*x);
R2+=0.00000002128*cost(3.95329215734+1795.25844372100*x);
R2+=0.00000002236*cost(4.22073549375+2221.85663459700*x);
R2+=0.00000001933*cost(1.68771499202+350.33211960040*x);
R2+=0.00000001799*cost(2.06541260431+144.14657116320*x);
R2+=0.00000001904*cost(4.60953896857+182.27960680100*x);
R2+=0.00000002236*cost(5.17945392885+99.16062095550*x);
R2+=0.00000001755*cost(2.73425330428+291.26208774300*x);
R2+=0.00000002231*cost(5.42548168745+207.88246946660*x);
R2+=0.00000001848*cost(2.24194286719+168.05251279940*x);
R2+=0.00000001726*cost(1.31878655393+219.44943459230*x);
R2+=0.00000001709*cost(5.55913931846+92.79783348010*x);
R2+=0.00000001693*cost(1.95360003617+129.91947716160*x);
R2+=0.00000002064*cost(4.84900344498+1141.13406340540*x);
R2+=0.00000001758*cost(5.05088656436+214.26230328450*x);
R2+=0.00000001781*cost(2.85880153340+636.71589257630*x);
R2+=0.00000001900*cost(2.90295578617+2310.72231481400*x);
R2+=0.00000001759*cost(5.34657858395+45.57665103870*x);
R2+=0.00000001654*cost(6.14450664508+554.06998748280*x);
R2+=0.00000001578*cost(4.50941374663+210.37833413120*x);
R2+=0.00000001681*cost(3.55136706992+1354.43315884340*x);
R2+=0.00000001862*cost(3.01276783582+2317.83586181480*x);
R2+=0.00000001589*cost(1.15773448350+235.39049596580*x);
R2+=0.00000001551*cost(2.15558953807+207.67002114550*x);
R2+=0.00000001874*cost(4.12861627986+225.82926841020*x);
R2+=0.00000001621*cost(3.29992957653+1670.82502850000*x);
R2+=0.00000001911*cost(0.17724319140+12.53017297220*x);
R2+=0.00000001477*cost(5.90270260570+1.48447270830*x);
R2+=0.00000001618*cost(5.72513459206+1485.98012106520*x);
R2+=0.00000001446*cost(1.78104589920+1382.88734684660*x);
R2+=0.00000001683*cost(3.43534671475+2428.04218303420*x);
R2+=0.00000001542*cost(5.51223038941+204.70107572890*x);
R2+=0.00000001420*cost(2.07339356364+198.32124191100*x);
R2+=0.00000001444*cost(5.56032454849+128.36556848410*x);
R2+=0.00000001476*cost(6.12782257368+212.77783057620*x);
R2+=0.00000001474*cost(0.33626790634+213.82036029980*x);
R2+=0.00000001428*cost(3.25039966249+945.99421523210*x);
R2+=0.00000001410*cost(0.68747644676+429.04587143080*x);
R2+=0.00000001752*cost(2.70090942746+12.74262129330*x);
R2+=0.00000001681*cost(4.97526853273+2008.55753915900*x);
R2+=0.00000001408*cost(0.80461100746+1585.14074202070*x);
R2+=0.00000001485*cost(0.49674043855+120.35824960600*x);
R2+=0.00000001490*cost(2.68459799437+207.14875628370*x);
R2+=0.00000001411*cost(4.36399216092+5863.59120611620*x);
R2+=0.00000001315*cost(4.73430848989+241.75328344120*x);
R2+=0.00000001516*cost(4.99488503706+1162.47470440780*x);
R2+=0.00000001310*cost(1.98714265058+563.63121503840*x);
R2+=0.00000001286*cost(2.12891372062+251.43213107580*x);
R2+=0.00000001271*cost(5.70165238307+2.92076130680*x);
R2+=0.00000001312*cost(1.68811514551+2207.62954059540*x);
R2+=0.00000001259*cost(0.35924965717+334.55111692130*x);
R2+=0.00000001252*cost(2.14513440216+1055.44977692610*x);
R2+=0.00000001401*cost(6.13250261735+1802.37199072180*x);
R2+=0.00000001343*cost(5.79995727295+9793.80090233580*x);
R2+=0.00000001228*cost(3.29059284057+661.23792731640*x);
R2+=0.00000001202*cost(2.88792018909+2413.81508903260*x);
R2+=0.00000001286*cost(5.72360160371+298.23262239190*x);
R2+=0.00000001357*cost(0.93175963411+217.49188113200*x);
R2+=0.00000001356*cost(2.28121627817+601.76425067620*x);
R2+=0.00000001190*cost(1.94993809928+501.37978944330*x);
R2+=0.00000001304*cost(0.37337923280+3473.19701922180*x);
R2+=0.00000001350*cost(2.87235622320+142.44965013380*x);
R2+=0.00000001349*cost(3.21102203937+175.16605980020*x);
R2+=0.00000001312*cost(3.70149813509+2111.65031337760*x);
R2+=0.00000001129*cost(1.08860603834+842.15068148810*x);
R2+=0.00000001237*cost(0.08698781252+526.50957135690*x);
R2+=0.00000001217*cost(3.89835349840+209.10630974400*x);
R2+=0.00000001467*cost(1.16228775027+621.73803904930*x);
R2+=0.00000001044*cost(0.30512759901+436.15941843160*x);
R2+=0.00000001140*cost(5.33720637097+114.13847448250*x);
R2+=0.00000001295*cost(4.70261675421+9786.68735533500*x);
R2+=0.00000001037*cost(4.07846687083+156.67674413540*x);
R2+=0.00000001391*cost(4.73554028436+398.14400287280*x);
R2+=0.00000001167*cost(5.68899703631+479.28838891550*x);
R2+=0.00000001035*cost(5.34279429465+327.43756992050*x);
R2+=0.00000000997*cost(1.19323192891+710.74673161820*x);
R2+=0.00000001193*cost(5.17722376816+98.89998852460*x);
R2+=0.00000001165*cost(4.58588490135+732.69511979410*x);
R2+=0.00000001161*cost(4.90854984994+10206.17199921020*x);
R2+=0.00000001144*cost(0.50394784140+3906.90875709860*x);
R2+=0.00000001182*cost(3.69482624364+2854.64037391020*x);
R2+=0.00000000970*cost(2.89031410383+1987.21689815660*x);
R2+=0.00000001039*cost(0.48694895443+525.49817940060*x);
R2+=0.00000001079*cost(3.61750956217+2097.42321937600*x);
R2+=0.00000001148*cost(3.31015591733+5856.47765911540*x);
R2+=0.00000001241*cost(4.31971543677+230.70758317730*x);
R2+=0.00000000910*cost(4.59825926062+380.12776796000*x);
R2+=0.00000000907*cost(1.34912454077+685.47393735270*x);
R2+=0.00000001166*cost(1.61085609717+5849.36411211460*x);
R2+=0.00000000882*cost(6.12045540405+519.39602435610*x);
R2+=0.00000000963*cost(4.96065454054+699.70103135430*x);
R2+=0.00000001062*cost(5.13323858077+2751.54759969160*x);
R2+=0.00000000865*cost(6.12821112133+245.54242435240*x);
R2+=0.00000001100*cost(2.18435744407+1699.27921650320*x);
R2+=0.00000000822*cost(5.55083534581+739.05790726950*x);
R2+=0.00000000926*cost(2.01158276144+417.03696332040*x);
R2+=0.00000000813*cost(5.18401872205+214.78356814630*x);
R2+=0.00000001033*cost(5.48677848094+3995.77443731560*x);
R2+=0.00000000872*cost(3.02363724703+306.09692891810*x);
R2+=0.00000000796*cost(0.44343664540+486.40193591630*x);
R2+=0.00000000878*cost(1.82164034386+135.33610313300*x);
R2+=0.00000000791*cost(2.14989417962+2620.00063746980*x);
R2+=0.00000000881*cost(2.39697554334+289.56516671360*x);
R2+=0.00000000782*cost(4.50471317138+980.66817835880*x);
R2+=0.00000000783*cost(1.14229319753+540.73666535850*x);
R2+=0.00000000831*cost(0.69937251013+421.93232443000*x);
R2+=0.00000000770*cost(2.40292326155+576.16138801060*x);
R2+=0.00000000950*cost(5.97621460162+196.62432088160*x);
R2+=0.00000000814*cost(4.19303098086+831.10498122420*x);
R2+=0.00000000969*cost(4.78071024754+326.68681039510*x);
R2+=0.00000000760*cost(0.44860533530+425.63498302950*x);
R2+=0.00000000907*cost(0.94781730418+525.75881183150*x);
R2+=0.00000000788*cost(0.14287187051+916.93228005540*x);
R2+=0.00000000801*cost(1.86383119100+3039.48528134500*x);
R2+=0.00000000801*cost(0.46947170994+3466.08347222100*x);
R2+=0.00000000747*cost(6.05374861925+211.81462272970*x);
R2+=0.00000000968*cost(3.02618272726+2634.22773147140*x);
R2+=0.00000000739*cost(2.27110740297+2303.60876781320*x);
R2+=0.00000000750*cost(5.48554383902+173.94221952280*x);
R2+=0.00000001024*cost(1.91564925560+229.97386999440*x);
R2+=0.00000000816*cost(4.98990432666+4209.07353275360*x);
R2+=0.00000000728*cost(1.30997967935+511.53171782990*x);
R2+=0.00000000716*cost(3.74192651696+3053.71237534660*x);
R2+=0.00000000727*cost(0.39191881243+1493.09366806600*x);
R2+=0.00000000717*cost(2.68899513085+228.27694896500*x);
R2+=0.00000000739*cost(2.12749199443+1176.70179840940*x);
R2+=0.00000000805*cost(0.07187193910+556.51766803760*x);
R2+=0.00000000835*cost(3.48287855700+84.93352695390*x);
R2+=0.00000000790*cost(0.48073040004+4017.11507831800*x);
R2+=0.00000000725*cost(1.96643065215+220.46082654860*x);
R2+=0.00000000683*cost(2.68825142163+151.04766984290*x);
R2+=0.00000000739*cost(3.33688408107+953.10776223290*x);
R2+=0.00000000745*cost(6.22304530635+1269.49963188950*x);

double R3=0;
R3+=0.00020315005*cost(3.02186626038+213.29909543800*x);
R3+=0.00008923581*cost(3.19144205755+220.41264243880*x);
R3+=0.00006908677*cost(4.35174889353+206.18554843720*x);
R3+=0.00004087129*cost(4.22406927376+7.11354700080*x);
R3+=0.00003879041*cost(2.01056445995+426.59819087600*x);
R3+=0.00001070788*cost(4.20360341236+199.07200143640*x);
R3+=0.00000907332*cost(2.28344368029+433.71173787680*x);
R3+=0.00000606121*cost(3.17458570534+227.52618943960*x);
R3+=0.00000596639*cost(4.13455753351+14.22709400160*x);
R3+=0.00000483181*cost(1.17345973258+639.89728631400*x);
R3+=0.00000393174;
R3+=0.00000229472*cost(4.69838526383+419.48464387520*x);
R3+=0.00000188250*cost(4.59003889007+110.20632121940*x);
R3+=0.00000149508*cost(3.20199444400+103.09277421860*x);
R3+=0.00000121442*cost(3.76831374104+323.50541665740*x);
R3+=0.00000101215*cost(5.81884137755+412.37109687440*x);
R3+=0.00000102146*cost(4.70974422803+95.97922721780*x);
R3+=0.00000093078*cost(1.43531270909+647.01083331480*x);
R3+=0.00000072601*cost(4.15395598507+117.31986822020*x);
R3+=0.00000084347*cost(2.63462379693+216.48048917570*x);
R3+=0.00000062198*cost(2.31239345505+440.82528487760*x);
R3+=0.00000045145*cost(4.37317047297+191.95845443560*x);
R3+=0.00000049536*cost(2.38854232908+209.36694217490*x);
R3+=0.00000054829*cost(0.30526468471+853.19638175200*x);
R3+=0.00000040498*cost(1.83836569765+302.16477565500*x);
R3+=0.00000038089*cost(5.94455115525+88.86568021700*x);
R3+=0.00000032243*cost(4.01146349387+21.34064100240*x);
R3+=0.00000040671*cost(0.68845183210+522.57741809380*x);
R3+=0.00000028209*cost(5.77193013961+210.11770170030*x);
R3+=0.00000024976*cost(3.06249709014+234.63973644040*x);
R3+=0.00000020824*cost(4.92570695678+625.67019231240*x);
R3+=0.00000025070*cost(0.73137425284+515.46387109300*x);
R3+=0.00000017485*cost(5.73135068691+728.76296653100*x);
R3+=0.00000018009*cost(1.45593152612+309.27832265580*x);
R3+=0.00000016927*cost(3.52771580455+3.18139373770*x);
R3+=0.00000013437*cost(3.36479898106+330.61896365820*x);
R3+=0.00000011090*cost(3.37212682914+224.34479570190*x);
R3+=0.00000011082*cost(3.41719974793+956.28915597060*x);
R3+=0.00000009978*cost(1.58791582772+202.25339517410*x);
R3+=0.00000011551*cost(5.99093726182+735.87651353180*x);
R3+=0.00000010500*cost(6.06911092266+405.25754987360*x);
R3+=0.00000009144*cost(2.93557421591+124.43341522100*x);
R3+=0.00000008737*cost(4.65432480769+632.78373931320*x);
R3+=0.00000010023*cost(0.58247011625+860.30992875280*x);
R3+=0.00000007482*cost(4.50669216436+942.06206196900*x);
R3+=0.00000010091*cost(0.28268774007+838.96928775040*x);
R3+=0.00000009243*cost(2.57034547708+223.59403617650*x);
R3+=0.00000008652*cost(1.75808100881+429.77958461370*x);
R3+=0.00000007564*cost(1.45635107202+654.12438031560*x);
R3+=0.00000007058*cost(5.47394786065+1045.15483618760*x);
R3+=0.00000006970*cost(1.51811695028+422.66603761290*x);
R3+=0.00000008067*cost(4.48457709292+742.99006053260*x);
R3+=0.00000006817*cost(4.83084424818+316.39186965660*x);
R3+=0.00000007693*cost(0.43769724671+831.85574074960*x);
R3+=0.00000007934*cost(4.20112367712+195.13984817330*x);
R3+=0.00000006119*cost(2.33960392135+269.92144674060*x);
R3+=0.00000005589*cost(1.14518720694+284.14854074220*x);
R3+=0.00000005564*cost(4.18123189068+529.69096509460*x);
R3+=0.00000005034*cost(2.12020038657+295.05122865420*x);
R3+=0.00000006556*cost(3.42459866876+10.29494073850*x);
R3+=0.00000005544*cost(2.46823271699+536.80451209540*x);
R3+=0.00000006189*cost(6.01433827520+1066.49547719000*x);
R3+=0.00000005649*cost(0.82784598388+217.23124870110*x);
R3+=0.00000004264*cost(3.23245736673+1272.68102562720*x);
R3+=0.00000004450*cost(0.92477808590+203.00415469950*x);
R3+=0.00000003268*cost(4.32777516976+1258.45393162560*x);
R3+=0.00000003655*cost(0.05832123987+81.75213321620*x);
R3+=0.00000003951*cost(0.11124996745+1155.36115740700*x);
R3+=0.00000003773*cost(6.01157059552+1052.26838318840*x);
R3+=0.00000002915*cost(5.64342950039+3.93215326310*x);
R3+=0.00000003019*cost(2.19411778004+447.93883187840*x);
R3+=0.00000002977*cost(1.89387342550+149.56319713460*x);
R3+=0.00000003146*cost(0.19215180096+1148.24761040620*x);
R3+=0.00000002763*cost(0.92363342001+508.35032409220*x);
R3+=0.00000002790*cost(4.97199778427+1677.93857550080*x);
R3+=0.00000002608*cost(2.99591016813+1589.07289528380*x);
R3+=0.00000002881*cost(5.40535671721+1361.54670584420*x);
R3+=0.00000002337*cost(1.30362271569+184.84490743480*x);
R3+=0.00000002536*cost(3.71412120849+408.43894361130*x);
R3+=0.00000002450*cost(3.22118361135+319.57326339430*x);
R3+=0.00000002585*cost(2.31346415454+543.91805909620*x);
R3+=0.00000002324*cost(5.87500715503+721.64941953020*x);
R3+=0.00000001990*cost(0.51565577383+416.30325013750*x);
R3+=0.00000002490*cost(4.24017800021+1059.38193018920*x);
R3+=0.00000001935*cost(2.41463084855+337.73251065900*x);
R3+=0.00000001886*cost(0.53809070779+635.96513305090*x);
R3+=0.00000001893*cost(5.62352727352+11.04570026390*x);
R3+=0.00000002389*cost(5.73399981234+313.21047591890*x);
R3+=0.00000001900*cost(2.41000566465+131.54696222180*x);
R3+=0.00000001743*cost(4.57646237847+1994.33044515740*x);
R3+=0.00000001913*cost(5.17436386408+2854.64037391020*x);
R3+=0.00000001946*cost(6.23355845623+1471.75302706360*x);
R3+=0.00000001963*cost(6.17814558628+1464.63948006280*x);
R3+=0.00000001838*cost(5.59464577559+1038.04128918680*x);
R3+=0.00000001541*cost(0.60765337379+210.85141488320*x);
R3+=0.00000001617*cost(1.75479346067+195.89060769870*x);
R3+=0.00000001577*cost(0.55789908488+2324.94940881560*x);
R3+=0.00000001492*cost(0.26624235633+497.44763618020*x);
R3+=0.00000001659*cost(2.57526072926+2090.30967237520*x);
R3+=0.00000001809*cost(1.82317819973+436.89313161450*x);
R3+=0.00000001566*cost(6.15328100324+490.33408917940*x);
R3+=0.00000001771*cost(6.11741716855+1073.60902419080*x);
R3+=0.00000001456*cost(0.85374460914+415.55249061210*x);
R3+=0.00000001645*cost(2.95335775161+437.64389113990*x);
R3+=0.00000001391*cost(4.12025028560+1574.84580128220*x);
R3+=0.00000001585*cost(5.96841377266+1781.03134971940*x);
R3+=0.00000001507*cost(3.84895122542+1251.34038462480*x);
R3+=0.00000001442*cost(5.32547705924+2538.24850425360*x);
R3+=0.00000001805*cost(1.50973093681+750.10360753340*x);
R3+=0.00000001462*cost(3.28599831588+1884.12412393800*x);
R3+=0.00000001482*cost(0.99340744053+643.07868005170*x);
R3+=0.00000001312*cost(3.79347668996+1567.73225428140*x);
R3+=0.00000001665*cost(0.02551523913+423.41679713830*x);
R3+=0.00000001469*cost(5.35285153471+1354.43315884340*x);
R3+=0.00000001352*cost(0.69945139243+867.42347575360*x);
R3+=0.00000001124*cost(1.79624810407+618.55664531160*x);
R3+=0.00000001126*cost(4.70052329245+113.38771495710*x);
R3+=0.00000001122*cost(3.95537224270+1891.23767093880*x);
R3+=0.00000001458*cost(1.50198846753+430.53034413910*x);
R3+=0.00000001145*cost(5.13093399117+25.27279426550*x);
R3+=0.00000001178*cost(2.97062300389+241.75328344120*x);
R3+=0.00000001274*cost(2.29089799814+2420.92863603340*x);
R3+=0.00000001071*cost(0.04888943982+63.73589830340*x);
R3+=0.00000001377*cost(5.58271514873+1382.88734684660*x);
R3+=0.00000001145*cost(3.10797488346+2200.51599359460*x);
R3+=0.00000001076*cost(0.79465514815+127.47179660680*x);
R3+=0.00000001046*cost(5.85060227045+215.74677599280*x);
R3+=0.00000001082*cost(3.72589445510+131.40394986990*x);
R3+=0.00000001218*cost(0.47504349592+824.74219374880*x);
R3+=0.00000001116*cost(3.78039049056+1375.77379984580*x);
R3+=0.00000000969*cost(5.90752273481+265.98929347750*x);
R3+=0.00000001230*cost(1.41325962069+2634.22773147140*x);
R3+=0.00000001070*cost(4.80334493874+1987.21689815660*x);
R3+=0.00000000946*cost(6.25968535931+2015.67108615980*x);
R3+=0.00000001030*cost(1.08973644893+362.86229257260*x);
R3+=0.00000001072*cost(5.41838042079+1279.79457262800*x);
R3+=0.00000000880*cost(1.92224908504+483.22054217860*x);
R3+=0.00000000878*cost(2.96591300878+934.94851496820*x);
R3+=0.00000000879*cost(2.65659265685+145.63104387150*x);
R3+=0.00000000872*cost(6.26261969664+2.44768055480*x);
R3+=0.00000001082*cost(4.48298283322+2214.74308759620*x);
R3+=0.00000000959*cost(0.74479087918+16.67477455640*x);
R3+=0.00000001035*cost(4.05664979327+231.45834270270*x);
R3+=0.00000000851*cost(0.09360495322+628.85158605010*x);
R3+=0.00000000888*cost(5.98816755324+2524.02141025200*x);
R3+=0.00000000866*cost(3.16259265630+2207.62954059540*x);
R3+=0.00000000843*cost(1.23731248821+74.78159856730*x);
R3+=0.00000000809*cost(2.89742868175+2008.55753915900*x);
R3+=0.00000000779*cost(2.28434811609+1478.86657406440*x);
R3+=0.00000000990*cost(5.32604038017+2428.04218303420*x);
R3+=0.00000000795*cost(2.38178135810+2228.97018159780*x);
R3+=0.00000000765*cost(4.70033674940+1670.82502850000*x);
R3+=0.00000001024*cost(4.23352869513+1802.37199072180*x);
R3+=0.00000000831*cost(5.87457134912+1368.66025284500*x);
R3+=0.00000000717*cost(5.92144324994+1685.05212250160*x);
R3+=0.00000000772*cost(1.15596098579+3053.71237534660*x);
R3+=0.00000000691*cost(3.13193109668+56.62235130260*x);

double R4=0;
R4+=0.00001202050*cost(1.41499446465+220.41264243880*x);
R4+=0.00000707796*cost(1.16153570102+213.29909543800*x);
R4+=0.00000516121*cost(6.23973568330+206.18554843720*x);
R4+=0.00000426664*cost(2.46924890293+7.11354700080*x);
R4+=0.00000267736*cost(0.18659206741+426.59819087600*x);
R4+=0.00000170171*cost(5.95926972384+199.07200143640*x);
R4+=0.00000145113*cost(1.44211060143+227.52618943960*x);
R4+=0.00000150339*cost(0.47970167140+433.71173787680*x);
R4+=0.00000121033*cost(2.40527320817+14.22709400160*x);
R4+=0.00000047332*cost(5.56857488676+639.89728631400*x);
R4+=0.00000015745*cost(2.90112466278+110.20632121940*x);
R4+=0.00000016668*cost(0.52920774279+440.82528487760*x);
R4+=0.00000018954*cost(5.85626429118+647.01083331480*x);
R4+=0.00000014074*cost(1.30343550656+412.37109687440*x);
R4+=0.00000012708*cost(2.09349305926+323.50541665740*x);
R4+=0.00000014724*cost(0.29905316786+419.48464387520*x);
R4+=0.00000011133*cost(2.46304825990+117.31986822020*x);
R4+=0.00000011320*cost(0.21785507019+95.97922721780*x);
R4+=0.00000009233*cost(2.28127318068+21.34064100240*x);
R4+=0.00000009246*cost(1.56496312830+88.86568021700*x);
R4+=0.00000008970*cost(0.68301278041+216.48048917570*x);
R4+=0.00000007674*cost(3.59367715368+302.16477565500*x);
R4+=0.00000007823*cost(4.48688804175+853.19638175200*x);
R4+=0.00000008360*cost(1.27239488455+234.63973644040*x);
R4-=0.00000009552;
R4+=0.00000004834*cost(2.58836294602+515.46387109300*x);
R4+=0.00000006059*cost(5.16774448740+103.09277421860*x);
R4+=0.00000004410*cost(0.02211643085+191.95845443560*x);
R4+=0.00000004364*cost(1.59622746023+330.61896365820*x);
R4+=0.00000003676*cost(3.29899839673+210.11770170030*x);
R4+=0.00000004364*cost(5.97349927933+654.12438031560*x);
R4+=0.00000004447*cost(4.97415112184+860.30992875280*x);
R4+=0.00000003220*cost(2.72684237392+522.57741809380*x);
R4+=0.00000004005*cost(1.59858435636+405.25754987360*x);
R4+=0.00000003099*cost(0.75235436533+209.36694217490*x);
R4+=0.00000002464*cost(1.19167306488+124.43341522100*x);
R4+=0.00000003088*cost(1.32258934286+728.76296653100*x);
R4+=0.00000002220*cost(3.28087994088+203.00415469950*x);
R4+=0.00000002127*cost(6.14648095022+429.77958461370*x);
R4+=0.00000002110*cost(0.75462855247+295.05122865420*x);
R4+=0.00000002020*cost(3.89394929749+1066.49547719000*x);
R4+=0.00000002248*cost(0.49319150178+447.93883187840*x);
R4+=0.00000002180*cost(0.72761059998+625.67019231240*x);
R4+=0.00000001809*cost(0.09057839517+942.06206196900*x);
R4+=0.00000001672*cost(1.39635398184+224.34479570190*x);
R4+=0.00000001641*cost(3.02468307550+184.84490743480*x);
R4+=0.00000001772*cost(0.81879250825+223.59403617650*x);
R4+=0.00000001902*cost(2.00472814984+831.85574074960*x);
R4+=0.00000001600*cost(5.41185167676+824.74219374880*x);
R4+=0.00000001505*cost(5.95520747253+422.66603761290*x);
R4+=0.00000001133*cost(1.11512973946+838.96928775040*x);
R4+=0.00000001190*cost(1.89600567803+956.28915597060*x);
R4+=0.00000001487*cost(2.11906469507+529.69096509460*x);
R4+=0.00000001409*cost(0.72254420236+536.80451209540*x);
R4+=0.00000001125*cost(0.89062692183+721.64941953020*x);
R4+=0.00000001301*cost(1.64867038984+17.40848773930*x);
R4+=0.00000001164*cost(5.96957981840+195.13984817330*x);
R4+=0.00000000950*cost(5.36080713290+316.39186965660*x);
R4+=0.00000000985*cost(3.05768671768+1574.84580128220*x);
R4+=0.00000001050*cost(1.59202481523+735.87651353180*x);
R4+=0.00000000817*cost(4.92838813598+56.62235130260*x);
R4+=0.00000000780*cost(2.72125404102+508.35032409220*x);
R4+=0.00000000969*cost(1.00708261792+1045.15483618760*x);
R4+=0.00000000716*cost(1.11042181341+1169.58825140860*x);

double R5=0;
R5+=0.00000128612*cost(5.91282565136+220.41264243880*x);
R5+=0.00000032273*cost(0.69256228602+7.11354700080*x);
R5+=0.00000026698*cost(5.91428528629+227.52618943960*x);
R5+=0.00000019923*cost(0.67370653385+14.22709400160*x);
R5+=0.00000020223*cost(4.95136801768+433.71173787680*x);
R5+=0.00000013537*cost(1.45669521408+199.07200143640*x);
R5+=0.00000014097*cost(2.67074280191+206.18554843720*x);
R5+=0.00000013364*cost(4.58826996370+426.59819087600*x);
R5+=0.00000007257*cost(4.62966127155+213.29909543800*x);
R5+=0.00000004876*cost(3.61448275002+639.89728631400*x);
R5+=0.00000003136*cost(4.65661021909+191.95845443560*x);
R5+=0.00000002917*cost(0.48665273315+323.50541665740*x);
R5+=0.00000003759*cost(4.89624165044+440.82528487760*x);
R5+=0.00000003303*cost(4.07190859545+647.01083331480*x);
R5+=0.00000002883*cost(3.18003019204+419.48464387520*x);
R5+=0.00000002338*cost(3.69553554327+88.86568021700*x);
R5+=0.00000001950*cost(5.32729247780+302.16477565500*x);
R5+=0.00000002052*cost(3.31663577368+95.97922721780*x);
R5+=0.00000001591*cost(2.67009215574+853.19638175200*x);
R5+=0.00000002028*cost(0.56025552769+117.31986822020*x);
R5+=0.00000001560*cost(0.85608042681+515.46387109300*x);
R5+=0.00000001678;
R5+=0.00000001102*cost(5.98011943842+3.18139373770*x);
R5+=0.00000001285*cost(5.82563377753+234.63973644040*x);
R5+=0.00000000896*cost(5.22791858719+216.48048917570*x);
R5+=0.00000001141*cost(0.15741228205+412.37109687440*x);
R5+=0.00000000798*cost(0.37452846153+28.45418800320*x);
R5+=0.00000000837*cost(5.04769794123+124.43341522100*x);

double x2=x*x;
double x3=x2*x;
double x4=x3*x;
double x5=x4*x;

return (R0+R1*x+R2*x2+R3*x3+R4*x4+R5*x5); //END Saturn
}



//Aberration JM p.151
void Aberration(double TE, double *kappa,double *peri, double *eab)
{  //JM p.151 
double dtr,TE2;
dtr=3.14159265358979323846;
TE2=TE*TE;
//degrees 
*kappa = 20.49552/3600; //JM p.151
*peri = (102.93735+1.71946*TE+0.00046*TE2); //JM p 152
*eab = 0.016708634-0.000042037*TE-0.0000001267*TE2;
}

int starlistx(int iterq, int idstar)
{  
   int i,ileng,j,kkk; 
   char stlist[60][20]=
   {
	   " 0 > Acamar" ,	   
	   " 1 > Achernar" ,
	   " 2 > Acrux" ,
	   " 3 > Adhara" ,
	   " 4 > Aldebaran" ,
	   " 5 > Alioth" ,
	   " 6 > Alkaid" ,
	   " 7 > Al Na'ir" ,
	   " 8 > Alnilam" ,
	   " 9 > Alphard" ,
	   " 10 > Alphecca" ,
	   " 11 > Alpheratz" ,
	   " 12 > Altair" ,
	   " 13 > Ankaa" ,
	   " 14 > Antares" ,
	   " 15 > Arcturus" ,
	   " 16 > Atria" ,
	   " 17 > Avior" ,
	   " 18 > Bellatrix" ,
	   " 19 > Betelgeuse" ,
	   " 20 > Canopus" ,
	   " 21 > Capella" ,
	   " 22 > Deneb" ,
	   " 23 > Denebola" ,
	   " 24 > Diphda" ,
	   " 25 > Dubhe" ,
	   " 26 > Elnath" ,
	   " 27 > Eltanin" ,
	   " 28 > Enif" ,
	   " 29 > Fomalhaut" ,
	   " 30 > Gacrux" ,
	   " 31 > Gienah" ,
	   " 32 > Hadar" ,
	   " 33 > Hamal" ,
	   " 34 > Kaus Aust." ,
	   " 35 > Kochab" ,
	   " 36 > Markab" ,
	   " 37 > Menkar" ,
	   " 38 > Menkent" ,
	   " 39 > Miaplacidus" ,
	   " 40 > Mirfak" ,
	   " 41 > Nunki" ,
	   " 42 > Peacock" ,
	   " 43 > POLARIS" ,
	   " 44 > Pollux" ,
	   " 45 > Procyon" ,
	   " 46 > Rasalhague" ,
	   " 47 > Regulus" ,
	   " 48 > Rigel" ,
	   " 49 > Rigil Kent." ,
	   " 50 > Sabik" ,
	   " 51 > Schedar" ,
	   " 52 > Shaula" ,
	   " 53 > Sirius" ,
	   " 54 > Spica" ,
	   " 55 > Suhail" ,
	   " 56 > Vega" ,
	   " 57 > Zubenelgenubi" ,
	   " 58 > DUMMY" ,
	   "  " 
    };
    
    gstar00:
    	
    printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
    i=0;
    ileng=15;  //BLOCK-LENGTH for PRINT
    j=ileng; 
    printf("* * * * * * * * * * * *\n");
    printf(" STAR-CATALOG 0..59:\n");
    while(i<60)
     {
     	printf("%s",stlist[i]);
     	printf("\n");
     	if(i==j)
     	{
		  j=j+ileng;
     	  printf("  - press RETURN to continue\n"); 
		  if(iterq==0) getchar(); 
		  fflush(stdin); // clear the input buffer
		}
     	i++;
	 }
	 kkk=idstar;
	 printf("\n");
	 printf(" - Default-Star: %d \n",idstar);
	 printf(" ==>  enter Number of Star:");
	 if(iterq==0) kkk=parsenth(1,kkk);
	 if(kkk<0) kkk=58;
	 if(kkk>59) kkk=58;
	 printf(" - Star selected= %s\n",stlist[kkk]);
	 if(iterq==0) getchar(); 
	 if(kkk==58) goto gstar00;
	 
	 return(kkk);
	}

int starlist(int iterq, int idstar)
{  
   int i,ileng,j,kkk; 
   char stlist[60][20]=
   {
	   "0=Acamar",	   
	   "1=Achernar",
	   "2=Acrux",
	   "3=Adhara",
	   "4=Aldebaran",
	   "5=Alioth",
	   "6=Alkaid",
	   "7=Al Na'ir",
	   "8=Alnilam",
	   "9=Alphard",
	   "10=Alphecca",
	   "11=Alpheratz",
	   "12=Altair",
	   "13=Ankaa",
	   "14=Antares",
	   "15=Arcturus",
	   "16=Atria",
	   "17=Avior",
	   "18=Bellatrix",
	   "19=Betelgeus",
	   "20=Canopus",
	   "21=Capella",
	   "22=Deneb",
	   "23=Denebola",
	   "24=Diphda",
	   "25=Dubhe",
	   "26=Elnath",
	   "27=Eltanin",
	   "28=Enif",
	   "29=Fomalhaut",
	   "30=Gacrux",
	   "31=Gienah",
	   "32=Hadar",
	   "33=Hamal",
	   "34=Kaus Aust",
	   "35=Kochab",
	   "36=Markab",
	   "37=Menkar",
	   "38=Menkent",
	   "39=Miaplacid",
	   "40=Mirfak",
	   "41=Nunki",
	   "42=Peacock",
	   "43=Polaris",
	   "44=Pollux",
	   "45=Procyon",
	   "46=Rasalhague",
	   "47=Regulus",
	   "48=Rigel",
	   "49=Rigil Kent.",
	   "50=Sabik",
	   "51=Schedar",
	   "52=Shaula",
	   "53=Sirius",
	   "54=Spica",
	   "55=Suhail",
	   "56=Vega",
	   "57=Zub.elgenu",
	   "58=DUMMY",
	   " "
    };
    
    gstar00:
    	
    printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
    i=0;
    ileng=20;  //BLOCK-LENGTH for PRINT
    j=ileng; 

    printf(" *** STAR-CATALOG 0..57: ***\n");
    while(i<20)
     {
     	printf(" %-12s %-12s %-12s",stlist[i],stlist[i+20],stlist[i+40]);
     	printf("\n");
     	/* if(i==j)
     	{
		  j=j+ileng;
     	  printf("  -press RETURN to continue\n"); 
		  if(iterq==0) getchar(); 
		  fflush(stdin); // clear the input buffer
		}*/
     	i++;
	 }
	 kkk=idstar;
	 printf(" ----------> Default-Star: %d \n",idstar);
	 printf(" ==>  enter Number of Star:");
	 if(iterq==0) kkk=parsenth(1,kkk);
	 if(kkk<0) kkk=58;
	 if(kkk>=58) { kkk=58; idstar=58;}
	 printf(" - Star selected: %s\n",stlist[kkk]);
	 if(iterq==0) getchar(); 
	 if(kkk>=58) goto gstar00;
	 
	 return(kkk);
	}

//////////////////////////////////////////////////////////////////////////////////////////////////
int starseph(int iterq,int idstar,double DeltaT0,int ky,int km,int kd,int kth,int ktm,int kts, 
double *delta1, double *grts1, double *grtg1, double *alfa1,double *shast1) 
{
//input: idstar. 0..59, DeltaT0=Delta-T, ky..kts=Datum und Zeit,
//output: *delta1=Declination, *grts1=GHAplanet, *grtg1=GHAAries, *alfa1=RAplanet, *hpar1=HorPar. 
//idplanet: 4=Venus, 5=Mars, 6=Jupiter, 7=Saturn
///////////////////////////////////////////////////////
//static int year=1992, month=10, day=13, hour=0, min=0, sec=0;
int i,j,jmax,k,ki,l,m,n,ka,ke,kdif,jz,kk,kmax,kq, is0,idstar0;
int k1,k2,k3;
double delta0, grts0, grtg0, alfa0;
double DeltaT0t,GMST,TE, jd, Tau, JD,JDE, JDE0;
double Learth0, Bearth0, Rearth0, Le,Be,Re, L,B,R;
double Lplanet0, Bplanet0, Rplanet0;
double RAplanet, DECplanet,GHAplanet,HPplanet,SDplanet;
double pi,e,kappa,pi0,dtr,Lsun_true,TE2,TE3,delta_psi,delta_eps,rtd,eps,GHAAmean,GHAAtrue;
double dpsi,deps,epsilon0,epsilon1,peri,eab,eps0,Tau_corr,xx,xxx;
double fld1[64],fld2[64],fld3[64],fld4[64],fld5[64];

///////// allgemeiner Teil //////////////////////////

pi=3.14159265358979323;
dtr=pi/180;
rtd=180/pi;

//printf("\n------------ J. Meeus p. 225 (and p.219)--------------\n");
//printf(" REMEMBER:  Delta-T noch einbauen!\n");

//////////////////////////////////////////////////////////////////

jd=julday(ky,km,kd,kth,ktm,kts); JD=jd;
JDE=jd+DeltaT0/86400;  JDE0=JDE;

//printf(">>STARS JDE= %f\n",JDE); getchar();

TE=(JDE-2451545.0)/36525.;
TE2=TE*TE;
TE3=TE2*TE;
Tau=TE/10;

//Calculations for EARTH /////////////////////////////////////////////////////////

Nutation(TE,&dpsi,&deps,&epsilon0,&epsilon1);
  //NOTE: dpsi, deps in DEGREES!
//  printf("NUTATION: TE=%.12f, dpsi=%f deps=%f, epsilon0=%f, epsilon1=%f\n",TE,dpsi*3600,deps*3600,epsilon0,epsilon1);
//  printf("agreement with JM p343 and JM p.148,  OK!");
//  printf("   aber VSOP87, nicht JM p.145.\n");

Aberration(TE,&kappa,&peri, &eab);
//  printf("\nAberration-Test\n");
//  printf(">> Aberration: TE=%.12f, arcsec: kappa=%f deg: peri=%.8f, eab=%.8f\n",TE,kappa*3600,peri,eab);

//Nutation in longitude
 delta_psi = dpsi;
//Nutation in obliquity
 delta_eps = deps;   
//Mean obliquity of the ecliptic
 eps0 = epsilon0;   
//True obliquity of the ecliptic
 eps  = epsilon1;
//GHA Aries, GAST, GMST, equation of the equinoxes
//Mean GHA Aries, = GMST
GHAAmean = norm360(280.46061837+ 360.98564736629*(JD-2451545)+0.000387933*TE2-TE3/38710000);
//True GHA Aries
GHAAtrue = norm360(GHAAmean+delta_psi*cosd(eps));
//printf(">> GHAAmean, GHAAtrue= %.8f %.8f\n",GHAAmean,GHAAtrue);


//printf(" ------------- Calculation for Earth -------------------------\n");
 
// HELIOCENTRIC COORDINATES of EARTH

//printf(" Tau= %.9f JDE= %.12f\n", Tau,jd); 

Learth0= Learth(Tau);
Bearth0= Bearth(Tau);
Rearth0= Rearth(Tau);

//printf(" EARTH L: %.16f  B: %.16f  R:%.16f\n", Learth0,Bearth0,Rearth0); getchar();

Le=Learth0; Be=Bearth0; Re=Rearth0;
//Geocentric longitude of the Sun
Lsun_true = norm360(Le+180-0.09033/3600.);

//////////////////////////////////////////////////////////////////////////////////////////
////////// STARS /////////////////////////////////////////////////////////////////////////
//Ephemerides of selected star
   //FK5-Star catalog, see there. -    Fruehlingspkt + SHA = 360 - RA(degrees)
   char navstar[64][60] =     
 {
 	//   RA            DEC            dRA      dDEC  ann.Parallax
   //Acamar
    " 2.9710266670 -40.3047138890  -0.3910    1.9400  0.0280 ",
   //Achernar
    " 1.6285700000 -57.2367166670   1.1730   -3.4700  0.0230 ",
   //Acrux
    "12.4432975000 -63.0990500000  -0.5240   -1.2100  0.0000 ",
   //Adhara
    " 6.9770966670 -28.9720833330   0.0310    0.2800  0.0000 ",
   //Aldebaran
    " 4.5986769440  16.5092750000   0.4390  -18.9700  0.0480 ",
   //Alioth
    "12.9004855560  55.9598527780   1.3280   -0.5800  0.0090 ",
   //Alkaid
    "13.7923427780  49.3133194440  -1.2490   -1.0900  0.0350 ",
   //Al Na'ir
    "22.1372222220 -46.9609972220   1.2590  -15.1000  0.0510 ",
   //Alnilam
    " 5.6035580560  -1.2019500000   0.0060   -0.2400  0.0000 ",
   //Alphard
    " 9.4597908330  -8.6586527780  -0.0930    3.2800  0.0170 ",
   //Alphecca
    "15.5781322220  26.7147055560   0.9060   -8.8600  0.0430 ",
   //Alpheratz
    " 0.1397958330  29.0904388890   1.0390  -16.3300  0.0240 ",
   //Altair
    "19.8463894440   8.8683416670   3.6290   38.6300  0.1981 ",
   //Ankaa
    " 0.4380638890 -42.3060583330   1.8330  -39.5700  0.0350 ",
   //Antares
    "16.4901219440 -26.4319861110  -0.0710   -2.0300  0.0190 ",
   //Arcturus
    "14.2610213890  19.1824194440  -7.7140 -199.8400  0.0900 ",
   //Atria
    "16.8110747220 -69.0277277780   0.2600   -3.4000  0.0240 ",
   //Avior
    " 8.3752313890 -59.5095861110  -0.3460    1.4400  0.0000 ",
   //Bellatrix
    " 5.4188491670   6.3496500000  -0.0590   -1.3900  0.0260 ",
   //Betelgeuse
    " 5.9195297220   7.4070416670   0.1730    0.8700  0.0050 ",
   //Canopus
    " 6.3991997220 -52.6956944440   0.2450    2.0700  0.0180 ",
   //Capella
    " 5.2781536110  45.9980277780   0.7280  -42.4700  0.0730 ",
   //Deneb
    "20.6905325000  45.2803638890   0.0270    0.2300  0.0000 ",
   //Denebola
    "11.8176611110  14.5720416670  -3.4220  -11.4100  0.0760 ",
   //Diphda
    " 0.7264922220 -17.9866166670   1.6370    3.2500  0.0570 ",
   //Dubhe
    "11.0621294440  61.7508944440  -1.6750   -6.6500  0.0310 ",
   //Elnath
    " 5.4381975000  28.6074083330   0.1690  -17.5100  0.0180 ",
   //Eltanin
    "17.9434352780  51.4889472220  -0.0810   -1.9400  0.0170 ",
   //Enif
    "21.7364344440   9.8749777780   0.2070   -0.0600  0.0060 ",
   //Fomalhaut
    "22.9608486110 -29.6222500000   2.5510  -16.4700  0.1440 ",
   //Gacrux
    "12.5194247220 -57.1131944440   0.2850  -26.2300  0.0000 ",
   //Gienah
    "12.2634350000 -17.5419361110  -1.1240    2.3300  0.0000 ",
   //Hadar
    "14.0637244440 -60.3729972220  -0.4260   -1.9300  0.0160 ",
   //Hamal
    " 2.1195563890  23.4624055560   1.3830  -14.8300  0.0430 ",
   //Kaus Aust.
    "18.4028686110 -34.3846472220  -0.3090  -12.4100  0.0150 ",
   //Kochab
    "14.8450961110  74.1554944440  -0.7630    1.2200  0.0310 ",
   //Markab
    "23.0793494440  15.2052500000   0.4360   -4.2500  0.0300 ",
   //Menkar
    " 3.0379925000   4.0897027780  -0.0630   -7.8000  0.0090 ",
   //Menkent
    "14.1113752780 -36.3700083330  -4.2930  -51.9000  0.0590 ",
   //Miaplacidus
    " 9.2199880560 -69.7172083330  -3.1080   10.7800  0.0380 ",
   //Mirfak
    " 3.4053791670  49.8612055560   0.2460   -2.4600  0.0290 ",
   //Nunki
    "18.9210900000 -26.2967305560   0.0990   -5.4200  0.0000 ",
   //Peacock
    "20.4274588890 -56.7351055560   0.0820   -8.9100  0.0000 ", 
        //Polaris      HEIDELBERG, Wielen et al. J2000:   
        //" 2.530277752   89.26410349    21.183    -1.523   0.0070 ",
   //Polaris      Original FK5:   
   " 2.5301955560  89.2640888890   19.8770   -1.520   0.0070 ",
   //Pollux
    " 7.7552627780  28.0261833330  -4.7400   -4.5900  0.0930 ",
   //Procyon
    " 7.6550313890   5.2250166670  -4.7550 -102.2900  0.2880 ",
   //Rasalhague
    "17.5822433330  12.5600388890   0.8220  -22.6400  0.0560 ",
   //Regulus
    "10.1395319440  11.9671916670  -1.6930    0.6400  0.0390 ",
   //Rigel
    " 5.2422966670  -8.2016611110   0.0030   -0.1300  0.0130 ",
   //Rigil Kent.
    "14.6599680560 -60.8354000000 -49.8260   69.9300  0.7516 ",
   //Sabik
    "17.1729669440 -15.7249194400   0.2600    9.5000  0.0520 ",
   //Schedar
    " 0.6751250000  56.5373500000   0.6360   -3.1900  0.0160 ",
   //Shaula
    "17.5601483330 -37.1038111110  -0.0110   -2.9200  0.0000 ",
   //Sirius
    " 6.7524641670 -16.7161083330  -3.8470 -120.5300  0.3751 ",
   //Spica
    "13.4198852780 -11.1613083330  -0.2780   -2.8300  0.0210 ",
   //Suhail
    " 9.1332711110 -43.4326055560  -0.1720    1.2700  0.0150 ",
   //Vega
    "18.6156477780  38.7836583330   1.7260   28.6100  0.1230 ",
   //Zubenelgenubi
    "14.8479758330 -16.0417833330  -0.7340   -6.6800  0.0490 ",
    //Polaris
    " 2.5301955560  89.2640888890  19.8770   -1.520   0.0070 ",
    //Polaris
    " 2.5301955560  89.2640888890  19.8770   -1.520   0.0070 ",
    
   };
  // printf("STARS-----navstar\n");
   
  // printf("%s",navstar[ 0]); printf("\n");
  // printf("%s",navstar[59]); printf("\n");

////////////////////// fill Arrays fld1[] to fld5[]
/////////////   Surboutine moonepx, program-section //////////////

jmax=60;
// Spalten von ld[][] auf einzelne Vektoren nld0[]schreiben.
for (jz=0; jz<jmax; jz++)
{
  // 0,13  14,28  29,37  38,47  49,55
  ka=0;
  ke=13;
  xx=farr60(navstar, jz, ka,ke);
  fld1[jz]=xx;
  
  ka=14;
  ke=28;
  xx=farr60(navstar, jz, ka,ke);
  fld2[jz]=xx;
  
  ka=29;
  ke=37;
  xx=farr60(navstar, jz, ka,ke);
  fld3[jz]=xx;
  
  ka=38;
  ke=47;
  xx=farr60(navstar, jz, ka,ke);
  fld4[jz]=xx;
 
  ka=49;
  ke=55;
  xx=farr60(navstar, jz, ka,ke);
  fld5[jz]=xx;
  
  //printf("%2d =jz: %12.7f %12.7f %12.7f %12.7f %12.7f\n", jz,fld1[jz],fld2[jz],fld3[jz],fld4[jz],fld5[jz] );
};

char stlist[60][20]=
   {
	   " 0 > Acamar" ,	   
	   " 1 > Achernar" ,
	   " 2 > Acrux" ,
	   " 3 > Adhara" ,
	   " 4 > Aldebaran" ,
	   " 5 > Alioth" ,
	   " 6 > Alkaid" ,
	   " 7 > Al Na'ir" ,
	   " 8 > Alnilam" ,
	   " 9 > Alphard" ,
	   " 10 > Alphecca" ,
	   " 11 > Alpheratz" ,
	   " 12 > Altair" ,
	   " 13 > Ankaa" ,
	   " 14 > Antares" ,
	   " 15 > Arcturus" ,
	   " 16 > Atria" ,
	   " 17 > Avior" ,
	   " 18 > Bellatrix" ,
	   " 19 > Betelgeuse" ,
	   " 20 > Canopus" ,
	   " 21 > Capella" ,
	   " 22 > Deneb" ,
	   " 23 > Denebola" ,
	   " 24 > Diphda" ,
	   " 25 > Dubhe" ,
	   " 26 > Elnath" ,
	   " 27 > Eltanin" ,
	   " 28 > Enif" ,
	   " 29 > Fomalhaut" ,
	   " 30 > Gacrux" ,
	   " 31 > Gienah" ,
	   " 32 > Hadar" ,
	   " 33 > Hamal" ,
	   " 34 > Kaus Aust." ,
	   " 35 > Kochab" ,
	   " 36 > Markab" ,
	   " 37 > Menkar" ,
	   " 38 > Menkent" ,
	   " 39 > Miaplacidus" ,
	   " 40 > Mirfak" ,
	   " 41 > Nunki" ,
	   " 42 > Peacock" ,
	   " 43 > POLARIS" ,
	   " 44 > Pollux" ,
	   " 45 > Procyon" ,
	   " 46 > Rasalhague" ,
	   " 47 > Regulus" ,
	   " 48 > Rigel" ,
	   " 49 > Rigil Kent." ,
	   " 50 > Sabik" ,
	   " 51 > Schedar" ,
	   " 52 > Shaula" ,
	   " 53 > Sirius" ,
	   " 54 > Spica" ,
	   " 55 > Suhail" ,
	   " 56 > Vega" ,
	   " 57 > Zubenelgenubi" ,
	   " 58 > DUMMY" ,
	   "   " 
    };
   
///////////////////////////////////////////////
// LIST to find the actual star for observation, from FK5-Star-Catalog

// k1= starlist(iterq,idstar);
// idstar=k1;

	//Read catalog
double RAstar0 = 15*fld1[idstar];         //eval(navstar[starname].substring(0,13));
double DECstar0 = fld2[idstar];           //eval(navstar[starname].substring(14,28));
double dRAstar = 15*fld3[idstar]/3600;    //eval(navstar[starname].substring(29,37))/3600;
double dDECstar = fld4[idstar]/3600;      //eval(navstar[starname].substring(38,47))/3600;
double par = fld5[idstar]/3600;           //eval(navstar[starname].substring(49,55))/3600;

   //NOTE:  Stars close to sun - like alpha Centauri - need special attention. 
   // The apparent proper-motion in 3d-space therefore is treated more precisely.
    double Vstar=0.;
    if(idstar==49) Vstar =-22.2; //RIGIL KENTAURI moshier #38 special treatment, nearest star
    if(idstar==12)  Vstar= -26.3;   // Altair 
    if(idstar==43)  Vstar= -17.0;   // Polaris
    if(idstar==53)  Vstar= -  7.6;  // Sirius  
    
    double argD   = tand(DECstar0)*cosd(TE*dRAstar); // Great Circle correction
    double dDECRA = atan(argD)*rtd - DECstar0;  
    double dDECstar1 = TE*dDECstar + dDECRA; 
    double DECstarGC = DECstar0 + dDECstar1; 
    double dRAstar1  = TE* dRAstar*cosd(DECstar0)/cosd(DECstarGC);  //real distances
	
	double parscale = - TE*Vstar*par*0.367;        // Relative Velocity correction
    dRAstar1  = dRAstar1 *(1.+parscale);   
	dDECstar1 = dDECstar1*(1.+parscale);

   //Equatorial coordinates at Julian Date T (mean equinox and equator 2000.0)
   double RAstar1  = RAstar0 +dRAstar1;
   double DECstar1 = DECstar0+dDECstar1;
   
   //Mean obliquity of ecliptic at 2000.0 in degrees
   double eps0_2000 = 23.439291111;
   
   //Transformation to ecliptic coordinates in radians (mean equinox and equator 2000.0)
      double lambdastar1 = atan2((sind(RAstar1)*cosd(eps0_2000)+tand(DECstar1)*sind(eps0_2000)),cosd(RAstar1));
      double betastar1 = asin(sind(DECstar1)*cosd(eps0_2000)-cosd(DECstar1)*sind(eps0_2000)*sind(RAstar1));
   
   //Precession
   double eta = (47.0029*TE-0.03302*TE2+0.00006*TE3)*dtr/3600;
   double PI0 = (174.876384-(869.8089*TE-0.03536*TE2)/3600)*dtr; //modified HMK, Meeus eq.(21.6)
   double p0 = (5029.0966*TE+1.11113*TE2-0.000006*TE3)*dtr/3600; //modified HMK, Meeus eq.(21.6)

      double A1 = cos(eta)*cos(betastar1)*sin(PI0-lambdastar1)-sin(eta)*sin(betastar1);
      double B1 = cos(betastar1)*cos(PI0-lambdastar1);
      double C1 = cos(eta)*sin(betastar1)+sin(eta)*cos(betastar1)*sin(PI0-lambdastar1);
      double lambdastar2 = p0+PI0-atan2(A1,B1);
      double betastar2 = asin(C1);
  
   //Annual parallax  fehlte by H.Umland in Longterm-118.htm
      double hbetacos = cos(betastar2);
        if( fabs(hbetacos) < 0.0000001) hbetacos=0.0000001; // modified limit  HMK
      double par_lambda = dtr*par*sin(dtr*Lsun_true-lambdastar2)/hbetacos;
      double par_beta = -dtr*par*sin(betastar2)*cos(dtr*Lsun_true-lambdastar2);
    
      lambdastar2 += par_lambda;
      betastar2 += par_beta;
   
   //Nutation in longitude
   lambdastar2 += dtr*delta_psi;

   //Aberration
   kappa = dtr*20.49552/3600;
   pi0 = dtr*(102.93735+1.71946*TE+0.00046*TE2);
   e = 0.016708634-0.000042037*TE-0.0000001267*TE2;
      
  //hbetacos:
  hbetacos = cos(betastar2);
  double dlambdastar = (e*kappa*cos(pi0-lambdastar2)-kappa*cos(dtr*Lsun_true-lambdastar2))/hbetacos;
  double dbetastar = -kappa*sin(betastar2)*(sin(dtr*Lsun_true-lambdastar2)-e*sin(pi0-lambdastar2));

   lambdastar2 += dlambdastar;
   betastar2 += dbetastar;
    
   //Transformation back to equatorial coordinates in radians
      double RAstar2 =  atan2((sin(lambdastar2)*cosd(eps)-tan(betastar2)*sind(eps)),cos(lambdastar2));
      double DECstar2 = asin(sin(betastar2)*cosd(eps)+cos(betastar2)*sind(eps)*sin(lambdastar2));
   
   //Finals
   double GHAstar = norm360(GHAAtrue-RAstar2/dtr);
   double SHAstar = norm360(360-RAstar2/dtr);
   double DECstar = DECstar2/dtr;

GHAplanet=GHAstar;
DECplanet=DECstar;
RAplanet =RAstar2/dtr;

/////////////////// End output ///////////////////////////////////////////////////////////////
g9999:  //Sprungmarke

*delta1= DECstar;
*grts1 = GHAstar;
*grtg1 = GHAAtrue; // GHA Aries
*alfa1 = RAplanet;
*shast1= SHAstar;

return(idstar);
}//End starseph /////////////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////////////////////////////
void planeteph(int idplanet,double DeltaT0,int ky,int km,int kd,int kth,int ktm,int kts, 
double *delta1, double *grts1, double *grtg1, double *alfa1,double *hpar1) 
{
//input: idplanet-planet..saturn, DeltaT0=Delta-T, ky..kts=Datum und Zeit,
//output: *delta1=Declination, *grts1=GHAplanet, *grtg1=GHAAries, *alfa1=RAplanet, *hpar1=HorPar. 
//idplanet: 4=Venus, 5=Mars, 6=Jupiter, 7=Saturn
///////////////////////////////////////////////////////
//static int year=1992, month=10, day=13, hour=0, min=0, sec=0;
int i,j,jmax,k,ki,l,m,n,ka,ke,kdif,jz,kk,kmax,kq, is0;
int k1,k2,k3;
double delta0, grts0, grtg0, alfa0;
double GMST,TE, jd, Tau, JD,JDE, JDE0;
double Learth0, Bearth0, Rearth0, Le,Be,Re, L,B,R;
double Lplanet0, Bplanet0, Rplanet0;
double RAplanet, DECplanet,GHAplanet,HPplanet,SDplanet;
double pi,e,kappa,pi0,dtr,Lsun_true,TE2,TE3,delta_psi,delta_eps,rtd,eps,GHAAmean,GHAAtrue;
double dpsi,deps,epsilon0,epsilon1,peri,eab,eps0,Tau_corr,xx,xxx;

double x,y,z,lambda,beta,d,lt,dlambda,dbeta,lambda_prime;

///////// allgemeiner Teil //////////////////////////

//printf(">> ky,km,kd,kth,ktm,kts= %d %d %d %d %d %d \n",ky,km,kd,kth,ktm,kts);

pi=3.14159265358979323;
dtr=pi/180;
rtd=180/pi;

//printf("\n------------ J. Meeus p. 225 (and p.219)--------------\n");

//////////////////////////////////////////////////////////////////


jd=julday(ky,km,kd,kth,ktm,kts); JD=jd;
JDE=jd+DeltaT0/86400;  JDE0=JDE;

////printf(">>planet  JDE, DeltaT0=%f %f\n",JDE,DeltaT0); getchar();

TE=(JDE-2451545.0)/36525.;
TE2=TE*TE;
TE3=TE2*TE;
Tau=TE/10;

//Calculations for EARTH /////////////////////////////////////////////////////////

Nutation(TE,&dpsi,&deps,&epsilon0,&epsilon1);
  //NOTE: dpsi, deps in DEGREES!
  //printf("NUTATION: TE=%.12f, dpsi=%f deps=%f, epsilon0=%f, epsilon1=%f\n",TE,dpsi*3600,deps*3600,epsilon0,epsilon1);
  //printf("agreement with JM p343 and JM p.148,  OK!");
  //printf("   aber VSOP87, nicht JM p.145.\n");

Aberration(TE,&kappa,&peri, &eab);
  //printf("\nAberration-Test\n");
  //printf(">> Aberration: TE=%.12f, arcsec: kappa=%f deg: peri=%.8f, eab=%.8f\n",TE,kappa*3600,peri,eab);

//Nutation in longitude
 delta_psi = dpsi;
//Nutation in obliquity
 delta_eps = deps;   
//Mean obliquity of the ecliptic
 eps0 = epsilon0;   
//True obliquity of the ecliptic
 eps  = epsilon1;
//GHA Aries, GAST, GMST, equation of the equinoxes
//Mean GHA Aries, = GMST
GHAAmean = norm360(280.46061837+ 360.98564736629*(JD-2451545)+0.000387933*TE2-TE3/38710000);
//True GHA Aries
GHAAtrue = norm360(GHAAmean+delta_psi*cosd(eps));
//printf(">> GHAAmean, GHAAtrue= %.8f %.8f\n",GHAAmean,GHAAtrue);


//printf(" ------------- Calculation for Earth -------------------------\n");
 
// HELIOCENTRIC COORDINATES of EARTH

//printf(" Tau= %.9f JDE= %.12f\n", Tau,jd); 
Learth0= Learth(Tau);
Bearth0= Bearth(Tau);
Rearth0= Rearth(Tau);
//printf(" EARTH L: %.12f  B: %.12f  R:%.12f\n", Learth0,Bearth0,Rearth0);

Le=Learth0; Be=Bearth0; Re=Rearth0;
//Geocentric longitude of the Sun
Lsun_true = norm360(Le+180-0.000025);

////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////// PLANETENAUSWAHL //////////////////////////////////////////////////////////////
//printf("\n idplanet= %d \n",idplanet);


////////// VENUS ///////////////////////////////////
if(idplanet==4)    
{

//printf(" ------------- Calculation for VENUS -------------------------");
//Achtung: Lvenus, Bvenus, Rvenus sind hier spezifisch, der Rest fuer alle Planeten gleich.

//printf("\n");
//printf(" Tau= %.12f\n", Tau); 
//Heliocentric spherical coordinates
L= Lvenus(Tau);
B= Bvenus(Tau);
R= Rvenus(Tau);
//printf(" Planet Venus see MEEus p. 219, JDE=%f\n",JDE);
//printf(" [A] venus L: %.12f  B: %.12f  R:%.12f\n", L,B,R);
if(floor(JDE-2448976.4) ==0 ) getchar();


//Rectangular coordinates
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);

//printf(">> x,y,z= %f %f %f\n",x,y,z);
//Geocentric spherical coordinates

lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));

//Distance from Earth / light time
d = sqrt(x*x+y*y+z*z);
lt = 0.0057755183*d;
//printf(">> lighttime= %.8f\n",lt);

//Time correction by iteration
JDE=JDE0 - lt;  TE=(JDE-2451545.0)/36525.; TE2=TE*TE;
Tau_corr=TE/10;
//printf(">>Tau_corr= %.12f\n",Tau_corr);

//Coordinates corrected for light time
L = Lvenus(Tau_corr);
B = Bvenus(Tau_corr);
R = Rvenus(Tau_corr);
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);
//printf(">> [B] L: %.12f  B: %.12f  R:%.12f\n", L,B,R);
//printf(">> [C] x,y,z= %f %f %f\n",x,y,z);

d = sqrt(x*x+y*y+z*z);
lt = 0.0057755183*d;
//printf(">> [C] lighttime= %.8f  dist=%.8f\n",lt,d);

lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));
//printf(">>lambda, beta= %f %f\n",360+lambda*rtd,beta*rtd);

//Aberration
kappa=dtr*kappa; //radians
e  =  eab; //dimensionless
pi0= dtr*peri;

dlambda = (e*kappa*cos(pi0-lambda)-kappa*cos(dtr*Lsun_true-lambda))/cos(beta);
dbeta = -kappa*sin(beta)*(sin(dtr*Lsun_true-lambda)-e*sin(pi0-lambda));
lambda += dlambda; //radians
beta += dbeta;
//printf(">> kappa,e,pi0= %.8f %.8f %.8f\n",kappa*rtd*3600,e*rtd,pi0*rtd);

//FK5
lambda_prime = lambda-dtr*1.397*TE-dtr*0.00031*TE2;
dlambda = -0.09033*dtr/3600+0.03916*dtr/3600*(cos(lambda_prime)+sin(lambda_prime))*tan(beta);
dbeta = 0.03916*dtr/3600*(cos(lambda_prime)-sin(lambda_prime));

lambda+=dlambda;
beta+=dbeta;

//Nutation in longitude
lambda += dtr*delta_psi;
//printf(">> delta_psi= %.8f\n",delta_psi*3600);

//printf(">> p.227: lambda, beta= %.8f %.8f\n",360+ lambda*rtd,beta*rtd);
//Right ascension, apparent

RAplanet = rtd*trunc2(atan2((sin(lambda)*cosd(eps)-tan(beta)*sind(eps)),cos(lambda)));
	
//Declination of planet, apparent 
DECplanet = rtd*asin(sin(beta)*cosd(eps)+cos(beta)*sind(eps)*sin(lambda));

//GHA of planet
GHAplanet = norm360(GHAAtrue-RAplanet);
		
//Semidiameter of planet (including cloud layer)
SDplanet = 8.41/d;

//Horizontal parallax of planet
HPplanet = 8.794/d;

//printf(" --------- Venus-Results: JM p.227 OK-------\n");

goto g9999;
}
////////// Mars  /////////////////////////////////////////////////////////////////////////////

if(idplanet==5)
{
//printf(" ------------- Calculation for MARS -------------------------");
//Achtung: Lvenus, Bvenus, Rvenus sind hier spezifisch, der Rest fuer alle Planeten gleich.

//printf("\n");
//printf(" Tau= %.12f\n", Tau); 
//Heliocentric spherical coordinates
L= Lmars(Tau);
B= Bmars(Tau);
R= Rmars(Tau);
//printf(" [A] mars L: %.12f  B: %.12f  R:%.12f\n", L,B,R);


//Rectangular coordinates
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);

//printf(">> x,y,z= %f %f %f\n",x,y,z);
//Geocentric spherical coordinates

lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));

//Distance from Earth / light time
d = sqrt(x*x+y*y+z*z);
lt = 0.0057755183*d;
//printf(">> lighttime= %.8f\n",lt);

//Time correction by iteration
JDE=JDE0 - lt;  TE=(JDE-2451545.0)/36525.; TE2=TE*TE;
Tau_corr=TE/10;
//printf(">>Tau_corr= %.12f\n",Tau_corr);

//Coordinates corrected for light time
L = Lmars(Tau_corr);
B = Bmars(Tau_corr);
R = Rmars(Tau_corr);
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);
//printf(">> [B] L: %.12f  B: %.12f  R:%.12f\n", L,B,R);
//printf(">> [C] x,y,z= %f %f %f\n",x,y,z);

d = sqrt(x*x+y*y+z*z);
lt = 0.0057755183*d;
//printf(">> [C] lighttime= %.8f  dist=%.8f\n",lt,d);

lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));
//printf(">>lambda, beta= %f %f\n",360+lambda*rtd,beta*rtd);

//Aberration
kappa=dtr*kappa; //radians
e = eab;
pi0= dtr*peri;

dlambda = (e*kappa*cos(pi0-lambda)-kappa*cos(dtr*Lsun_true-lambda))/cos(beta);
dbeta = -kappa*sin(beta)*(sin(dtr*Lsun_true-lambda)-e*sin(pi0-lambda));
lambda += dlambda; //radians
beta += dbeta;
//printf(">> kappa,e,pi0= %.8f %.8f %.8f\n",kappa*rtd*3600,e*rtd,pi0*rtd);
//printf("e,kappa,pi0,lambda,dtr,Lsun_true,beta=\n %f %f %f %f %f %f %f\n",
//       e,kappa,pi0,lambda,dtr,Lsun_true,beta);

//FK5
lambda_prime = lambda-dtr*1.397*TE-dtr*0.00031*TE2;
dlambda = -0.09033*dtr/3600+0.03916*dtr/3600*(cos(lambda_prime)+sin(lambda_prime))*tan(beta);
dbeta = 0.03916*dtr/3600*(cos(lambda_prime)-sin(lambda_prime));

lambda+=dlambda;
beta+=dbeta;

//Nutation in longitude
lambda += dtr*delta_psi;
//printf(">> delta_psi= %.8f\n",delta_psi*3600);

//printf(">> p.227: lambda, beta= %.8f %.8f\n",360+ lambda*rtd,beta*rtd);
//Right ascension, apparent

RAplanet = rtd*trunc2(atan2((sin(lambda)*cosd(eps)-tan(beta)*sind(eps)),cos(lambda)));
	
//Declination of planet, apparent 
DECplanet = rtd*asin(sin(beta)*cosd(eps)+cos(beta)*sind(eps)*sin(lambda));

//GHA of planet
GHAplanet = norm360(GHAAtrue-RAplanet);
		
//Semidiameter of planet (including cloud layer)
SDplanet = 4.66/d;

//Horizontal parallax of planet
HPplanet = 8.794/d;

//printf(" --------- Mars-Results: -------\n");

goto g9999;
}
////////// Jupiter ///////////////////////////////////////////////////////////////////////////
if(idplanet==6) 
{
//Calculations for Jupiter
//printf(" ------------- Calculation for JUPITER -------------------------");
//Achtung: Lvenus, Bvenus, Rvenus sind hier spezifisch, der Rest fuer alle Planeten gleich.

//printf("\n");
//printf(" Tau= %.12f\n", Tau); 

//Heliocentric coordinates
L = Ljupiter(Tau);  
B = Bjupiter(Tau);
R = Rjupiter(Tau);
 

//Rectangular coordinates
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);


//Geocentric coordinates
//with(Math)

lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));

//Distance from earth / light time
d = sqrt(x*x+y*y+z*z);
lt = 0.0057755183*d;

//Time correction
Tau_corr = (JDE-lt-2451545.)/365250.;

//Coordinates corrected for light time
L = Ljupiter(Tau_corr);
B = Bjupiter(Tau_corr);
R = Rjupiter(Tau_corr);
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);

   
lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));

//Aberration 
kappa=dtr*kappa; //radians
e = eab;
pi0= dtr*peri;

dlambda = (e*kappa*cos(pi0-lambda)-kappa*cos(dtr*Lsun_true-lambda))/cos(beta);
dbeta = -kappa*sin(beta)*(sin(dtr*Lsun_true-lambda)-e*sin(pi0-lambda));

//printf("e,kappa,pi0,lambda,dtr,Lsun_true,beta=\n %f %f %f %f %f %f %f\n",
//       e,kappa,pi0,lambda,dtr,Lsun_true,beta);


lambda += dlambda;
beta += dbeta;

//FK5
lambda_prime = lambda-dtr*1.397*TE-dtr*0.00031*TE2;

dlambda = -0.09033*dtr/3600+0.03916*dtr/3600*(cos(lambda_prime)+sin(lambda_prime))*tan(beta);
dbeta = 0.03916*dtr/3600*(cos(lambda_prime)-sin(lambda_prime));

lambda+=dlambda;
beta+=dbeta;

//Nutation in longitude
lambda += dtr*delta_psi;

   

//Right ascension, apparent
RAplanet = rtd*trunc2(atan2((sin(lambda)*cosd(eps)-tan(beta)*sind(eps)),cos(lambda)));

	
//Declination of Jupiter, apparent 
DECplanet = rtd*asin(sin(beta)*cosd(eps)+cos(beta)*sind(eps)*sin(lambda));


//GHA of Jupiter
GHAplanet = norm360(GHAAtrue-RAplanet);
		
//Semidiameter of Jupiter (equatorial)
SDplanet = 98.44/d;

//Horizontal parallax of Jupiter
HPplanet = 8.794/d;

//printf(" --------- Jupiter-Results: -------\n");


goto g9999;
}
////////// Saturn ////////////////////////////////////////////////////////////////////////////
if(idplanet==7) 
{
//Calculations for Saturn
//Heliocentric coordinates
L = Lsaturn(Tau);
B = Bsaturn(Tau);
R = Rsaturn(Tau);

//Rectangular coordinates
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);

//Geocentric coordinates
lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));

//Distance from earth / light time
d  = sqrt(x*x+y*y+z*z);
lt = 0.0057755183*d;

//Time correction
Tau_corr = (JDE-lt-2451545)/365250.;

//Coordinates corrected for light time
L = Lsaturn(Tau_corr);
B = Bsaturn(Tau_corr);
R = Rsaturn(Tau_corr);
x = R*cosd(B)*cosd(L)-Re*cosd(Be)*cosd(Le);
y = R*cosd(B)*sind(L)-Re*cosd(Be)*sind(Le);
z = R*sind(B)-Re*sind(Be);

lambda = atan2(y,x);
beta = atan(z/sqrt(x*x+y*y));

//Aberration
kappa=dtr*kappa; //radians
e = eab;
pi0= dtr*peri;

dlambda = (e*kappa*cos(pi0-lambda)-kappa*cos(dtr*Lsun_true-lambda))/cos(beta);
dbeta = -kappa*sin(beta)*(sin(dtr*Lsun_true-lambda)-e*sin(pi0-lambda));
lambda += dlambda;
beta += dbeta;

//FK5
lambda_prime = lambda-dtr*1.397*TE-dtr*0.00031*TE2;
dlambda = -0.09033*dtr/3600+0.03916*dtr/3600*(cos(lambda_prime)+sin(lambda_prime))*tan(beta);
dbeta = 0.03916*dtr/3600*(cos(lambda_prime)-sin(lambda_prime));

lambda+=dlambda;
beta+=dbeta;

//Nutation in longitude
lambda += dtr*delta_psi;

//Right ascension, apparent
RAplanet = rtd*trunc2(atan2((sin(lambda)*cosd(eps)-tan(beta)*sind(eps)),cos(lambda)));
	
//Declination of Saturn, apparent
DECplanet = rtd*asin(sin(beta)*cosd(eps)+cos(beta)*sind(eps)*sin(lambda));

//GHA of Saturn
GHAplanet = norm360(GHAAtrue-RAplanet);
		
//Semidiameter of Saturn (equatorial)
SDplanet = 82.73/d;

//Horizontal parallax of Saturn
HPplanet = 8.794/d;

//printf(" --------- Saturn-Results: -------\n");
}

/////////////////// End output ///////////////////////////////////////////////////////////////

g9999:  //Sprungmarke

*delta1= DECplanet;
*grts1 = GHAplanet;
*grtg1 = GHAAtrue; // GHA Aries
*alfa1 = RAplanet;
*hpar1 = HPplanet/60;

}//End planeteph /////////////////////////////////////////////////////////////////////////////////

//cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
double suntime(int year, int month, int day, double Lange, double Breite,
       int *srd,int *srm,int *ssd,int *ssm,int *Ar,int *As,int *D) 
 {
 	int year0,month0,day0,hour0,min0,sec0;
 	int srd0,srm0,ssd0,ssm0,daemm,ih1,ih2;
 	
 	double jd,jd0,t0,tx,td;
 	double pi=3.1415926535898; 
 	double h,T,B,M,L,eob,DK,RA,RAm,Zeitgl,Zd,Tl,st,aux,dtr,rtd,h1,h2,h3;
 	double sr,ss;

//Constants
    h=-34/60.; //degrees, center	
    h=-0.83; //see Jean Meeus, Rising and Setting
    dtr=pi/180;   rtd=1./dtr;
 	
 	
 	//year=2020; month=11; day=1;
 	
 // START Program Sunrise-Sunset , epoch-2000	
    year0= 2000; month0=1; day0=1;    hour0=12; min0=0; sec0=0;
 
    jd0=julday( year0, month0, day0, hour0, min0, sec0 );
    jd =julday( year , month , day , hour0, min0, sec0 );
	
	t0=2451545.0; //=2451545.0 ?
	tx=jd ;
 
    // Aktueller Tag wird als tx festgelegt
    td=tx-t0;
    T=td/36525.;
 
    //Fr einen einzigen Ort kann die Position im Programm festgelegt werden, andernfalls weglassen und oben eingeben
    //Lange = 06 + 53/60. ;   Lange=0;
    //Breite= 51 + 06/60. ;   Breite=70; 
    //Am 1. Nov. 2020 laut Naut Jahrbuch fuer lambda=0 und phi=70:  sr=08:33h   ss=14:53h
    if(Breite>89.99) Breite=89.99; if(Breite<-89.99) Breite=-89.99;
    
    B=pi*Breite/180;
    h=pi*h/180;
     
    M=2*pi*(0.993133 + 99.997361*T); //mean anomaly of sun
    while (M>2*pi) M=M-2*pi;   while (M<0) M=M+2*pi;
         
    L=2*pi*(0.7859453 + M/(2*pi) + (6893*sin(M)+72*sin(2*M)+6191.2*T)/1296000); //mean longitude of sun
    while (L>2*pi) L=L-2*pi;   while (L<0) L=L+2*pi;
 
    eob=2*pi*(23.43929111 + (-46.8150*T - 0.00059*T*T + 0.001813*T*T*T)/3600)/360; //obliquity of ecliptic
 
    DK=asin(sin(eob)*sin(L)); //declination of sun
 
    RA=atan(tan(L)*cos(eob)); //Rectascension 
    if (RA<0 ) RA=RA+pi;       
	if (L>pi)  RA=RA+pi;
    RA=RA*3.81972;
 
    RAm=18.71506921 + 2400.0513369*T + ((2.5862E-5) - (1.72E-9*T))*T*T; //Greewich Sidereal Time as RA
    RAm=fmod(RAm,24.0);
 
    Zeitgl=1.0027379*(RAm - RA);
 
    aux=(sin(h) - sin(B)*sin(DK))/(cos(B)*cos(DK));
	if(aux > 1 || aux<-1) aux=-1; 
	Zd=12*acos(aux)/pi;
    Tl=2*Zd; 
 
    sr=12-Zd-Zeitgl;
    sr=sr-(Lange/15);
    sr=fmod(sr,24.0);
 
    ss=12+Zd-Zeitgl;         	   
    ss=ss-(Lange/15);
    ss=fmod(ss,24.0);
    
    h2=sin(DK)/cos(dtr*Breite);
    if(h2<-1) h2=-1; if(h2>1) h2=1;
    h1=rtd*acos(h2);

	if(sr<0) sr=sr+24;
	if(ss<0) ss=ss+24;
    if(aux < -0.999999999) {st=0; sr=0; ss=0;}

    srd0=sr ; srm0=60*(sr-srd0);
    ssd0=ss ; ssm0=60*(ss-ssd0);
    h1=round(h1); if(h1<0) h1=0;
    ih1=h1; 
    daemm=20+0.01*Breite*Breite; if(srd0<1) daemm=2*srm0;

    //printf(" srd0,srm0,ssd0,ssm0: %d %d %d %d\n",srd0,srm0,ssd0,ssm0);
    
    *ssd=ssd0; *ssm=ssm0;
	*srd=srd0; *srm=srm0;
	 
	*Ar=ih1;
	*As=360-ih1;
	*D=daemm;
         	 
    return 0;
}

double zeitgleichung(double JDE,double alfa,double dpsi,double eps)
{
	double L0,zeitg0;
	double tau,tau2,tau3,tau4,tau5;
	
	tau=(JDE-2451545.0)/365250.;
	tau2=tau*tau; tau3=tau*tau2; tau4=tau*tau3; tau5=tau*tau4;
		
	L0= 280.4664567 + 360007.6982779*tau + 0.03032028*tau2 + tau3/49931 +- tau4/15300-tau5/2000000;
	L0 = norm360(L0);
	zeitg0 = L0 - 0.0057183 - alfa + dpsi*cosd(eps);
	
	return zeitg0;
}


double equ_of_time(int hour,int min,int sec,double grtg0,double alfasun)
{
	//Equation of Time: see Wikipedia (simpler: J. Meeus p.183)
	//eqot0=Zeitgleichung(JDE,alfasun,delta_psi,eps) //= EPHEMERIS Eq. of TIME;
	//NOTE: this verison based on the here computed ephemerides is used instead of J.Meeus,
	//      since the basisi L=280.4664...at T=0 is different from grtg0-Basis!
	double houreff,eqot0,eqoth;
	
	eqot0=norm360(grtg0-alfasun); // = Equation of Time =GAST-RAsun -hours [+-12h offset]
	houreff=(hour+min/60.+sec/3600.);
	eqoth=eqot0/15-houreff;
	if(eqoth>0) eqoth=eqoth-12;
	else if(eqoth<0) eqoth=eqoth+12;
	if(eqoth> 24) eqoth+=24;
	if(eqoth<-24) eqoth+=24;

    return eqoth;
}

void HcAz(double lat0,double lon0,double DEC0,double GHA0,double *LHA00,double *Hcalc,double *Az0)
{   
    double degrad,raddeg=180./3.14159265358979;
	double cosphi,cosdel,LHA0,coslha,sindel,sinphi,sinhc,coshc,cosaz,hc,hc0,az,az0;
	degrad=1./raddeg;
	
//calculate delta-H and Azimut
cosphi = cos(lat0*degrad);
cosdel = cos(DEC0*degrad);
LHA0  = GHA0+lon0;  LHA0=norm360(LHA0);
coslha = cos(LHA0*degrad);
sindel = sin(DEC0*degrad);
sinphi = sin(lat0*degrad);

sinhc = cosphi*cosdel*coslha + sindel*sinphi;
hc=asin(sinhc);
coshc = cos(hc);
hc0=hc*raddeg;

*Hcalc= hc0;  // Theoretical exact Height for given position and time. 

cosaz=(sindel-sinphi*sinhc)/(cosphi*coshc);
az=acos(cosaz); az0=az*raddeg; 
if((0. < LHA0) && (LHA0 < 180.)) az0=360.-az0;

*LHA00=LHA0;
*Az0=az0;    // Theoretical Azimuth
	
}

double dxangle(int adeg, double aminf)
{                    // construct angle[degrees] from deg and min.
  double angle;	
	if(adeg< 0) angle=adeg - fabs(aminf)/60.;
	else        angle=adeg + fabs(aminf)/60.;
	if(adeg==0) angle = aminf/60.;
  return angle;
}

//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//cccccccccccccccccc MMAIN cccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc
//ccccccccccccccccccccccccccccccccccccccccccccccccccc


//int main()
int main (int argc, char *argv[])  
//Ephemerides-Variables
//c  Erste Version war aus Formelsamm.Navig. von Albrand u. Junge.
//c  Dann nach J. Meeus, fuer Sonne inzwischen:
//c  NEUE Version: Genauigkeit +- 1 Winkelsekunde. Jahre 1800-2200. 
//c  Jean Meeus p.169, Chapter 32 und Anhang III  !!!

{	  
int result;  
int year1, month1, day1;
int year2,month2,day2;
int hour1, min1, sec1;  
int hour2, min2, sec2;
int year,month,day,hour,min,sec;
int lond, lonm, latd, latm, lats, lons=0;
int lond1, lonm1, latd1, latm1, lats1, lons1;
int lond2, lonm2, latd2, latm2, lats2, lons2;

int iur, iur1, iur2; //iur1=0: SUN lower, iur2=2: MOON lower
int had=0, has=0, hed=0, hem=0, hes=0, hcd=0, hcm=0, hcs=0;
int had1, ham1,  has1=0;
int had2, ham2,  has2=0;
int nobs,iersum,iterq;
int sdat1,sdat2, sh1,sm1,sh2,sm2, slad1,slam1,slod1,slom1, slad2,slam2,slod2,slom2;
int sunrise,srd,srm,ssd,ssm,Ar,As,daemm;
int idplanet,idstar,idstar1,idstar2,signdist;

double indb=1, aug=6, isw=0, indb2,aug2 ; 
double slamf1,slomf1,slamf2,slomf2;
double velav=0,kursav=0,temperature,pressure,tempin,pressin;
double kursbak,kursaz,dist, hdif1,hdif2,azim1,azim2, jd,jd1,jd2,delta_psi,delta_eps;

//General Values
int i,j,k,l,m,n,kres,kkk,lenstr,kmax,kq, is0;
int iaux, jaux, kaux, iverseg, ier1,ier2,errvers;

int y,d,ih,id, ihmk,idf2, iloop;
int ky,km,kd,kth,ktm,kts;
int ig,im,is,moonpar,moonorb;
int zlad1,zlam1,zlod1,zlom1, zlad2,zlam2,zlod2,zlom2;
int ig0,im0,imr0,isr0;

double pigrd, grdpi, g, xaux, xxx, hdif,degrad,raddeg,pi;
double utc,utm,ut,tm,ta,T,TE,houreff;
double GAST0,grtg,g0,als0,als,alsu0,alsun,eps0,eps;
double sdelta,delta,DEC0,tana2,alfa,RA0,RA0h,alfah,RAsun,GHA0,SHA0;
double ha0,hb0,he0,ur,ur0,gb,gb0,dip,dip0,HPsun,HPmoon,HP,HPall,SDiam,SDsun,SDmoon,SDa,shastar0;
double hamf,hamf1,hamf2,hemf,hcmf;
double arg0,argpi,r,r0, lat0,lon0,loha,LHA0,az,az0;
double cosphi,cosdel,coslha,sindel,sinphi,sinhc,coshc,cosaz;
double h1,h2,h3,h4,DeltaT0,DeltaTT,jdesun,JD,JDE, hc,hc0, hcheck1,hcheck2;
double latitude0,longitude0,latitude1,longitude1,latitude2,longitude2;
double latbasic,lonbasic;
double wink1,wink2,slope1,slope2;
double x0,x1,x2,xav,y1,y2,y0,ynorm,icase,latitudep,longitudep,latxx1,latxx2,lonxx1,lonxx2;
double xpos,ypos,angle;
double kursav0,kursav2, velav2, eqot0, eqoth,GMST0,mindist;
double sdeg1,sdeg2,smin1,smin2,latmf,latmf1,latmf2,lonmf,lonmf1,lonmf2;
double hpar1,sm0,ss0, LD_limb,xnear;

int resetRX=0;
char str0[21]="                    ";
char str1[21]="abcdefg";
FILE *fptr;


//Assignments and executable code starts here
char stlist[60][20]=
   {
	   " 0 > Acamar" ,	   
	   " 1 > Achernar" ,
	   " 2 > Acrux" ,
	   " 3 > Adhara" ,
	   " 4 > Aldebaran" ,
	   " 5 > Alioth" ,
	   " 6 > Alkaid" ,
	   " 7 > Al Na'ir" ,
	   " 8 > Alnilam" ,
	   " 9 > Alphard" ,
	   " 10 > Alphecca" ,
	   " 11 > Alpheratz" ,
	   " 12 > Altair" ,
	   " 13 > Ankaa" ,
	   " 14 > Antares" ,
	   " 15 > Arcturus" ,
	   " 16 > Atria" ,
	   " 17 > Avior" ,
	   " 18 > Bellatrix" ,
	   " 19 > Betelgeuse" ,
	   " 20 > Canopus" ,
	   " 21 > Capella" ,
	   " 22 > Deneb" ,
	   " 23 > Denebola" ,
	   " 24 > Diphda" ,
	   " 25 > Dubhe" ,
	   " 26 > Elnath" ,
	   " 27 > Eltanin" ,
	   " 28 > Enif" ,
	   " 29 > Fomalhaut" ,
	   " 30 > Gacrux" ,
	   " 31 > Gienah" ,
	   " 32 > Hadar" ,
	   " 33 > Hamal" ,
	   " 34 > Kaus Aust." ,
	   " 35 > Kochab" ,
	   " 36 > Markab" ,
	   " 37 > Menkar" ,
	   " 38 > Menkent" ,
	   " 39 > Miaplacidus" ,
	   " 40 > Mirfak" ,
	   " 41 > Nunki" ,
	   " 42 > Peacock" ,
	   " 43 > POLARIS" ,
	   " 44 > Pollux" ,
	   " 45 > Procyon" ,
	   " 46 > Rasalhague" ,
	   " 47 > Regulus" ,
	   " 48 > Rigel" ,
	   " 49 > Rigil Kent." ,
	   " 50 > Sabik" ,
	   " 51 > Schedar" ,
	   " 52 > Shaula" ,
	   " 53 > Sirius" ,
	   " 54 > Spica" ,
	   " 55 > Suhail" ,
	   " 56 > Vega" ,
	   " 57 > Zubenelgenubi" ,
	   " 58 > DUMMY" ,
	   " " 
    };

pi=3.14159265359;
degrad = 2. * pi / 360.;
raddeg = 180. / pi;
lenstr=999;
iloop=0;
kkk=0;
eqot0=0;
az0=180;
az=az0*degrad; 
has1=0;
has2=0;
mindist=0.1;
iur=0;
nobs=1;


// Inital Conditions initconditions ////////////////////////////////////////////////////

temperature=10.0;                      // Temperatur
pressure=1010.0;                       // Luftdruck
year1=1997, month1=9, day1=25;         //Datum
hour1=21, min1=31, sec1=53;              // Time at DR 1
hour2=21, min2=33; sec2=21;              // Time at Dr 2
latd1= -41; latmf1= -33.0;               // Position at DR 1
lond1= -173; lonmf1= -20.0;               //  same
latd2= 0; latmf2= 0;               // Position
lond2= 0; lonmf2= 0;
iur1=0;  idstar1=43;              //iu1=2: MOON lower limb;  iur2=0: SUN lower limb
iur2=2;  idstar2=49;              // ur2=4:VENUS;  iur2=8, idstar=33: HAMAL
had1= 42; hamf1= 5.0;        // sextant altitude 1
had2= 23; hamf2= 16.0;        // sextant altitude 2  
indb=1.; aug= 6.0;           // idex-correction, height-of-eye
velav = 0.;                 // velocity of ship
kursav= 0.;                 // course

// end Initial conditions /////////////////////////////////////////////////////////

latitude1=dxangle(latd1,latmf1); longitude1=dxangle(lond1,lonmf1);
latitude2=latitude1; longitude2=longitude1;

cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
latd1=ig0; latmf1=sm0;
cxangle(longitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
lond1=ig0; lonmf1=sm0;
iur=iur1;
hdif=0;
velav2=0; kursav2=0;
iverseg=0;
iersum=0;
iterq=0;
kq=0;
SDiam=0.;
HPall=0.;
tempin=temperature;
pressin=pressure;

    year=year1; month=month1; day=day1;
    hour=hour1; min=min1; sec=sec1;
    latd=latd1; latmf=latmf1; lond=lond1; lonmf=lonmf1;
    iur=iur1;
    had=had1; hamf=hamf1;
    //Vorbesetzung Delta_T: siehe nach Einlesen der Dateien 1 und 2
    DeltaT0 = delta0x(year);  //Vorbesetzung der Datei   astronav0x0.txt
	DeltaT0 = deltatime(year,month);  
	if(year>2020) DeltaT0=delta0x(year);  

    hamf= hamf1;
	year2=year1; month2=month1; day2=day1;    
	idstar=idstar1; 

// moonpar=0; //Moon-Orbit set following J.Meeus p.338
moonpar=1; //Moon-Orbit set following IERS2003


skip(25);
printf(" Astro-Navigation by SEXTANT & CLOCK. V13\n");
printf(" ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ \n\n");

printf(" Determine position of a ship at sea\n");
printf(" using Sun or Moon, Planets or Stars.\n");
printf(" Date, TIME and SEXTANT-data required,\n");
printf(" and approximate estimates for the position.\n");
printf(" Estimated values for Longitude and Latitude\n");
printf(" expected in degrees and angular minutes,\n");
printf(" degrees positive for NORTH and EAST,\n");
printf(" negative for SOUTH and WEST.\n");
printf(" Two observations needed to determine position.\n");
printf("   \n");
printf(" The values are entered one after the other\n");
printf(" but dont use leading zeroes.\n");
printf(" The program remembers the input-values.\n");
printf(" The following screen shows an example.\n");

// Check for RESET of Files  0x1 and ox2.txt
int iremov;
printf("\n");
printf("  To RESET files 0x1,0x2 enter:'R' or '1' ==>"); resetRX=getchar(); // printf("resetRX= %d\n",resetRX); getchar();
if(resetRX==82 || resetRX==114 || resetRX==49) 
{ printf(" OK, + RESETTiNG files 0x1 and 0x2.txt\n"); 
  iremov=remove("astronav0x1.txt"); if(iremov!=0) printf(" ??? file astronav0x1.txt possibly PROTECTED\n");
  iremov=remove("astronav0x2.txt"); if(iremov!=0) printf(" ??? file astronav0x2.txt possibly PROTECTED\n");
  getchar(); 
} 
else 
{printf(" OK, - No RESET of files 0x0,0x1,0x2.txt\n"); } ;

// Check for RESET of Files  0x1 and ox2.txt
if(resetRX==82 || resetRX==114 || resetRX==49)
{
  printf("  To RESET file 0x0 enter:'X' or '2' ==>"); resetRX=getchar(); // printf("resetRX= %d\n",resetRX); getchar();
  if(resetRX==88 || resetRX==120 || resetRX==50) 
  { printf(" OK, + RESETTiNG file 0x0.txt\n"); 
    iremov=remove("astronav0x0.txt"); 
	if(iremov!=0) printf(" ??? file astronav0x0.txt is WRITE PROTECTED\n"); 
    getchar(); 
  }  
  else 
  {printf(" OK, - No RESET of file 0x0.txt\n"); getchar(); } 
};
//END of RESET-Checks

printf("         ... press ENTER to continue: \n"); getchar();

g0000: //Beginn Daten-Abfrage: ////////////////////////////////////////  

iloop=iloop+1; /// check,how often this has been restartet here

if(nobs == 2 ) goto g0012; 

    year=year1; month=month1; day=day1;
    hour=hour1; min=min1; sec=sec1;
      cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    latd1=ig0; latmf1=sm0;
      cxangle(longitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    lond1=ig0; lonmf1=sm0;
    latd=latd1; latmf=latmf1; lond=lond1; lonmf=lonmf1;
    iur=iur1; idstar=idstar1;
    had=had1; hamf=hamf1; 
    if(iterq==1) goto g0011; //iterate final result
//Datei-Existenzpruefung 1 ################################

   fptr=fopen("astronav0x1.txt","r");
   if(fptr==NULL)
   {
      //printf("Datei 1 existiert noch nicht!\n"); getchar();
	  id=0; 
      goto g0011;
   } 
   	  id=1;
   	//Fileread starten  
   	//printf("***  2389 fileread 1 start\n"); getchar();
   	rewind(fptr);
    fscanf(fptr,"%d %d %d \n", &year,&month,&day);
    fscanf(fptr,"%d %d %d \n", &hour, &min, &sec);  
    fscanf(fptr,"%d %lf \n", &latd,&latmf);
    fscanf(fptr,"%d %lf \n", &lond,&lonmf);
    fscanf(fptr,"%d %d \n", &iur,&idstar);
	fscanf(fptr,"%d %lf %d \n", &had,&hamf,&has);
    fscanf(fptr,"%lf %lf \n", &indb,&aug);
    fscanf(fptr,"%lf %lf %lf \n", &hdif,&az0,&az);
    fscanf(fptr,"%lf %lf \n", &temperature,&pressure);
	fclose(fptr);
	year1=year; month1=month; day1=day;
    hour1=hour; min1=min; sec1=sec;
    latd1=latd; latmf1=latmf; lond1=lond; lonmf1=lonmf;
    iur1=iur; idstar1=idstar;
    had1=had; hamf1=hamf; 
    latitude1=dxangle(latd1,latmf1); longitude1=dxangle(lond1,lonmf1);
	hamf1= hamf;
	tempin=temperature; pressin=pressure;
			
	//Vorbesetzung Delta_T: hier nach Einlesen der Dateien 1 und 2
	DeltaT0 = deltatime(year,month);
    if(year>2020) DeltaT0=delta0x(year);	
			
	goto g0012;

g0011:
	if(id ==1) goto g0012;
	//printf("2394 filewrite 1 starten\n"); getchar();
	//Datei 1 erzeugen mit Default Werten
   	fptr=fopen("astronav0x1.txt","w");
   	has=0;
   	
      cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    latd1=ig0; latmf1=sm0;
      cxangle(longitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    lond1=ig0; lonmf1=sm0;
    latd=latd1; latmf=latmf1; lond=lond1; lonmf=lonmf1;
   	fprintf(fptr,"%d %d %d \n",year,month,day);
    fprintf(fptr,"%d %d %d \n",hour1, min1, sec1);  
    fprintf(fptr,"%d %f \n",latd1,latmf1);
    fprintf(fptr,"%d %f \n",lond1,lonmf1);
    fprintf(fptr,"%d %d \n",iur1,idstar1);
    fprintf(fptr,"%d %f %d \n",had1,hamf1,has);
    fprintf(fptr,"%.2f %.2f \n",indb,aug);
    fprintf(fptr,"%.2f %.2f %.2f \n",hdif,azim1,az);
    fprintf(fptr,"%.2f %.2f \n",temperature,pressure);
    fclose(fptr);
    year1=year; month1=month; day1=day;
    hour1=hour; min1=min; sec1=sec;
    latd1=latd; latmf1=latmf; lond1=lond; lonmf1=lonmf;
    iur1=iur; idstar1=idstar;
    had1=had; hamf1=hamf; 
	id=1;
	//printf("filewrite ende\n");  
	goto g0010;
//	printf("########## EXISTENZ-TEST 1 ENDE ###########\n");  

g0012:
	
    if (nobs ==1) goto g0010;

    year=year2; month=month2; day=day2;
    hour=hour2; min=min2; sec=sec2;
    latd=latd2; latmf=latmf2; lond=lond2; lonmf=lonmf2;
    iur=iur2; idstar=idstar2;
    had=had2; hamf=hamf2; 
    
    if(iterq==1) goto g0021; //iterate final result
  	
//Datei-Existenzpruefung 2 ################################
   fptr=fopen("astronav0x2.txt","r");
   if(fptr==NULL)
   {
      //printf("Datei existiert noch nicht!\n"); getchar();
	  id=0;
	  idf2=0; //idf2=0 sagt, dass Datei 2 nicht existiert ; idf2=1: datei existiert.
      goto g0021;
   }
      //printf(" Datei existiert schon!\n"); getchar();
   	  id=1;
   	  idf2=1;
   	//Fileread starten  
   	//printf("2442 fileread 2 start\n"); getchar();
    fscanf(fptr,"%d %d %d \n", &year,&month,&day);
    fscanf(fptr,"%d %d %d \n", &hour, &min, &sec);
    fscanf(fptr,"%d %lf \n", &latd,&latmf);
    fscanf(fptr,"%d %lf \n", &lond,&lonmf);
    fscanf(fptr,"%d %d \n", &iur,&idstar);
	fscanf(fptr,"%d %lf %d \n", &had,&hamf,&has);
    fscanf(fptr,"%lf %lf \n", &indb2,&aug2);
    fscanf(fptr,"%lf %lf %lf \n", &hdif,&az0,&az);
    fscanf(fptr,"%lf %lf \n",&kursav,&velav);
    fclose(fptr);

    year2=year; month2=month; day2=day;
    hour2=hour; min2=min; sec2=sec;
    latd2=latd; latmf2=latmf; lond2=lond; lonmf2=lonmf;
    latitude2=dxangle(latd2,latmf2); longitude2=dxangle(lond2,lonmf2);    
    iur2=iur; idstar2=idstar;
    had2=had; hamf2=hamf;
    kursav2=kursav; velav2=velav;
    
    hamf2=hamf;
	
	goto g0022;

g0021:
	if(id ==1) goto g0022;
	//printf("2449 filewrite 2 starten\n"); getchar();
	//Datei erzeugen mit Default Werten
	cxangle(latitude2 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    latd2=ig0; latmf2=sm0;
    cxangle(longitude2 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    lond2=ig0; lonmf2=sm0;
	
   	fptr=fopen("astronav0x2.txt","w");
   	has2=0;
   	fprintf(fptr,"%d %d %d \n",year,month,day);
    fprintf(fptr,"%d %d %d \n",hour2, min2, sec2);
    fprintf(fptr,"%d %f \n",latd2,latmf2);
    fprintf(fptr,"%d %f \n",lond2,lonmf2);
    fprintf(fptr,"%d %d \n",iur2,idstar2);
    fprintf(fptr,"%d %f %d \n",had2,hamf2,has);
    fprintf(fptr,"%.2f %.2f \n",indb,aug);
    fprintf(fptr,"%.2f %.2f %.2f \n",hdif,azim2,az);
    fprintf(fptr,"%.2f %.2f \n",kursav,velav);    
    year2=year; month2=month; day2=day;
	id=1;
	fclose(fptr);  

g0022:
		
g0010:

//CCCCCCCCCCCC    MainLOOP CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

//~~~~~~~~~~~~~~~~~~~~~~~~~   EXAMPLE ~~~~~~~~~~~~~~~~~~~~~~~~	

if(nobs == 1) 
{
skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK\n\n");
printf(" ~~~~~~~~~~~~+~~ E X A M P L E  ~~~~~~~~~~~~~ \n");
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Latitude:  %d deg %.2f' \n", latd,latmf);
printf(" Longitude: %d deg %.2f' \n", lond,lonmf);
printf(" Sextant viewed: Ha= %d deg %3.2f' \n", had,2.1);
printf(" Sextant calcul. Hc: %d deg %3.2f' \n", had,3.4);
printf(" => Position incorrect by: %6.2f miles \n", 5.6 );
printf(" => Azimut direction: %6.2f deg \n", az0);
printf(" ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ \n");
printf(" (Thanks: J.Meeus,VSOP87,H.Umland,LEA406 ...!)\n");
printf(" ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ \n");
printf(" (3 files created: astronav0x0,1,2.txt, for\n");
printf(" Delta-T in years >2020 see file ...0x0.txt)\n");
printf(" \n            ... press ENTER to continue: \n");
if(iterq==0 ) getchar();
}

fflush(stdin);  // CLEAR the INPUT-BUFFER

/// nobs=1,2: Erste oder Zweite Beobachtungsrunde ///////////////////////////////////////////
   
   if(nobs==1)
   { 
  	year=year1; month=month1; day=day1;
    hour=hour1; min=min1; sec=sec1;
    
    cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    latd1=ig0; latmf1=sm0;
    cxangle(longitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    lond1=ig0; lonmf1=sm0;
	
    latd=latd1; latmf=latmf1; lond=lond1; lonmf=lonmf1;
    iur=iur1; idstar=idstar1;
    had=had1; hamf=hamf1;
   }   
   
   if(nobs==2)
   { 
  	year=year2; month=month2; day=day2;
    hour=hour2; min=min2; sec=sec2;
    cxangle(latitude2 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    latd2=ig0; latmf2=sm0;
    cxangle(longitude2 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
    lond2=ig0; lonmf2=sm0;
    latd=latd2; latmf=latmf2; lond=lond2; lonmf=lonmf2;
    iur=iur2; idstar=idstar2;
    had=had2; hamf=hamf2;	
   }  
	
skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf("###> Year: %d   Month: %d   Day: %d\n",year,month,day);

strcpy(str1,str0);
printf("                              Year Month Day\n");
printf(" [Default: %d %d %d ] Input: ",year, month,day );

  year  = parse4nth(iterq,1, year );
  month = parse4nth(iterq,2, month);
  day   = parse4nth(iterq,3, day  );
  
  if(year<-1999) year=-1999; // absolute limitation of years
  if(year>5999) year=5999;
  
  if(year<1500 || year>2500)  { printf(" Year outside the range of high precision!\n"); getchar; }
  if(year<=1582) { printf("\n Dates before 1582-OCT-5 are JULIAN calender\n"); getchar(); }
  
//TIME

skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf("\n###> Time-UTC:  %d h %d min %d sec \n", hour,min,sec);

strcpy(str1,str0);
printf("                          Hour Minute Second\n");
printf(" [Default: %d %d %d ] Input: ",
hour, min, sec );

  hour  = parse4nth(iterq,1, hour );
  min   = parse4nth(iterq,2, min);
  sec   = parse4nth(iterq,3, sec  );
  printf(" Time-UTC: %d hour %d min %d sec\n",hour,min,sec);

  if(nobs==1)
 { 
  year1=year; month1=month; day1=day; hour1=hour; min1=min; sec1=sec;
 }  
 if(nobs==2)
 { 
  year2=year; month2=month; day2=day; hour2=hour; min2=min; sec2=sec;
 } 

// Calculate DELTA-T via Fred Espenak, Eclipsewise.com, for y=-1000..3000 ////////////////////////

//Check for J.Meeus p.342-conditions:
   hcheck1=year*10000+month*100+day;
   hcheck2=hour+min+sec;
   if(hcheck1==19920412.0 && hcheck2<=0.1) DeltaT0=0;
   
///////////////// earth conditions ///////////////////////////////////////
if(nobs ==1 ) 
{
   //Check for J.Meeus p.342-conditions:
   hcheck1=ky*10000+km*100+kd;
   hcheck2=kth+ktm+kts;
   if(hcheck1==19920412.0 && hcheck2==0) DeltaT0=0;
   
   //Set EARTH-CONDITIONS
   if(iterq==0)
   earthcon(year,DeltaT0, tempin, pressin,moonpar, &DeltaTT, &temperature, &pressure,&moonorb);
   
   DeltaT0=DeltaTT; tempin=temperature; pressin=pressure; moonpar=moonorb;          
}
//////////////////////////////////////////////////////////////////////////


g003: //Latitude

skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Delta-T : %.2f sec\n",DeltaTT);

jd=julday(year,month,day,hour,min,sec);
GMST0=green0mean(jd); // Greenwich Mean Siderel Time (degrees)
T =(jd-2451545.0)/36525.; // Time without Delta_T in Julian Centuries
Nutation(T ,&delta_psi,&delta_eps,&eps0,&eps); //Full VSOP87-Nutation correction

// Check for 1. or 2. Observation. if nobs=2, longitude also will not be entered.
if(nobs ==1) 
{
jd1=julday(year1,month1,day1,hour1,min1,sec1);
printf("\n###> Latitude:  %d deg %5.2f' \n", latd,latmf);
printf("                            +-Degree Minute \n");
  latitude1=dxangle(latd,latmf);
  cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
  latd1=ig0; latmf1=sm0;
  sdeg1=latd1; smin1=latmf1;  sdeg2=sdeg1; smin2=smin1;
  if(iterq == 0) lies2(sdeg1,smin1,&sdeg2,&smin2);
  latd=sdeg2; latmf=smin2;
  latitude1=dxangle(latd,latmf);
  lat0=99999;
  if(fabs(latitude1) > 90) { printf("\n??? ERROR, Latitude=%f\n",lat0); getchar();  goto g999;}
  
g004: // Longitude

skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Delta-T : %.2f sec\n",DeltaTT);
printf(" Latitude:  %d deg %5.2f' \n", latd,latmf);
printf("\n###>  Longitude: %d deg %5.2f' \n", lond,lonmf);

strcpy(str1,str0);
printf("                            +-Degree Minute\n");

  sdeg1=lond;  sdeg2=sdeg1;
  smin1=lonmf; smin2=smin1;
  if(iterq == 00) lies2(sdeg1,smin1,&sdeg2,&smin2);
  lond=sdeg2;
  lonmf=smin2;
  lon0=dxangle(lond,lonmf);   
  lon0  = norm360(lon0); lon0=lim180(lon0);
  longitude1=lon0;
   
}
if(nobs == 2) 
{
// new version: VERSEGELUNG
//printf(" VERSPOS-Versegelung-Position \n");

//year1=1989; month1=10; day1=19;  hour1=1; min1=45; sec1=11;
//year2=1989; month2=10; day2=19;  hour2=5; min2=0; sec2=50;

jd1=julday(year1,month1,day1,hour1,min1,sec1); 
jd2=julday(year2,month2,day2,hour2,min2,sec2);

//kursav=128;
//velav=15;

skip(25);

printf(" ~~~ DEAD RECKONING Pos.2 from obs.1 ~~~\n\n");
//kursav=kursav2; velav=velav2;

// transport old DR-Long-Lat to new position
printf(" To find position 2 by 'dead reckoning',\n");
printf(" give course-direction and velocity\n");
printf(" while sailing from pos-1 to pos-2:\n");
printf("\n");
printf(" Enter COURSE direction (degrees): \n ");
printf("###> Default: [%5.2f]  ",kursav);
if(iterq==0) kursav = parsefd(1 ,kursav);
printf("\n");
printf(" Now enter the velocity. \n");
printf(" (If negative, it will be interpreted \n");
printf(" as a distance [nm], not as a velocity)\n\n");

printf(" Enter VELOCITY (knots): \n ");
printf("###> Default: [%5.2f]  ",velav);
if(iterq==0) 
{
velav = parsefd(1 ,velav); dist=-velav;
if(velav<0){ printf(" Dist between Pos1 and Pos2= %6.2f[nm]\n",dist); getchar(); }
}
if( abs(kursav) < 1 ) velav=0;
if( abs(velav) <0.01) velav=0;

kursav0=kursav; kursav2=kursav; velav2=velav;
  
//printf("latitude1, longitude1= %f %f\n",latitude1,longitude1); getchar();

//VERSEGELUNG JETZT
errvers=  verspos(jd1,jd2,velav,kursav0,latitude1,longitude1,&latitude2,&longitude2) ; 
if(errvers==1) printf(" ??? ERROR- Distance too large\n");
if(errvers==2) printf(" ??? ERROR- Latitude > 89 deg\n");
if(errvers!=0) 
{
	printf(" press ENTER to restart!\n");
	getchar();  nobs=1; goto g0000;
}
//printf("latitude2, longitude2= %f %f\n",latitude2,longitude2); 

  cxangle(latitude2 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
  latd=ig0;
  latmf=sm0; 
  lat0=latitude2;
  if(latd<0) latmf=-fabs(latmf);
 
  cxangle(longitude2, &ig0,&im0,&imr0,&isr0,&sm0,&ss0); 
  lond=ig0;
  lonmf=sm0;
  lon0  = longitude2; 
  lon0  = norm360(lon0);
  if(lond<0) lonmf=-fabs(lonmf);

//printf("Knopp: -49 g 47.1,  091 g 37.3  ### press ENTER:\n"); 
//getchar();
  
}

  
g005: //Sextant correction indb

skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Delta-T : %.2f sec\n",DeltaTT);
if(nobs==1)
{
printf(" Latitude:  %d deg %5.2f' \n", latd,latmf);
printf(" Longitude: %d deg %5.2f' \n", lond,lonmf); 
//getchar();
}
if(nobs==2)
{
printf(" Course: %2.2f  Velocity: %2.2f\n",kursav,velav);
printf(" DR-Latitude:  %d deg %5.2f' \n", latd,latmf);
printf(" DR-Longitude: %d deg %5.2f' \n", lond,lonmf);
//getchar();
}

///////////////////Planets or starts //////////////////////
skip(25);
strcpy(str1,str0);
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf(" Celestial object: Sun, Moon, Planet, Star?\n");
printf("\n");
printf(" 0=SUN lower rim,    1=UPPER rim of SUN\n");
printf(" 2=MOON lower rim,   3=UPPER rim of MOON\n");
printf(" 4=VENUS, 5=MARS 6=JUPITER 7=SATURN 8=*STAR*\n");
printf("\n");
printf("###>  [Default: %d  ]   Input: ", iur);
  
        iur  = abs(parse4nth(iterq,1, iur )); 
if(iur == 0) printf(" => Sun lower rim\n");
if(iur == 1) printf(" => Sun upper rim\n");
if(iur == 2) printf(" => Moon lower rim\n");
if(iur == 3) printf(" => Moon upper rim\n");
if(iur == 4) printf(" => Planet Venus\n");
if(iur == 5) printf(" => Planet Mars\n");
if(iur == 6) printf(" => Planet Jupiter\n");
if(iur == 7) printf(" => Planet Saturn\n");
if(iur == 8) printf(" => Star (see catalog)\n");

if(iur==8)
 {
    idstar= starlist(iterq,idstar);
    if(nobs==1) idstar1=idstar; if(nobs==2) idstar2=idstar;
 }
 
///////////////////////////////////////////////////////////
if(nobs==1)
{
  skip(25);
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs); 	
printf(" SEXTANT-Data:\n");
if(iur == 0) printf(" => Sun lower rim\n");
if(iur == 1) printf(" => Sun upper rim\n");
if(iur == 2) printf(" => Moon lower rim\n");
if(iur == 3) printf(" => Moon upper rim\n");
if(iur == 4) printf(" => Planet Venus\n");
if(iur == 5) printf(" => Planet Mars\n");
if(iur == 6) printf(" => Planet Jupiter\n");
if(iur == 7) printf(" => Planet Saturn\n");
if(iur == 8) printf(" => Star %d \n",idstar);
  printf("\n###> Index correction Ic: %.1f' \n",indb);
  strcpy(str1,str0);
  printf("                         +-Minutes \n");
  printf(" [Default: %.1f  ] Input: ",indb);
  if(iterq==0) indb  = parsefd(1 ,indb);
  //indb  = parse4nth(iterq,1, indb );
}

g006: //Sextant correction aug= height of eye
if(nobs==1) {lat0=latitude1; lon0=longitude1;}
if(nobs==2) {lat0=latitude2; lon0=longitude2;}
cxangle(lat0 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
latd=ig0; latmf=sm0;
cxangle(lon0 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
lond=ig0; lonmf=sm0;


skip(25);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~ \n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Latitude:  %d deg %5.2f' \n", latd,latmf);
printf(" Longitude: %d deg %5.2f' \n", lond,lonmf);
printf(" Index corr. Ic: %.1f'\n",indb);
printf("\n###> Height of eye: %.2f m \n",aug);

if(nobs==1)
{
strcpy(str1,str0);
printf("                         Meters \n");
printf(" [Default: %.2f  ] Input: ",aug);

  //aug  = abs(parse4nth(iterq,1, aug )); 
  if(iterq==0) aug  = parsefd(1 ,aug);
  if(aug < 0.) aug=0. ; if(aug > 40.) aug=40.;
}

g007:
//Sextant observation

skip(25);
if(nobs == 1 ) hamf=hamf1;
if(nobs == 2 ) hamf=hamf2;

printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~ \n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Latitude:  %d deg %.2f' \n", latd,latmf);
printf(" Longitude: %d deg %.2f' \n", lond,lonmf);
printf(" Indx corr. Ic: %.1f' Height of eye: %.1fm \n",indb,aug);

printf("\n###> SEXTANT measurement: Hs= %d deg %3.2f'\n", had,hamf);

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

strcpy(str1,str0);
printf("                          +-Degrees  Min.\n");
//printf(" [Default: %d %d ]   Input: ", had, hamf );

  sdeg1=had;   sdeg2=sdeg1;
  smin1=hamf;  smin2=smin1;
  if(iterq==0) lies2(sdeg1,smin1,&sdeg2,&smin2);
  had=sdeg2;
  hamf=smin2;   //double
  
  hamf=smin2; // integer
  if(nobs ==1 ) hamf1=hamf;
  if(nobs ==2 ) hamf2=hamf;
  ha0= floor(sdeg2+0.00000001)+smin2/60.; //Hoehe, noch ohne Beschickung
                                                           
/////  EPHEMERIDEN und SEXTANT-Rechnung, Bestimmung einer Standlinie ///////////////////////
// neue version +-1 arcsecond, fast VSOP87! Jean Meeuas p.169 u. Appendix III.

//~~~~ From here on, GHA and Declination are calculated

pigrd = 360. / (2. * 3.14159265359);
grdpi = 2. * 3.14159265359 /360. ;
xxx = 0.;

//transpose data to ephemerides-calculation 
ky = year;
km = month;
kd = day;
kth = hour;
ktm = min;
kts = sec;

//printf(" \n Sun-Ephemeris-3. Genauigkeit ~2040 entspricht \n");
//printf("  etwa Nautical Almanac, sowohl GHA wie DECLIN.\n");
	
///////////hmk0///////  EPHEMERIDEN der SONNE des Mondes der Planeten und Sterne /////////// 

// Calculate the EPHEMERIDES of SUN, MOON, Planets ans Stars  //////////////////////////////

suneph(DeltaTT,ky,km,kd,kth,ktm,kts,&DEC0,&GHA0,&GAST0,&RA0,&eqot0,&HPsun,&SDsun,&jdesun); 
RAsun=RA0; 

//suneph is always calculated!

if(nobs==1) idstar=idstar1; if(nobs==2) idstar=idstar2;

if(iur>3 && iur<8)  idplanet=iur;
if(iur==2 || iur==3) mooneph(moonpar,DeltaTT,ky,km,kd,kth,ktm,kts,&DEC0,&GHA0,&GAST0,&RA0,&HPmoon,&SDmoon);
if(iur>3 && iur<8)   planeteph(idplanet,DeltaTT,ky,km,kd,kth,ktm,kts,&DEC0,&GHA0,&GAST0,&RA0,&hpar1); 
if(iur==8)  idstar=  starseph(iterq,idstar,DeltaTT,ky,km,kd,kth,ktm,kts,&DEC0,&GHA0,&GAST0,&RA0,&shastar0);
if(nobs==1) idstar1=idstar; if(nobs==2) idstar2=idstar;
 
////////////////// END:  EPHEMERIDEN von SONNE, Mond, Planeten, Sterne END ////////////////////////// 

//SEXTANT  GesamtBESCHICKUNG, Hoehe: he = ha + gb (in arc-minutes)
// sonnenunterrand  (iur!=0: sonnenoberrand!) Helmut Knopp
      //HPsun=8.79/60. ; //Horizontal-Parallaxe arcmin; Sonne =8.79 ArcSecs.
      
      HPall=0;
      SDiam=0;
      if(iur==0||iur==1)  { HPall=HPsun;  SDiam=SDsun; }
      if(iur==2||iur==3)  { HPall=HPmoon; SDiam=SDmoon; }
      if(iur>3) HPall=hpar1;
      if(iur>7) HPall=0;
      
// GesamtBESCHICKUNG, inkl Indexberichtigung  
      double Hs,Happ,Hcorr,Hcalc; 
	  
	  if(nobs==1) {lat0=latitude1; lon0=longitude1; az0=azim1;}
      if(nobs==2) {lat0=latitude2; lon0=longitude2; az0=azim2;}

      HcAz(lat0,lon0,DEC0,GHA0,&LHA0,&Hcalc,&az0); // calculate Theoretical Sextant-Height Hcalc and Azimuth
	    	         
	  he0 = BESCHICKUNG(1,iur,lat0,az0, ha0, indb, temperature, pressure,aug,SDiam,HPall,&HP,&dip,&r,&ur,&gb); 	     
	  he0  = fabs(he0);
      cxangle(he0 , &hed,&im0,&hem,&isr0,&sm0,&ss0);
      hemf = (he0 - hed)*60;
      SDa=ur; // augmented Semi-Diameter of Sun, Moon.
     
      Hs=ha0;     // direct obseration lower/upper limb; change notation of sextant heights
      Happ=Hs+indb/60.-dip/60.+SDa/60;  // Apparent Height of star
      Hcorr=he0;                 // Corrected Height = observed geocentric height  
      Hcalc=0.;                 // Theoretical exact Height for given position and time, value see below. 
      
g020:   //Hier Ansprungmarke f�r die versegelte Position:
    
//calculate delta-H and Azimut
HcAz(lat0,lon0,DEC0,GHA0,&LHA0,&Hcalc,&az0); // calculate Theoretical Sextant-Height Hcalc and Azimuth

hc0=Hcalc;
cxangle(hc0 , &hcd,&hcm,&imr0,&isr0,&hcmf,&ss0);
hdif= 60.* ( he0-hc0 );
// if(hcd <0) { az0=-9999.9; hdif=9999.9; }
/////  ENDE: EPHEMERIDEN und SEXTANT-Rechnung, Bestimmung einer Standlinie, ENDE  ////////////////////////////

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
if(iverseg ==1 ) goto g030; 

g008:

//Sextant output
cxangle(lat0 , &latd,&im0,&imr0,&isr0,&latmf,&ss0);
cxangle(lon0 , &lond,&im0,&imr0,&isr0,&lonmf,&ss0);

skip(15);
printf(" Astro-Navigation by SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation ~~~~~~~~~~~~~\n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Latitude:  %d deg %.2f' \n", latd,latmf);
printf(" Longitude: %d deg %.2f' \n", lond,lonmf);
printf(" Index corr. Ic: %.1f'  Height of eye: %.2fm \n",indb,aug);
  cxangle(Hs   , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant viewed: Hs= %d deg %3.2f'\n", ig,sm0);
  cxangle(Happ , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant appar.: Ha= %d deg %3.2f'\n", ig,sm0);
  cxangle(Hcorr, &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant corr. : Ho= %d deg %3.2f'\n", ig,sm0);
  cxangle(hc0 , &hcd,&hcm,&imr0,&isr0,&hcmf,&ss0);
if(iur == 0 || iur == 1)
printf(" Sext. calculat: Hc= %d deg %3.2f' SUN_%d\n", hcd,hcmf,iur);  	
if(iur == 2 || iur == 3)
printf(" Sext. calculat: Hc= %d deg %3.2f' Moon_%d\n", hcd,hcmf,iur);
if(iur >3 && iur < 8)
printf(" Sext. calculat: Hc= %d deg %3.2f' Planet_%d\n", hcd,hcmf,iur);
if(iur == 8)
printf(" Sext. calculat. Hc= %d deg %3.2f' Star_%d\n", hcd,hcmf,idstar);
printf("                 Hc= %d deg %d' %.2f''\n", hcd,hcm,ss0);

if(hdif < 0) printf(" ==> Position = %6.2f miles, away from star\n", hdif);
else if (hdif < 1999.) printf(" ==> Position = %6.2f miles closer to star\n", hdif);
else printf(" ==> ???  Error in the measured values ??? \n",az0);
printf(" ==> Azimut   = %6.2f degrees\n",az0);
printf(" ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n");
 
//Ergebnis speichern	
if(nobs == 1){
  	//printf(">> 2979 filewrite 1 starten\n"); getchar();
	fptr=fopen("astronav0x1.txt","w");
	has=0;
	fprintf(fptr,"%d %d %d \n",year,month,day);
    fprintf(fptr,"%d %d %d \n",hour1, min1, sec1);
    fprintf(fptr,"%d %f \n",latd1,latmf1);
    fprintf(fptr,"%d %f \n",lond1,lonmf1);
    fprintf(fptr,"%d %d \n",iur1,idstar1);
    fprintf(fptr,"%d %f %d \n",had1,hamf1,has);
    fprintf(fptr,"%.2f %.2f \n",indb,aug);
    fprintf(fptr,"%.2f %.2f %.2f \n",hdif,azim1,az);
    fprintf(fptr,"%.2f %.2f \n",temperature,pressure);   	
	fclose(fptr);
	year1=year; month1=month; day1=day;
    hour1=hour; min1=min; sec1=sec;
    latd1=latd; latmf1=latmf; lond1=lond; lonmf1=lonmf;
    iur1=iur; idstar1=idstar;
    had1=had; hamf1=hamf;
    
	sdat1 = day;
	sh1=hour; sm1=min; slad1=latd; slamf1=latmf; slod1=lond; slomf1=lonmf;
	hdif1 = hdif; azim1=az0;
}

if(nobs == 2){
	//printf(">> 3005 filewrite 2 starten\n"); getchar();
	//Datei erzeugen mit Default Werten
   	fptr=fopen("astronav0x2.txt","w");
   	has=0;
   	fprintf(fptr,"%d %d %d \n",year,month,day);
    fprintf(fptr,"%d %d %d \n",hour2, min2, sec2);
    fprintf(fptr,"%d %f \n",latd2,latmf2);
    fprintf(fptr,"%d %f \n",lond2,lonmf2);
    fprintf(fptr,"%d %d \n",iur2,idstar2);
    fprintf(fptr,"%d %f %d \n",had2,hamf2,has);
    fprintf(fptr,"%.2f %.2f \n",indb,aug);
    fprintf(fptr,"%.2f %.2f %.2f \n",hdif,azim2,az);
    fprintf(fptr,"%.2f %.2f \n",kursav,velav);   	
	fclose(fptr);
	year2=year; month2=month; day2=day;
    hour2=hour; min2=min; sec2=sec;
    latd2=latd; latmf2=latmf; lond2=lond; lonmf2=lonmf;
    iur2=iur; idstar2=idstar;
    had2=had; hamf2=hamf; has2=has;
    
	sh2=0; sdat2=day; if(sdat2 != sdat1) sh2=24;
	sh2=sh2+hour; sm2=min; slad2=latd; slam2=latmf; slod2=lond; slom2=lonmf;
	azim2=az0;
}
printf(" ... press ENTER to continue:\n"); 
if(iterq==0) getchar();

//  MMAINOUTPUTMMAIN mainoutputmain preparation of output
   //finaloutput ephemeris
JDE=jdesun;
printf(" EPHEMERIDES of celestial object\n");
printf(" ========== JDE = %15.7f ============\n",JDE);
cxangle(GHA0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
if(iur<2) printf(" GHA of SUN = %d deg %d' %.2f''\n",ig,im,ss0);
if(iur==2||iur==3) printf(" GHA of MOON = %d deg %d' %.2f''\n",ig,im,ss0);
if(iur==4) printf(" GHA of VENUS = %d deg %d' %.2f''\n",ig,im,ss0);
if(iur==5) printf(" GHA of MARS = %d deg %d' %.2f''\n",ig,im,ss0);
if(iur==6) printf(" GHA of JUPITER = %d deg %d' %.2f''\n",ig,im,ss0);
if(iur==7) printf(" GHA of SATURN = %d deg %d' %.2f''\n",ig,im,ss0);
if(iur==8)
  {
  	if(idstar==43)
  	 {printf(" GHA_STAR"); printf("%s",stlist[idstar]); printf("= %d deg %.2f'\n",ig,sm0);}
    else
	 {printf(" GHA_STAR"); printf("%s",stlist[idstar]); printf("= %d deg %d' %.2f''\n",ig,im,ss0);}
  }


printf(" GHA (dec.) = %.8f deg \n",GHA0);

cxangle(LHA0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" LHA ship  = %d deg %d' %.2f''\n",ig,im,ss0);

cxangle(DEC0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Declination = %.8f deg\n",DEC0);
printf(" Declination = %d deg %d' %.2f''\n",ig,im,ss0);


//if(iur!=8)
{
 RA0=norm360(RA0);
 cxangle(RA0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
 printf(" Rectascension = %.8f deg \n", RA0);

 RA0h=RA0/15.;

 cxangle(RA0h , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
 printf(" Rectascension = %d hour %d m %.2f s\n", ig, im, ss0);
}
if(iur==8)
{ 
 SHA0=norm360(shastar0);
 cxangle(SHA0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
 printf(" SHA (star)= %d deg %d' %.2f'' \n", ig, im, ss0);
}

cxangle(GAST0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" GAST (appar. Sid.Time) = %.8f deg \n", GAST0);
printf(" GAST = 'Aries'         =  %d deg %d' %.2f'' \n", ig, im, ss0);

cxangle(GMST0 , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" GMST  (mean Sid.Time)  =  %d deg %d' %.2f'' \n", ig, im, ss0);

// Equation of Time : Zeitgleichung (J.Meeus p.87:L0 at T=0 different from GMST p.87!!)
//  but now: see Wikipedia -definition
eqoth=equ_of_time(hour,min,sec,GAST0,RAsun);

cxangle(eqoth, &ig ,&im ,&imr0,&is ,&sm0,&ss0);
h1=(eqoth*60-im)*60; if(im!=0) h1=fabs(h1);

printf(" EoT= %dm %.2fs;   DELTA-T = %.2f sec(+-1)\n",im,h1,DeltaTT); 
printf(" delta_psi=%.2f''; delta_eps=%.2f''\n",delta_psi*3600,delta_eps*3600); 
printf(" Ecliptic Obliquity eps=%.8f deg\n",eps); 
  cxangle(Happ, &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sext.: Ha=%dd%.1f' Ho=%dd%.1f' Hcalc=%dd%.1f'\n", ig,sm0, hed,hemf,hcd,hcmf);
printf(" S_Correction= %.2f'; Index= %.1f' SDa=%.2f'\n",gb,indb,SDa);
printf(" Dip= %.2f' Refr= %.2f' HP= %.2f'[max:%.2f]\n",dip,r,HP,HPall);
printf(" Precision:+-1'',see: NASA-JPL 'HORIZONS'\n");
printf(" =============================================\n");
printf("        ... press ENTER to continue, or:\n");
//getchar();

//-------------- ENDE des 1. Teils -------------------------------------

g998:
	
if(nobs == 1)	
  printf(" ### ENTER: 1=repeat  9=stop: ");
else  
  printf(" ### ENTER: 2=repeat[2.obs.] :");
  
kkk = 999;

if(iterq==0) kkk= parsenth(1,kkk);                //read the input
if(iterq!=0 && nobs==1) kkk=2;
if(iterq!=0 && nobs==2) kkk=3;

if(kkk<0) goto g998; 
//if(kkk>9) goto g998; // when is is swithed on, program makes a pause here.

//Decision for continuation --------------------------------------------

if(nobs ==1 ){
 if( kkk == 999 ) kkk=2;
   if( kkk == 0 ) goto g0010;
   if( kkk == 1 ) goto g0010;
   if( kkk == 2 ) { nobs=2;  goto g0000; }
   if( kkk >  2 ) goto g999; //stop
}

if(nobs ==2 ){
 if( kkk == 999 ) kkk=3;
  if( kkk == 0 ) goto g0010;
  if( kkk == 1 ) { nobs=1;  goto g0000; }
  if( kkk == 2 ) goto g0012;
  if( kkk == 3 ) goto g500;
  if( kkk >  3 ) goto g999; //stop
}

g500:  //MARK 3    ######################################

//VERSEGELUNG von Pos-1 nach Pos-2 mit velav und kursav
// dabei Korrektur von Pos 2 = latitude0, longitude0 !
isw=1; dist=0; 
if(velav<0) { dist=-velav; isw=0; }

latbasic  = slad1+slamf1/60;
lonbasic = slod1+slomf1/60;

// NEUE POSITION
errvers=  verspos(jd1,jd2,velav,kursav0,latbasic,lonbasic,&latitude0,&longitude0) ;

cxangle(latitude0 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
latd=ig0;
latmf=sm0;
cxangle(longitude0, &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
lond=ig0;
lonmf=sm0;

lat0=latitude0;
lon0=longitude0;
//Jetzt haben wir eine neue versegelte Position fuer Beobachtungen 1 u. 2 ! 
//Dazu ist eine Neuberechnung der Standlinien-Abweichung noetig!
//anschliessend Geschwindigkeit auf NULL setzen!
iverseg=1; goto g020;  //Ruecksprung erfolgt nach g030:

g030:
iverseg=0;

skip(25);
printf(" Renewing Position 2 after sailing from Pos. 1\n");
printf(" Astro-Navigation by SUN, SEXTANT and CLOCK \n");
printf(" ~~~~~~~~~~~ [%d.] Observation FINAL ~~~~~~~~ \n\n",nobs);
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC:  %d h %d min %d sec \n", hour,min,sec);
printf(" Latitude:  %d deg %.2f' \n", latd,latmf);
printf(" Longitude: %d deg %.2f' \n", lond,lonmf);
printf(" Index corr. Ic: %.2f'  Height of eye: %.2fm \n",indb,aug);
  cxangle(Hs   , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant viewed:  Hs= %d deg %3.2f'\n", ig,sm0);
  cxangle(Happ , &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant appar.:  Ha= %d deg %3.2f'\n", ig,sm0);
  cxangle(Hcorr, &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant corr. :  Ho= %d deg %3.2f'\n", ig,sm0);
  cxangle(Hcalc, &ig ,&im ,&imr0,&is ,&sm0,&ss0);
printf(" Sextant calcul:  Hc= %d deg %3.2f'\n", ig,sm0);  	
printf(" Course was: %5.0f  Velocity: %4.2f \n",kursav,velav);
if(hdif < 0) 
 printf(" ==> Position = %6.2f miles, away from sun\n", hdif);
else if (hdif < 999.)
 printf(" ==> Position = %6.2f miles closer to sun\n", hdif);
else
 printf(" ==> ???  Error in the measured values ??? \n",az0); 
 printf(" ==> Azimut   = %6.2f degrees  \n",az0); 
 
	sh2=0; sdat2=day; if(sdat2 != sdat1) sh2=24;
	sh2=sh2+hour; sm2=min; slad2=latd; slam2=latmf; slod2=lond; slom2=lonmf;
	hdif2=hdif; azim2=az0;  kursav2=kursav; velav2=velav; 

// Nun ist latitude0, longitude0 der Punkt, auf den Punkt 1 versegelt wurde, 
// und von dem aus folglich auch die 2. Observation gemessen wurde.
// Ausgehend von Latitude0, longitude0 Positionspunkte 1 u 2 
// in Richtung der jeweiligen Azimute auf die Standlinien markieren: 
// latxx1,lonxx1, latxx2,lonxx2:

//ERROR AZIMUT-CHECK:
if(abs(azim1) > 360 || abs(azim2) > 360 ) 
{
	printf("\n ??? ERROR: Azimut1,2: %f %f\n",azim1,azim2);
	printf(" press ENTER to restart!\n");
	getchar();  iterq=0; nobs=1; goto g0000;
}

isw=0; 
dist=hdif1;  kursaz=azim1;
shiftpos(isw,dist,sh1,sm1,sh2,sm2,latitude0,longitude0,velav,kursaz,&latxx1,&lonxx1);

dist=hdif2;  kursaz=azim2;
shiftpos(isw,dist,sh1,sm1,sh2,sm2,latitude0,longitude0,velav,kursaz,&latxx2,&lonxx2);

//ERROR LATITUDE:
if(abs(latxx1) > 89 || abs(latxx2) > 89 ) 
{
	printf("\n ??? ERROR: calc. Latitude > 89: %f %f\n",latxx1,latxx2);
	printf(" press ENTER to restart!\n");
	getchar(); iterq=0; nobs=1; goto g0000;
}

// Aktuelle Position nach SHIFT
// Bestimmun der Position durch Schnitt der standlinien

ier1=angcheck(azim1); ier2=angcheck(azim2);
wink1=(azim1-90.)*degrad; 
slope1=9999; if(ier1==0) slope1=tan(wink1);
wink2=(azim2-90.)*degrad;
slope2=9999; if(ier2==0) slope2=tan(wink2);

//Konvertiere Longitude zu Y-Koordinaten (gleiches Mass wie Latitude)
x1= latxx1;        x2 =latxx2;  
xav =(x1+x2)/2.; 
ynorm=cos(xav*degrad);
y1= lonxx1*ynorm; y2=lonxx2*ynorm;

//Loese Lineares 2x2 Gleichungssystem fuer den Geradenschnitt
//Fallunterscheidung
icase=0;
if((ier1 != 0) && (ier2 == 0)) icase=1;
if((ier1 == 0) && (ier2 != 0)) icase=2;
if((ier1 != 0) && (ier2 != 0)) icase=3;
if(  fabs(fabs(slope1)-fabs(slope2)) < 0.01  ) icase=4;

//Zwei Geraden:  y=y1+slope1*(x-x1);  y=y2+slope1*(x-x2);
//printf("Gerade1: slope1= %f x1= %f y1= %f\n",slope1,x1,y1);
//printf("Gerade2: slope2= %f x2= %f y2= %f\n",slope2,x2,y2);
//getchar();

if(icase ==0 ){  //NORMAL
//printf(">CASE 0\n");
x0=(slope2*x2-slope1*x1 + y1-y2)/(slope2-slope1);
y0=y1+slope1*(x0-x1);
goto g600;	
}

if(icase ==1 ){ // SLOPE1 = unendlich
//printf(">CASE 1\n");
x0=x1;
y0=y2+slope2*(x1-x2);
goto g600;	
}

if(icase ==2 ){ // SLOPE2 = unendlich
//printf(">CASE 2\n");
x0=x2;
y0=y1+slope1*(x2-x1);
goto g600;	
}

if(icase ==3 ){ // SLOPE1 u. SLOPE2  = unendlich
printf("\n");
printf("??? Error 3, bad intersection of position lines!\n");
iersum=iersum+1;
getchar();
x0=x2; y0=y2;
goto g600;	
}

if(icase ==4 ){ //beide Slopes fast parallel
printf("\n");
printf("??? Error 4, bad intersection of position lines!\n");
iersum=iersum+1;
getchar();
x0=x2; y0=y2;
goto g600;	
}
// Geradenschnitt erledigt: x0,y0 ist die ermittelte Position

g600: latitudep=x0; longitudep=y0/ynorm; longitudep=lim180(longitudep);

xpos=x0; ypos=y0;
x0=latitude0; y0=longitude0*ynorm;

cxangle(latitudep , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
latd=ig0;
latmf=sm0;
cxangle(longitudep, &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
lond=ig0;
lonmf=sm0;

//SUNRISE SUNSET Azimuths and DAWN   for the final position. Vereinfachte Rechnug +- 2 Minuten genau
sunrise=suntime(year,month,day,longitudep,latitudep, &srd, &srm, &ssd, &ssm, &Ar,&As,&daemm);
 
skip(25);
printf("   Astro-Navigation by  SEXTANT and CLOCK\n");
printf(" ~~~~~~~~~~~~~~~ FINAL RESULT ~~~~~~~~~~~~~\n");
printf(" Year: %d   Month: %d   Day: %d\n",year,month,day);
printf(" Time-UTC: %dh %dm %ds, delta_T: %.2f\n", hour,min,sec,DeltaTT);
printf(" JulianDay [incl.Del_T]= %.7f\n",JDE);
printf(" Temperature= %.1fC  Pressure= %.1fhPa\n",temperature,pressure);
if(fabs(dist)<1)
printf(" SUN_R/S(Az)=%dh%dm(%d) %dh%dm(%d) D~%dm\n",srd,srm,Ar,ssd,ssm,As,daemm);
printf(" MOON: high precision by LEA406b-tables.\n");

h1=(jd2-jd1)*24;
h2=velav*h1;
printf(" Tdif(hours)= %3.2f Dist(nm)= %2.2f\n",h1,h2);
if(velav>=0) printf(" Course(deg)= %2.0f Veloc(knots)= %2.2f\n",kursav2,velav);
else         printf(" Course(deg)= %2.0f Distance(nm)= %2.2f\n",kursav2,-velav);
if(abs(h1)>8760) printf(" ??? Very large Time-Diff. ???\n");
if(abs(h2)>3000) printf(" ??? Very large Distance   ???\n");

dist = bestver(1,x0,y0,xpos,ypos,ynorm);
angle= bestver(2,x0,y0,xpos,ypos,ynorm);
printf("\n");
printf(" --> Deviation from last DR-Position\n");
printf("    Distance = %5.1f nautical miles\n",dist);
printf("    Direction= %5.1f degrees\n",angle);

//Check for dist vs. radius of position-circle
if(dist > 10*abs(90-had1)) printf(" ?? Displacement too big, St. Hilaire?\n");
printf("\n");

if(fabs(dist)<mindist) 
printf(" ==> FINAL POSITION Fixed:\n");
else printf(" ==> Approximate POSITION Fixed:\n"); 
printf("    Latitude  = %4d deg %5.2f' \n",latd,latmf);
printf("    Longitude = %4d deg %5.2f' \n",lond,lonmf);
if(fabs(dist)<mindist) printf(" This is FINAL POSITION, devi.< 1nm\n");
if(iersum != 0) {
printf(" ??? Observations not independent ???\n");
printf(" ??? Result probably not good ???\n");
}
printf("\n");
iersum=0; 

g801:
	
if(fabs(dist)<mindist) 
{
	latd1=latd; latmf1=latmf; latd2=latd; latmf2=latmf;
    printf(" ## ENTER: 1=restart, 9=stop:");
}
else printf(" ## ENTER: 1=restart, 4=iterate, 9=stop:");

iterq=0;
kkk = -1;
kkk= parsenth(1,kkk);                //read the input
if(kkk== 0) goto g500;
if(kkk== 1) { iterq=0; nobs=1; goto g0000; }
if(kkk== 4){ iterq=1; skip(25);  printf(" ITERATION started:\n"); 
printf(" Repeat all steps automatically, \n");
printf(" by pressing ENTER.\n");
printf(" You may repeat the iteration several times,\n");
printf(" until there is no more change\n"); 
printf(" in the FINAL POSITION.\n\n");
printf(" ...now press ENTER to continue:\n"); getchar();

kursbak=kursav0-180.0; if(kursbak<0.) kursbak=kursbak+360.0; 
printf("kursav0 kursbak, velav %f %f %f\n",kursav0,kursbak,velav);
// Now we change the first estimated position with reference to the obtained FIX:
errvers=  verspos(jd1,jd2,velav,kursbak,latitudep,longitudep,&latitude1,&longitude1); 

cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
latd1=ig0;
latmf1=sm0;
cxangle(longitude1, &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
lond1=ig0;
lonmf1=sm0;

latd2=latd; latmf2=latmf;
lond2=lond; lonmf2=lonmf;
nobs=1; goto g0000; }

if(kkk== 9) goto g999a; 
goto g801;

g999a:

// Print both files

cxangle(latitude1 , &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
latd1=ig0;
latmf1=sm0;
cxangle(longitude1, &ig0,&im0,&imr0,&isr0,&sm0,&ss0);
lond1=ig0;
lonmf1=sm0;

printf("\n>> fixed: write astronav0x1.txt \n"); 
	fptr=fopen("astronav0x1.txt","w");
	has=0; hdif=0.; az=0.;
   	fprintf(fptr,"%d %d %d \n",year,month,day);
    fprintf(fptr,"%d %d %d \n",hour1, min1, sec1);
    fprintf(fptr,"%d %f \n",latd1,latmf1);
    fprintf(fptr,"%d %f \n",lond1,lonmf1);
    fprintf(fptr,"%d %d \n",iur1,idstar1);
    fprintf(fptr,"%d %f %d \n",had1,hamf1,has);
    fprintf(fptr,"%.2f %.2f \n",indb,aug);
    fprintf(fptr,"%.2f %.2f %.2f \n",hdif,azim1,az);
    fprintf(fptr,"%.2f %.2f \n",temperature,pressure);
	fclose(fptr);
	
printf(">> fixed: write astronav0x2.txt \n"); 	
   	fptr=fopen("astronav0x2.txt","w");
   	has=0;
   	fprintf(fptr,"%d %d %d \n",year,month,day);
    fprintf(fptr,"%d %d %d \n",hour2, min2, sec2);
    fprintf(fptr,"%d %f \n",latd2,latmf2);
    fprintf(fptr,"%d %f \n",lond2,lonmf2);
    fprintf(fptr,"%d %d \n",iur2,idstar2);
    fprintf(fptr,"%d %f %d \n",had2,hamf2,has);
    fprintf(fptr,"%.2f %.2f \n",indb,aug);
    fprintf(fptr,"%.2f %.2f %.2f \n",hdif,azim2,az);
    fprintf(fptr,"%.2f %.2f \n",kursav,velav);
	fclose(fptr);

g999:  

printf(" \n");
printf(" The program is based on Jean Meeus's book:\n");
printf(" Astronomical Algorithms, 2nd edition. Data:\n");
printf(" Earth,Planets: VSOP87D; Stars: FK5-catalog.\n");
printf(" CELNAV.DE/AstroAlmanac: H.Umland, Germany.\n");
printf(" Nutation Model IAU1980. Moon-precision:\n");
printf(" LEA406b by S.Kudryavtsev.  Delta-T as by\n");
printf(" F.Espenak,P.Hirose. Stars comp: S.Moshier.\n");
printf(" Precision about +- 1'',years 1800-2200,see:\n");
printf(" NASA-JPL-HORIZONS-prog., Mod:[DE431],USA\n");
printf(" \n");

 printf(" [Heiner Mueller-Krumbhaar; Ephemerides\n");
 printf(" program with Henning Umland, March 2021]\n");   
       
printf("\n           --- END ---\n");
getchar(); 
return 0; 
//#########    END of MAIN    ################################
}
